
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear

local dep_var act_log_ld


* Check effect by AEZ (agro-ecological zone) of country

**** Ethiopia *****
* 1 - Tropic-cool/semiarid
* 2 - Tropic-cool/subhumid
* 3 - Other AEZs

* summary stats by aez
use "$newdata/ET panel data merged", replace
bysort hhid: egen ae_temp = max(aez)
replace aez = ae_temp

gen per_maize = acres_maize / acres
gen per_sorghum = acres_sorghum /acres
forvalues i=1/3 {
	estpost sum hhsize_phase acres owned_acres ld_cult_kids ld_harv_kids maize sorghum fertilized irrigated any_sales any_oxen per_maize per_sorghum if aez==`i'
	est sto et_aez_stats`i'
}
label var hhsize_phase "Labor endowment, with kids"
label var acres "Acres cultivated"
label var owned_acres "Acres owned"
label var ld_cult_kids "Labor demand - cultivation"
label var ld_harv_kids "Labor demand - harvest"
label var maize "Plant any maize"
label var sorghum "Plant any sorghum"
label var per_maize "Percent acres with maize"
label var per_sorghum "Percent acres with sorghum"
label var fertilized "Use any fertilizer"
label var irrigated "Use any irrigation"
label var any_oxen "Use oxen"
label var any_sales "Sell any crops"


esttab et_aez_stats* using "$path/output/ET_aez_stats.tex", cell(mean(fmt(%11.2fc %11.2fc %11.2fc %11.2fc %11.2fc)) sd(par)) ///
		mtitles("Tropic-cool/semiarid" "Tropic-cool/subhumid" "Other AEZs") posthead("\hline") nodep ///
		stats(N, fmt(%9.0fc) labels("Number of obs.")) label replace fragment tex

* symmetric results - all aezs
use "$newdata/ET_reg_ready", clear
egen ea_wave = group(ea1 wave)
gen harv = activity==1
gen change_harv = diff_$hhsize_var*harv
gen zone2 = ae_zone==2
gen zone3 = ae_zone==3
gen change_zone2 = diff_$hhsize_var * zone2
gen change_zone3 = diff_$hhsize_var * zone3
gen harv_zone2 = harv*zone2
gen harv_zone3 = harv*zone3
gen change_harv_zone2 = change_harv*zone2
gen change_harv_zone3 = change_harv*zone3
foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
	gen `var'_zone2 = zone2 * `var'
	gen `var'_zone3 = zone3 * `var'
}

reg diff_`dep_var' diff_$hhsize_var harv change_harv zone2 zone3 change_zone2 change_zone3 harv_zone2 harv_zone3 change_harv_zone2 change_harv_zone3 diff_log_A* diff_sh*, cluster(ea_wave)
local ET_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local ET_sym_chg_le_p = r(p)
local ET_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test diff_$hhsize_var + change_harv = 0
local ET_sym_chg_harv_p = r(p)
local ET_sym_chg_le2_b = _b[diff_$hhsize_var] + _b[change_zone2]
test diff_$hhsize_var + change_zone2 =0
local ET_sym_chg_le2_p = r(p)
local ET_sym_chg_harv2_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[change_zone2] + _b[change_harv_zone2]
test diff_$hhsize_var + change_harv + change_zone2 + change_harv_zone2 = 0
local ET_sym_chg_harv2_p = r(p)
local ET_sym_chg_le3_b = _b[diff_$hhsize_var] + _b[change_zone3]
test diff_$hhsize_var + change_zone3 =0
local ET_sym_chg_le3_p = r(p)
local ET_sym_chg_harv3_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[change_zone3] + _b[change_harv_zone3]
test diff_$hhsize_var + change_harv + change_zone3 + change_harv_zone3 = 0
local ET_sym_chg_harv3_p = r(p)
local ET_sym_obv = e(N)
local ET_sym_r2 = e(r2)
test _b[change_harv] = 0
local ET_sym_ref_harv_zone1 = r(p)
test _b[change_harv] + _b[change_harv_zone2] = 0
local ET_sym_ref_harv_zone2 = r(p)
test _b[change_harv] + _b[change_harv_zone3] = 0
local ET_sym_ref_harv_zone3 = r(p)

*test across zones
test change_zone2 = 0
local ET_sym_zone12_p = r(p)
test change_zone3 = 0
local ET_sym_zone13_p = r(p)
test change_zone3 - change_zone2 = 0
local ET_sym_zone23_p = r(p)
test change_zone2 + change_harv_zone2 = 0
local ET_sym_harv_zone12_p = r(p)
test change_zone3 + change_harv_zone3 = 0
local ET_sym_harv_zone13_p = r(p)
test change_zone3 + change_harv_zone3 - change_zone2 - change_harv_zone2 = 0
local ET_sym_harv_zone23_p = r(p)


* asymmetric results - all AEZs
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
gen INC_zone2 = INC_hhsize*zone2
gen DEC_zone2 = DEC_hhsize*zone2
gen INC_zone3 = INC_hhsize*zone3
gen DEC_zone3 = DEC_hhsize*zone3
gen INC_harv_zone2 = INC_harv*zone2
gen DEC_harv_zone2 = DEC_harv*zone2
gen INC_harv_zone3 = INC_harv*zone3
gen DEC_harv_zone3 = DEC_harv*zone3

reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv zone2 zone3 INC_zone2 DEC_zone2 INC_zone3 DEC_zone3 INC_harv_zone2 DEC_harv_zone2 INC_harv_zone3 DEC_harv_zone3 diff_log_A* diff_sh*, cluster(ea_wave)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local ET_asym_diff_harv_p = r(p)
test INC_hhsize + INC_zone2 - DEC_hhsize - DEC_zone2 = 0
local ET_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_harv + INC_harv_zone2 + INC_zone2 - DEC_hhsize - DEC_harv - DEC_zone2 - DEC_harv_zone2 = 0
local ET_asym_diff_harv2_p = r(p)
test INC_hhsize + INC_zone3 - DEC_hhsize - DEC_zone3 = 0
local ET_asym_diff_pre3_p = r(p)
test INC_hhsize + INC_harv + INC_zone3 + INC_harv_zone3 - DEC_hhsize - DEC_harv - DEC_zone3 - DEC_harv_zone3 = 0
local ET_asym_diff_harv3_p = r(p)
test _b[INC_harv] = 0
local ET_inc_ref_harv_zone1 = r(p)
test _b[DEC_harv] = 0
local ET_dec_ref_harv_zone1 = r(p)
test _b[INC_harv] + _b[INC_harv_zone2] = 0
local ET_inc_ref_harv_zone2 = r(p)
test _b[DEC_harv] + _b[DEC_harv_zone2] = 0
local ET_dec_ref_harv_zone2 = r(p)
test _b[INC_harv] + _b[INC_harv_zone3] = 0
local ET_inc_ref_harv_zone3 = r(p)
test _b[DEC_harv] + _b[DEC_harv_zone3] = 0
local ET_dec_ref_harv_zone3 = r(p)
	
local ET_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local ET_asym_inc_le_p = r(p)
local ET_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local ET_asym_dec_le_p = r(p)
local ET_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local ET_asym_inc_harv_p = r(p)
local ET_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local ET_asym_dec_harv_p = r(p)

local ET_asym_inc_le2_b = _b[INC_hhsize] + _b[INC_zone2]
test INC_hhsize + INC_zone2 =0
local ET_asym_inc_le2_p = r(p)
local ET_asym_dec_le2_b = _b[DEC_hhsize] + _b[DEC_zone2]
test DEC_hhsize + DEC_zone2 =0
local ET_asym_dec_le2_p = r(p)
local ET_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv] + _b[INC_zone2] + _b[INC_harv_zone2]
test _b[INC_hhsize] + _b[INC_harv] + INC_zone2 + INC_harv_zone2 = 0
local ET_asym_inc_harv2_p = r(p)
local ET_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv] + _b[DEC_zone2] + _b[DEC_harv_zone2]
test _b[DEC_hhsize] + _b[DEC_harv] + DEC_zone2 + DEC_harv_zone2 = 0
local ET_asym_dec_harv2_p = r(p)

local ET_asym_inc_le3_b = _b[INC_hhsize] + _b[INC_zone3]
test INC_hhsize + INC_zone3 =0
local ET_asym_inc_le3_p = r(p)
local ET_asym_dec_le3_b = _b[DEC_hhsize] + _b[DEC_zone3]
test DEC_hhsize + DEC_zone3 =0
local ET_asym_dec_le3_p = r(p)
local ET_asym_inc_harv3_b = _b[INC_hhsize] + _b[INC_harv] + _b[INC_zone3] + _b[INC_harv_zone3]
test _b[INC_hhsize] + _b[INC_harv] + INC_zone3 + INC_harv_zone3 = 0
local ET_asym_inc_harv3_p = r(p)
local ET_asym_dec_harv3_b = _b[DEC_hhsize] + _b[DEC_harv] + _b[DEC_zone3] + _b[DEC_harv_zone3]
test _b[DEC_hhsize] + _b[DEC_harv] + DEC_zone3 + DEC_harv_zone3 = 0
local ET_asym_dec_harv3_p = r(p)

*test across zones
test INC_zone2 = 0
local ET_asym_inc_zone12_p = r(p)
test DEC_zone2 = 0
local ET_asym_dec_zone12_p = r(p)
test INC_zone3 = 0
local ET_asym_inc_zone13_p = r(p)
test DEC_zone3 = 0
local ET_asym_dec_zone13_p = r(p)
test INC_zone3 - INC_zone2 = 0
local ET_asym_inc_zone23_p = r(p)
test DEC_zone3 - DEC_zone2 = 0
local ET_asym_dec_zone23_p = r(p)
test INC_zone2 + INC_harv_zone2 = 0
local ET_asym_inc_harv_zone12_p = r(p)
test DEC_zone2 + DEC_harv_zone2 = 0
local ET_asym_dec_harv_zone12_p = r(p)
test INC_zone3 + INC_harv_zone3 = 0
local ET_asym_inc_harv_zone13_p = r(p)
test DEC_zone3 + DEC_harv_zone3 = 0
local ET_asym_dec_harv_zone13_p = r(p)
test INC_zone3 + INC_harv_zone3 - INC_zone2 - INC_harv_zone2 = 0
local ET_asym_inc_harv_zone23_p = r(p)
test DEC_zone3 + DEC_harv_zone3 - DEC_zone2 - DEC_harv_zone2 = 0
local ET_asym_dec_harv_zone23_p = r(p)

local ET_asym_obv = e(N)
local ET_asym_r2 = e(r2)


**** Malawi *****
*1 = Tropic-warm/semiarid
*2 = Tropic-warm/subhumid
*3 = Tropic-cool (other)

* summary stats by aez
use "$newdata/Malawi Panel Data Clean", replace
bysort hhid: egen ae_temp = max(aez)
replace aez = ae_temp

gen per_maize = acres_maize / acres
gen per_groundnut = acres_groundnut /acres
forvalues i=1/3 {
	estpost sum hhsize_phase acres owned_acres ld_cult_kids ld_harv_kids maize groundnut fertilized irrigated any_sold per_maize per_groundnut if aez==`i'
	est sto mw_aez_stats`i'
}
label var hhsize_phase "Labor endowment, with kids"
label var acres "Acres cultivated"
label var owned_acres "Acres owned"
label var ld_cult_kids "Labor demand - cultivation"
label var ld_harv_kids "Labor demand - harvest"
label var maize "Plant any maize"
label var groundnut "Plant any groundnut"
label var per_maize "Percent acres with maize"
label var per_groundnut "Percent acres with groundnut"
label var fertilized "Use any fertilizer"
label var irrigated "Use any irrigation"
label var any_sold "Sell any crops"


esttab mw_aez_stats* using "$path/output/MW_aez_stats.tex", cell(mean(fmt(%11.2fc %11.2fc %11.2fc %11.2fc %11.2fc)) sd(par)) ///
		mtitles("Tropic-warm/semiarid" "Tropic-warm/subhumid" "Tropic-cool (other)") posthead("\hline") nodep ///
		stats(N, fmt(%9.0fc) labels("Number of obs.")) label replace fragment tex

* symmetric results - all aezs
use "$newdata/MW_reg_ready", clear
egen ea_wave = group(ea1 wave)
gen harv = activity==1
gen change_harv = diff_$hhsize_var*harv
gen zone2 = ae_zone==2
gen zone3 = ae_zone==3
gen change_zone2 = diff_$hhsize_var * zone2
gen change_zone3 = diff_$hhsize_var * zone3
gen harv_zone2 = harv*zone2
gen harv_zone3 = harv*zone3
gen change_harv_zone2 = change_harv*zone2
gen change_harv_zone3 = change_harv*zone3
foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
	gen `var'_zone2 = zone2 * `var'
	gen `var'_zone3 = zone3 * `var'
}

reg diff_`dep_var' diff_$hhsize_var harv change_harv zone2 zone3 change_zone2 change_zone3 harv_zone2 harv_zone3 change_harv_zone2 change_harv_zone3 diff_log_A* diff_sh*, cluster(ea_wave)
local MW_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local MW_sym_chg_le_p = r(p)
local MW_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test diff_$hhsize_var + change_harv = 0
local MW_sym_chg_harv_p = r(p)
local MW_sym_chg_le2_b = _b[diff_$hhsize_var] + _b[change_zone2]
test diff_$hhsize_var + change_zone2 =0
local MW_sym_chg_le2_p = r(p)
local MW_sym_chg_harv2_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[change_zone2] + _b[change_harv_zone2]
test diff_$hhsize_var + change_harv + change_zone2 + change_harv_zone2 = 0
local MW_sym_chg_harv2_p = r(p)
local MW_sym_chg_le3_b = _b[diff_$hhsize_var] + _b[change_zone3]
test diff_$hhsize_var + change_zone3 =0
local MW_sym_chg_le3_p = r(p)
local MW_sym_chg_harv3_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[change_zone3] + _b[change_harv_zone3]
test diff_$hhsize_var + change_harv + change_zone3 + change_harv_zone3 = 0
local MW_sym_chg_harv3_p = r(p)
local MW_sym_obv = e(N)
local MW_sym_r2 = e(r2)
test _b[change_harv] = 0
local MW_sym_ref_harv_zone1 = r(p)
test _b[change_harv] + _b[change_harv_zone2] = 0
local MW_sym_ref_harv_zone2 = r(p)
test _b[change_harv] + _b[change_harv_zone3] = 0
local MW_sym_ref_harv_zone3 = r(p)

*test across zones
test change_zone2 = 0
local MW_sym_zone12_p = r(p)
test change_zone3 = 0
local MW_sym_zone13_p = r(p)
test change_zone3 - change_zone2 = 0
local MW_sym_zone23_p = r(p)
test change_zone2 + change_harv_zone2 = 0
local MW_sym_harv_zone12_p = r(p)
test change_zone3 + change_harv_zone3 = 0
local MW_sym_harv_zone13_p = r(p)
test change_zone3 + change_harv_zone3 - change_zone2 - change_harv_zone2 = 0
local MW_sym_harv_zone23_p = r(p)

* asymmetric results - all AEZs
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
gen INC_zone2 = INC_hhsize*zone2
gen DEC_zone2 = DEC_hhsize*zone2
gen INC_zone3 = INC_hhsize*zone3
gen DEC_zone3 = DEC_hhsize*zone3
gen INC_harv_zone2 = INC_harv*zone2
gen DEC_harv_zone2 = DEC_harv*zone2
gen INC_harv_zone3 = INC_harv*zone3
gen DEC_harv_zone3 = DEC_harv*zone3

reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv zone2 zone3 INC_zone2 DEC_zone2 INC_zone3 DEC_zone3 INC_harv_zone2 DEC_harv_zone2 INC_harv_zone3 DEC_harv_zone3 diff_log_A* diff_sh*, cluster(ea_wave)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local MW_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local MW_asym_diff_harv_p = r(p)
test INC_hhsize + INC_zone2 - DEC_hhsize - DEC_zone2 = 0
local MW_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_harv + INC_harv_zone2 + INC_zone2 - DEC_hhsize - DEC_harv - DEC_zone2 - DEC_harv_zone2 = 0
local MW_asym_diff_harv2_p = r(p)
test INC_hhsize + INC_zone3 - DEC_hhsize - DEC_zone3 = 0
local MW_asym_diff_pre3_p = r(p)
test INC_hhsize + INC_harv + INC_zone3 + INC_harv_zone3 - DEC_hhsize - DEC_harv - DEC_zone3 - DEC_harv_zone3 = 0
local MW_asym_diff_harv3_p = r(p)
test _b[INC_harv] = 0
local MW_inc_ref_harv_zone1 = r(p)
test _b[DEC_harv] = 0
local MW_dec_ref_harv_zone1 = r(p)
test _b[INC_harv] + _b[INC_harv_zone2] = 0
local MW_inc_ref_harv_zone2 = r(p)
test _b[DEC_harv] + _b[DEC_harv_zone2] = 0
local MW_dec_ref_harv_zone2 = r(p)
test _b[INC_harv] + _b[INC_harv_zone3] = 0
local MW_inc_ref_harv_zone3 = r(p)
test _b[DEC_harv] + _b[DEC_harv_zone3] = 0
local MW_dec_ref_harv_zone3 = r(p)

local MW_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local MW_asym_inc_le_p = r(p)
local MW_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local MW_asym_dec_le_p = r(p)
local MW_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local MW_asym_inc_harv_p = r(p)
local MW_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local MW_asym_dec_harv_p = r(p)

local MW_asym_inc_le2_b = _b[INC_hhsize] + _b[INC_zone2]
test INC_hhsize + INC_zone2 =0
local MW_asym_inc_le2_p = r(p)
local MW_asym_dec_le2_b = _b[DEC_hhsize] + _b[DEC_zone2]
test DEC_hhsize + DEC_zone2 =0
local MW_asym_dec_le2_p = r(p)
local MW_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv] + _b[INC_zone2] + _b[INC_harv_zone2]
test _b[INC_hhsize] + _b[INC_harv] + INC_zone2 + INC_harv_zone2 = 0
local MW_asym_inc_harv2_p = r(p)
local MW_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv] + _b[DEC_zone2] + _b[DEC_harv_zone2]
test _b[DEC_hhsize] + _b[DEC_harv] + DEC_zone2 + DEC_harv_zone2 = 0
local MW_asym_dec_harv2_p = r(p)

local MW_asym_inc_le3_b = _b[INC_hhsize] + _b[INC_zone3]
test INC_hhsize + INC_zone3 =0
local MW_asym_inc_le3_p = r(p)
local MW_asym_dec_le3_b = _b[DEC_hhsize] + _b[DEC_zone3]
test DEC_hhsize + DEC_zone3 =0
local MW_asym_dec_le3_p = r(p)
local MW_asym_inc_harv3_b = _b[INC_hhsize] + _b[INC_harv] + _b[INC_zone3] + _b[INC_harv_zone3]
test _b[INC_hhsize] + _b[INC_harv] + INC_zone3 + INC_harv_zone3 = 0
local MW_asym_inc_harv3_p = r(p)
local MW_asym_dec_harv3_b = _b[DEC_hhsize] + _b[DEC_harv] + _b[DEC_zone3] + _b[DEC_harv_zone3]
test _b[DEC_hhsize] + _b[DEC_harv] + DEC_zone3 + DEC_harv_zone3 = 0
local MW_asym_dec_harv3_p = r(p)

*test across zones
test INC_zone2 = 0
local MW_asym_inc_zone12_p = r(p)
test DEC_zone2 = 0
local MW_asym_dec_zone12_p = r(p)
test INC_zone3 = 0
local MW_asym_inc_zone13_p = r(p)
test DEC_zone3 = 0
local MW_asym_dec_zone13_p = r(p)
test INC_zone3 - INC_zone2 = 0
local MW_asym_inc_zone23_p = r(p)
test DEC_zone3 - DEC_zone2 = 0
local MW_asym_dec_zone23_p = r(p)
test INC_zone2 + INC_harv_zone2 = 0
local MW_asym_inc_harv_zone12_p = r(p)
test DEC_zone2 + DEC_harv_zone2 = 0
local MW_asym_dec_harv_zone12_p = r(p)
test INC_zone3 + INC_harv_zone3 = 0
local MW_asym_inc_harv_zone13_p = r(p)
test DEC_zone3 + DEC_harv_zone3 = 0
local MW_asym_dec_harv_zone13_p = r(p)
test INC_zone3 + INC_harv_zone3 - INC_zone2 - INC_harv_zone2 = 0
local MW_asym_inc_harv_zone23_p = r(p)
test DEC_zone3 + DEC_harv_zone3 - DEC_zone2 - DEC_harv_zone2 = 0
local MW_asym_dec_harv_zone23_p = r(p)

local MW_asym_obv = e(N)
local MW_asym_r2 = e(r2)


**** Tanzania *****
*1 = Tropic-warm/subhumid
*2 = Tropic-cool/subhumid
*3 = other

* summary stats by aez
use "$newdata/TZ panel data merged", replace
bysort hhid: egen ae_temp = max(aez)
replace aez = ae_temp

gen per_maize = acres_maize / acres
gen per_cassava = acres_cassava /acres
forvalues i=1/3 {
	estpost sum hhsize_phase acres owned_acres ld_cult_kids ld_harv_kids ld_weed_kids maize cassava fertilized irrigated any_sold any_asset per_maize per_cassava if aez==`i'
	est sto tz_aez_stats`i'
}
label var hhsize_phase "Labor endowment, with kids"
label var acres "Acres cultivated"
label var owned_acres "Acres owned"
label var ld_cult_kids "Labor demand - cultivation"
label var ld_harv_kids "Labor demand - harvest"
label var ld_weed_kids "Labor demand - weeding"
label var maize "Plant any maize"
label var cassava "Plant any cassava"
label var per_maize "Percent acres with maize"
label var per_cassava "Percent acres with cassava"
label var fertilized "Use any fertilizer"
label var irrigated "Use any irrigation"
label var any_asset "Own farm assets"
label var any_sold "Sell any crops"

esttab tz_aez_stats* using "$path/output/TZ_aez_stats.tex", cell(mean(fmt(%11.2fc %11.2fc %11.2fc %11.2fc %11.2fc)) sd(par)) ///
		mtitles("Tropic-warm/subhumid" "Tropic-cool/subhumid" "Other AEZs") posthead("\hline") nodep ///
		stats(N, fmt(%9.0fc) labels("Number of obs.")) label replace fragment tex

* symmetric results - all AEZs
use "$newdata/TZ_reg_ready", clear
egen ea_wave = group(ea1 wave)
gen weed = activity==1
gen harv = activity==2
gen change_weed = diff_$hhsize_var*weed
gen change_harv = diff_$hhsize_var*harv
gen zone2 = ae_zone==2
gen zone3 = ae_zone==3
gen change_zone2 = diff_$hhsize_var * zone2
gen change_zone3 = diff_$hhsize_var * zone3
gen harv_zone2 = harv*zone2
gen harv_zone3 = harv*zone3
gen change_harv_zone2 = change_harv*zone2
gen change_harv_zone3 = change_harv*zone3
gen weed_zone2 = weed*zone2
gen weed_zone3 = weed*zone3
gen change_weed_zone2 = change_weed*zone2
gen change_weed_zone3 = change_weed*zone3
foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
	gen `var'_zone2 = zone2 * `var'
	gen `var'_zone3 = zone3 * `var'
}

reg diff_`dep_var' diff_$hhsize_var harv change_harv weed change_weed zone2 zone3 change_zone2 change_zone3 harv_zone2 harv_zone3 weed_zone2 weed_zone3 change_harv_zone2 change_harv_zone3 change_weed_zone2 change_weed_zone3 diff_log_A* diff_sh* wave3, cluster(ea_wave)
local TZ_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local TZ_sym_chg_le_p = r(p)
local TZ_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test diff_$hhsize_var + change_harv = 0
local TZ_sym_chg_harv_p = r(p)
local TZ_sym_chg_weed_b = _b[diff_$hhsize_var] + _b[change_weed]
test diff_$hhsize_var + change_weed = 0
local TZ_sym_chg_weed_p = r(p)
local TZ_sym_chg_le2_b = _b[diff_$hhsize_var] + _b[change_zone2]
test diff_$hhsize_var + change_zone2 =0
local TZ_sym_chg_le2_p = r(p)
local TZ_sym_chg_le3_b = _b[diff_$hhsize_var] + _b[change_zone3]
test diff_$hhsize_var + change_zone3 =0
local TZ_sym_chg_le3_p = r(p)
local TZ_sym_chg_harv2_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[change_zone2] + _b[change_harv_zone2]
test diff_$hhsize_var + change_harv + change_zone2 + change_harv_zone2 = 0
local TZ_sym_chg_harv2_p = r(p)
local TZ_sym_chg_harv3_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[change_zone3] + _b[change_harv_zone3]
test diff_$hhsize_var + change_harv + change_zone3 + change_harv_zone3 = 0
local TZ_sym_chg_harv3_p = r(p)
local TZ_sym_chg_weed2_b = _b[diff_$hhsize_var] + _b[change_weed] + _b[change_zone2] + _b[change_weed_zone2]
test diff_$hhsize_var + change_weed + change_zone2 + change_weed_zone2 = 0
local TZ_sym_chg_weed2_p = r(p)
local TZ_sym_chg_weed3_b = _b[diff_$hhsize_var] + _b[change_weed] + _b[change_zone3] + _b[change_weed_zone3]
test diff_$hhsize_var + change_weed + change_zone3 + change_weed_zone3 = 0
local TZ_sym_chg_weed3_p = r(p)
local TZ_sym_obv = e(N)
local TZ_sym_r2 = e(r2)
test _b[change_harv] = 0
local TZ_sym_ref_harv_zone1 = r(p)
test _b[change_harv] + _b[change_harv_zone2] = 0
local TZ_sym_ref_harv_zone2 = r(p)
test _b[change_harv] + _b[change_harv_zone3] = 0
local TZ_sym_ref_harv_zone3 = r(p)
test _b[change_weed] = 0
local TZ_sym_ref_weed_zone1 = r(p)
test _b[change_weed] + _b[change_weed_zone2] = 0
local TZ_sym_ref_weed_zone2 = r(p)
test _b[change_weed] + _b[change_weed_zone3] = 0
local TZ_sym_ref_weed_zone3 = r(p)
test _b[change_harv] - _b[change_weed] = 0
local TZ_sym_harv_weed_zone1 = r(p)
test _b[change_harv] + _b[change_harv_zone2] - _b[change_weed] - _b[change_weed_zone2] = 0
local TZ_sym_harv_weed_zone2 = r(p)
test _b[change_harv] + _b[change_harv_zone3] - _b[change_weed] - _b[change_weed_zone3] = 0
local TZ_sym_harv_weed_zone3 = r(p)

*test across zones
test change_zone2 = 0
local TZ_sym_zone12_p = r(p)
test change_zone3 = 0
local TZ_sym_zone13_p = r(p)
test change_zone3 - change_zone2 = 0
local TZ_sym_zone23_p = r(p)
test change_zone2 + change_harv_zone2 = 0
local TZ_sym_harv_zone12_p = r(p)
test change_zone3 + change_harv_zone3 = 0
local TZ_sym_harv_zone13_p = r(p)
test change_zone3 + change_harv_zone3 - change_zone2 - change_harv_zone2 = 0
local TZ_sym_harv_zone23_p = r(p)
test change_zone2 + change_weed_zone2 = 0
local TZ_sym_weed_zone12_p = r(p)
test change_zone3 + change_weed_zone3 = 0
local TZ_sym_weed_zone13_p = r(p)
test change_zone3 + change_weed_zone3 - change_zone2 - change_weed_zone2 = 0
local TZ_sym_weed_zone23_p = r(p)


* asymmetric results - all AEZs
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
gen INC_weed = INC_hhsize*weed
gen DEC_weed = DEC_hhsize*weed
gen INC_zone2 = INC_hhsize*zone2
gen DEC_zone2 = DEC_hhsize*zone2
gen INC_zone3 = INC_hhsize*zone3
gen DEC_zone3 = DEC_hhsize*zone3
gen INC_harv_zone2 = INC_harv*zone2
gen DEC_harv_zone2 = DEC_harv*zone2
gen INC_harv_zone3 = INC_harv*zone3
gen DEC_harv_zone3 = DEC_harv*zone3
gen INC_weed_zone2 = INC_weed*zone2
gen DEC_weed_zone2 = DEC_weed*zone2
gen INC_weed_zone3 = INC_weed*zone3
gen DEC_weed_zone3 = DEC_weed*zone3

reg diff_`dep_var' harv weed INC_hhsize INC_harv INC_weed DEC_hhsize DEC_harv DEC_weed zone2 zone3 INC_zone2 DEC_zone2 INC_zone3 DEC_zone3 INC_harv_zone2 DEC_harv_zone2 INC_harv_zone3 DEC_harv_zone3 INC_weed_zone2 INC_weed_zone3 DEC_weed_zone2 DEC_weed_zone3 diff_log_A* diff_sh* wave3, cluster(ea_wave)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local TZ_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local TZ_asym_diff_harv_p = r(p)
test INC_hhsize + INC_weed - DEC_hhsize - DEC_weed = 0		// Check whether weeding values are different
local TZ_asym_diff_weed_p = r(p)
test INC_hhsize + INC_zone2 - DEC_hhsize - DEC_zone2 = 0
local TZ_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_harv + INC_harv_zone2 + INC_zone2 - DEC_hhsize - DEC_harv - DEC_zone2 - DEC_harv_zone2 = 0
local TZ_asym_diff_harv2_p = r(p)
test INC_hhsize + INC_weed + INC_weed_zone2 + INC_zone2 - DEC_hhsize - DEC_weed - DEC_zone2 - DEC_weed_zone2 = 0
local TZ_asym_diff_weed2_p = r(p)
test INC_hhsize + INC_zone3 - DEC_hhsize - DEC_zone3 = 0
local TZ_asym_diff_pre3_p = r(p)
test INC_hhsize + INC_harv + INC_zone3 + INC_harv_zone3 - DEC_hhsize - DEC_harv - DEC_zone3 - DEC_harv_zone3 = 0
local TZ_asym_diff_harv3_p = r(p)
test INC_hhsize + INC_weed + INC_zone3 + INC_weed_zone3 - DEC_hhsize - DEC_weed - DEC_zone3 - DEC_weed_zone3 = 0
local TZ_asym_diff_weed3_p = r(p)
test _b[INC_harv] = 0
local TZ_inc_ref_harv_zone1 = r(p)
test _b[DEC_harv] = 0
local TZ_dec_ref_harv_zone1 = r(p)
test _b[INC_harv] + _b[INC_harv_zone2] = 0
local TZ_inc_ref_harv_zone2 = r(p)
test _b[DEC_harv] + _b[DEC_harv_zone2] = 0
local TZ_dec_ref_harv_zone2 = r(p)
test _b[INC_harv] + _b[INC_harv_zone3] = 0
local TZ_inc_ref_harv_zone3 = r(p)
test _b[DEC_harv] + _b[DEC_harv_zone3] = 0
local TZ_dec_ref_harv_zone3 = r(p)
test _b[INC_weed] = 0
local TZ_inc_ref_weed_zone1 = r(p)
test _b[DEC_weed] = 0
local TZ_dec_ref_weed_zone1 = r(p)
test _b[INC_weed] + _b[INC_weed_zone2] = 0
local TZ_inc_ref_weed_zone2 = r(p)
test _b[DEC_weed] + _b[DEC_weed_zone2] = 0
local TZ_dec_ref_weed_zone2 = r(p)
test _b[INC_weed] + _b[INC_weed_zone3] = 0
local TZ_inc_ref_weed_zone3 = r(p)
test _b[DEC_weed] + _b[DEC_weed_zone3] = 0
local TZ_dec_ref_weed_zone3 = r(p)
test _b[INC_weed] - _b[INC_harv]= 0
local TZ_inc_harv_weed_zone1 = r(p)
test _b[DEC_weed]- _b[DEC_harv] = 0
local TZ_dec_harv_weed_zone1 = r(p)
test _b[INC_weed] + _b[INC_weed_zone2] - _b[INC_harv] - _b[INC_harv_zone2]= 0
local TZ_inc_harv_weed_zone2 = r(p)
test _b[DEC_weed] + _b[DEC_weed_zone2] - _b[DEC_harv] - _b[DEC_harv_zone2] = 0
local TZ_dec_harv_weed_zone2 = r(p)
test _b[INC_weed] + _b[INC_weed_zone3] - _b[INC_harv] - _b[INC_harv_zone3]= 0
local TZ_inc_harv_weed_zone3 = r(p)
test _b[DEC_weed] + _b[DEC_weed_zone3] - _b[DEC_harv] - _b[DEC_harv_zone3] = 0
local TZ_dec_harv_weed_zone3 = r(p)

local TZ_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local TZ_asym_inc_le_p = r(p)
local TZ_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local TZ_asym_dec_le_p = r(p)
local TZ_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local TZ_asym_inc_harv_p = r(p)
local TZ_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local TZ_asym_dec_harv_p = r(p)
local TZ_asym_inc_weed_b = _b[INC_hhsize] + _b[INC_weed]
test _b[INC_hhsize] + _b[INC_weed] = 0
local TZ_asym_inc_weed_p = r(p)
local TZ_asym_dec_weed_b = _b[DEC_hhsize] + _b[DEC_weed]
test _b[DEC_hhsize] + _b[DEC_weed] = 0
local TZ_asym_dec_weed_p = r(p)

local TZ_asym_inc_le2_b = _b[INC_hhsize] + _b[INC_zone2]
test INC_hhsize + INC_zone2 =0
local TZ_asym_inc_le2_p = r(p)
local TZ_asym_dec_le2_b = _b[DEC_hhsize] + _b[DEC_zone2]
test DEC_hhsize + DEC_zone2 =0
local TZ_asym_dec_le2_p = r(p)
local TZ_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv] + _b[INC_zone2] + _b[INC_harv_zone2]
test _b[INC_hhsize] + _b[INC_harv] + INC_zone2 + INC_harv_zone2 = 0
local TZ_asym_inc_harv2_p = r(p)
local TZ_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv] + _b[DEC_zone2] + _b[DEC_harv_zone2]
test _b[DEC_hhsize] + _b[DEC_harv] + DEC_zone2 + DEC_harv_zone2 = 0
local TZ_asym_dec_harv2_p = r(p)
local TZ_asym_inc_weed2_b = _b[INC_hhsize] + _b[INC_weed] + _b[INC_zone2] + _b[INC_weed_zone2]
test _b[INC_hhsize] + _b[INC_weed] + INC_zone2 + INC_weed_zone2 = 0
local TZ_asym_inc_weed2_p = r(p)
local TZ_asym_dec_weed2_b = _b[DEC_hhsize] + _b[DEC_weed] + _b[DEC_zone2] + _b[DEC_weed_zone2]
test _b[DEC_hhsize] + _b[DEC_weed] + DEC_zone2 + DEC_weed_zone2 = 0
local TZ_asym_dec_weed2_p = r(p)

local TZ_asym_inc_le3_b = _b[INC_hhsize] + _b[INC_zone3]
test INC_hhsize + INC_zone3 =0
local TZ_asym_inc_le3_p = r(p)
local TZ_asym_dec_le3_b = _b[DEC_hhsize] + _b[DEC_zone3]
test DEC_hhsize + DEC_zone3 =0
local TZ_asym_dec_le3_p = r(p)
local TZ_asym_inc_harv3_b = _b[INC_hhsize] + _b[INC_harv] + _b[INC_zone3] + _b[INC_harv_zone3]
test _b[INC_hhsize] + _b[INC_harv] + INC_zone3 + INC_harv_zone3 = 0
local TZ_asym_inc_harv3_p = r(p)
local TZ_asym_dec_harv3_b = _b[DEC_hhsize] + _b[DEC_harv] + _b[DEC_zone3] + _b[DEC_harv_zone3]
test _b[DEC_hhsize] + _b[DEC_harv] + DEC_zone3 + DEC_harv_zone3 = 0
local TZ_asym_dec_harv3_p = r(p)
local TZ_asym_inc_weed3_b = _b[INC_hhsize] + _b[INC_weed] + _b[INC_zone3] + _b[INC_weed_zone3]
test _b[INC_hhsize] + _b[INC_weed] + INC_zone3 + INC_weed_zone3 = 0
local TZ_asym_inc_weed3_p = r(p)
local TZ_asym_dec_weed3_b = _b[DEC_hhsize] + _b[DEC_weed] + _b[DEC_zone3] + _b[DEC_weed_zone3]
test _b[DEC_hhsize] + _b[DEC_weed] + DEC_zone3 + DEC_weed_zone3 = 0
local TZ_asym_dec_weed3_p = r(p)

*test across zones
test INC_zone2 = 0
local TZ_asym_inc_zone12_p = r(p)
test DEC_zone2 = 0
local TZ_asym_dec_zone12_p = r(p)
test INC_zone3 = 0
local TZ_asym_inc_zone13_p = r(p)
test DEC_zone3 = 0
local TZ_asym_dec_zone13_p = r(p)
test INC_zone3 - INC_zone2 = 0
local TZ_asym_inc_zone23_p = r(p)
test DEC_zone3 - DEC_zone2 = 0
local TZ_asym_dec_zone23_p = r(p)
test INC_zone2 + INC_harv_zone2 = 0
local TZ_asym_inc_harv_zone12_p = r(p)
test DEC_zone2 + DEC_harv_zone2 = 0
local TZ_asym_dec_harv_zone12_p = r(p)
test INC_zone3 + INC_harv_zone3 = 0
local TZ_asym_inc_harv_zone13_p = r(p)
test DEC_zone3 + DEC_harv_zone3 = 0
local TZ_asym_dec_harv_zone13_p = r(p)
test INC_zone3 + INC_harv_zone3 - INC_zone2 - INC_harv_zone2 = 0
local TZ_asym_inc_harv_zone23_p = r(p)
test DEC_zone3 + DEC_harv_zone3 - DEC_zone2 - DEC_harv_zone2 = 0
local TZ_asym_dec_harv_zone23_p = r(p)
test INC_zone2 + INC_weed_zone2 = 0
local TZ_asym_inc_weed_zone12_p = r(p)
test DEC_zone2 + DEC_weed_zone2 = 0
local TZ_asym_dec_weed_zone12_p = r(p)
test INC_zone3 + INC_weed_zone3 = 0
local TZ_asym_inc_weed_zone13_p = r(p)
test DEC_zone3 + DEC_weed_zone3 = 0
local TZ_asym_dec_weed_zone13_p = r(p)
test INC_zone3 + INC_weed_zone3 - INC_zone2 - INC_weed_zone2 = 0
local TZ_asym_inc_weed_zone23_p = r(p)
test DEC_zone3 + DEC_weed_zone3 - DEC_zone2 - DEC_weed_zone2 = 0
local TZ_asym_dec_weed_zone23_p = r(p)

local TZ_asym_obv = e(N)
local TZ_asym_r2 = e(r2)


**** Uganda *****
*1 Tropic-warm/humid
*2 Tropic-cool/humid
*3 Other

* summary stats by aez
use "$newdata/UG panel data merged", replace
bysort hhid: egen ae_temp = max(aez)
replace aez = ae_temp
gen per_maize = acres_maize / acres
gen per_cassava = acres_cassava /acres
gen per_beans = acres_beans / acres
forvalues i=1/3 {
	estpost sum hhsize_phase acres owned_acres ld_tot_kids maize beans cassava fertilized irrigated any_sold per_maize per_beans per_cassava if aez==`i'
	est sto ug_aez_stats`i'
}
label var hhsize_phase "Labor endowment, with kids"
label var acres "Acres cultivated"
label var owned_acres "Acres owned"
label var ld_tot_kids "Labor demand"
label var maize "Plant any maize"
label var beans "Plant any beans"
label var cassava "Plant any cassava"
label var per_maize "Percent acres with maize"
label var per_beans "Percent acres with beans"
label var per_cassava "Percent acres with cassava"
label var fertilized "Use any fertilizer"
label var irrigated "Use any irrigation"
label var any_sold "Sell any crops"

esttab ug_aez_stats* using "$path/output/UG_aez_stats.tex", cell(mean(fmt(%11.2fc %11.2fc %11.2fc %11.2fc)) sd(par)) ///
		mtitles("Tropic-warm/humid" "Tropic-cool/humid" "Other AEZs") posthead("\hline") nodep ///
		stats(N, fmt(%9.0fc) labels("Number of obs.")) label replace fragment tex

* symmetric results - all AEZs
use "$newdata/UG_reg_ready", clear
egen ea_wave = group(ea wave)
gen zone2 = ae_zone==2
gen zone3 = ae_zone==3
gen change_zone2 = diff_$hhsize_var * zone2
gen change_zone3 = diff_$hhsize_var * zone3
foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
	gen `var'_zone2 = zone2 * `var'
	gen `var'_zone3 = zone3 * `var'
}

reg diff_`dep_var' diff_$hhsize_var zone2 zone3 change_zone2 change_zone3 diff_log_A* diff_sh* wave3 wave4, cluster(ea_wave)
local UG_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local UG_sym_chg_le_p = r(p)
local UG_sym_chg_le2_b = _b[diff_$hhsize_var] + _b[change_zone2]
test diff_$hhsize_var + change_zone2 =0
local UG_sym_chg_le2_p = r(p)
local UG_sym_chg_le3_b = _b[diff_$hhsize_var] + _b[change_zone3]
test diff_$hhsize_var + change_zone3 =0
local UG_sym_chg_le3_p = r(p)

*test across zones
test change_zone2 = 0
local UG_sym_zone12_p = r(p)
test change_zone3 = 0
local UG_sym_zone13_p = r(p)
test change_zone3 - change_zone2 = 0
local UG_sym_zone23_p = r(p)

local UG_sym_obv = e(N)
local UG_sym_r2 = e(r2)


* asymmetric results - all AEZs
gen INC_zone2 = INC_hhsize*zone2
gen DEC_zone2 = DEC_hhsize*zone2
gen INC_zone3 = INC_hhsize*zone3
gen DEC_zone3 = DEC_hhsize*zone3

reg diff_`dep_var' INC_hhsize DEC_hhsize zone2 zone3 INC_zone2 DEC_zone2 INC_zone3 DEC_zone3 diff_log_A* diff_sh* wave3 wave4, cluster(ea_wave)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local UG_asym_diff_pre_p = r(p)
test INC_hhsize + INC_zone2 - DEC_hhsize - DEC_zone2 = 0
local UG_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_zone3 - DEC_hhsize - DEC_zone3 = 0
local UG_asym_diff_pre3_p = r(p)

local UG_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local UG_asym_inc_le_p = r(p)
local UG_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local UG_asym_dec_le_p = r(p)

local UG_asym_inc_le2_b = _b[INC_hhsize] + _b[INC_zone2]
test INC_hhsize + INC_zone2 =0
local UG_asym_inc_le2_p = r(p)
local UG_asym_dec_le2_b = _b[DEC_hhsize] + _b[DEC_zone2]
test DEC_hhsize + DEC_zone2 =0
local UG_asym_dec_le2_p = r(p)

local UG_asym_inc_le3_b = _b[INC_hhsize] + _b[INC_zone3]
test INC_hhsize + INC_zone3 =0
local UG_asym_inc_le3_p = r(p)
local UG_asym_dec_le3_b = _b[DEC_hhsize] + _b[DEC_zone3]
test DEC_hhsize + DEC_zone3 =0
local UG_asym_dec_le3_p = r(p)

*test across zones
test INC_zone2 = 0
local UG_asym_inc_zone12_p = r(p)
test DEC_zone2 = 0
local UG_asym_dec_zone12_p = r(p)
test INC_zone3 = 0
local UG_asym_inc_zone13_p = r(p)
test DEC_zone3 = 0
local UG_asym_dec_zone13_p = r(p)
test INC_zone3 - INC_zone2 = 0
local UG_asym_inc_zone23_p = r(p)
test DEC_zone3 - DEC_zone2 = 0
local UG_asym_dec_zone23_p = r(p)

local UG_asym_obv = e(N)
local UG_asym_r2 = e(r2)


** EXPORT

*create table of marginals and F-tests for Ethiopia results
clear
set obs 19
gen col0 = "Reference \$\times \Delta E\$" in 1
replace col0 = "Reference \$\times \Delta E^+\$" in 3
replace col0 = "Reference \$\times \Delta E^-\$" in 5
replace col0 = "Harvest \$\times \Delta E\$" in 7
replace col0 = "Harvest \$\times \Delta E^+\$" in 9
replace col0 = "Harvest \$\times \Delta E^-\$" in 11

replace col0 = "\hline Reference: Inc = Dec" in 13
replace col0 = "Harvest: Inc = Dec" in 14
replace col0 = "\hline Reference = Harvest" in 15
replace col0 = "Reference = Harvest, \$+\$" in 16
replace col0 = "Reference = Harvest, \$-\$" in 17
replace col0 = "\hline Observations" in 18
replace col0 = "\$R^2\$" in 19

forvalues i=1/9 {
	gen col`i' = . in 1
	gen star`i' = ""
}

*put marginal effects into table
forvalues i=1/3 {
	di "in margins loop, i=`i'"
	local j = 2*`i'-1
	if `i'==1 {
		local k=""
	}
	else {
		local k `i'
	}

	replace col`j' = `ET_sym_chg_le`k'_b' in 1
	replace col`j' = `ET_sym_chg_le`k'_p' in 2
	replace col`j' = `ET_sym_chg_harv`k'_b' in 7
	replace col`j' = `ET_sym_chg_harv`k'_p' in 8
	if `i'==1 {
		replace col`j' = `ET_sym_r2' in 19
	}
	
	local j = 2*`i'
	replace col`j' = `ET_asym_inc_le`k'_b' in 3
	replace col`j' = `ET_asym_inc_le`k'_p' in 4
	replace col`j' = `ET_asym_dec_le`k'_b' in 5
	replace col`j' = `ET_asym_dec_le`k'_p' in 6
	replace col`j' = `ET_asym_inc_harv`k'_b' in 9
	replace col`j' = `ET_asym_inc_harv`k'_p' in 10
	replace col`j' = `ET_asym_dec_harv`k'_b' in 11
	replace col`j' = `ET_asym_dec_harv`k'_p' in 12
	replace col`j' = `ET_asym_diff_pre`k'_p' in 13
	replace col`j' = `ET_asym_diff_harv`k'_p' in 14
	if `i'==1 {
		replace col`j' = `ET_asym_r2' in 19
	}

	* assigning stars
	forvalues j=1/6 {
		local row = 1
		foreach var in sym_chg_le asym_inc_le asym_dec_le sym_chg_harv asym_inc_harv asym_dec_harv {
			local temp = 2*`row'-1

			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "country_var_p = ET_`var'_p"
			if `j'<3 {
				local p_var  ET_`var'_p
			}
			else if `j'>2 & `j'<5 {
				local p_var  ET_`var'2_p	
			}
			else {
				local p_var  ET_`var'3_p	
			}
			di "p_var = `p_var'"
			replace star`j' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`j' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`j' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`j' = "" in `temp' if col`j'[`temp']==.
			local ++row
		}		
	}
}

* put tests across waves into table
forvalues i=1/3 {
	di "in aez tests loop, i=`i'"
	local j = 6 + `i'
	if `i' == 1 {
		local zone 12
	}
	else if `i' == 2 {
		local zone 13
	}
	else {
		local zone 23
	}
	replace col`j' = `ET_sym_zone`zone'_p'  in 1
	replace col`j' = `ET_asym_inc_zone`zone'_p'  in 3
	replace col`j' = `ET_asym_dec_zone`zone'_p'  in 5
	replace col`j' = `ET_sym_harv_zone`zone'_p'  in 7
	replace col`j' = `ET_asym_inc_harv_zone`zone'_p'  in 9
	replace col`j' = `ET_asym_dec_harv_zone`zone'_p'  in 11
}

* add the F-tests for differences across activities
forvalues j = 1/3 {
	local i = 2*`j'-1
	replace col`i' =  `ET_sym_ref_harv_zone`j'' in 15
	local i = 2*`j'
	replace col`i' =  `ET_inc_ref_harv_zone`j'' in 16
	replace col`i' =  `ET_dec_ref_harv_zone`j'' in 17	
}

*convert cells to strings
forvalues j=1/9 {
	di "in format loop with j=`j'"

	tostring col`j', replace force format(%9.3f)

	forvalues row=1(2)11 {
		replace col`j' = "$"+col`j'+"^"+star`j'+"$" in `row' if star`j'[`row']!=""
		di "value =  col`j'[`row']"
		di col`j'[`row']
		di " and strpos="  strpos(col`j'[`row'],".")
		replace col`j' = "" in `row' if strpos(col`j'[`row'],".")==1
	}
	forvalues row=2(2)12 {
		replace col`j' = "("+col`j'+")" in `row'
		replace col`j' = "" in `row' if col`j'[`row']=="(.)"
	}
}

*observations in bottom panel
local j 1
foreach var in sym asym {
	di "obv local = ET_`var'_obv"
	gen ET_`var' = `ET_`var'_obv' in 18
	tostring ET_`var', replace force format(%8.0fc)
	replace col`j' = ET_`var' in 18
	local ++j
}

keep col*
replace col9 = col9 + " \\"
outsheet using "$path/output/ET_aezs_margins.tex", replace delim("&") non noq


*create table of marginals and F-tests for Malawi results
clear
set obs 19
gen col0 = "Reference \$\times \Delta E\$" in 1
replace col0 = "Reference \$\times \Delta E^+\$" in 3
replace col0 = "Reference \$\times \Delta E^-\$" in 5
replace col0 = "Harvest \$\times \Delta E\$" in 7
replace col0 = "Harvest \$\times \Delta E^+\$" in 9
replace col0 = "Harvest \$\times \Delta E^-\$" in 11

replace col0 = "\hline Reference: Inc = Dec" in 13
replace col0 = "Harvest: Inc = Dec" in 14
replace col0 = "\hline Reference = Harvest" in 15
replace col0 = "Reference = Harvest, \$+\$" in 16
replace col0 = "Reference = Harvest, \$-\$" in 17
replace col0 = "\hline Observations" in 18
replace col0 = "\$R^2\$" in 19

forvalues i=1/9 {
	gen col`i' = . in 1
	gen star`i' = ""
}

forvalues i=1/3 {
	di "in regions loop, i=`i'"
	local j = 2*`i'-1
	if `i'==1 {
		local k=""
	}
	else {
		local k `i'
	}

	replace col`j' = `MW_sym_chg_le`k'_b' in 1
	replace col`j' = `MW_sym_chg_le`k'_p' in 2
	replace col`j' = `MW_sym_chg_harv`k'_b' in 7
	replace col`j' = `MW_sym_chg_harv`k'_p' in 8
	if `i'==1 {
		replace col`j' = `MW_sym_r2' in 19
	}

	local j = 2*`i'
	replace col`j' = `MW_asym_inc_le`k'_b' in 3
	replace col`j' = `MW_asym_inc_le`k'_p' in 4
	replace col`j' = `MW_asym_dec_le`k'_b' in 5
	replace col`j' = `MW_asym_dec_le`k'_p' in 6
	replace col`j' = `MW_asym_inc_harv`k'_b' in 9
	replace col`j' = `MW_asym_inc_harv`k'_p' in 10
	replace col`j' = `MW_asym_dec_harv`k'_b' in 11
	replace col`j' = `MW_asym_dec_harv`k'_p' in 12
	replace col`j' = `MW_asym_diff_pre`k'_p' in 13
	replace col`j' = `MW_asym_diff_harv`k'_p' in 14
	if `i'==1 {
		replace col`j' = `MW_asym_r2' in 19
	}

	* assigning stars
	forvalues j=1/6 {
		local row = 1
		foreach var in sym_chg_le asym_inc_le asym_dec_le sym_chg_harv asym_inc_harv asym_dec_harv {
			local temp = 2*`row'-1

			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "country_var_p = MW_`var'_p"
			if `j'<3 {
				local p_var  MW_`var'_p
			}
			else if `j'>2 & `j'<5 {
				local p_var  MW_`var'2_p	
			}
			else {
				local p_var  MW_`var'3_p	
			}
			di "p_var = `p_var'"
			replace star`j' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`j' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`j' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`j' = "" in `temp' if col`j'[`temp']==.
			local ++row
		}		
	}
}

* put tests across waves into table
forvalues i=1/3 {
	di "in aez tests loop, i=`i'"
	local j = 6 + `i'
	if `i' == 1 {
		local zone 12
	}
	else if `i' == 2 {
		local zone 13
	}
	else {
		local zone 23
	}
	replace col`j' = `MW_sym_zone`zone'_p'  in 1
	replace col`j' = `MW_asym_inc_zone`zone'_p'  in 3
	replace col`j' = `MW_asym_dec_zone`zone'_p'  in 5
	replace col`j' = `MW_sym_harv_zone`zone'_p'  in 7
	replace col`j' = `MW_asym_inc_harv_zone`zone'_p'  in 9
	replace col`j' = `MW_asym_dec_harv_zone`zone'_p'  in 11
}

* add the F-tests for differences across activities
forvalues j = 1/3 {
	local i = 2*`j'-1
	replace col`i' =  `MW_sym_ref_harv_zone`j'' in 15
	local i = 2*`j'
	replace col`i' =  `MW_inc_ref_harv_zone`j'' in 16
	replace col`i' =  `MW_dec_ref_harv_zone`j'' in 17	
}

*convert cells to strings
forvalues j=1/9 {
	di "in format loop with j=`j'"

	tostring col`j', replace force format(%9.3f)

	forvalues row=1(2)11 {
		replace col`j' = "$"+col`j'+"^"+star`j'+"$" in `row' if star`j'[`row']!=""
		di "value =  col`j'[`row']"
		di col`j'[`row']
		di " and strpos="  strpos(col`j'[`row'],".")
		replace col`j' = "" in `row' if strpos(col`j'[`row'],".")==1
	}
	forvalues row=2(2)12 {
		replace col`j' = "("+col`j'+")" in `row'
		replace col`j' = "" in `row' if col`j'[`row']=="(.)"
	}
}

*observations in bottom panel
local j 1
foreach var in sym asym {
	di "obv local = MW_`var'_obv"
	gen MW_`var' = `MW_`var'_obv' in 18
	tostring MW_`var', replace force format(%8.0fc)
	replace col`j' = MW_`var' in 18
	local ++j
}

keep col*
replace col9 = col9 + " \\"
outsheet using "$path/output/MW_aezs_margins.tex", replace delim("&") non noq


*create table of marginals and F-tests for Tanzania results
clear
set obs 32
gen col0 = "Reference \$\times \Delta E\$" in 1
replace col0 = "Reference \$\times \Delta E^+\$" in 3
replace col0 = "Reference \$\times \Delta E^-\$" in 5
replace col0 = "Harvest \$\times \Delta E\$" in 7
replace col0 = "Harvest \$\times \Delta E^+\$" in 9
replace col0 = "Harvest \$\times \Delta E^-\$" in 11
replace col0 = "Weeding \$\times \Delta E\$" in 13
replace col0 = "Weeding \$\times \Delta E^+\$" in 15
replace col0 = "Weeding \$\times \Delta E^-\$" in 17

replace col0 = "\hline Reference: Inc = Dec" in 19
replace col0 = "Harvest: Inc = Dec" in 20
replace col0 = "Weeding: Inc = Dec" in 21
replace col0 = "\hline Reference = Harvest" in 22
replace col0 = "Reference = Weeding" in 23
replace col0 = "Weeding = Harvest" in 24
replace col0 = "Reference = Harvest, \$+\$" in 25
replace col0 = "Reference = Harvest, \$-\$" in 26
replace col0 = "Reference = Weeding, \$+\$" in 27
replace col0 = "Reference = Weeding, \$-\$" in 28
replace col0 = "Weeding = Harvest, \$+\$" in 29
replace col0 = "Weeding = Harvest, \$-\$" in 30
replace col0 = "\hline Observations" in 31
replace col0 = "\$R^2\$" in 32

forvalues i=1/9 {
	gen col`i' = . in 1
	gen star`i' = ""
}

forvalues i=1/3 {
	di "in regions loop, i=`i'"
	local j = 2*`i'-1
	if `i'==1 {
		local k=""
	}
	else {
		local k `i'
	}

	replace col`j' = `TZ_sym_chg_le`k'_b' in 1
	replace col`j' = `TZ_sym_chg_le`k'_p' in 2
	replace col`j' = `TZ_sym_chg_harv`k'_b' in 7
	replace col`j' = `TZ_sym_chg_harv`k'_p' in 8
	replace col`j' = `TZ_sym_chg_weed`k'_b' in 13
	replace col`j' = `TZ_sym_chg_weed`k'_p' in 14
	if `i'==1 {
		replace col`j' = `TZ_sym_r2' in 32
	}

	local j = 2*`i'
	replace col`j' = `TZ_asym_inc_le`k'_b' in 3
	replace col`j' = `TZ_asym_inc_le`k'_p' in 4
	replace col`j' = `TZ_asym_dec_le`k'_b' in 5
	replace col`j' = `TZ_asym_dec_le`k'_p' in 6
	replace col`j' = `TZ_asym_diff_pre`k'_p' in 19
	replace col`j' = `TZ_asym_inc_harv`k'_b' in 9
	replace col`j' = `TZ_asym_inc_harv`k'_p' in 10
	replace col`j' = `TZ_asym_dec_harv`k'_b' in 11
	replace col`j' = `TZ_asym_dec_harv`k'_p' in 12
	replace col`j' = `TZ_asym_diff_harv`k'_p' in 20
	replace col`j' = `TZ_asym_inc_weed`k'_b' in 15
	replace col`j' = `TZ_asym_inc_weed`k'_p' in 16
	replace col`j' = `TZ_asym_dec_weed`k'_b' in 17
	replace col`j' = `TZ_asym_dec_weed`k'_p' in 18
	replace col`j' = `TZ_asym_diff_weed`k'_p' in 21
	if `i'==1 {
		replace col`j' = `TZ_asym_r2' in 32
	}

	* assigning stars
	forvalues j=1/6 {
		local row = 1
		foreach var in sym_chg_le asym_inc_le asym_dec_le sym_chg_harv asym_inc_harv asym_dec_harv sym_chg_weed asym_inc_weed asym_dec_weed {
			local temp = 2*`row'-1

			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "country_var_p = TZ_`var'_p"
			if `j'<3 {
				local p_var  TZ_`var'_p
			}
			else if `j'>2 & `j'<5 {
				local p_var  TZ_`var'2_p	
			}
			else {
				local p_var  TZ_`var'3_p	
			}
			di "p_var = `p_var'"
			di "p_var = ``p_var''"
			replace star`j' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`j' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`j' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`j' = "" in `temp' if col`j'[`temp']==.
			local ++row
		}		
	}
}

* put tests across waves into table
forvalues i=1/3 {
	di "in aez tests loop, i=`i'"
	local j = 6 + `i'
	if `i' == 1 {
		local zone 12
	}
	else if `i' == 2 {
		local zone 13
	}
	else {
		local zone 23
	}
	replace col`j' = `TZ_sym_zone`zone'_p'  in 1
	replace col`j' = `TZ_asym_inc_zone`zone'_p'  in 3
	replace col`j' = `TZ_asym_dec_zone`zone'_p'  in 5
	replace col`j' = `TZ_sym_harv_zone`zone'_p'  in 7
	replace col`j' = `TZ_asym_inc_harv_zone`zone'_p'  in 9
	replace col`j' = `TZ_asym_dec_harv_zone`zone'_p'  in 11
	replace col`j' = `TZ_sym_weed_zone`zone'_p'  in 13
	replace col`j' = `TZ_asym_inc_weed_zone`zone'_p'  in 15
	replace col`j' = `TZ_asym_dec_weed_zone`zone'_p'  in 17
}

* add the F-tests for differences across activities
forvalues j = 1/3 {
	local i = 2*`j'-1
	replace col`i' =  `TZ_sym_ref_harv_zone`j'' in 22
	replace col`i' =  `TZ_sym_ref_weed_zone`j'' in 23
	replace col`i' =  `TZ_sym_harv_weed_zone`j'' in 24
	local i = 2*`j'
	replace col`i' =  `TZ_inc_ref_harv_zone`j'' in 25
	replace col`i' =  `TZ_dec_ref_harv_zone`j'' in 26	
	replace col`i' =  `TZ_inc_ref_weed_zone`j'' in 27
	replace col`i' =  `TZ_dec_ref_weed_zone`j'' in 28
	replace col`i' =  `TZ_inc_harv_weed_zone`j'' in 29
	replace col`i' =  `TZ_dec_harv_weed_zone`j'' in 30	
}

*convert cells to strings
forvalues j=1/9 {
	di "in format loop with j=`j'"

	tostring col`j', replace force format(%9.3f)

	forvalues row=1(2)17 {
		replace col`j' = "$"+col`j'+"^"+star`j'+"$" in `row' if star`j'[`row']!=""
		di "value =  col`j'[`row']"
		di col`j'[`row']
		di " and strpos="  strpos(col`j'[`row'],".")
		replace col`j' = "" in `row' if strpos(col`j'[`row'],".")==1
	}
	forvalues row=2(2)18 {
		replace col`j' = "("+col`j'+")" in `row'
		replace col`j' = "" in `row' if col`j'[`row']=="(.)"
	}
}

*observations in bottom panel
local j 1
foreach var in sym asym {
	di "obv local = TZ_`var'_obv"
	gen TZ_`var' = `TZ_`var'_obv' in 31
	tostring TZ_`var', replace force format(%8.0fc)
	replace col`j' = TZ_`var' in 31
	local ++j
}

keep col*
replace col9 = col9 + " \\"
outsheet using "$path/output/TZ_aezs_margins.tex", replace delim("&") non noq



*create table of marginals and F-tests for Uganda results
clear
set obs 9
gen col0 = "Reference \$\times \Delta E\$" in 1
replace col0 = "Reference \$\times \Delta E^+\$" in 3
replace col0 = "Reference \$\times \Delta E^-\$" in 5

replace col0 = "\hline Reference: Inc = Dec" in 7
replace col0 = "\hline Observations" in 8
replace col0 = "\$R^2\$" in 9

forvalues i=1/9 {
	gen col`i' = . in 1
	gen star`i' = ""
}

forvalues i=1/3 {
	di "in regions loop, i=`i'"
	local j = 2*`i'-1
	if `i'==1 {
		local k=""
	}
	else {
		local k `i'
	}

	replace col`j' = `UG_sym_chg_le`k'_b' in 1
	replace col`j' = `UG_sym_chg_le`k'_p' in 2
	if `i'==1 {
		replace col`j' = `UG_sym_r2' in 9
	}

	local j = 2*`i'
	replace col`j' = `UG_asym_inc_le`k'_b' in 3
	replace col`j' = `UG_asym_inc_le`k'_p' in 4
	replace col`j' = `UG_asym_dec_le`k'_b' in 5
	replace col`j' = `UG_asym_dec_le`k'_p' in 6
	replace col`j' = `UG_asym_diff_pre`k'_p' in 7
	if `i'==1 {
		replace col`j' = `UG_asym_r2' in 9
	}

	* assigning stars
	forvalues j=1/6 {
		local row = 1
		foreach var in sym_chg_le asym_inc_le asym_dec_le {
			local temp = 2*`row'-1

			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "country_var_p = UG_`var'_p"
			if `j'<3 {
				local p_var  UG_`var'_p
			}
			else if `j'>2 & `j'<5 {
				local p_var  UG_`var'2_p	
			}
			else {
				local p_var UG_`var'3_p
			}
			di "p_var = `p_var'"
			replace star`j' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`j' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`j' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`j' = "" in `temp' if col`j'[`temp']==.
			local ++row
		}		
	}
}

* put tests across waves into table
forvalues i=1/3 {
	di "in aez tests loop, i=`i'"
	local j = 6 + `i'
	if `i' == 1 {
		local zone 12
	}
	else if `i' == 2 {
		local zone 13
	}
	else {
		local zone 23
	}
	replace col`j' = `UG_sym_zone`zone'_p'  in 1
	replace col`j' = `UG_asym_inc_zone`zone'_p'  in 3
	replace col`j' = `UG_asym_dec_zone`zone'_p'  in 5
}

*convert cells to strings
forvalues j=1/9 {
	di "in format loop with j=`j'"

	tostring col`j', replace force format(%9.3f)

	forvalues row=1(2)5 {
		replace col`j' = "$"+col`j'+"^"+star`j'+"$" in `row' if star`j'[`row']!=""
		di "value =  col`j'[`row']"
		di col`j'[`row']
		di " and strpos="  strpos(col`j'[`row'],".")
		replace col`j' = "" in `row' if strpos(col`j'[`row'],".")==1
	}
	forvalues row=2(2)6 {
		replace col`j' = "("+col`j'+")" in `row'
		replace col`j' = "" in `row' if col`j'[`row']=="(.)"
	}
}

*observations in bottom panel
local j 1
foreach var in sym asym {
	di "obv local = UG_`var'_obv"
	gen UG_`var' = `UG_`var'_obv' in 8
	tostring UG_`var', replace force format(%8.0fc)
	replace col`j' = UG_`var' in 8
	local ++j
}

keep col*
replace col9 = col9 + " \\"
outsheet using "$path/output/UG_aezs_margins.tex", replace delim("&") non noq


exit






