
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear



*********************************************************************************************************************
* pwb - added triggers to allow harvest labor as outcome var and control which hh size variable to use

local dep_var act_log_ld

*********************************************************************************************************************


* Combined results for output

**** Ethiopia *****

* pooled cross-section results
use "$path/Constructed Data/ET panel data merged", replace
egen ea_wave = group(ea1 wave)

xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea1, cluster(ea_wave)
eststo ET_pool
test $hhsize_var = 0
local ET_pool_le_b = _b[$hhsize_var]
local ET_pool_le_p = r(p)
local ET_pool_obv = e(N)
local ET_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave

*merge in agedin information
merge m:1 hhid using "$path/Constructed Data/ET_hhld_movers.dta"

gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0

sort hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var log_hhsize2 share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}

reg diff_log_ld_tot_kids diff_log_hhsize2 log_agedin2 diff_log_A diff_sh*, cluster(ea_wave)
eststo ET_panel
test diff_log_hhsize2 = 0
local ET_panel_le_b1 = _b[diff_log_hhsize2]
local ET_panel_le_p1 = r(p)
test log_agedin2 = 0
local ET_panel_le_b2 = _b[log_agedin2]
local ET_panel_le_p2 = r(p)
local ET_panel_obv = e(N)
local ET_panel_r2 = e(r2)

* base symmetric results
use "$newdata/ET_reg_ready", clear		// generated in the "Ethiopia panel analysis.do" file
egen ea_wave = group(ea1 wave)
gen harv = activity==1

merge m:1 hhid using "$path/Constructed Data/ET_hhld_movers.dta"
gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0
sort hhid wave
by hhid:gen diff_log_hhsize2 = D.log_hhsize2

gen change_harv2 = diff_log_hhsize2*harv
gen change_harv_age = log_agedin2 *harv
gen INC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2>0)
gen INC_agedin = log_agedin2 * (log_agedin2>0)
gen DEC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2<0)

gen INC_harv2 = INC_hhsize2*harv
gen DEC_harv2 = DEC_hhsize2*harv
gen INC_harv_age = INC_agedin*harv

reg diff_`dep_var' harv diff_log_hhsize2 log_agedin2 change_harv* diff_log_A diff_sh* , cluster(ea_wave)
eststo ET_sym
local ET_sym_chg_le_b1 = _b[diff_log_hhsize2]
test diff_log_hhsize2 =0
local ET_sym_chg_le_p1 = r(p)
local ET_sym_chg_harv_b1 = _b[diff_log_hhsize2] + _b[change_harv2]
test _b[diff_log_hhsize2] + _b[change_harv2] = 0
local ET_sym_chg_harv_p1 = r(p)
test _b[change_harv2] = 0
local ET_sym_ref_harv1 = r(p)

local ET_sym_chg_le_b2 = _b[log_agedin2]
test log_agedin2 =0
local ET_sym_chg_le_p2 = r(p)
local ET_sym_chg_harv_b2 = _b[log_agedin2] + _b[change_harv_age]
test _b[log_agedin2] + _b[change_harv_age] = 0
local ET_sym_chg_harv_p2 = r(p)
test _b[change_harv_age] = 0
local ET_sym_ref_harv2 = r(p)

local ET_sym_obv = e(N)
local ET_sym_r2 = e(r2)

* asymmetric results
reg diff_`dep_var' harv INC_hhsize2 INC_harv2 DEC_hhsize2 DEC_harv2 INC_agedin INC_harv_age diff_log_A diff_sh* , cluster(ea_wave)
eststo ET_asym
test INC_hhsize2 - DEC_hhsize2 = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre_p1 = r(p)
test INC_hhsize2 + INC_harv2 - DEC_hhsize2 - DEC_harv2 = 0		// Check whether harvest values are different
local ET_asym_diff_harv_p1 = r(p)

local ET_asym_inc_le_b1 = _b[INC_hhsize2]
test INC_hhsize2=0
local ET_asym_inc_le_p1 = r(p)
local ET_asym_dec_le_b1 = _b[DEC_hhsize2]
test DEC_hhsize2=0
local ET_asym_dec_le_p1 = r(p)
local ET_asym_inc_harv_b1 = _b[INC_hhsize2] + _b[INC_harv2]
test _b[INC_hhsize2] + _b[INC_harv2] = 0
local ET_asym_inc_harv_p1 = r(p)
local ET_asym_dec_harv_b1 = _b[DEC_hhsize2] + _b[DEC_harv2]
test _b[DEC_hhsize2] + _b[DEC_harv2] = 0
local ET_asym_dec_harv_p1 = r(p)
local ET_asym_obv = e(N)
local ET_asym_r2 = e(r2)
test _b[INC_harv2] = 0
local ET_inc_ref_harv1 = r(p)
test _b[DEC_harv2] = 0
local ET_dec_ref_harv1 = r(p)

local ET_asym_inc_le_b2 = _b[INC_agedin]
test INC_agedin=0
local ET_asym_inc_le_p2 = r(p)
local ET_asym_inc_harv_b2 = _b[INC_agedin] + _b[INC_harv_age]
test _b[INC_agedin] + _b[INC_harv_age] = 0
local ET_asym_inc_harv_p2 = r(p)
test _b[INC_harv_age] = 0
local ET_inc_ref_harv2 = r(p)


***** Malawi *****

* pooled cross-section results
use "$path/Constructed Data/Malawi Panel Data Clean", replace
egen ea_wave = group(ea1 wave)
xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea1, cluster(ea_wave)
eststo MW_pool
test $hhsize_var = 0
local MW_pool_le_b = _b[$hhsize_var]
local MW_pool_le_p = r(p)
local MW_pool_obv = e(N)
local MW_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave

*merge in agedin information
merge m:1 hhid using "$path/Constructed Data/MW_hhld_movers.dta"

gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0

sort hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var log_hhsize2 share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}

reg diff_log_ld_tot_kids diff_log_hhsize2 log_agedin diff_log_A diff_sh*, cluster(ea_wave)
eststo MW_panel
test diff_log_hhsize2= 0
local MW_panel_le_b1 = _b[diff_log_hhsize2]
local MW_panel_le_p1 = r(p)
test log_agedin = 0
local MW_panel_le_b2 = _b[log_agedin]
local MW_panel_le_p2 = r(p)
local MW_panel_obv = e(N)
local MW_panel_r2 = e(r2)

* base symmetric results
use "$newdata/MW_reg_ready.dta", clear		// generated in the "Malawi panel analysis final.do" file
egen ea_wave = group(ea1 wave)
gen harv = activity==1

merge m:1 hhid using "$path/Constructed Data/MW_hhld_movers.dta"
gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0
sort hhid wave
by hhid: gen diff_log_hhsize2 = D.log_hhsize2

gen change_harv2 = diff_log_hhsize2*harv
gen change_harv_age = log_agedin2 *harv
gen INC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2>0)
gen INC_agedin = log_agedin2 * (log_agedin2>0)
gen DEC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2<0)

gen INC_harv2 = INC_hhsize2*harv
gen DEC_harv2 = DEC_hhsize2*harv
gen INC_harv_age = INC_agedin*harv

reg diff_`dep_var' harv diff_log_hhsize2 log_agedin change_harv* diff_log_A diff_sh* , cluster(ea_wave)
eststo MW_sym
local MW_sym_chg_le_b1 = _b[diff_log_hhsize2]
test diff_log_hhsize2 =0
local MW_sym_chg_le_p1 = r(p)
local MW_sym_chg_harv_b1 = _b[diff_log_hhsize2] + _b[change_harv2]
test _b[diff_log_hhsize2] + _b[change_harv2] = 0
local MW_sym_chg_harv_p1 = r(p)
test _b[change_harv2] = 0
local MW_sym_ref_harv1 = r(p)

local MW_sym_chg_le_b2 = _b[log_agedin]
test log_agedin =0
local MW_sym_chg_le_p2 = r(p)
local MW_sym_chg_harv_b2 = _b[log_agedin] + _b[change_harv_age]
test _b[log_agedin] + _b[change_harv_age] = 0
local MW_sym_chg_harv_p2 = r(p)
test _b[change_harv_age] = 0
local MW_sym_ref_harv2 = r(p)

local MW_sym_obv = e(N)
local MW_sym_r2 = e(r2)

* asymmetric results
reg diff_`dep_var' harv INC_hhsize2 INC_harv2 DEC_hhsize2 DEC_harv2 INC_agedin INC_harv_age diff_log_A diff_sh* , cluster(ea_wave)
eststo MW_asym
test INC_hhsize2 - DEC_hhsize2 = 0		// Check whether pre-harvest values are different
local MW_asym_diff_pre_p1 = r(p)
test INC_hhsize2 + INC_harv2 - DEC_hhsize2 - DEC_harv2 = 0		// Check whether harvest values are different
local MW_asym_diff_harv_p1 = r(p)

local MW_asym_inc_le_b1 = _b[INC_hhsize2]
test INC_hhsize2=0
local MW_asym_inc_le_p1 = r(p)
local MW_asym_dec_le_b1 = _b[DEC_hhsize2]
test DEC_hhsize2=0
local MW_asym_dec_le_p1 = r(p)
local MW_asym_inc_harv_b1 = _b[INC_hhsize2] + _b[INC_harv2]
test _b[INC_hhsize2] + _b[INC_harv2] = 0
local MW_asym_inc_harv_p1 = r(p)
local MW_asym_dec_harv_b1 = _b[DEC_hhsize2] + _b[DEC_harv2]
test _b[DEC_hhsize2] + _b[DEC_harv2] = 0
local MW_asym_dec_harv_p1 = r(p)
local MW_asym_obv = e(N)
local MW_asym_r2 = e(r2)
test _b[INC_harv2] = 0
local MW_inc_ref_harv1 = r(p)
test _b[DEC_harv2] = 0
local MW_dec_ref_harv1 = r(p)

local MW_asym_inc_le_b2 = _b[INC_agedin]
test INC_agedin =0
local MW_asym_inc_le_p2 = r(p)
local MW_asym_inc_harv_b2 = _b[INC_agedin] + _b[INC_harv_age]
test _b[INC_agedin] + _b[INC_harv_age] = 0
local MW_asym_inc_harv_p2 = r(p)
test _b[INC_harv_age] = 0
local MW_inc_ref_harv2 = r(p)


***** Tanzania *****

* pooled cross-section results
use "$path/Constructed Data/TZ panel data merged", replace
egen ea_wave = group(ea1 wave)
xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea1, cluster(ea_wave)
eststo TZ_pool
test $hhsize_var = 0
local TZ_pool_le_b = _b[$hhsize_var]
local TZ_pool_le_p = r(p)
local TZ_pool_obv = e(N)
local TZ_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
*merge in agedin information
merge 1:1 hhid wave using "$path/Constructed Data/TZ_hhld_movers.dta"

gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0

sort hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var log_hhsize2 share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}

reg diff_log_ld_tot_kids diff_log_hhsize2 log_agedin diff_log_A diff_sh* wave3, cluster(ea_wave)
eststo TZ_panel
test diff_log_hhsize2= 0
local TZ_panel_le_b1 = _b[diff_log_hhsize2]
local TZ_panel_le_p1 = r(p)
test log_agedin= 0
local TZ_panel_le_b2 = _b[log_agedin]
local TZ_panel_le_p2 = r(p)
local TZ_panel_obv = e(N)
local TZ_panel_r2 = e(r2)

* base symmetric results
use "$newdata/TZ_reg_ready.dta", clear		// generated in the "Tanzania panel analysis final.do" file
egen ea_wave = group(ea1 wave)
gen weed = activity==1
gen harv = activity==2

merge m:1 hhid wave using "$path/Constructed Data/TZ_hhld_movers.dta"
gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0
sort hhid wave
by hhid: gen diff_log_hhsize2 = D.log_hhsize2

gen change_harv2 = diff_log_hhsize2*harv
gen change_harv_age = log_agedin2 *harv
gen INC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2>0)
gen INC_agedin = log_agedin2 * (log_agedin2>0)
gen DEC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2<0)

gen INC_harv2 = INC_hhsize2*harv
gen DEC_harv2 = DEC_hhsize2*harv
gen INC_harv_age = INC_agedin*harv

gen change_weed2 = diff_log_hhsize2*weed
gen change_weed_age = log_agedin2 *weed

gen INC_weed2 = INC_hhsize2*weed
gen DEC_weed2 = DEC_hhsize2*weed
gen INC_weed_age = INC_agedin*weed


reg diff_`dep_var' weed harv diff_log_hhsize2 log_agedin change_weed2 change_harv2 change_weed_age change_harv_age diff_log_A diff_sh* wave3 , cluster(ea_wave)
eststo TZ_sym
local TZ_sym_chg_le_b1 = _b[diff_log_hhsize2]
test diff_log_hhsize2 =0
local TZ_sym_chg_le_p1 = r(p)
local TZ_sym_chg_harv_b1 = _b[diff_log_hhsize2] + _b[change_harv2]
test _b[diff_log_hhsize2] + _b[change_harv2] = 0
local TZ_sym_chg_harv_p1 = r(p)
local TZ_sym_chg_weed_b1 = _b[diff_log_hhsize2] + _b[change_weed2]
test _b[diff_log_hhsize2] + _b[change_weed2] = 0
local TZ_sym_chg_weed_p1 = r(p)

local TZ_sym_chg_le_b2 = _b[log_agedin]
test log_agedin =0
local TZ_sym_chg_le_p2 = r(p)
local TZ_sym_chg_harv_b2 = _b[log_agedin] + _b[change_harv_age]
test _b[log_agedin] + _b[change_harv_age] = 0
local TZ_sym_chg_harv_p2 = r(p)
local TZ_sym_chg_weed_b2 = _b[log_agedin] + _b[change_weed_age]
test _b[log_agedin] + _b[change_weed_age] = 0
local TZ_sym_chg_weed_p2 = r(p)

local TZ_sym_obv = e(N)
local TZ_sym_r2 = e(r2)
test _b[change_harv2] = 0
local TZ_sym_ref_harv1 = r(p)
test _b[change_weed2] = 0
local TZ_sym_ref_weed1 = r(p)
test _b[change_harv2] - _b[change_weed2] = 0
local TZ_sym_harv_weed1 = r(p)
test _b[change_harv_age] = 0
local TZ_sym_ref_harv2 = r(p)
test _b[change_weed_age] = 0
local TZ_sym_ref_weed2 = r(p)
test _b[change_harv_age] - _b[change_weed_age] = 0
local TZ_sym_harv_weed2 = r(p)


* asymmetric results
reg diff_`dep_var' weed harv INC_hhsize2 INC_agedin INC_weed2 INC_weed_age INC_harv2 INC_harv_age DEC_hhsize2 DEC_weed2 DEC_harv2 diff_log_A diff_sh* wave3 , cluster(ea_wave)
eststo TZ_asym
test INC_hhsize2 - DEC_hhsize2 = 0		// Check whether pre-harvest values are different
local TZ_asym_diff_pre_p1 = r(p)
test INC_hhsize2 + INC_harv2 - DEC_hhsize2 - DEC_harv2 = 0		// Check whether harvest values are different
local TZ_asym_diff_harv_p1 = r(p)
test INC_hhsize2 + INC_weed2 - DEC_hhsize2 - DEC_weed2 = 0		// Check whether weeding values are different
local TZ_asym_diff_weed_p1 = r(p)


local TZ_asym_inc_le_b1 = _b[INC_hhsize2]
test INC_hhsize2=0
local TZ_asym_inc_le_p1 = r(p)
local TZ_asym_dec_le_b1 = _b[DEC_hhsize2]
test DEC_hhsize2=0
local TZ_asym_dec_le_p1 = r(p)
local TZ_asym_inc_harv_b1 = _b[INC_hhsize2] + _b[INC_harv2]
test _b[INC_hhsize2] + _b[INC_harv2] = 0
local TZ_asym_inc_harv_p1 = r(p)
local TZ_asym_dec_harv_b1 = _b[DEC_hhsize2] + _b[DEC_harv2]
test _b[DEC_hhsize2] + _b[DEC_harv2] = 0
local TZ_asym_dec_harv_p1 = r(p)
local TZ_asym_inc_weed_b1 = _b[INC_hhsize2] + _b[INC_weed2]
test _b[INC_hhsize2] + _b[INC_weed2] = 0
local TZ_asym_inc_weed_p1 = r(p)
local TZ_asym_dec_weed_b1 = _b[DEC_hhsize2] + _b[DEC_weed2]
test _b[DEC_hhsize2] + _b[DEC_weed2] = 0
local TZ_asym_dec_weed_p1 = r(p)
local TZ_asym_obv = e(N)
local TZ_asym_r2 = e(r2)
test _b[INC_harv2] = 0
local TZ_inc_ref_harv1 = r(p)
test _b[DEC_harv2] = 0
local TZ_dec_ref_harv1 = r(p)
test _b[INC_weed2] = 0
local TZ_inc_ref_weed1 = r(p)
test _b[DEC_weed2] = 0
local TZ_dec_ref_weed1 = r(p)
test _b[INC_weed2] - _b[INC_harv2]= 0
local TZ_inc_harv_weed1 = r(p)
test _b[DEC_weed2]- _b[DEC_harv2] = 0
local TZ_dec_harv_weed1 = r(p)

local TZ_asym_inc_le_b2 = _b[INC_agedin]
test INC_agedin=0
local TZ_asym_inc_le_p2 = r(p)
local TZ_asym_inc_harv_b2 = _b[INC_agedin] + _b[INC_harv_age]
test _b[INC_agedin] + _b[INC_harv_age] = 0
local TZ_asym_inc_harv_p2 = r(p)
local TZ_asym_inc_weed_b2 = _b[INC_agedin] + _b[INC_weed_age]
test _b[INC_agedin] + _b[INC_weed_age] = 0
local TZ_asym_inc_weed_p2 = r(p)
test _b[INC_harv_age] = 0
local TZ_inc_ref_harv2 = r(p)
test _b[INC_weed_age] = 0
local TZ_inc_ref_weed2 = r(p)
test _b[INC_weed_age] - _b[INC_harv_age]= 0
local TZ_inc_harv_weed2 = r(p)

***** Uganda *****
* pooled cross-section results
use "$path/Constructed Data/UG panel data merged", replace
egen ea_wave = group(ea wave)
xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea, cluster(ea_wave)
eststo UG_pool
test $hhsize_var = 0
local UG_pool_le_b = _b[$hhsize_var]
local UG_pool_le_p = r(p)
local UG_pool_obv = e(N)
local UG_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave

*merge in agedin information
merge 1:1 hhid wave using "$path/Constructed Data/UG_hhld_movers.dta"

gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0

sort hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var log_hhsize2 share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}

reg diff_log_ld_tot_kids diff_log_hhsize2 log_agedin diff_log_A diff_sh* i.wave, cluster(ea_wave)
eststo UG_panel
test diff_log_hhsize2 = 0
local UG_panel_le_b1 = _b[diff_log_hhsize2]
local UG_panel_le_p1 = r(p)
test log_agedin = 0
local UG_panel_le_b2 = _b[log_agedin]
local UG_panel_le_p2 = r(p)
local UG_panel_obv = e(N)
local UG_panel_r2 = e(r2)

*base symmetric results
use "$newdata/UG_reg_ready", clear
egen ea_wave = group(ea wave)

merge 1:1 hhid wave using "$path/Constructed Data/UG_hhld_movers.dta"
gen hhsize2 = hhsize_phase - lf_agedin_2
gen log_hhsize2 = log_phase
replace log_hhsize2 = ln(hhsize2) if wave!=1
gen log_agedin2 = ln(lf_agedin_2)
replace log_agedin2 = ln(0.1) if lf_agedin_2==0
sort hhid wave
by hhid: gen diff_log_hhsize2 = D.log_hhsize2

gen INC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2>0)
gen INC_agedin = log_agedin2 * (log_agedin2>0)
gen DEC_hhsize2 = diff_log_hhsize2 * (diff_log_hhsize2<0)


reg diff_`dep_var' diff_log_hhsize2 log_agedin diff_log_A diff_sh* i.wave, cluster(ea_wave)
eststo UG_sym
local UG_sym_chg_le_b1 = _b[diff_log_hhsize2]
test diff_log_hhsize2 =0
local UG_sym_chg_le_p1 = r(p)
local UG_sym_chg_le_b2 = _b[log_agedin]
test log_agedin =0
local UG_sym_chg_le_p2 = r(p)
local UG_sym_obv = e(N)
local UG_sym_r2 = e(r2)

*asymmetric results
reg diff_`dep_var' INC_hhsize2 DEC_hhsize2 INC_agedin diff_log_A diff_sh* i.wave, cluster(ea_wave)
eststo UG_asym
test INC_hhsize2 - DEC_hhsize2 = 0		// Check whether pre-harvest values are different
local UG_asym_diff_pre_p1 = r(p)

local UG_asym_inc_le_b1 = _b[INC_hhsize2]
test INC_hhsize2=0
local UG_asym_inc_le_p1 = r(p)
local UG_asym_dec_le_b1 = _b[DEC_hhsize2]
test DEC_hhsize2=0
local UG_asym_dec_le_p1 = r(p)
local UG_asym_inc_le_b2 = _b[INC_agedin]
test INC_agedin=0
local UG_asym_inc_le_p2 = r(p)
local UG_asym_obv = e(N)
local UG_asym_r2 = e(r2)


** Output raw results
estout ET_pool ET_panel MW_pool MW_panel TZ_pool TZ_panel UG_pool UG_panel using "$path/output/ALL_raw_all_agedin.tex", ///
	cells(b(star fmt(3)) se(par fmt(3))) order(log_phase diff_log_hhsize2 log_agedin log_A diff_log_A share_pm share_pf share_em diff_share_pm diff_share_pf diff_share_em) ///
	varl(diff_log_hhsize2 "\$\Delta E\$" log_agedin "ln(agedin)" diff_log_A "\$\Delta\$ Acres Cultivated" diff_share_pm "\$\Delta\$ Prime Male Share" diff_share_pf "\$\Delta\$ Prime Female Share" diff_share_em "\$\Delta\$ Elderly Male Share" log_phase "\$E\$" log_A "Acres Cultivated" share_pm "Prime Male Share" share_pf "Prime Female Share" share_em "Elderly Male Share" _cons Constant) ///
	nonumbers collabels(none) mlabels(none) end(" \\ ") stats(N r2_a, fmt(0 3) labels("\hline Observations" "Adj. \$R^2$")) starlevels(* 0.10 ** 0.05 *** 0.01) drop(*ea1* *ea_* wave*) style(tex) replace

estout ET_sym ET_asym MW_sym MW_asym TZ_sym TZ_asym UG_sym UG_asym using "$path/output/ALL_raw_byact_agedin.tex", ///
	cells(b(star fmt(3)) se(par fmt(3))) order(diff_log_hhsize2 log_agedin INC_hhsize2 INC_agedin DEC_hhsize2 harv change_harv2 change_harv_age INC_harv2 INC_harv_age DEC_harv2 weed change_weed2 change_weed-age INC_weed2 INC_weed_age DEC_weed2 diff_log_A diff_share_pm diff_share_pf diff_share_em) ///
	varl(diff_log_hhsize2 "Reference \$\times \Delta E\$" log_agedin "Reference \$\times ln(agedin)\$" INC_hhsize2 "Reference \$\times \Delta E^+\$" INC_agedin "Reference \$\times ln(agedin) \$" DEC_hhsize2 "Reference \$\times \Delta E^-\$" harv "Harvest" change_harv2 "Harvest \$\times \Delta E\$" change_harv_age "Harvest \$\times ln(agedin) \$" INC_harv2 "Harvest \$\times \Delta E^+\$" INC_harv_age "Harvest \$\times ln(agedin) \$" DEC_harv "Harvest \$\times \Delta E^-\$" weed "Weeding" change_weed2 "Weeding \$\times \Delta E\$" change_weed_age "Weeding \$\times ln(agedin) \$" INC_weed2 "Weeding \$\times \Delta E^+\$" INC_weed_age "Weeding \$\times ln(agedin) \$" DEC_weed2 "Weeding \$\times \Delta E^-\$" ///
	diff_log_A "\$\Delta\$ Acres Cultivated" diff_share_pm "\$\Delta\$ Prime Male Share" diff_share_pf "\$\Delta\$ Prime Female Share" diff_share_em "\$\Delta\$ Elderly Male Share" log_phase "\hline \$\E\$" log_owned "Acres Cultivated" share_pm "Prime Male Share" share_pf "Prime Female Share" share_em "Elderly Male Share" _cons Constant) ///
	nonumbers collabels(none) mlabels(none) end(" \\ ") stats(N r2_a, fmt(0 3) labels("\hline Observations" "Adj. \$R^2$" )) starlevels(* 0.10 ** 0.05 *** 0.01) drop(wave*) style(tex) replace


** EXPORT marginal effects

*save data temporarily
tempfile export_data
save `export_data'


*create table of marginals and F-tests for asymmetric results
clear
set obs 60

gen col0 = " \textbf{All activities}" in 1
replace col0 = "Labor endow. (\$E\$)" in 2
replace col0 = "\$\Delta E\$" in 4
replace col0 = "\$ln(agedin)\$" in 6
replace col0 = "\hline Observations" in 8
replace col0 = "\$R^2\$" in 9

replace col0 = "\hline \hline \textbf{By activity}" in 10
replace col0 = "Reference \$\times \Delta E\$" in 11
replace col0 = "Reference \$\times ln(agedin)\$" in 13
replace col0 = "Reference \$\times \Delta E^+\$" in 15
replace col0 = "Reference \$\times ln(agedin)\$" in 17
replace col0 = "Reference \$\times \Delta E^-\$" in 19
replace col0 = "Harvest \$\times \Delta E\$" in 21
replace col0 = "Harvest \$\times ln(agedin)\$" in 23
replace col0 = "Harvest \$\times \Delta E^+\$" in 25
replace col0 = "Harvest \$\times ln(agedin)\$" in 27
replace col0 = "Harvest \$\times \Delta E^-\$" in 29
replace col0 = "Weeding \$\times \Delta E\$" in 31
replace col0 = "Weeding \$\times ln(agedin)\$" in 33
replace col0 = "Weeding \$\times \Delta E^+\$" in 35
replace col0 = "Weeding \$\times ln(agedin)\$" in 37
replace col0 = "Weeding \$\times \Delta E^-\$" in 39

replace col0 = "\hline Reference: Inc = Dec" in 41
replace col0 = "Harvest: Inc = Dec" in 42
replace col0 = "Weeding: Inc = Dec" in 43
replace col0 = "\hline Reference = Harvest" in 44
replace col0 = "Ref age = Harv age" in 45
replace col0 = "Reference = Weeding" in 46
replace col0 = "Ref age = Weed age" in 47
replace col0 = "Weeding = Harvest" in 48
replace col0 = "Weed age = Harv age" in 49
replace col0 = "Reference = Harvest, \$+\$" in 50
replace col0 = "Ref age = Harv age, \$+\$" in 51
replace col0 = "Reference = Harvest, \$-\$" in 52
replace col0 = "Reference = Weeding, \$+\$" in 53
replace col0 = "Ref age = Weed age, \$+\$" in 54
replace col0 = "Reference = Weeding, \$-\$" in 55
replace col0 = "Weeding = Harvest, \$+\$" in 56
replace col0 = "Weed age = Harv age, \$+\$" in 57
replace col0 = "Weeding = Harvest, \$-\$" in 58
replace col0 = "\hline Observations" in 59
replace col0 = "\$R^2\$" in 60

forvalues i=1/8 {
	gen col`i' = . in 1
	gen star`i' = ""
}

local i = 1
foreach country in ET MW TZ UG {
	local varlist
	di "in country loop, i=`i'"
	local j = 2*`i'-1
	replace col`j' = ``country'_pool_le_b' in 2
	replace col`j' = ``country'_pool_le_p' in 3
	replace col`j' = ``country'_pool_r2' in 9
	local j = 2*`i'
	replace col`j' = ``country'_panel_le_b1' in 4
	replace col`j' = ``country'_panel_le_p1' in 5
	replace col`j' = ``country'_panel_le_b2' in 6
	replace col`j' = ``country'_panel_le_p2' in 7
	replace col`j' = ``country'_panel_r2' in 9
	local j = 2*`i'-1
	replace col`j' = ``country'_sym_chg_le_b1' in 11
	replace col`j' = ``country'_sym_chg_le_p1' in 12
	replace col`j' = ``country'_sym_chg_le_b2' in 13
	replace col`j' = ``country'_sym_chg_le_p2' in 14
	replace col`j' = ``country'_sym_r2' in 60
	local j = 2*`i'
	replace col`j' = ``country'_asym_inc_le_b1' in 15
	replace col`j' = ``country'_asym_inc_le_p1' in 16
	replace col`j' = ``country'_asym_inc_le_b2' in 17
	replace col`j' = ``country'_asym_inc_le_p2' in 18
	replace col`j' = ``country'_asym_dec_le_b1' in 19
	replace col`j' = ``country'_asym_dec_le_p1' in 20
	replace col`j' = ``country'_asym_diff_pre_p1' in 41
	replace col`j' = ``country'_asym_r2' in 60

	if inlist(`i',1,2,3) {
		local j = 2*`i'-1
		replace col`j' = ``country'_sym_chg_harv_b1' in 21
		replace col`j' = ``country'_sym_chg_harv_p1' in 22
		replace col`j' = ``country'_sym_chg_harv_b2' in 23
		replace col`j' = ``country'_sym_chg_harv_p2' in 24

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_harv_b1' in 25
		replace col`j' = ``country'_asym_inc_harv_p1' in 26
		replace col`j' = ``country'_asym_inc_harv_b2' in 27
		replace col`j' = ``country'_asym_inc_harv_p2' in 28
		replace col`j' = ``country'_asym_dec_harv_b1' in 29
		replace col`j' = ``country'_asym_dec_harv_p1' in 30
		replace col`j' = ``country'_asym_diff_harv_p1' in 42
		local varlist sym_chg_harv_p1 sym_chg_harv_p2 asym_inc_harv_p1 asym_inc_harv_p2 asym_dec_harv_p1
	}
	if `i'==3 {
		local j = 2*`i'-1
		replace col`j' = ``country'_sym_chg_weed_b1' in 31
		replace col`j' = ``country'_sym_chg_weed_p1' in 32
		replace col`j' = ``country'_sym_chg_weed_b2' in 33
		replace col`j' = ``country'_sym_chg_weed_p2' in 34

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_weed_b1' in 35
		replace col`j' = ``country'_asym_inc_weed_p1' in 36
		replace col`j' = ``country'_asym_inc_weed_b2' in 37
		replace col`j' = ``country'_asym_inc_weed_p2' in 38
		replace col`j' = ``country'_asym_dec_weed_b1' in 39
		replace col`j' = ``country'_asym_dec_weed_p1' in 40
		replace col`j' = ``country'_asym_diff_weed_p1' in 43
		local varlist `varlist' sym_chg_weed_p1 sym_chg_weed_p2 asym_inc_weed_p1 asym_inc_weed_p2 asym_dec_weed_p1
	}

	* assigning stars for first 2 rows
	di "about to var list with varlist=`varlist'"
	forvalues j=1/2 {
		local row = 1
		foreach var in pool_le_p panel_le_p1 panel_le_p2 {
			local temp = 2*`row'
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'"
			local p_var  `country'_`var'
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}
	}

	* assigning stars for bottom panel
	forvalues j=1/2 {
		local row = 1
		foreach var in sym_chg_le_p1 sym_chg_le_p2 asym_inc_le_p1 asym_inc_le_p2 asym_dec_le_p1 `varlist' {
			local temp = 2*`row'+9
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'"
			local p_var  `country'_`var'
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}		
	}

	local ++i
}

* add the F-tests for differences across activities
local i = 1
foreach country in ET MW TZ {
	if "`country'"!="TZ" {
		replace col`i' =  ``country'_sym_ref_harv1' in 44
		replace col`i' =  ``country'_sym_ref_harv2' in 45
		local ++i
		replace col`i' =  ``country'_inc_ref_harv1' in 50
		replace col`i' =  ``country'_inc_ref_harv2' in 51
		replace col`i' =  ``country'_dec_ref_harv1' in 52	
	}
	if "`country'"=="TZ" {
		replace col`i' =  ``country'_sym_ref_harv1' in 44
		replace col`i' =  ``country'_sym_ref_weed1' in 46
		replace col`i' =  ``country'_sym_harv_weed1' in 48
		replace col`i' =  ``country'_sym_ref_harv2' in 45
		replace col`i' =  ``country'_sym_ref_weed2' in 47
		replace col`i' =  ``country'_sym_harv_weed2' in 49
		local ++i
		replace col`i' =  ``country'_inc_ref_harv1' in 50
		replace col`i' =  ``country'_inc_ref_harv2' in 51
		replace col`i' =  ``country'_dec_ref_harv1' in 52	
		replace col`i' =  ``country'_inc_ref_weed1' in 53
		replace col`i' =  ``country'_inc_ref_weed2' in 54
		replace col`i' =  ``country'_dec_ref_weed1' in 55
		replace col`i' =  ``country'_inc_harv_weed1' in 56
		replace col`i' =  ``country'_inc_harv_weed2' in 57
		replace col`i' =  ``country'_dec_harv_weed1' in 58
	}
	local ++i
}

*convert cells to strings
local i = 1
foreach country in ET MW TZ UG {
	forvalues j=1/2 {
		di "in format loop with country=`country', j=`j', and i=`i'"
		local col = 2*`i'-2+`j'
		tostring col`col', replace force format(%9.3f)
		*top panel
		forvalues row=2(2)6 {
			replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
			di "value =  col`col'[`row']"
			di col`col'[`row']
			di " and strpos="  strpos(col`col'[`row'],".")
			replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
		}
		forvalues row=1(2)7 {
			replace col`col' = "("+col`col'+")" in `row'
			replace col`col' = "" in `row' if col`col'[`row']=="(.)"
		}
		*bottom panel
		forvalues row=11(2)39 {
			replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
			di "value =  col`col'[`row']"
			di col`col'[`row']
			di " and strpos="  strpos(col`col'[`row'],".")
			replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
		}
		forvalues row=12(2)40 {
			replace col`col' = "("+col`col'+")" in `row'
			replace col`col' = "" in `row' if col`col'[`row']=="(.)"
		}
	}
	local j = 1
	*observations in top panel
	foreach var in pool panel {
		gen `country'_`var' = ``country'_`var'_obv' in 8
		tostring `country'_`var', replace force format(%8.0fc)
		local col = 2*`i'-2+`j'
		replace col`col' = `country'_`var' in 8
		local ++j
	}
	*observatiosn in bottom panel
	local j = 1
	foreach var in sym asym {
		gen `country'_`var' = ``country'_`var'_obv' in 59
		tostring `country'_`var', replace force format(%8.0fc)
		local col = 2*`i'-2+`j'
		replace col`col' = `country'_`var' in 59
		local ++j
	}
	local ++i
}

keep col*
replace col8 = col8 + " \\"
outsheet using "$path/output/ALL_agedin_margins.tex", replace delim("&") non noq


exit
