
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear

local dep_var act_log_ld

* Combined panel results by gender for output

**** Ethiopia *****

* symmetric results by gender
use "$newdata/ET_reg_ready", clear		// generated in the "Ethiopia panel data prep3.do" file
egen ea_wave = group(ea1 wave)

	gen harv=activity
	gen change_harv = diff_$hhsize_var*harv
	gen change_harv_male = diff_log_male*harv
	gen change_harv_female = diff_log_female*harv
	foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
		gen `var'_male = diff_log_male * `var'
		gen `var'_female = diff_log_female * `var'
	}

	la var harv "Harvest"
	reg diff_`dep_var' harv diff_log_male diff_log_female change_harv_male change_harv_female diff_log_A_* diff_sh*male, cluster(ea_wave)

	local ET_sym_chg_male_b = _b[diff_log_male]
	test diff_log_male=0
	local ET_sym_chg_male_p = r(p)
	local ET_sym_chg_fem_b = _b[diff_log_female]
	test diff_log_female=0
	local ET_sym_chg_fem_p = r(p)

	local ET_sym_chg_male_harv_b = _b[diff_log_male] + _b[change_harv_male]
	test diff_log_male + change_harv_male = 0
	local ET_sym_chg_male_harv_p = r(p)
	local ET_sym_chg_fem_harv_b = _b[diff_log_female] + _b[change_harv_female]
	test diff_log_female + change_harv_female = 0
	local ET_sym_chg_fem_harv_p = r(p)
	local ET_sym_obv = e(N)
	local ET_sym_r2 = e(r2)
	test _b[change_harv_male] = 0
	local ET_sym_ref_harv_male = r(p)
	test _b[change_harv_female] = 0
	local ET_sym_ref_harv_female = r(p)
	test _b[diff_log_male] - _b[diff_log_female] = 0
	local ET_sym_ref_male_female = r(p)
	test _b[diff_log_male] + _b[change_harv_male] - _b[diff_log_female] - _b[change_harv_female] = 0
	local ET_sym_harv_male_female = r(p)

	* gen asymm results by gender
	gen INC_harv = INC_hhsize*harv
	gen DEC_harv = DEC_hhsize*harv
	gen INC_harv_male = INC_male*harv
	gen DEC_harv_male = DEC_male*harv
	gen INC_harv_female = INC_female*harv
	gen DEC_harv_female = DEC_female*harv

	reg diff_`dep_var' harv INC_male INC_female INC_harv_male INC_harv_female DEC_male DEC_female DEC_harv_male DEC_harv_female diff_log_A_male diff_log_A_female diff_sh*male, cluster(ea_wave)

	test INC_male - DEC_male = 0		// Check whether pre-harvest values are different
	local ET_asym_diff_pre_male_p = r(p)
	test INC_male + INC_harv_male - DEC_male - DEC_harv_male = 0		// Check whether harvest values are different
	local ET_asym_diff_harv_male_p = r(p)
	test INC_female - DEC_female = 0		// Check whether pre-harvest values are different for females
	local ET_asym_diff_pre_fem_p = r(p)
	test INC_female + INC_harv_female - DEC_female - DEC_harv_female = 0		// Check whether harvest values are different for females
	local ET_asym_diff_harv_fem_p = r(p)
	test _b[INC_harv_male] = 0
	local ET_inc_ref_harv_male = r(p)
	test _b[DEC_harv_male] = 0
	local ET_dec_ref_harv_male = r(p)
	test _b[INC_harv_female] = 0
	local ET_inc_ref_harv_female = r(p)
	test _b[DEC_harv_female] = 0
	local ET_dec_ref_harv_female = r(p)
	test _b[INC_male] - _b[INC_female] = 0
	local ET_inc_ref_male_female = r(p)
	test _b[DEC_male] - _b[DEC_female] = 0
	local ET_dec_ref_male_female = r(p)
	test _b[INC_male] + _b[INC_harv_male] - _b[INC_female] - _b[INC_harv_female] = 0
	local ET_inc_harv_male_female = r(p)
	test _b[DEC_male] + _b[DEC_harv_male] - _b[DEC_female] - _b[DEC_harv_female] = 0
	local ET_dec_harv_male_female = r(p)

	local ET_asym_inc_male_b = _b[INC_male]
	test INC_male = 0
	local ET_asym_inc_male_p = r(p)
	local ET_asym_inc_fem_b = _b[INC_female]
	test INC_female = 0
	local ET_asym_inc_fem_p = r(p)
	local ET_asym_dec_male_b = _b[DEC_male]
	test DEC_male = 0
	local ET_asym_dec_male_p = r(p)
	local ET_asym_dec_fem_b = _b[DEC_female]
	test DEC_female = 0
	local ET_asym_dec_fem_p = r(p)

	local ET_asym_inc_harv_male_b = _b[INC_male] + _b[INC_harv_male]
	test INC_male + INC_harv_male =0
	local ET_asym_inc_harv_male_p = r(p)
	local ET_asym_dec_harv_male_b = _b[DEC_male] + _b[DEC_harv_male]
	test DEC_male + DEC_harv_male =0
	local ET_asym_dec_harv_male_p = r(p)
	local ET_asym_inc_harv_fem_b = _b[INC_female] + _b[INC_harv_female]
	test INC_female + INC_harv_female =0
	local ET_asym_inc_harv_fem_p = r(p)
	local ET_asym_dec_harv_fem_b = _b[DEC_female] + _b[DEC_harv_female]
	test DEC_female + DEC_harv_female =0
	local ET_asym_dec_harv_fem_p = r(p)
	
	local ET_asym_obv = e(N)
	local ET_asym_r2 = e(r2)



***** Malawi *****

* symmetric results by gender
use "$newdata/MW_reg_ready.dta", clear
egen ea_wave = group(ea1 wave)

	gen harv=activity
	gen change_harv = diff_$hhsize_var*harv
	gen change_harv_male = diff_log_male*harv
	gen change_harv_female = diff_log_female*harv
	la var harv "Harvest"
	foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
		gen `var'_male = diff_log_male * `var'
		gen `var'_female = diff_log_female * `var'
	}

	reg diff_`dep_var' harv diff_log_male diff_log_female change_harv_male change_harv_female diff_log_A_male diff_log_A_female diff_sh*male, cluster(ea_wave)
	local MW_sym_chg_male_b = _b[diff_log_male]
	test diff_log_male=0
	local MW_sym_chg_male_p = r(p)
	local MW_sym_chg_fem_b = _b[diff_log_female]
	test diff_log_female=0
	local MW_sym_chg_fem_p = r(p)


	local MW_sym_chg_male_harv_b = _b[diff_log_male] + _b[change_harv_male]
	test diff_log_male + change_harv_male = 0
	local MW_sym_chg_male_harv_p = r(p)
	local MW_sym_chg_fem_harv_b = _b[diff_log_female] + _b[change_harv_female]
	test diff_log_female + change_harv_female = 0
	local MW_sym_chg_fem_harv_p = r(p)
	local MW_sym_obv = e(N)
	local MW_sym_r2 = e(r2)
	test _b[change_harv_male] = 0
	local MW_sym_ref_harv_male = r(p)
	test _b[change_harv_female] = 0
	local MW_sym_ref_harv_female = r(p)
	test _b[diff_log_male] - _b[diff_log_female] = 0
	local MW_sym_ref_male_female = r(p)
	test _b[diff_log_male] + _b[change_harv_male] - _b[diff_log_female] - _b[change_harv_female] = 0
	local MW_sym_harv_male_female = r(p)

	* gen asymm results by gender
	gen INC_harv = INC_hhsize*harv
	gen DEC_harv = DEC_hhsize*harv
	gen INC_harv_male = INC_male*harv
	gen DEC_harv_male = DEC_male*harv
	gen INC_harv_female = INC_female*harv
	gen DEC_harv_female = DEC_female*harv
	la var INC_hhsize "$\Delta$ LE if increase"
	la var DEC_hhsize "$\Delta$ LE if decrease"
	la var INC_harv "Harvest $\times$ $\Delta$ LE if increase"
	la var DEC_harv "Harvest $\times$ $\Delta$ LE if decrease"

	reg diff_`dep_var' harv INC_male INC_female INC_harv_male INC_harv_female DEC_male DEC_female DEC_harv_male DEC_harv_female diff_log_A_male diff_log_A_female  diff_sh*male, cluster(ea_wave)

	test INC_male - DEC_male = 0		// Check whether pre-harvest values are different
	local MW_asym_diff_pre_male_p = r(p)
	test INC_male + INC_harv_male - DEC_male - DEC_harv_male = 0		// Check whether harvest values are different
	local MW_asym_diff_harv_male_p = r(p)
	test INC_female - DEC_female = 0		// Check whether pre-harvest values are different for females
	local MW_asym_diff_pre_fem_p = r(p)
	test INC_female + INC_harv_female - DEC_female - DEC_harv_female = 0		// Check whether harvest values are different for females
	local MW_asym_diff_harv_fem_p = r(p)
	test _b[INC_harv_male] = 0
	local MW_inc_ref_harv_male = r(p)
	test _b[DEC_harv_male] = 0
	local MW_dec_ref_harv_male = r(p)
	test _b[INC_harv_female] = 0
	local MW_inc_ref_harv_female = r(p)
	test _b[DEC_harv_female] = 0
	local MW_dec_ref_harv_female = r(p)
	test _b[INC_male] - _b[INC_female] = 0
	local MW_inc_ref_male_female = r(p)
	test _b[DEC_male] - _b[DEC_female] = 0
	local MW_dec_ref_male_female = r(p)
	test _b[INC_male] + _b[INC_harv_male] - _b[INC_female] - _b[INC_harv_female] = 0
	local MW_inc_harv_male_female = r(p)
	test _b[DEC_male] + _b[DEC_harv_male] - _b[DEC_female] - _b[DEC_harv_female] = 0
	local MW_dec_harv_male_female = r(p)

	local MW_asym_inc_male_b = _b[INC_male]
	test INC_male = 0
	local MW_asym_inc_male_p = r(p)
	local MW_asym_inc_fem_b = _b[INC_female]
	test INC_female = 0
	local MW_asym_inc_fem_p = r(p)
	local MW_asym_dec_male_b = _b[DEC_male]
	test DEC_male = 0
	local MW_asym_dec_male_p = r(p)
	local MW_asym_dec_fem_b = _b[DEC_female]
	test DEC_female = 0
	local MW_asym_dec_fem_p = r(p)

	local MW_asym_inc_harv_male_b = _b[INC_male] + _b[INC_harv_male]
	test INC_male + INC_harv_male =0
	local MW_asym_inc_harv_male_p = r(p)
	local MW_asym_dec_harv_male_b = _b[DEC_male] + _b[DEC_harv_male]
	test DEC_male + DEC_harv_male =0
	local MW_asym_dec_harv_male_p = r(p)
	local MW_asym_inc_harv_fem_b = _b[INC_female] + _b[INC_harv_female]
	test INC_female + INC_harv_female =0
	local MW_asym_inc_harv_fem_p = r(p)
	local MW_asym_dec_harv_fem_b = _b[DEC_female] + _b[DEC_harv_female]
	test DEC_female + DEC_harv_female =0
	local MW_asym_dec_harv_fem_p = r(p)
	
	local MW_asym_obv = e(N)
	local MW_asym_r2 = e(r2)




***** Tanzania *****

* symmetric results by gedner
use "$newdata/TZ_reg_ready.dta", clear		// generated in the "Tanzania panel data prep3.do" file
egen ea_wave = group(ea1 wave)

	gen weed = activity==1
	gen harv = activity==2
	gen change_weed = diff_$hhsize_var*weed
	gen change_harv = diff_$hhsize_var*harv
	la var harv "Harvest"
	la var weed "Weeding"
	gen change_harv_male = diff_log_male*harv
	gen change_weed_male = diff_log_male*weed
	gen change_harv_female = diff_log_female*harv
	gen change_weed_female = diff_log_female*weed
	foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
		gen `var'_male = diff_log_male * `var'
		gen `var'_female = diff_log_female * `var'
	}

	reg diff_`dep_var' harv weed diff_log_male diff_log_female change_harv_male change_harv_female change_weed_male change_weed_female diff_log_A_male diff_log_A_female diff_sh*male wave3, cluster(ea_wave)
	local TZ_sym_chg_male_b = _b[diff_log_male]
	test diff_log_male=0
	local TZ_sym_chg_male_p = r(p)
	local TZ_sym_chg_fem_b = _b[diff_log_female]
	test diff_log_female=0
	local TZ_sym_chg_fem_p = r(p)

	local TZ_sym_chg_male_harv_b = _b[diff_log_male] + _b[change_harv_male]
	test diff_log_male + change_harv_male = 0
	local TZ_sym_chg_male_harv_p = r(p)
	local TZ_sym_chg_fem_harv_b = _b[diff_log_female] + _b[change_harv_female]
	test diff_log_female + change_harv_female = 0
	local TZ_sym_chg_fem_harv_p = r(p)
	local TZ_sym_chg_male_weed_b = _b[diff_log_male] + _b[change_weed_male]
	test diff_log_male + change_weed_male = 0
	local TZ_sym_chg_male_weed_p = r(p)
	local TZ_sym_chg_fem_weed_b = _b[diff_log_female] + _b[change_weed_female]
	test diff_log_female + change_weed_female = 0
	local TZ_sym_chg_fem_weed_p = r(p)
	local TZ_sym_obv = e(N)
	local TZ_sym_r2 = e(r2)
	test _b[change_harv_male] = 0
	local TZ_sym_ref_harv_male = r(p)
	test _b[change_harv_female] = 0
	local TZ_sym_ref_harv_female = r(p)
	test _b[diff_log_male] - _b[diff_log_female] = 0
	local TZ_sym_ref_male_female = r(p)
	test _b[diff_log_male] + _b[change_harv_male] - _b[diff_log_female] - _b[change_harv_female] = 0
	local TZ_sym_harv_male_female = r(p)
	test _b[change_weed_male] = 0
	local TZ_sym_ref_weed_male = r(p)
	test _b[change_weed_female] = 0
	local TZ_sym_ref_weed_female = r(p)
	test _b[diff_log_male] + _b[change_weed_male] - _b[diff_log_female] - _b[change_weed_female] = 0
	local TZ_sym_weed_male_female = r(p)
	test _b[change_harv_male] - _b[change_weed_male] = 0
	local TZ_sym_harv_weed_male = r(p)
	test _b[change_harv_female] - _b[change_weed_female] = 0
	local TZ_sym_harv_weed_female = r(p)

	* gen asymm results by gender
	gen INC_harv = INC_hhsize*harv
	gen DEC_harv = DEC_hhsize*harv
	gen INC_harv_male = INC_male*harv
	gen DEC_harv_male = DEC_male*harv
	gen INC_harv_female = INC_female*harv
	gen DEC_harv_female = DEC_female*harv
	gen INC_weed = INC_hhsize*weed
	gen DEC_weed = DEC_hhsize*weed
	gen INC_weed_male = INC_male*weed
	gen DEC_weed_male = DEC_male*weed
	gen INC_weed_female = INC_female*weed
	gen DEC_weed_female = DEC_female*weed
	la var INC_hhsize "$\Delta$ LE if increase"
	la var DEC_hhsize "$\Delta$ LE if decrease"
	la var INC_harv "Harvest $\times$ $\Delta$ LE if increase"
	la var DEC_harv "Harvest $\times$ $\Delta$ LE if decrease"

	reg diff_`dep_var' harv weed INC_male INC_female INC_harv_male INC_harv_female INC_weed_male INC_weed_female DEC_male DEC_female DEC_harv_male DEC_harv_female DEC_weed_male DEC_weed_female diff_log_A_male diff_log_A_female diff_sh*male wave3, cluster(ea_wave)
	
	test INC_male - DEC_male = 0		// Check whether pre-harvest values are different
	local TZ_asym_diff_pre_male_p = r(p)
	test INC_male + INC_harv_male - DEC_male - DEC_harv_male = 0		// Check whether harvest values are different
	local TZ_asym_diff_harv_male_p = r(p)
	test INC_male + INC_weed_male - DEC_male - DEC_weed_male = 0		// Check whether weeding values are different
	local TZ_asym_diff_weed_male_p = r(p)
	test INC_female - DEC_female = 0		// Check whether pre-harvest values are different for females
	local TZ_asym_diff_pre_fem_p = r(p)
	test INC_female + INC_harv_female - DEC_female - DEC_harv_female = 0		// Check whether harvest values are different for females
	local TZ_asym_diff_harv_fem_p = r(p)
	test INC_female + INC_weed_female - DEC_female - DEC_weed_female = 0		// Check whether weeding values are different for females
	local TZ_asym_diff_weed_fem_p = r(p)
	test _b[INC_harv_male] = 0
	local TZ_inc_ref_harv_male = r(p)
	test _b[DEC_harv_male] = 0
	local TZ_dec_ref_harv_male = r(p)
	test _b[INC_harv_female] = 0
	local TZ_inc_ref_harv_female = r(p)
	test _b[DEC_harv_female] = 0
	local TZ_dec_ref_harv_female = r(p)
	test _b[INC_male] - _b[INC_female] = 0
	local TZ_inc_ref_male_female = r(p)
	test _b[DEC_male] - _b[DEC_female] = 0
	local TZ_dec_ref_male_female = r(p)
	test _b[INC_male] + _b[INC_harv_male] - _b[INC_female] - _b[INC_harv_female] = 0
	local TZ_inc_harv_male_female = r(p)
	test _b[DEC_male] + _b[DEC_harv_male] - _b[DEC_female] - _b[DEC_harv_female] = 0
	local TZ_dec_harv_male_female = r(p)
	test _b[INC_weed_male] = 0
	local TZ_inc_ref_weed_male = r(p)
	test _b[DEC_weed_male] = 0
	local TZ_dec_ref_weed_male = r(p)
	test _b[INC_weed_female] = 0
	local TZ_inc_ref_weed_female = r(p)
	test _b[DEC_weed_female] = 0
	local TZ_dec_ref_weed_female = r(p)
	test _b[INC_male] + _b[INC_weed_male] - _b[INC_female] - _b[INC_weed_female] = 0
	local TZ_inc_weed_male_female = r(p)
	test _b[DEC_male] + _b[DEC_weed_male] - _b[DEC_female] - _b[DEC_weed_female] = 0
	local TZ_dec_weed_male_female = r(p)
	test _b[INC_harv_male] - _b[INC_weed_male] = 0
	local TZ_inc_harv_weed_male = r(p)
	test _b[INC_harv_female] - _b[INC_weed_female] = 0
	local TZ_inc_harv_weed_female = r(p)
	test _b[DEC_harv_male] - _b[DEC_weed_male] = 0
	local TZ_dec_harv_weed_male = r(p)
	test _b[DEC_harv_female] - _b[DEC_weed_female] = 0
	local TZ_dec_harv_weed_female = r(p)

	local TZ_asym_inc_male_b = _b[INC_male]
	test INC_male = 0
	local TZ_asym_inc_male_p = r(p)
	local TZ_asym_inc_fem_b = _b[INC_female]
	test INC_female = 0
	local TZ_asym_inc_fem_p = r(p)
	local TZ_asym_dec_male_b = _b[DEC_male]
	test DEC_male = 0
	local TZ_asym_dec_male_p = r(p)
	local TZ_asym_dec_fem_b = _b[DEC_female]
	test DEC_female = 0
	local TZ_asym_dec_fem_p = r(p)

	local TZ_asym_inc_harv_male_b = _b[INC_male] + _b[INC_harv_male]
	test INC_male + INC_harv_male =0
	local TZ_asym_inc_harv_male_p = r(p)
	local TZ_asym_dec_harv_male_b = _b[DEC_male] + _b[DEC_harv_male]
	test DEC_male + DEC_harv_male =0
	local TZ_asym_dec_harv_male_p = r(p)
	local TZ_asym_inc_harv_fem_b = _b[INC_female] + _b[INC_harv_female]
	test INC_female + INC_harv_female =0
	local TZ_asym_inc_harv_fem_p = r(p)
	local TZ_asym_dec_harv_fem_b = _b[DEC_female] + _b[DEC_harv_female]
	test DEC_female + DEC_harv_female =0
	local TZ_asym_dec_harv_fem_p = r(p)

	local TZ_asym_inc_weed_male_b = _b[INC_male] + _b[INC_weed_male]
	test INC_male + INC_weed_male =0
	local TZ_asym_inc_weed_male_p = r(p)
	local TZ_asym_dec_weed_male_b = _b[DEC_male] + _b[DEC_weed_male]
	test DEC_male + DEC_weed_male =0
	local TZ_asym_dec_weed_male_p = r(p)
	local TZ_asym_inc_weed_fem_b = _b[INC_female] + _b[INC_weed_female]
	test INC_female + INC_weed_female =0
	local TZ_asym_inc_weed_fem_p = r(p)
	local TZ_asym_dec_weed_fem_b = _b[DEC_female] + _b[DEC_weed_female]
	test DEC_female + DEC_weed_female =0
	local TZ_asym_dec_weed_fem_p = r(p)

	local TZ_asym_obv = e(N)
	local TZ_asym_r2 = e(r2)



***** Uganda *****

* symmetric results by gedner
use "$newdata/UG_reg_ready", clear	// generated in the "Uganda panel data prep3.do" file
egen ea_wave = group(ea wave)

	foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
		gen `var'_male = diff_log_male * `var'
		gen `var'_female = diff_log_female * `var'
	}

	reg diff_`dep_var' diff_log_male diff_log_female diff_log_A_male diff_log_A_female diff_sh*male wave3 wave4, cluster(ea_wave)
	local UG_sym_chg_male_b = _b[diff_log_male]
	test diff_log_male=0
	local UG_sym_chg_male_p = r(p)
	local UG_sym_chg_fem_b = _b[diff_log_female]
	test diff_log_female=0
	local UG_sym_chg_fem_p = r(p)
	test _b[diff_log_male] - _b[diff_log_female] = 0
	local UG_sym_ref_male_female = r(p)

	local UG_sym_obv = e(N)
	local UG_sym_r2 = e(r2)

	* gen asymm results by gender
	la var INC_hhsize "$\Delta$ LE if increase"
	la var DEC_hhsize "$\Delta$ LE if decrease"

	reg diff_`dep_var' INC_male INC_female DEC_male DEC_female diff_log_A_male diff_log_A_female diff_sh*male wave3 wave4, cluster(ea_wave)
	test INC_male - DEC_male = 0		// Check whether pre-harvest values are different
	local UG_asym_diff_pre_male_p = r(p)
	test INC_female - DEC_female = 0		// Check whether pre-harvest values are different for females
	local UG_asym_diff_pre_fem_p = r(p)
	test _b[INC_male] - _b[INC_female] = 0
	local UG_inc_ref_male_female = r(p)
	test _b[DEC_male] - _b[DEC_female] = 0
	local UG_dec_ref_male_female = r(p)

	local UG_asym_inc_male_b = _b[INC_male]
	test INC_male = 0
	local UG_asym_inc_male_p = r(p)
	local UG_asym_inc_fem_b = _b[INC_female]
	test INC_female = 0
	local UG_asym_inc_fem_p = r(p)
	local UG_asym_dec_male_b = _b[DEC_male]
	test DEC_male = 0
	local UG_asym_dec_male_p = r(p)
	local UG_asym_dec_fem_b = _b[DEC_female]
	test DEC_female = 0
	local UG_asym_dec_fem_p = r(p)
	
	local UG_asym_obv = e(N)
	local UG_asym_r2 = e(r2)


** EXPORT

*create table of marginals and tests for asymmetric results
clear
set obs 53

gen col0 = "Reference \$\times \Delta Male\$" in 1
replace col0 = "Reference \$\times \Delta Male^+\$" in 3
replace col0 = "Reference \$\times \Delta Male^-\$" in 5
replace col0 = "Reference \$\times \Delta Female\$" in 7
replace col0 = "Reference \$\times \Delta Female^+\$" in 9
replace col0 = "Reference \$\times \Delta Female^-\$" in 11
replace col0 = "Harvest \$\times \Delta Male\$" in 13
replace col0 = "Harvest \$\times \Delta Male^+\$" in 15
replace col0 = "Harvest \$\times \Delta Male^-\$" in 17
replace col0 = "Harvest \$\times \Delta Female\$" in 19
replace col0 = "Harvest \$\times \Delta Female^+\$" in 21
replace col0 = "Harvest \$\times \Delta Female^-\$" in 23
replace col0 = "Weeding \$\times \Delta Male\$" in 25
replace col0 = "Weeding \$\times \Delta Male^+\$" in 27
replace col0 = "Weeding \$\times \Delta Male^-\$" in 29
replace col0 = "Weeding \$\times \Delta Female\$" in 31
replace col0 = "Weeding \$\times \Delta Female^+\$" in 33
replace col0 = "Weeding \$\times \Delta Female^-\$" in 35

replace col0 = "\hline Reference-Male: Inc = Dec" in 37
replace col0 = "Reference-Female: Inc = Dec" in 38
replace col0 = "Harvest-Male: Inc = Dec" in 39
replace col0 = "Harvest-Female: Inc = Dec" in 40
replace col0 = "Weeding-Male: Inc = Dec" in 41
replace col0 = "Weeding-Female: Inc = Dec" in 42

replace col0 = "\hline Reference: Male=Female" in 43
replace col0 = "Harvest: Male=Female" in 44
replace col0 = "Weeding: Male=Female" in 45
replace col0 = "Reference: Male=Female,\$+\$" in 46
replace col0 = "Reference: Male=Female,\$-\$" in 47
replace col0 = "Harvest: Male=Female,\$+\$" in 48
replace col0 = "Harvest: Male=Female,\$-\$" in 49
replace col0 = "Weeding: Male=Female,\$+\$" in 50
replace col0 = "Weeding: Male=Female,\$-\$" in 51

replace col0 = "\hline Observations" in 52
replace col0 = "\$R^2\$" in 53

forvalues i=1/8 {
	gen col`i' = . in 1
	gen star`i' = ""
}

local i = 1
foreach country in ET MW TZ UG {
	local varlist
	local richlist
	di "in country loop, i=`i'"
	local j = 2*`i'-1
	di "country=`country' and i=`i' and j=`j'"
	replace col`j' = ``country'_sym_chg_male_b' in 1
	replace col`j' = ``country'_sym_chg_male_p' in 2
	replace col`j' = ``country'_sym_chg_fem_b' in 7
	replace col`j' = ``country'_sym_chg_fem_p' in 8
	replace col`j' = ``country'_sym_r2' in 53
	local j = 2*`i'
	di "country=`country' and i=`i' and j=`j'"
	replace col`j' = ``country'_asym_inc_male_b' in 3
	replace col`j' = ``country'_asym_inc_male_p' in 4
	replace col`j' = ``country'_asym_dec_male_b' in 5
	replace col`j' = ``country'_asym_dec_male_p' in 6
	replace col`j' = ``country'_asym_diff_pre_male_p' in 37
	replace col`j' = ``country'_asym_inc_fem_b' in 9
	replace col`j' = ``country'_asym_inc_fem_p' in 10
	replace col`j' = ``country'_asym_dec_fem_b' in 11
	replace col`j' = ``country'_asym_dec_fem_p' in 12
	replace col`j' = ``country'_asym_diff_pre_fem_p' in 38
	replace col`j' = ``country'_asym_r2' in 53

	if inlist(`i',1,2,3) {
		local j = 2*`i'-1
		di "country=`country' and i=`i' and j=`j'"
		replace col`j' = ``country'_sym_chg_male_harv_b' in 13
		replace col`j' = ``country'_sym_chg_male_harv_p' in 14
		replace col`j' = ``country'_sym_chg_fem_harv_b' in 19
		replace col`j' = ``country'_sym_chg_fem_harv_p' in 20

		local j = 2*`i'
		di "country=`country' and i=`i' and j=`j'"
		replace col`j' = ``country'_asym_inc_harv_male_b' in 15
		replace col`j' = ``country'_asym_inc_harv_male_p' in 16
		replace col`j' = ``country'_asym_dec_harv_male_b' in 17
		replace col`j' = ``country'_asym_dec_harv_male_p' in 18
		replace col`j' = ``country'_asym_diff_harv_male_p' in 39
		replace col`j' = ``country'_asym_inc_harv_fem_b' in 21
		replace col`j' = ``country'_asym_inc_harv_fem_p' in 22
		replace col`j' = ``country'_asym_dec_harv_fem_b' in 23
		replace col`j' = ``country'_asym_dec_harv_fem_p' in 24
		replace col`j' = ``country'_asym_diff_harv_fem_p' in 40

		local varlist sym_chg_male_harv asym_inc_harv_male asym_dec_harv_male sym_chg_fem_harv asym_inc_harv_fem asym_dec_harv_fem

	}
	if `i'==3 {
		local j = 2*`i'-1
		replace col`j' = ``country'_sym_chg_male_weed_b' in 25
		replace col`j' = ``country'_sym_chg_male_weed_p' in 26
		replace col`j' = ``country'_sym_chg_fem_weed_b' in 31
		replace col`j' = ``country'_sym_chg_fem_weed_p' in 32

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_weed_male_b' in 27
		replace col`j' = ``country'_asym_inc_weed_male_p' in 28
		replace col`j' = ``country'_asym_dec_weed_male_b' in 29
		replace col`j' = ``country'_asym_dec_weed_male_p' in 30
		replace col`j' = ``country'_asym_diff_weed_male_p' in 41
		replace col`j' = ``country'_asym_inc_weed_fem_b' in 33
		replace col`j' = ``country'_asym_inc_weed_fem_p' in 34
		replace col`j' = ``country'_asym_dec_weed_fem_b' in 35
		replace col`j' = ``country'_asym_dec_weed_fem_p' in 36
		replace col`j' = ``country'_asym_diff_weed_fem_p' in 42

		local varlist `varlist' sym_chg_male_weed asym_inc_weed_male asym_dec_weed_male sym_chg_fem_weed asym_inc_weed_fem asym_dec_weed_fem
	}

	* assigning stars for top panel
	di "about to var list with varlist=`varlist'"
	forvalues j=1/2 {
		local row = 1
		foreach var in sym_chg_male asym_inc_male asym_dec_male sym_chg_fem asym_inc_fem asym_dec_fem `varlist' {
			local temp = 2*`row'-1
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'_p"
			local p_var  `country'_`var'_p
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}
	}
	local ++i
}

* add the F-tests for differences across activities
local i = 1
foreach country in ET MW TZ UG {
	if `i' < 5 {
		replace col`i' =  ``country'_sym_ref_male_female' in 43
		replace col`i' =  ``country'_sym_harv_male_female' in 44

		local ++i
		replace col`i' =  ``country'_inc_ref_male_female' in 46
		replace col`i' =  ``country'_dec_ref_male_female' in 47
		replace col`i' =  ``country'_inc_harv_male_female' in 48
		replace col`i' =  ``country'_dec_harv_male_female' in 49
	}
	if "`country'"=="TZ" {
		replace col`i' =  ``country'_sym_ref_male_female' in 43
		replace col`i' =  ``country'_sym_harv_male_female' in 44
		replace col`i' =  ``country'_sym_weed_male_female' in 45

		local ++i
		replace col`i' =  ``country'_inc_ref_male_female' in 46
		replace col`i' =  ``country'_dec_ref_male_female' in 47
		replace col`i' =  ``country'_inc_harv_male_female' in 48
		replace col`i' =  ``country'_dec_harv_male_female' in 49
		replace col`i' =  ``country'_inc_weed_male_female' in 50
		replace col`i' =  ``country'_dec_weed_male_female' in 51
	}
	if "`country'"=="UG" {
		replace col`i' =  ``country'_sym_ref_male_female' in 43

		local ++i
		replace col`i' =  ``country'_inc_ref_male_female' in 46
		replace col`i' =  ``country'_dec_ref_male_female' in 47
	}
	local ++i
}

*convert cells to strings
local i = 1
foreach country in ET MW TZ UG {
	forvalues j=1/2 {
		di "in format loop with country=`country', j=`j', and i=`i'"
		local col = 2*`i'-2+`j'
		tostring col`col', replace force format(%9.3f)

		forvalues row=1(2)35 {
			replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
			di "value =  col`col'[`row']"
			di col`col'[`row']
			di " and strpos="  strpos(col`col'[`row'],".")
			replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
		}
		forvalues row=2(2)36 {
			replace col`col' = "("+col`col'+")" in `row'
			replace col`col' = "" in `row' if col`col'[`row']=="(.)"
		}
	}
	*observations in bottom panel
	local j = 1
	foreach var in sym asym {
		gen `country'_`var' = ``country'_`var'_obv' in 52
		tostring `country'_`var', replace force format(%8.0fc)
		local col = 2*`i'-2+`j'
		replace col`col' = `country'_`var' in 52
		local ++j
	}
	local ++i
}

keep col*
replace col8 = col8 + " \\"
outsheet using "$path/output/ALL_gender_margins.tex", replace delim("&") non noq

exit
