
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear

local hhsize_var  log_phase
local dep_var log_A


* Combined land results for output

**** Ethiopia *****

use "$newdata/ET_reg_ready", clear		// generated in the "Ethiopia panel data prep3.do" file
egen ea_wave = group(ea1 wave)

* asymmetric results
reg diff_`dep_var' INC_hhsize DEC_hhsize diff_sh* , cluster(ea_wave)
eststo ET_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre_p = r(p)

local ET_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local ET_asym_inc_le_p = r(p)
local ET_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local ET_asym_dec_le_p = r(p)

local ET_asym_obv = e(N)
local ET_asym_r2 = e(r2)



***** Malawi *****

use "$newdata/MW_reg_ready.dta", clear		// generated in the "Malawi panel data prep3.do" file
egen ea_wave = group(ea1 wave)

* asymmetric results
reg diff_`dep_var' INC_hhsize DEC_hhsize diff_sh* , cluster(ea_wave)
eststo MW_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local MW_asym_diff_pre_p = r(p)

local MW_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local MW_asym_inc_le_p = r(p)
local MW_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local MW_asym_dec_le_p = r(p)

local MW_asym_obv = e(N)
local MW_asym_r2 = e(r2)




***** Tanzania *****

use "$newdata/TZ_reg_ready.dta", clear		// generated in the "Tanzania panel data prep3.do" file
egen ea_wave = group(ea1 wave)

* asymmetric results
reg diff_`dep_var' INC_hhsize DEC_hhsize diff_sh* wave3 , cluster(ea_wave)
eststo TZ_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local TZ_asym_diff_pre_p = r(p)

local TZ_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local TZ_asym_inc_le_p = r(p)
local TZ_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local TZ_asym_dec_le_p = r(p)

local TZ_asym_dec_weed_p = r(p)
local TZ_asym_obv = e(N)
local TZ_asym_r2 = e(r2)


***** Uganda *****

*base symmetric results
use "$newdata/UG_reg_ready", clear
egen ea_wave = group(ea wave)

*asymmetric results
reg diff_`dep_var' INC_hhsize DEC_hhsize diff_sh* wave3 wave4, cluster(ea_wave)
eststo UG_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local UG_asym_diff_pre_p = r(p)

local UG_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local UG_asym_inc_le_p = r(p)
local UG_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local UG_asym_dec_le_p = r(p)
local UG_asym_obv = e(N)
local UG_asym_r2 = e(r2)

** EXPORT

*create table of marginals and tests for asymmetric results
clear
set obs 7
gen col0 = "\$ \Delta E^+\$" in 1
replace col0 = "\$ \Delta E^-\$" in 3

replace col0 = "\hline F-test: Inc = Dec (p-val)" in 5
replace col0 = "\hline Observations" in 6
replace col0 = "\$R^2\$" in 7
forvalues i=1/4 {
	gen col`i' = . in 1
	gen star`i' = ""
}

local i = 1
foreach country in ET MW TZ UG {
	local varlist
	di "in country loop, i=`i'"
	local j = `i'
	replace col`j' = ``country'_asym_inc_le_b' in 1
	replace col`j' = ``country'_asym_inc_le_p' in 2
	replace col`j' = ``country'_asym_dec_le_b' in 3
	replace col`j' = ``country'_asym_dec_le_p' in 4
	replace col`j' = ``country'_asym_diff_pre_p' in 5
	replace col`j' = ``country'_asym_r2' in 7


	* assigning stars
	local row = 1
	foreach var in asym_inc_le asym_dec_le {
		local temp = 2*`row'-1
		local col = `i'
		di "in var loop with row = `row', var=`var', and temp = `temp'"
		di "col=`col' and country_var_p = `country'_`var'_p"
		local p_var  `country'_`var'_p
		di "p_var = `p_var'"
		replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
		replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
		replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
		replace star`col' = "" in `temp' if col`col'[`temp']==.
		local ++row
	}		
	local ++i
}


*convert cells to strings
local i = 1
foreach country in ET MW TZ UG {
	di "in format loop with country=`country', and i=`i'"
	local col = `i'
	tostring col`col', replace force format(%9.3f)

	forvalues row=1(2)3 {
		replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
		di "value =  col`col'[`row']"
		di col`col'[`row']
		di " and strpos="  strpos(col`col'[`row'],".")
		replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
	}
	forvalues row=2(2)4 {
		replace col`col' = "("+col`col'+")" in `row'
		replace col`col' = "" in `row' if col`col'[`row']=="(.)"
	}

	*observations
	di "about to set obs with i=`i'"
	gen `country'_asym = ``country'_asym_obv' in 6
	tostring `country'_asym, replace force format(%8.0fc)
	local col = `i'
	replace col`col' = `country'_asym in 6
	local ++i
}

keep col*
replace col4 = col4 + " \\"

outsheet using "$path/output/ALL_land_margins.tex", replace delim("&") non noq

exit
