*********************************
*** Directories and Paths     ***
*** SALAM project - Spring 2016 ***

* Oct-27-2016	pwb	added code to allow separate effects by gender
* Mar-24-2017	pwb	created tables of marginals and p-values, and added code for separate effects by wealth
*********************************
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear

local dep_var act_log_ld
*********************************************************************************************************************


* Robustness checks results for output

**** Ethiopia *****
* asymmetric results - no kids
use "$newdata/ET_reg_ready", clear		// generated in the "Ethiopia panel analysis.do" file
drop INC_hhsize DEC_hhsize
gen INC_hhsize = diff_log_hhsize*(diff_log_hhsize>0)
gen DEC_hhsize = diff_log_hhsize*(diff_log_hhsize<0)
gen harv = activity==1
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var harv "Harvest (=1)"
la var INC_harv "Harvest $\times$ $\Delta$ Labor endowment if positive"
la var DEC_harv "Harvest $\times$ $\Delta$ Labor endowment if negative"
la var diff_$hhsize_var "$\Delta$ Labor endowment"

reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv diff_log_A diff_sh* , cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local ET_asym_diff_harv_p = r(p)

local ET_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local ET_asym_inc_le_p = r(p)
local ET_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local ET_asym_dec_le_p = r(p)
local ET_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local ET_asym_inc_harv_p = r(p)
local ET_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local ET_asym_dec_harv_p = r(p)
local ET_asym_obv = e(N)
local ET_asym_r2 = e(r2)

* asymmetric results - time away
drop INC_* DEC_*
gen INC_hhsize = diff_log_phase_away*(diff_log_phase_away>0)
gen DEC_hhsize = diff_log_phase_away*(diff_log_phase_away <0)
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var INC_harv "Harvest $\times$ $\Delta$ Labor endowment if positive"
la var DEC_harv "Harvest $\times$ $\Delta$ Labor endowment if negative"

reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv diff_log_A diff_sh* , cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local ET_asym_diff_harv2_p = r(p)

local ET_asym_inc_le2_b = _b[INC_hhsize]
test INC_hhsize=0
local ET_asym_inc_le2_p = r(p)
local ET_asym_dec_le2_b = _b[DEC_hhsize]
test DEC_hhsize=0
local ET_asym_dec_le2_p = r(p)
local ET_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local ET_asym_inc_harv2_p = r(p)
local ET_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local ET_asym_dec_harv2_p = r(p)
local ET_asym2_obv = e(N)
local ET_asym2_r2 = e(r2)


***** Malawi *****

* asymmetric results - no kids
use "$newdata/MW_reg_ready.dta", clear	
drop INC_hhsize DEC_hhsize
gen INC_hhsize = diff_log_hhsize*(diff_log_hhsize>0)
gen DEC_hhsize = diff_log_hhsize*(diff_log_hhsize<0)
gen harv = activity==1
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var harv "Harvest (=1)"
la var INC_harv "Harvest $\times$ $\Delta$ Labor endowment if positive"
la var DEC_harv "Harvest $\times$ $\Delta$ Labor endowment if negative"
la var diff_$hhsize_var "$\Delta$ Labor endowment"

reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv diff_log_A diff_sh* , cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local MW_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local MW_asym_diff_harv_p = r(p)

local MW_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local MW_asym_inc_le_p = r(p)
local MW_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local MW_asym_dec_le_p = r(p)
local MW_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local MW_asym_inc_harv_p = r(p)
local MW_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local MW_asym_dec_harv_p = r(p)
local MW_asym_obv = e(N)
local MW_asym_r2 = e(r2)

* asymmetric results - time away
drop INC_* DEC_*
gen INC_hhsize = diff_log_phase_away*(diff_log_phase_away>0)
gen DEC_hhsize = diff_log_phase_away*(diff_log_phase_away <0)
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var INC_harv "Harvest $\times$ $\Delta$ Labor endowment if positive"
la var DEC_harv "Harvest $\times$ $\Delta$ Labor endowment if negative"

reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv diff_log_A diff_sh* , cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local MW_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local MW_asym_diff_harv2_p = r(p)

local MW_asym_inc_le2_b = _b[INC_hhsize]
test INC_hhsize=0
local MW_asym_inc_le2_p = r(p)
local MW_asym_dec_le2_b = _b[DEC_hhsize]
test DEC_hhsize=0
local MW_asym_dec_le2_p = r(p)
local MW_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local MW_asym_inc_harv2_p = r(p)
local MW_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local MW_asym_dec_harv2_p = r(p)
local MW_asym2_obv = e(N)
local MW_asym2_r2 = e(r2)




***** Tanzania *****

* asymmetric results - no kids
use "$newdata/TZ_reg_ready.dta", clear
drop INC_hhsize DEC_hhsize
gen INC_hhsize = diff_log_hhsize*(diff_log_hhsize>0)
gen DEC_hhsize = diff_log_hhsize*(diff_log_hhsize<0)
gen weed = activity==1
gen harv = activity==2
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
gen INC_weed = INC_hhsize*weed
gen DEC_weed = DEC_hhsize*weed
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var harv "Harvest (=1)"
la var weed "Weeding (=1)"
la var INC_harv "Harvest $\times$ $\Delta$ Labor endowment if positive"
la var DEC_harv "Harvest $\times$ $\Delta$ Labor endowment if negative"
la var INC_weed "Weeding $\times$ $\Delta$ LE if increase"
la var DEC_weed "Weeding $\times$ $\Delta$ LE if decrease"
la var diff_$hhsize_var "$\Delta$ Labor endowment"

reg diff_`dep_var' weed harv INC_hhsize INC_weed INC_harv DEC_hhsize DEC_weed DEC_harv diff_log_A diff_sh* wave3 , cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local TZ_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local TZ_asym_diff_harv_p = r(p)
test INC_hhsize + INC_weed - DEC_hhsize - DEC_weed = 0		// Check whether weeding values are different
local TZ_asym_diff_weed_p = r(p)

local TZ_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local TZ_asym_inc_le_p = r(p)
local TZ_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local TZ_asym_dec_le_p = r(p)
local TZ_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local TZ_asym_inc_harv_p = r(p)
local TZ_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local TZ_asym_dec_harv_p = r(p)
local TZ_asym_inc_weed_b = _b[INC_hhsize] + _b[INC_weed]
test _b[INC_hhsize] + _b[INC_weed] = 0
local TZ_asym_inc_weed_p = r(p)
local TZ_asym_dec_weed_b = _b[DEC_hhsize] + _b[DEC_weed]
test _b[DEC_hhsize] + _b[DEC_weed] = 0
local TZ_asym_dec_weed_p = r(p)
local TZ_asym_obv = e(N)
local TZ_asym_r2 = e(r2)

* asymmetric results - time away
drop INC_* DEC_*
gen INC_hhsize = diff_log_phase_away*(diff_log_phase_away>0)
gen DEC_hhsize = diff_log_phase_away*(diff_log_phase_away <0)
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
gen INC_weed = INC_hhsize*weed
gen DEC_weed = DEC_hhsize*weed
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var INC_harv "Harvest $\times$ $\Delta$ Labor endowment if positive"
la var DEC_harv "Harvest $\times$ $\Delta$ Labor endowment if negative"
la var INC_weed "Weeding $\times$ $\Delta$ LE if increase"
la var DEC_weed "Weeding $\times$ $\Delta$ LE if decrease"


reg diff_`dep_var' weed harv INC_hhsize INC_weed INC_harv DEC_hhsize DEC_weed DEC_harv diff_log_A diff_sh* wave3 , cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local TZ_asym_diff_pre2_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local TZ_asym_diff_harv2_p = r(p)
test INC_hhsize + INC_weed - DEC_hhsize - DEC_weed = 0		// Check whether weeding values are different
local TZ_asym_diff_weed2_p = r(p)

local TZ_asym_inc_le2_b = _b[INC_hhsize]
test INC_hhsize=0
local TZ_asym_inc_le2_p = r(p)
local TZ_asym_dec_le2_b = _b[DEC_hhsize]
test DEC_hhsize=0
local TZ_asym_dec_le2_p = r(p)
local TZ_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local TZ_asym_inc_harv2_p = r(p)
local TZ_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local TZ_asym_dec_harv2_p = r(p)
local TZ_asym_inc_weed2_b = _b[INC_hhsize] + _b[INC_weed]
test _b[INC_hhsize] + _b[INC_weed] = 0
local TZ_asym_inc_weed2_p = r(p)
local TZ_asym_dec_weed2_b = _b[DEC_hhsize] + _b[DEC_weed]
test _b[DEC_hhsize] + _b[DEC_weed] = 0
local TZ_asym_dec_weed2_p = r(p)
local TZ_asym2_obv = e(N)
local TZ_asym2_r2 = e(r2)


***** Uganda *****
* asymmetric results - no kids
use "$newdata/UG_reg_ready", clear
drop INC_hhsize DEC_hhsize
gen INC_hhsize = diff_log_hhsize*(diff_log_hhsize>0)
gen DEC_hhsize = diff_log_hhsize*(diff_log_hhsize<0)
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"
la var diff_$hhsize_var "$\Delta$ Labor endowment"

reg diff_`dep_var' INC_hhsize DEC_hhsize diff_log_A diff_sh* wave3 wave4, cluster(hhid)
test INC_hhsize - DEC_hhsize = 0		
local UG_asym_diff_pre_p = r(p)

local UG_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local UG_asym_inc_le_p = r(p)
local UG_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local UG_asym_dec_le_p = r(p)
local UG_asym_obv = e(N)
local UG_asym_r2 = e(r2)

* asymmetric results - time away
drop INC_* DEC_*
gen INC_hhsize = diff_log_phase_away*(diff_log_phase_away>0)
gen DEC_hhsize = diff_log_phase_away*(diff_log_phase_away <0)
la var INC_hhsize "$\Delta$ Labor endowment if positive"
la var DEC_hhsize "$\Delta$ Labor endowment if negative"

reg diff_`dep_var' INC_hhsize DEC_hhsize diff_log_A diff_sh* wave3 wave4, cluster(hhid)
test INC_hhsize - DEC_hhsize = 0	
local UG_asym_diff_pre2_p = r(p)

local UG_asym_inc_le2_b = _b[INC_hhsize]
test INC_hhsize=0
local UG_asym_inc_le2_p = r(p)
local UG_asym_dec_le2_b = _b[DEC_hhsize]
test DEC_hhsize=0
local UG_asym_dec_le2_p = r(p)
local UG_asym2_obv = e(N)
local UG_asym2_r2 = e(r2)

** EXPORT

*save data temporarily
tempfile export_data
save `export_data'


*create table of marginals and F-tests for asymmetric results
clear
set obs 17
gen col0 = "Reference \$\times \Delta LE\$ if Inc" in 1
replace col0 = "Reference \$\times \Delta LE\$ if Dec" in 3
replace col0 = "Harvest \$\times \Delta LE\$ if Inc" in 5
replace col0 = "Harvest \$\times \Delta LE\$ if Dec" in 7
replace col0 = "Weeding \$\times \Delta LE\$ if Inc" in 9
replace col0 = "Weeding \$\times \Delta LE\$ if Dec" in 11

replace col0 = "\hline Reference: Inc - Dec" in 13
replace col0 = "Harvest: Inc - Dec" in 14
replace col0 = "Weeding: Inc - Dec" in 15
replace col0 = "\hline Observations" in 16
replace col0 = "\$R^2\$" in 17

forvalues i=1/8 {
	gen col`i' = . in 1
	gen star`i' = ""
}

local i = 1
foreach country in ET MW TZ UG {
	local varlist
	di "in country loop, i=`i'"
	local j = 2*`i'-1
	replace col`j' = ``country'_asym_inc_le_b' in 1
	replace col`j' = ``country'_asym_inc_le_p' in 2
	replace col`j' = ``country'_asym_dec_le_b' in 3
	replace col`j' = ``country'_asym_dec_le_p' in 4
	replace col`j' = ``country'_asym_diff_pre_p' in 13
	replace col`j' = ``country'_asym_r2' in 17
	local j = 2*`i'
	replace col`j' = ``country'_asym_inc_le2_b' in 1
	replace col`j' = ``country'_asym_inc_le2_p' in 2
	replace col`j' = ``country'_asym_dec_le2_b' in 3
	replace col`j' = ``country'_asym_dec_le2_p' in 4
	replace col`j' = ``country'_asym_diff_pre2_p' in 13
	replace col`j' = ``country'_asym2_r2' in 17

	if inlist(`i',1,2,3) {
		local j = 2*`i'-1
		replace col`j' = ``country'_asym_inc_harv_b' in 5
		replace col`j' = ``country'_asym_inc_harv_p' in 6
		replace col`j' = ``country'_asym_dec_harv_b' in 7
		replace col`j' = ``country'_asym_dec_harv_p' in 8
		replace col`j' = ``country'_asym_diff_harv_p' in 14

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_harv2_b' in 5
		replace col`j' = ``country'_asym_inc_harv2_p' in 6
		replace col`j' = ``country'_asym_dec_harv2_b' in 7
		replace col`j' = ``country'_asym_dec_harv2_p' in 8
		replace col`j' = ``country'_asym_diff_harv2_p' in 14
		local varlist asym_inc_harv asym_dec_harv
	}
	if `i'==3 {
		local j = 2*`i'-1
		replace col`j' = ``country'_asym_inc_weed_b' in 9
		replace col`j' = ``country'_asym_inc_weed_p' in 10
		replace col`j' = ``country'_asym_dec_weed_b' in 11
		replace col`j' = ``country'_asym_dec_weed_p' in 12
		replace col`j' = ``country'_asym_diff_weed_p' in 15

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_weed2_b' in 9
		replace col`j' = ``country'_asym_inc_weed2_p' in 10
		replace col`j' = ``country'_asym_dec_weed2_b' in 11
		replace col`j' = ``country'_asym_dec_weed2_p' in 12
		replace col`j' = ``country'_asym_diff_weed2_p' in 15
		local varlist `varlist' asym_inc_weed asym_dec_weed
	}

	* assigning stars
	forvalues j=1/2 {
		local row = 1
		foreach var in asym_inc_le asym_dec_le `varlist' {
			local temp = 2*`row'-1
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'_p"
			if `j'<2 {
				local p_var  `country'_`var'_p
			}
			else {
				local p_var  `country'_`var'2_p	
			}
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}		
	}
	local ++i
}

*convert cells to strings
local i = 1
foreach country in ET MW TZ UG {
	forvalues j=1/2 {
		di "in format loop with country=`country', j=`j', and i=`i'"
		local col = 2*`i'-2+`j'
		tostring col`col', replace force format(%9.3f)

		forvalues row=1(2)11 {
			replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
			di "value =  col`col'[`row']"
			di col`col'[`row']
			di " and strpos="  strpos(col`col'[`row'],".")
			replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
		}
		forvalues row=2(2)12 {
			replace col`col' = "("+col`col'+")" in `row'
			replace col`col' = "" in `row' if col`col'[`row']=="(.)"
		}
	}

	*observations in bottom panel
	local j = 1
	foreach var in asym asym2 {
		gen `country'_`var' = ``country'_`var'_obv' in 16
		tostring `country'_`var', replace force format(%8.0fc)
		local col = 2*`i'-2+`j'
		replace col`col' = `country'_`var' in 16
		local ++j
	}
	local ++i
}

keep col*
replace col8 = col8 + " \\"
outsheet using "$path/output/ALL_robust_margins.tex", replace delim("&") non noq

exit






