
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear



*********************************************************************************************************************
* pwb - added triggers to allow harvest labor as outcome var and control which hh size variable to use

local dep_var act_log_ld

*********************************************************************************************************************


* Combined results for output

**** Ethiopia *****

* pooled cross-section results
use "$path/Constructed Data/ET panel data merged", replace
egen ea_wave = group(ea1 wave)

xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea1, cluster(ea_wave)
eststo ET_pool
test $hhsize_var = 0
local ET_pool_le_b = _b[$hhsize_var]
local ET_pool_le_p = r(p)
local ET_pool_obv = e(N)
local ET_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}
reg diff_log_ld_tot_kids diff_$hhsize_var diff_log_A diff_sh*, cluster(ea_wave)
eststo ET_panel
test diff_$hhsize_var = 0
local ET_panel_le_b = _b[diff_$hhsize_var]
local ET_panel_le_p = r(p)
local ET_panel_obv = e(N)
local ET_panel_r2 = e(r2)

* base symmetric results
use "$newdata/ET_reg_ready", clear		// generated in the "Ethiopia panel analysis.do" file
egen ea_wave = group(ea1 wave)
gen harv = activity==1

gen change_harv = diff_$hhsize_var*harv
replace INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
replace DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv


reg diff_`dep_var' harv diff_$hhsize_var change_harv diff_log_A diff_sh* , cluster(ea_wave)
eststo ET_sym
local ET_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local ET_sym_chg_le_p = r(p)
local ET_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test _b[diff_$hhsize_var] + _b[change_harv] = 0
local ET_sym_chg_harv_p = r(p)
local ET_sym_obv = e(N)
local ET_sym_r2 = e(r2)
test _b[change_harv] = 0
local ET_sym_ref_harv = r(p)

* asymmetric results
reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv diff_log_A diff_sh* , cluster(ea_wave)
eststo ET_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local ET_asym_diff_harv_p = r(p)

local ET_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local ET_asym_inc_le_p = r(p)
local ET_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local ET_asym_dec_le_p = r(p)
local ET_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local ET_asym_inc_harv_p = r(p)
local ET_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local ET_asym_dec_harv_p = r(p)
local ET_asym_obv = e(N)
local ET_asym_r2 = e(r2)
test _b[INC_harv] = 0
local ET_inc_ref_harv = r(p)
test _b[DEC_harv] = 0
local ET_dec_ref_harv = r(p)


***** Malawi *****

* pooled cross-section results
use "$path/Constructed Data/Malawi Panel Data Clean", replace
egen ea_wave = group(ea1 wave)

xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea1, cluster(ea_wave)
eststo MW_pool
test $hhsize_var = 0
local MW_pool_le_b = _b[$hhsize_var]
local MW_pool_le_p = r(p)
local MW_pool_obv = e(N)
local MW_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}
reg diff_log_ld_tot_kids diff_$hhsize_var diff_log_A diff_sh*, cluster(ea_wave)
eststo MW_panel
test diff_$hhsize_var = 0
local MW_panel_le_b = _b[diff_$hhsize_var]
local MW_panel_le_p = r(p)
local MW_panel_obv = e(N)
local MW_panel_r2 = e(r2)

* base symmetric results
use "$newdata/MW_reg_ready.dta", clear		// generated in the "Malawi panel analysis final.do" file
egen ea_wave = group(ea1 wave)
gen harv = activity==1
gen change_harv = diff_$hhsize_var*harv
replace INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
replace DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv

reg diff_`dep_var' harv diff_$hhsize_var change_harv diff_log_A diff_sh* , cluster(ea_wave)
eststo MW_sym
local MW_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local MW_sym_chg_le_p = r(p)
local MW_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test _b[diff_$hhsize_var] + _b[change_harv] = 0
local MW_sym_chg_harv_p = r(p)
local MW_sym_obv = e(N)
local MW_sym_r2 = e(r2)
test _b[change_harv] = 0
local MW_sym_ref_harv = r(p)

* asymmetric results
reg diff_`dep_var' harv INC_hhsize INC_harv DEC_hhsize DEC_harv diff_log_A diff_sh* , cluster(ea_wave)
eststo MW_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local MW_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local MW_asym_diff_harv_p = r(p)

local MW_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local MW_asym_inc_le_p = r(p)
local MW_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local MW_asym_dec_le_p = r(p)
local MW_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local MW_asym_inc_harv_p = r(p)
local MW_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local MW_asym_dec_harv_p = r(p)
local MW_asym_obv = e(N)
local MW_asym_r2 = e(r2)
test _b[INC_harv] = 0
local MW_inc_ref_harv = r(p)
test _b[DEC_harv] = 0
local MW_dec_ref_harv = r(p)



***** Tanzania *****

* pooled cross-section results
use "$path/Constructed Data/TZ panel data merged", replace
egen ea_wave = group(ea1 wave)

xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea1, cluster(ea_wave)
eststo TZ_pool
test $hhsize_var = 0
local TZ_pool_le_b = _b[$hhsize_var]
local TZ_pool_le_p = r(p)
local TZ_pool_obv = e(N)
local TZ_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}
reg diff_log_ld_tot_kids diff_$hhsize_var diff_log_A diff_sh* wave3, cluster(ea_wave)
eststo TZ_panel
test diff_$hhsize_var = 0
local TZ_panel_le_b = _b[diff_$hhsize_var]
local TZ_panel_le_p = r(p)
local TZ_panel_obv = e(N)
local TZ_panel_r2 = e(r2)


* base symmetric results
use "$newdata/TZ_reg_ready.dta", clear		// generated in the "Tanzania panel analysis final.do" file
egen ea_wave = group(ea1 wave)
gen weed = activity==1
gen harv = activity==2
gen change_weed = diff_$hhsize_var*weed
gen change_harv = diff_$hhsize_var*harv
replace INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
replace DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_weed = INC_hhsize*weed
gen DEC_weed = DEC_hhsize*weed
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv

reg diff_`dep_var' weed harv diff_$hhsize_var change_weed change_harv diff_log_A diff_sh* wave3 , cluster(ea_wave)
eststo TZ_sym
local TZ_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local TZ_sym_chg_le_p = r(p)
local TZ_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test _b[diff_$hhsize_var] + _b[change_harv] = 0
local TZ_sym_chg_harv_p = r(p)
local TZ_sym_chg_weed_b = _b[diff_$hhsize_var] + _b[change_weed]
test _b[diff_$hhsize_var] + _b[change_weed] = 0
local TZ_sym_chg_weed_p = r(p)
local TZ_sym_obv = e(N)
local TZ_sym_r2 = e(r2)
test _b[change_harv] = 0
local TZ_sym_ref_harv = r(p)
test _b[change_weed] = 0
local TZ_sym_ref_weed = r(p)
test _b[change_harv] - _b[change_weed] = 0
local TZ_sym_harv_weed = r(p)

* asymmetric results
reg diff_`dep_var' weed harv INC_hhsize INC_weed INC_harv DEC_hhsize DEC_weed DEC_harv diff_log_A diff_sh* wave3 , cluster(ea_wave)
eststo TZ_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local TZ_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local TZ_asym_diff_harv_p = r(p)
test INC_hhsize + INC_weed - DEC_hhsize - DEC_weed = 0		// Check whether weeding values are different
local TZ_asym_diff_weed_p = r(p)

local TZ_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local TZ_asym_inc_le_p = r(p)
local TZ_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local TZ_asym_dec_le_p = r(p)
local TZ_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test _b[INC_hhsize] + _b[INC_harv] = 0
local TZ_asym_inc_harv_p = r(p)
local TZ_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test _b[DEC_hhsize] + _b[DEC_harv] = 0
local TZ_asym_dec_harv_p = r(p)
local TZ_asym_inc_weed_b = _b[INC_hhsize] + _b[INC_weed]
test _b[INC_hhsize] + _b[INC_weed] = 0
local TZ_asym_inc_weed_p = r(p)
local TZ_asym_dec_weed_b = _b[DEC_hhsize] + _b[DEC_weed]
test _b[DEC_hhsize] + _b[DEC_weed] = 0
local TZ_asym_dec_weed_p = r(p)
local TZ_asym_obv = e(N)
local TZ_asym_r2 = e(r2)
test _b[INC_harv] = 0
local TZ_inc_ref_harv = r(p)
test _b[DEC_harv] = 0
local TZ_dec_ref_harv = r(p)
test _b[INC_weed] = 0
local TZ_inc_ref_weed = r(p)
test _b[DEC_weed] = 0
local TZ_dec_ref_weed = r(p)
test _b[INC_weed] - _b[INC_harv]= 0
local TZ_inc_harv_weed = r(p)
test _b[DEC_weed]- _b[DEC_harv] = 0
local TZ_dec_harv_weed = r(p)


***** Uganda *****
* pooled cross-section results
use "$path/Constructed Data/UG panel data merged", replace
egen ea_wave = group(ea wave)

xi: reg log_ld_tot_kids $hhsize_var log_A share_pm share_pf share_em i.ea, cluster(ea_wave)
eststo UG_pool
test $hhsize_var = 0
local UG_pool_le_b = _b[$hhsize_var]
local UG_pool_le_p = r(p)
local UG_pool_obv = e(N)
local UG_pool_r2 = e(r2)

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var share_pm share_pf share_em log_A {
	gen diff_`i' = D.`i'
}
reg diff_log_ld_tot_kids diff_$hhsize_var diff_log_A diff_sh* i.wave, cluster(ea_wave)
eststo UG_panel
test diff_$hhsize_var = 0
local UG_panel_le_b = _b[diff_$hhsize_var]
local UG_panel_le_p = r(p)
local UG_panel_obv = e(N)
local UG_panel_r2 = e(r2)

*base symmetric results
use "$newdata/UG_reg_ready", clear
egen ea_wave = group(ea wave)
replace INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
replace DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)

reg diff_`dep_var' diff_$hhsize_var diff_log_A diff_sh* i.wave, cluster(ea_wave)
eststo UG_sym
local UG_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local UG_sym_chg_le_p = r(p)
local UG_sym_obv = e(N)
local UG_sym_r2 = e(r2)

*asymmetric results
reg diff_`dep_var' INC_hhsize DEC_hhsize diff_log_A diff_sh* i.wave, cluster(ea_wave)
eststo UG_asym
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local UG_asym_diff_pre_p = r(p)

local UG_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local UG_asym_inc_le_p = r(p)
local UG_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local UG_asym_dec_le_p = r(p)
local UG_asym_obv = e(N)
local UG_asym_r2 = e(r2)


** Output raw results
/*
estout ET_pool ET_panel MW_pool MW_panel TZ_pool TZ_panel UG_pool UG_panel using "$path/output/ALL_IV_raw_allactivity.tex", ///
	cells(b(star fmt(3)) se(par fmt(3))) order(log_phase diff_log_phase log_A diff_log_A share_pm share_pf share_em diff_share_pm diff_share_pf diff_share_em) ///
	varl(diff_log_phase "\$\Delta E\$" diff_log_A "\$\Delta\$ Acres Cultivated" diff_share_pm "\$\Delta\$ Prime Male Share" diff_share_pf "\$\Delta\$ Prime Female Share" diff_share_em "\$\Delta\$ Elderly Male Share" log_phase "\$E\$" log_A "Acres Cultivated" share_pm "Prime Male Share" share_pf "Prime Female Share" share_em "Elderly Male Share" _cons Constant) ///
	nonumbers collabels(none) mlabels(none) end(" \\ ") stats(N r2_a, fmt(0 3) labels("\hline Observations" "Adj. \$R^2$")) starlevels(* 0.10 ** 0.05 *** 0.01) drop(*ea1* *ea_* wave*) style(tex) replace

estout ET_sym ET_asym MW_sym MW_asym TZ_sym TZ_asym UG_sym UG_asym using "$path/output/ALL_IV_raw_byactivity.tex", ///
	cells(b(star fmt(3)) se(par fmt(3))) order(diff_log_phase INC_hhsize DEC_hhsize harv change_harv INC_harv DEC_harv weed change_weed INC_weed DEC_weed diff_log_A diff_share_pm diff_share_pf diff_share_em) ///
	varl(diff_log_phase "Reference \$\times \Delta E\$" INC_hhsize "Reference \$\times \Delta E^+\$" DEC_hhsize "Reference \$\times \Delta E^-\$" harv "Harvest" change_harv "Harvest \$\times \Delta E\$" INC_harv "Harvest \$\times \Delta E^+\$"  DEC_harv "Harvest \$\times \Delta E^-\$" weed "Weeding" change_weed "Weeding \$\times \Delta E\$" INC_weed "Weeding \$\times \Delta E^+\$" DEC_weed "Weeding \$\times \Delta E^-\$" ///
	diff_log_A "\$\Delta\$ Acres Cultivated" diff_share_pm "\$\Delta\$ Prime Male Share" diff_share_pf "\$\Delta\$ Prime Female Share" diff_share_em "\$\Delta\$ Elderly Male Share" log_phase "\hline \$\E\$" log_owned "Acres Cultivated" share_pm "Prime Male Share" share_pf "Prime Female Share" share_em "Elderly Male Share" _cons Constant) ///
	nonumbers collabels(none) mlabels(none) end(" \\ ") stats(N r2_a, fmt(0 3) labels("\hline Observations" "Adj. \$R^2$" )) starlevels(* 0.10 ** 0.05 *** 0.01) drop(wave*) style(tex) replace
*/

** EXPORT marginal effects

*save data temporarily
tempfile export_data
save `export_data'


*create table of marginals and F-tests for asymmetric results
clear
set obs 40

gen col0 = " \textbf{All activities}" in 1
replace col0 = "Labor endow. (\$E\$)" in 2
replace col0 = "\$\Delta E\$" in 4
replace col0 = "\hline Observations" in 6
replace col0 = "\$R^2\$" in 7

replace col0 = "\hline \hline \textbf{By activity}" in 8
replace col0 = "Reference \$\times \Delta E\$" in 9
replace col0 = "Reference \$\times \Delta E^+\$" in 11
replace col0 = "Reference \$\times \Delta E^-\$" in 13
replace col0 = "Harvest \$\times \Delta E\$" in 15
replace col0 = "Harvest \$\times \Delta E^+\$" in 17
replace col0 = "Harvest \$\times \Delta E^-\$" in 19
replace col0 = "Weeding \$\times \Delta E\$" in 21
replace col0 = "Weeding \$\times \Delta E^+\$" in 23
replace col0 = "Weeding \$\times \Delta E^-\$" in 25

replace col0 = "\hline Reference: Inc = Dec" in 27
replace col0 = "Harvest: Inc = Dec" in 28
replace col0 = "Weeding: Inc = Dec" in 29
replace col0 = "\hline Reference = Harvest" in 30
replace col0 = "Reference = Weeding" in 31
replace col0 = "Weeding = Harvest" in 32
replace col0 = "Reference = Harvest, \$+\$" in 33
replace col0 = "Reference = Harvest, \$-\$" in 34
replace col0 = "Reference = Weeding, \$+\$" in 35
replace col0 = "Reference = Weeding, \$-\$" in 36
replace col0 = "Weeding = Harvest, \$+\$" in 37
replace col0 = "Weeding = Harvest, \$-\$" in 38
replace col0 = "\hline Observations" in 39
replace col0 = "\$R^2\$" in 40

forvalues i=1/8 {
	gen col`i' = . in 1
	gen star`i' = ""
}

local i = 1
foreach country in ET MW TZ UG {
	local varlist
	di "in country loop, i=`i'"
	local j = 2*`i'-1
	replace col`j' = ``country'_pool_le_b' in 2
	replace col`j' = ``country'_pool_le_p' in 3
	replace col`j' = ``country'_pool_r2' in 7
	local j = 2*`i'
	replace col`j' = ``country'_panel_le_b' in 4
	replace col`j' = ``country'_panel_le_p' in 5
	replace col`j' = ``country'_panel_r2' in 7
	local j = 2*`i'-1
	replace col`j' = ``country'_sym_chg_le_b' in 9
	replace col`j' = ``country'_sym_chg_le_p' in 10
	replace col`j' = ``country'_sym_r2' in 40
	local j = 2*`i'
	replace col`j' = ``country'_asym_inc_le_b' in 11
	replace col`j' = ``country'_asym_inc_le_p' in 12
	replace col`j' = ``country'_asym_dec_le_b' in 13
	replace col`j' = ``country'_asym_dec_le_p' in 14
	replace col`j' = ``country'_asym_diff_pre_p' in 27
	replace col`j' = ``country'_asym_r2' in 40

	if inlist(`i',1,2,3) {
		local j = 2*`i'-1
		replace col`j' = ``country'_sym_chg_harv_b' in 15
		replace col`j' = ``country'_sym_chg_harv_p' in 16

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_harv_b' in 17
		replace col`j' = ``country'_asym_inc_harv_p' in 18
		replace col`j' = ``country'_asym_dec_harv_b' in 19
		replace col`j' = ``country'_asym_dec_harv_p' in 20
		replace col`j' = ``country'_asym_diff_harv_p' in 28
		local varlist sym_chg_harv asym_inc_harv asym_dec_harv
	}
	if `i'==3 {
		local j = 2*`i'-1
		replace col`j' = ``country'_sym_chg_weed_b' in 21
		replace col`j' = ``country'_sym_chg_weed_p' in 22

		local j = 2*`i'
		replace col`j' = ``country'_asym_inc_weed_b' in 23
		replace col`j' = ``country'_asym_inc_weed_p' in 24
		replace col`j' = ``country'_asym_dec_weed_b' in 25
		replace col`j' = ``country'_asym_dec_weed_p' in 26
		replace col`j' = ``country'_asym_diff_weed_p' in 29
		local varlist `varlist' sym_chg_weed asym_inc_weed asym_dec_weed
	}

	* assigning stars for first 2 rows
	di "about to var list with varlist=`varlist'"
	forvalues j=1/2 {
		local row = 1
		foreach var in pool_le panel_le {
			local temp = 2*`row'
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'_p"
			local p_var  `country'_`var'_p
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}
	}
	
	* assigning stars for bottom panel
	forvalues j=1/2 {
		local row = 1
		foreach var in sym_chg_le asym_inc_le asym_dec_le `varlist' {
			local temp = 2*`row'+7
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'_p"
			local p_var  `country'_`var'_p
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}		
	}
	local ++i
}

* add the F-tests for differences across activities
local i = 1
foreach country in ET MW TZ {
	if "`country'"!="TZ" {
		replace col`i' =  ``country'_sym_ref_harv' in 30
		local ++i
		replace col`i' =  ``country'_inc_ref_harv' in 33
		replace col`i' =  ``country'_dec_ref_harv' in 34	
	}
	if "`country'"=="TZ" {
		replace col`i' =  ``country'_sym_ref_harv' in 30
		replace col`i' =  ``country'_sym_ref_weed' in 31
		replace col`i' =  ``country'_sym_harv_weed' in 32
		local ++i
		replace col`i' =  ``country'_inc_ref_harv' in 33
		replace col`i' =  ``country'_dec_ref_harv' in 34	
		replace col`i' =  ``country'_inc_ref_weed' in 35
		replace col`i' =  ``country'_dec_ref_weed' in 36
		replace col`i' =  ``country'_inc_harv_weed' in 37
		replace col`i' =  ``country'_dec_harv_weed' in 38
	}
	local ++i
}

*convert cells to strings
local i = 1
foreach country in ET MW TZ UG {
	forvalues j=1/2 {
		di "in format loop with country=`country', j=`j', and i=`i'"
		local col = 2*`i'-2+`j'
		tostring col`col', replace force format(%9.3f)
		*top panel
		forvalues row=2(2)4 {
			replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
			di "value =  col`col'[`row']"
			di col`col'[`row']
			di " and strpos="  strpos(col`col'[`row'],".")
			replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
		}
		forvalues row=1(2)5 {
			replace col`col' = "("+col`col'+")" in `row'
			replace col`col' = "" in `row' if col`col'[`row']=="(.)"
		}
		*bottom panel
		forvalues row=9(2)25 {
			replace col`col' = "$"+col`col'+"^"+star`col'+"$" in `row' if star`col'[`row']!=""
			di "value =  col`col'[`row']"
			di col`col'[`row']
			di " and strpos="  strpos(col`col'[`row'],".")
			replace col`col' = "" in `row' if strpos(col`col'[`row'],".")==1
		}
		forvalues row=8(2)26 {
			replace col`col' = "("+col`col'+")" in `row'
			replace col`col' = "" in `row' if col`col'[`row']=="(.)"
		}
	}
	local j = 1
	*observations in top panel
	foreach var in pool panel {
		gen `country'_`var' = ``country'_`var'_obv' in 6
		tostring `country'_`var', replace force format(%8.0fc)
		local col = 2*`i'-2+`j'
		replace col`col' = `country'_`var' in 6
		local ++j
	}
	*observatiosn in bottom panel
	local j = 1
	foreach var in sym asym {
		gen `country'_`var' = ``country'_`var'_obv' in 39
		tostring `country'_`var', replace force format(%8.0fc)
		local col = 2*`i'-2+`j'
		replace col`col' = `country'_`var' in 39
		local ++j
	}
	local ++i
}

keep col*
replace col8 = col8 + " \\"
outsheet using "$path/output/ALL_time_margins.tex", replace delim("&") non noq


exit
