
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear

if c(version) > 12.1 {
	di "*****"
	di "Warning: check the position of the F-stat in the e(first) table.  Current code uses the 4th position"
	di "****"
	exit
}


local dep_var act_log_ld
global hhsize_var log_hhsize

gl min_vill_size = 6
matrix results = .,.,.
mat male_results = J(4,3,.)
mat female_results = J(4,3,.)

** Combined results for output

**** Ethiopia *****
use "$newdata/ET panel data merged", replace
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
foreach i of varlist log_ld_tot_kids $hhsize_var share_pm share_pf share_em log_A log_owned log_phase log_male log_female log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

*All household members
*** by enumeration area
egen ea_wave = group(ea1 wave)
bysort ea1 wave: egen diff_vil_avg = mean(diff_$hhsize_var)
by ea1 wave: egen vil_num = count(diff_$hhsize_var)
replace diff_vil_avg = (diff_vil_avg*vil_num - diff_$hhsize_var) / (vil_num-1)
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var = diff_vil_avg) diff_log_A diff_sh*, cluster(ea_wave) first
* f-stat
mat res = e(first)
local f_1 = res[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_phase =diff_vil_avg) diff_log_A diff_sh*, cluster(ea_wave) first
mat res = e(first)
local f_2 = res[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg) diff_log_A diff_sh* if vil_num>=$min_vill_size, cluster(ea_wave) first
mat res = e(first)
local f_3 = res[4,1]

mat results = results\[`f_1',`f_2',`f_3']
mat list results

* Males
*** by enumeration area no kids
bysort ea1 wave: egen diff_vil_avg_male = mean(diff_log_male_nokids)
by ea1 wave: egen vil_num_male = count(diff_log_male_nokids)
replace diff_vil_avg_male = (diff_vil_avg_male * vil_num_male - diff_log_male_nokids) / (vil_num_male - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids diff_log_A =diff_vil_avg_male diff_log_owned) diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat male_results[1,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_male = diff_vil_avg_male) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat male_results[1,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh* if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat male_results[1,3] = temp[4,1]

* Females
*** by enumeration area no kids
bysort ea1 wave: egen diff_vil_avg_female = mean(diff_log_female_nokids)
by ea1 wave: egen vil_num_female = count(diff_log_female_nokids)
replace diff_vil_avg_female = (diff_vil_avg_female * vil_num_female - diff_log_female_nokids) / (vil_num_female - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat female_results[1,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_female = diff_vil_avg_female) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat female_results[1,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh* if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat female_results[1,3] = temp[4,1]


***** Malawi *****

use "$newdata/Malawi Panel Data Clean", replace
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g		
xtset hhid wave
foreach i of varlist log_ld_tot_kids log_hhsize log_phase share_pm share_pf share_em log_A log_owned log_male log_female log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

* by enumeration area
egen ea_wave = group(ea1 wave)
bysort ea1 wave: egen diff_vil_avg = mean(diff_$hhsize_var)
by ea1 wave: egen vil_num = count(diff_$hhsize_var)
replace diff_vil_avg = (diff_vil_avg*vil_num - diff_$hhsize_var) / (vil_num-1)
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg) diff_log_A diff_sh*, cluster(ea_wave) first
* f stat
mat res = e(first)
local f_1 = res[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_phase =diff_vil_avg) diff_log_A diff_sh*, cluster(ea_wave) first
mat res = e(first)
local f_2 = res[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg) diff_log_A diff_sh* if vil_num>=$min_vill_size, cluster(ea_wave) first
mat res = e(first)
local f_3 = res[4,1]
mat results = results\[`f_1',`f_2',`f_3']
mat list results


* Males
*** by enumeration area no kids
bysort ea1 wave: egen diff_vil_avg_male = mean(diff_log_male_nokids)
by ea1 wave: egen vil_num_male = count(diff_log_male_nokids)
replace diff_vil_avg_male = (diff_vil_avg_male * vil_num_male - diff_log_male_nokids) / (vil_num_male - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat male_results[2,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_male = diff_vil_avg_male) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat male_results[2,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh* if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat male_results[2,3] = temp[4,1]

* Females
*** by enumeration area no kids
bysort ea1 wave: egen diff_vil_avg_female = mean(diff_log_female_nokids)
by ea1 wave: egen vil_num_female = count(diff_log_female_nokids)
replace diff_vil_avg_female = (diff_vil_avg_female * vil_num_female - diff_log_female_nokids) / (vil_num_female - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat female_results[2,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_female = diff_vil_avg_female) diff_log_A diff_sh*, cluster(ea_wave) first
mat temp = e(first)
mat female_results[2,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh* if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat female_results[2,3] = temp[4,1]



***** Tanzania *****

use "$newdata/TZ panel data merged", replace
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			
xtset hhid wave
foreach i of varlist log_ld_tot_kids log_hhsize log_phase share_pm share_pf share_em log_A log_owned log_male log_female log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

** by enumeration area
egen ea_wave = group(ea1 wave)
capture drop *vil*
bysort ea1 wave: egen diff_vil_avg = mean(diff_$hhsize_var)
by ea1 wave: egen vil_num = count(diff_$hhsize_var)
replace diff_vil_avg = (diff_vil_avg*vil_num - diff_$hhsize_var) / (vil_num-1)
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg) diff_log_A diff_sh* wave3, cluster(ea_wave) first
* f stat
mat res = e(first)
local f_1 = res[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_phase =diff_vil_avg) diff_log_A diff_sh* wave3, cluster(ea_wave) first
mat res = e(first)
local f_2 = res[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg) diff_log_A diff_sh* wave3 if vil_num>=$min_vill_size, cluster(ea_wave) first
mat res = e(first)
local f_3 = res[4,1]
mat results = results\[`f_1',`f_2',`f_3']
mat list results

* Males
*** by enumeration area no kids
bysort ea1 wave: egen diff_vil_avg_male = mean(diff_log_male_nokids)
by ea1 wave: egen vil_num_male = count(diff_log_male_nokids)
replace diff_vil_avg_male = (diff_vil_avg_male * vil_num_male - diff_log_male_nokids) / (vil_num_male - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh* wave3, cluster(ea_wave) first
mat temp = e(first)
mat male_results[3,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_male = diff_vil_avg_male) diff_log_A diff_sh* wave3, cluster(ea_wave) first
mat temp = e(first)
mat male_results[3,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh* wave3 if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat male_results[3,3] = temp[4,1]

* Females
*** by enumeration area no kids
bysort ea1 wave: egen diff_vil_avg_female = mean(diff_log_female_nokids)
by ea1 wave: egen vil_num_female = count(diff_log_female_nokids)
replace diff_vil_avg_female = (diff_vil_avg_female * vil_num_female - diff_log_female_nokids) / (vil_num_female - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh* wave3, cluster(ea_wave) first
mat temp = e(first)
mat female_results[3,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_female = diff_vil_avg_female) diff_log_A diff_sh* wave3, cluster(ea_wave) first
mat temp = e(first)
mat female_results[3,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh* wave3 if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat female_results[3,3] = temp[4,1]


***** Uganda *****
use "$newdata/UG panel data merged", replace

* panel analysis - no activity info
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave
foreach i of varlist log_ld_tot_kids log_hhsize log_phase share_pm share_pf share_em log_A log_owned log_male log_female log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}
capture drop *vil*
egen ea_wave = group(ea wave)
bysort ea wave: egen diff_vil_avg = mean(diff_$hhsize_var)
by ea wave: egen vil_num = count(diff_$hhsize_var)
replace diff_vil_avg = (diff_vil_avg*vil_num - diff_$hhsize_var) / (vil_num-1)
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg diff_log_A) diff_log_A diff_sh* wave3 wave4, cluster(ea_wave) first
* f stat
mat res = e(first)
local f_1 = res[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_phase =diff_vil_avg) diff_log_A diff_sh* wave3 wave4, cluster(ea_wave) first
mat res = e(first)
local f_2 = res[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_$hhsize_var =diff_vil_avg) diff_log_A diff_sh* wave3 wave4 if vil_num>=$min_vill_size, cluster(ea_wave) first
mat res = e(first)
local f_3 = res[4,1]
mat results = results\[`f_1',`f_2',`f_3']
mat list results


* Males
*** by enumeration area no kids
bysort ea wave: egen diff_vil_avg_male = mean(diff_log_male_nokids)
by ea wave: egen vil_num_male = count(diff_log_male_nokids)
replace diff_vil_avg_male = (diff_vil_avg_male * vil_num_male - diff_log_male_nokids) / (vil_num_male - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh* wave3 wave4, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat male_results[4,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_male = diff_vil_avg_male) diff_log_A diff_sh* wave3 wave4, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat male_results[4,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_male_nokids =diff_vil_avg_male) diff_log_A diff_sh* wave3 wave4 if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat male_results[4,3] = temp[4,1]

* Females
*** by enumeration area no kids
bysort ea wave: egen diff_vil_avg_female = mean(diff_log_female_nokids)
by ea wave: egen vil_num_female = count(diff_log_female_nokids)
replace diff_vil_avg_female = (diff_vil_avg_female * vil_num_female - diff_log_female_nokids) / (vil_num_female - 1)
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh* wave3 wave4, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat female_results[4,1] = temp[4,1]

*** double check that endogenous adjustments are not taking aging kids into account
ivreg2 diff_log_ld_tot_kids (diff_log_female = diff_vil_avg_female) diff_log_A diff_sh* wave3 wave4, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat female_results[4,2] = temp[4,1]

*** drop the villages with <=8 households
ivreg2 diff_log_ld_tot_kids (diff_log_female_nokids =diff_vil_avg_female) diff_log_A diff_sh* wave3 wave4 if vil_num>=$min_vill_size, cluster(ea_wave) first
mat temp = e(first)
mat list temp
mat female_results[4,3] = temp[4,1]



***** Output results
clear
svmat results

gen country = " Ethiopia" in 2
replace country = " Malawi" in 3
replace country = " Tanzania" in 4
replace country = " Uganda" in 5
order country
drop in 1
tostring results*, force replace format(%6.2f)
replace results3 = results3 + " \\"
outsheet using "$path/output/F_stats_village_IVs.tex", non noq delim("&") replace

*output male results
clear
svmat male_results

gen country = " Ethiopia" in 1
replace country = " Malawi" in 2
replace country = " Tanzania" in 3
replace country = " Uganda" in 4
order country
tostring male_results*, force replace format(%6.2f)
replace male_results3 = male_results3 + " \\"
outsheet using "$path/output/F_stats_village_IVs_male.tex", non noq delim("&") replace

*output female results
clear
svmat female_results

gen country = " Ethiopia" in 1
replace country = " Malawi" in 2
replace country = " Tanzania" in 3
replace country = " Uganda" in 4
order country
tostring female_results*, force replace format(%6.2f)
replace female_results3 = female_results3 + " \\"
outsheet using "$path/output/F_stats_village_IVs_female.tex", non noq delim("&") replace

exit
