
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000
eststo clear

local dep_var act_log_ld

**** Ethiopia *****

*** Check effect by whether district was involved in PSNP program

* symmetric results - by PSNP
use "$newdata/ET_reg_ready", clear
egen ea_wave = group(ea1 wave)

gen harv = activity==1
gen change_harv = diff_$hhsize_var*harv
gen change_harv_psnp = change_harv*any_psnp
gen diff_hhsize_psnp = diff_$hhsize_var*any_psnp
gen psnp_harv = any_psnp*harv
foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
	gen `var'_psnp = any_psnp * `var'
}

reg diff_`dep_var' diff_$hhsize_var diff_hhsize_psnp any_psnp harv psnp_harv change_harv change_harv_psnp diff_log_A* diff_sh*, cluster(ea_wave)
local ET_sym_chg_le_b = _b[diff_$hhsize_var]
test diff_$hhsize_var=0
local ET_sym_chg_le_p = r(p)
local ET_sym_psnp_le_b = _b[diff_$hhsize_var] + _b[diff_hhsize_psnp]
test diff_$hhsize_var + diff_hhsize_psnp = 0
local ET_sym_psnp_le_p = r(p)
local ET_sym_chg_harv_b = _b[diff_$hhsize_var] + _b[change_harv]
test diff_$hhsize_var + change_harv = 0
local ET_sym_chg_harv_p = r(p)
local ET_sym_psnp_harv_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[diff_hhsize_psnp] + _b[change_harv_psnp]
test diff_$hhsize_var + change_harv + diff_hhsize_psnp + change_harv_psnp = 0
local ET_sym_psnp_harv_p = r(p)
local ET_sym_obv = e(N)
local ET_sym_r2 = e(r2)
test _b[change_harv] = 0
local ET_sym_ref_harv1 = r(p)
test _b[change_harv] + _b[change_harv_psnp] = 0
local ET_sym_ref_harv_psnp1 = r(p)
test _b[diff_hhsize_psnp] = 0
local ET_sym_ref_psnp = r(p)
test _b[diff_hhsize_psnp] + _b[change_harv_psnp] = 0
local ET_sym_harv_psnp = r(p)

* asymmetric results - by PSNP
gen INC_harv = INC_hhsize*harv
gen DEC_harv = DEC_hhsize*harv
gen INC_psnp = INC_hhsize*any_psnp
gen DEC_psnp = DEC_hhsize* any_psnp
gen INC_psnp_harv = INC_hhsize*any_psnp*harv
gen DEC_psnp_harv = DEC_hhsize*any_psnp*harv

reg diff_`dep_var' INC_hhsize DEC_hhsize INC_psnp DEC_psnp INC_harv DEC_harv harv any_psnp psnp_harv INC_psnp_harv DEC_psnp_harv diff_log_A* diff_sh*, cluster(ea_wave)
test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
local ET_asym_diff_pre_p = r(p)
test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
local ET_asym_diff_harv_p = r(p)
test INC_hhsize + INC_psnp - DEC_hhsize - DEC_psnp = 0
local ET_asym_diff_pre_psnp_p = r(p)
test INC_hhsize + INC_psnp + INC_harv + INC_psnp_harv - DEC_hhsize - DEC_psnp - DEC_harv - DEC_psnp_harv = 0
local ET_asym_diff_harv_psnp_p = r(p)
test _b[INC_harv] = 0
local ET_inc_ref_harv1 = r(p)
test _b[DEC_harv] = 0
local ET_dec_ref_harv1 = r(p)
test _b[INC_harv] + _b[INC_psnp_harv] = 0
local ET_inc_ref_harv_psnp1 = r(p)
test _b[DEC_harv] + _b[DEC_psnp_harv] = 0
local ET_dec_ref_harv_psnp1 = r(p)
test _b[INC_psnp] = 0
local ET_inc_ref_psnp = r(p)
test _b[INC_psnp] + _b[INC_psnp_harv] = 0
local ET_inc_harv_psnp = r(p)
test _b[DEC_psnp] = 0
local ET_dec_ref_psnp = r(p)
test _b[DEC_psnp] + _b[DEC_psnp_harv] = 0
local ET_dec_harv_psnp = r(p)

local ET_asym_inc_le_b = _b[INC_hhsize]
test INC_hhsize=0
local ET_asym_inc_le_p = r(p)
local ET_asym_dec_le_b = _b[DEC_hhsize]
test DEC_hhsize=0
local ET_asym_dec_le_p = r(p)
local ET_asym_inc_psnp_le_b = _b[INC_hhsize] + _b[INC_psnp]
test INC_hhsize + INC_psnp=0
local ET_asym_inc_psnp_le_p = r(p)
local ET_asym_dec_psnp_le_b = _b[DEC_hhsize] + _b[DEC_psnp]
test DEC_hhsize + DEC_psnp=0
local ET_asym_dec_psnp_le_p = r(p)

local ET_asym_inc_harv_b = _b[INC_hhsize] + _b[INC_harv]
test INC_hhsize + INC_harv=0
local ET_asym_inc_harv_p = r(p)
local ET_asym_dec_harv_b = _b[DEC_hhsize] + _b[DEC_harv]
test DEC_hhsize + DEC_harv=0
local ET_asym_dec_harv_p = r(p)
local ET_asym_inc_psnp_harv_b = _b[INC_hhsize] + _b[INC_psnp] + _b[INC_harv] + _b[INC_psnp_harv]
test INC_hhsize + INC_psnp + INC_harv + INC_psnp_harv = 0
local ET_asym_inc_psnp_harv_p = r(p)
local ET_asym_dec_psnp_harv_b = _b[DEC_hhsize] + _b[DEC_psnp] + _b[DEC_harv] + _b[DEC_psnp_harv]
test DEC_hhsize + DEC_psnp + DEC_harv + DEC_psnp_harv = 0
local ET_asym_dec_psnp_harv_p = r(p)
local ET_asym_obv = e(N)
local ET_asym_r2 = e(r2)


*** check results by wealth
* symmetric results by wealth (expenditure per capita)
use "$newdata/ET_reg_ready", clear		// generated in the "Ethiopia panel data prep3.do" file
egen ea_wave = group(ea1 wave)

	gen harv=activity
	gen diff_hhsize_erich = diff_$hhsize_var* exp_rich50
	gen change_harv = diff_$hhsize_var*harv
	gen change_harv_erich = change_harv* exp_rich50
	gen erich_harv = exp_rich50*harv
	foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
		gen `var'_erich = exp_rich50 * `var'
	}

	reg diff_`dep_var' diff_$hhsize_var diff_hhsize_erich exp_rich50 erich_harv change_harv_erich harv change_harv diff_log_A* diff_sh* , cluster(ea_wave)
	local ET_sym_chg_le2_b = _b[diff_$hhsize_var]
	test diff_$hhsize_var=0
	local ET_sym_chg_le2_p = r(p)
	local ET_sym_rich_le2_b = _b[diff_$hhsize_var] + _b[diff_hhsize_erich]
	test diff_$hhsize_var + diff_hhsize_erich = 0
	local ET_sym_rich_le2_p = r(p)
	local ET_sym_chg_harv2_b = _b[diff_$hhsize_var] + _b[change_harv]
	test diff_$hhsize_var + change_harv = 0
	local ET_sym_chg_harv2_p = r(p)
	local ET_sym_rich_harv2_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[diff_hhsize_erich] + _b[change_harv_erich]
	test diff_$hhsize_var + change_harv + diff_hhsize_erich + change_harv_erich = 0
	local ET_sym_rich_harv2_p = r(p)
	local ET_sym2_obv = e(N)
	local ET_sym2_r2 = e(r2)
	test _b[change_harv] = 0
	local ET_sym_ref_harv2 = r(p)
	test _b[change_harv] + _b[change_harv_erich] = 0
	local ET_sym_ref_harv_rich2 = r(p)
	test _b[diff_hhsize_erich] = 0
	local ET_sym_ref_erich = r(p)
	test _b[diff_hhsize_erich] + _b[change_harv_erich] = 0
	local ET_sym_harv_erich = r(p)

	* gen asymm results by wealth
	gen INC_erich = INC_hhsize*exp_rich50
	gen DEC_erich = DEC_hhsize* exp_rich50
	gen INC_harv = INC_hhsize*harv
	gen DEC_harv = DEC_hhsize*harv
	gen INC_erich_harv = INC_hhsize* exp_rich50*harv
	gen DEC_erich_harv = DEC_hhsize* exp_rich50*harv

	reg diff_`dep_var' INC_hhsize DEC_hhsize INC_erich DEC_erich exp_rich50 erich_harv INC_erich_harv DEC_erich_harv INC_harv DEC_harv harv diff_log_A* diff_sh*, cluster(ea_wave)
	test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
	local ET_asym_diff_pre2_p = r(p)
	test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
	local ET_asym_diff_harv2_p = r(p)
	test INC_hhsize + INC_erich - DEC_hhsize - DEC_erich = 0
	local ET_asym_diff_pre_rich2_p = r(p)
	test INC_hhsize + INC_erich + INC_harv + INC_erich_harv - DEC_hhsize - DEC_erich - DEC_harv - DEC_erich_harv = 0
	local ET_asym_diff_harv_rich2_p = r(p)
	test _b[INC_harv] = 0
	local ET_inc_ref_harv2 = r(p)
	test _b[DEC_harv] = 0
	local ET_dec_ref_harv2 = r(p)
	test _b[INC_harv] + _b[INC_erich_harv] = 0
	local ET_inc_ref_harv_rich2 = r(p)
	test _b[DEC_harv] + _b[DEC_erich_harv] = 0
	local ET_dec_ref_harv_rich2 = r(p)
	test _b[INC_erich] = 0
	local ET_inc_ref_erich = r(p)
	test _b[INC_erich] + _b[INC_erich_harv] = 0
	local ET_inc_harv_erich = r(p)
	test _b[DEC_erich] = 0
	local ET_dec_ref_erich = r(p)
	test _b[DEC_erich] + _b[DEC_erich_harv] = 0
	local ET_dec_harv_erich = r(p)

	local ET_asym_inc_le2_b = _b[INC_hhsize]
	test INC_hhsize=0
	local ET_asym_inc_le2_p = r(p)
	local ET_asym_dec_le2_b = _b[DEC_hhsize]
	test DEC_hhsize=0
	local ET_asym_dec_le2_p = r(p)
	local ET_asym_inc_rich_le2_b = _b[INC_hhsize] + _b[INC_erich]
	test INC_hhsize + INC_erich=0
	local ET_asym_inc_rich_le2_p = r(p)
	local ET_asym_dec_rich_le2_b = _b[DEC_hhsize] + _b[DEC_erich]
	test DEC_hhsize + DEC_erich=0
	local ET_asym_dec_rich_le2_p = r(p)

	local ET_asym_inc_harv2_b = _b[INC_hhsize] + _b[INC_harv]
	test INC_hhsize + INC_harv=0
	local ET_asym_inc_harv2_p = r(p)
	local ET_asym_dec_harv2_b = _b[DEC_hhsize] + _b[DEC_harv]
	test DEC_hhsize + DEC_harv=0
	local ET_asym_dec_harv2_p = r(p)
	local ET_asym_inc_rich_harv2_b = _b[INC_hhsize] + _b[INC_erich] + _b[INC_harv] + _b[INC_erich_harv]
	test INC_hhsize + INC_erich + INC_harv + INC_erich_harv = 0
	local ET_asym_inc_rich_harv2_p = r(p)
	local ET_asym_dec_rich_harv2_b = _b[DEC_hhsize] + _b[DEC_erich] + _b[DEC_harv] + _b[DEC_erich_harv]
	test DEC_hhsize + DEC_erich + DEC_harv + DEC_erich_harv = 0
	local ET_asym_dec_rich_harv2_p = r(p)
	local ET_asym2_obv = e(N)
	local ET_asym2_r2 = e(r2)



	*repeat by wealth index
	drop *_erich
	replace rich50 = asset_rich50
	foreach var in diff_log_A diff_share_pm diff_share_pf diff_share_em {
		gen `var'_rich = rich50 * `var'
	}

	gen diff_hhsize_rich = diff_$hhsize_var*rich50
	gen change_harv_rich = change_harv*rich50
	gen rich_harv = rich50*harv

	reg diff_`dep_var' diff_$hhsize_var diff_hhsize_rich rich50 harv rich_harv change_harv change_harv_rich diff_log_A* diff_sh*, cluster(ea_wave)
	local ET_sym_chg_le3_b = _b[diff_$hhsize_var]
	test diff_$hhsize_var=0
	local ET_sym_chg_le3_p = r(p)
	local ET_sym_rich_le3_b = _b[diff_$hhsize_var] + _b[diff_hhsize_rich]
	test diff_$hhsize_var + diff_hhsize_rich = 0
	local ET_sym_rich_le3_p = r(p)
	local ET_sym_chg_harv3_b = _b[diff_$hhsize_var] + _b[change_harv]
	test diff_$hhsize_var + change_harv = 0
	local ET_sym_chg_harv3_p = r(p)
	local ET_sym_rich_harv3_b = _b[diff_$hhsize_var] + _b[change_harv] + _b[diff_hhsize_rich] + _b[change_harv_rich]
	test diff_$hhsize_var + change_harv + diff_hhsize_rich + change_harv_rich = 0
	local ET_sym_rich_harv3_p = r(p)
	local ET_sym3_obv = e(N)
	local ET_sym3_r2 = e(r2)
	test _b[change_harv] = 0
	local ET_sym_ref_harv3 = r(p)
	test _b[change_harv] + _b[change_harv_rich] = 0
	local ET_sym_ref_harv_rich3 = r(p)
	test _b[diff_hhsize_rich] = 0
	local ET_sym_ref_arich = r(p)
	test _b[diff_hhsize_rich] + _b[change_harv_rich] = 0
	local ET_sym_harv_arich = r(p)

	* gen asymm results by wealth
	gen INC_rich = INC_hhsize*rich50
	gen DEC_rich = DEC_hhsize*rich50
	gen INC_rich_harv = INC_hhsize*rich50*harv
	gen DEC_rich_harv = DEC_hhsize*rich50*harv

	reg diff_`dep_var' INC_hhsize DEC_hhsize INC_rich DEC_rich INC_harv DEC_harv harv rich50 rich_harv INC_rich_harv DEC_rich_harv diff_log_A* diff_sh*, cluster(ea_wave)
	test INC_hhsize - DEC_hhsize = 0		// Check whether pre-harvest values are different
	local ET_asym_diff_pre3_p = r(p)
	test INC_hhsize + INC_harv - DEC_hhsize - DEC_harv = 0		// Check whether harvest values are different
	local ET_asym_diff_harv3_p = r(p)
	test INC_hhsize + INC_rich - DEC_hhsize - DEC_rich = 0
	local ET_asym_diff_pre_rich3_p = r(p)
	test INC_hhsize + INC_rich + INC_harv + INC_rich_harv - DEC_hhsize - DEC_rich - DEC_harv - DEC_rich_harv = 0
	local ET_asym_diff_harv_rich3_p = r(p)
	test _b[INC_harv] = 0
	local ET_inc_ref_harv3 = r(p)
	test _b[DEC_harv] = 0
	local ET_dec_ref_harv3 = r(p)
	test _b[INC_harv] + _b[INC_rich_harv] = 0
	local ET_inc_ref_harv_rich3 = r(p)
	test _b[DEC_harv] + _b[DEC_rich_harv] = 0
	local ET_dec_ref_harv_rich3 = r(p)
	test _b[INC_rich] = 0
	local ET_inc_ref_arich = r(p)
	test _b[INC_rich] + _b[INC_rich_harv] = 0
	local ET_inc_harv_arich = r(p)
	test _b[DEC_rich] = 0
	local ET_dec_ref_arich = r(p)
	test _b[DEC_rich] + _b[DEC_rich_harv] = 0
	local ET_dec_harv_arich = r(p)

	local ET_asym_inc_le3_b = _b[INC_hhsize]
	test INC_hhsize=0
	local ET_asym_inc_le3_p = r(p)
	local ET_asym_dec_le3_b = _b[DEC_hhsize]
	test DEC_hhsize=0
	local ET_asym_dec_le3_p = r(p)
	local ET_asym_inc_rich_le3_b = _b[INC_hhsize] + _b[INC_rich]
	test INC_hhsize + INC_rich=0
	local ET_asym_inc_rich_le3_p = r(p)
	local ET_asym_dec_rich_le3_b = _b[DEC_hhsize] + _b[DEC_rich]
	test DEC_hhsize + DEC_rich=0
	local ET_asym_dec_rich_le3_p = r(p)

	local ET_asym_inc_harv3_b = _b[INC_hhsize] + _b[INC_harv]
	test INC_hhsize + INC_harv=0
	local ET_asym_inc_harv3_p = r(p)
	local ET_asym_dec_harv3_b = _b[DEC_hhsize] + _b[DEC_harv]
	test DEC_hhsize + DEC_harv=0
	local ET_asym_dec_harv3_p = r(p)
	local ET_asym_inc_rich_harv3_b = _b[INC_hhsize] + _b[INC_rich] + _b[INC_harv] + _b[INC_rich_harv]
	test INC_hhsize + INC_rich + INC_harv + INC_rich_harv = 0
	local ET_asym_inc_rich_harv3_p = r(p)
	local ET_asym_dec_rich_harv3_b = _b[DEC_hhsize] + _b[DEC_rich] + _b[DEC_harv] + _b[DEC_rich_harv]
	test DEC_hhsize + DEC_rich + DEC_harv + DEC_rich_harv = 0
	local ET_asym_dec_rich_harv3_p = r(p)
	local ET_asym3_obv = e(N)
	local ET_asym3_r2 = e(r2)


** EXPORT

*create table of marginals and tests for asymmetric results
clear
set obs 17

gen col0 = "Reference \$\times \Delta E\$" in 1
replace col0 = "Reference \$\times \Delta E^+\$" in 3
replace col0 = "Reference \$\times \Delta E^-\$" in 5
replace col0 = "Harvest \$\times \Delta E\$" in 7
replace col0 = "Harvest \$\times \Delta E^+\$" in 9
replace col0 = "Harvest \$\times \Delta E^-\$" in 11

replace col0 = "\hline Reference: Inc = Dec" in 13
replace col0 = "Harvest: Inc = Dec" in 14
replace col0 = "\hline Reference = Harvest" in 15
replace col0 = "Reference = Harvest, \$+\$" in 16
replace col0 = "Reference = Harvest, \$-\$" in 17

forvalues i=1/6 {
	gen col`i' = . in 1
	gen star`i' = ""
}

forvalues i=1/3 {
	di "in PSNP loop, i=`i'"
	local j = 2*`i'-1
	if `i'==1 {
		replace col`j' = `ET_sym_chg_le_b' in 1
		replace col`j' = `ET_sym_chg_le_p' in 2
		replace col`j' = `ET_sym_chg_harv_b' in 7
		replace col`j' = `ET_sym_chg_harv_p' in 8

		local j = 2*`i'
		replace col`j' = `ET_asym_inc_le_b' in 3
		replace col`j' = `ET_asym_inc_le_p' in 4
		replace col`j' = `ET_asym_dec_le_b' in 5
		replace col`j' = `ET_asym_dec_le_p' in 6
		replace col`j' = `ET_asym_diff_pre_p' in 13
		replace col`j' = `ET_asym_inc_harv_b' in 9
		replace col`j' = `ET_asym_inc_harv_p' in 10
		replace col`j' = `ET_asym_dec_harv_b' in 11
		replace col`j' = `ET_asym_dec_harv_p' in 12
		replace col`j' = `ET_asym_diff_harv_p' in 14
	}
	else {
		local k `i'
		replace col`j' = `ET_sym_chg_le`k'_b' in 1
		replace col`j' = `ET_sym_chg_le`k'_p' in 2
		replace col`j' = `ET_sym_chg_harv`k'_b' in 7
		replace col`j' = `ET_sym_chg_harv`k'_p' in 8

		local j = 2*`i'
		replace col`j' = `ET_asym_inc_le`k'_b' in 3
		replace col`j' = `ET_asym_inc_le`k'_p' in 4
		replace col`j' = `ET_asym_dec_le`k'_b' in 5
		replace col`j' = `ET_asym_dec_le`k'_p' in 6
		replace col`j' = `ET_asym_diff_pre`k'_p' in 13
		replace col`j' = `ET_asym_inc_harv`k'_b' in 9
		replace col`j' = `ET_asym_inc_harv`k'_p' in 10
		replace col`j' = `ET_asym_dec_harv`k'_b' in 11
		replace col`j' = `ET_asym_dec_harv`k'_p' in 12
		replace col`j' = `ET_asym_diff_harv`k'_p' in 14
	}

	* assigning stars for top panel
	di "about to var list with varlist=`varlist'"
	forvalues j=1/2 {
		local row = 1
		foreach var in sym_chg_le asym_inc_le asym_dec_le sym_chg_harv asym_inc_harv asym_dec_harv {
			local temp = 2*`row'-1
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j', i=`i', and temp = `temp'"
			di "col=`col' and country_var_p = ET_`var'_p"
			if `i'<2 {
				local p_var ET_`var'_p
			}
			else {
				local p_var ET_`var'`i'_p
			}
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}
	}

}

* add the F-tests for differences across activities
forvalues i=1/3 {
	local j = 2*`i'-1
	replace col`j' =  `ET_sym_ref_harv`i'' in 15
	local j = 2*`i'
	replace col`j' =  `ET_inc_ref_harv`i'' in 16
	replace col`j' =  `ET_dec_ref_harv`i'' in 17	
}


*convert cells to strings
forvalues j=1/6 {
	di "in format loop with j=`j'"

	tostring col`j', replace force format(%9.3f)
	*top panel
	forvalues row=1(2)11 {
		replace col`j' = "$"+col`j'+"^"+star`j'+"$" in `row' if star`j'[`row']!=""
		di "value =  col`j'[`row']"
		di col`j'[`row']
		di " and strpos="  strpos(col`j'[`row'],".")
		replace col`j' = "" in `row' if strpos(col`j'[`row'],".")==1
	}
	forvalues row=2(2)12 {
		replace col`j' = "("+col`j'+")" in `row'
		replace col`j' = "" in `row' if col`j'[`row']=="(.)"
	}
}

keep col*
replace col6 = col6 + " \\"
outsheet using "$path/output/ET_extra_margins_top.tex", replace delim("&") non noq


clear
set obs 25
gen col0 = "Reference \$\times \Delta E\$" in 1
replace col0 = "Reference \$\times \Delta E^+\$" in 3
replace col0 = "Reference \$\times \Delta E^-\$" in 5
replace col0 = "Harvest \$\times \Delta E\$" in 7
replace col0 = "Harvest \$\times \Delta E^+\$" in 9
replace col0 = "Harvest \$\times \Delta E^-\$" in 11

replace col0 = "\hline Reference: Inc = Dec" in 13
replace col0 = "Harvest: Inc = Dec" in 14
replace col0 = "\hline Reference = Harvest" in 15
replace col0 = "Reference = Harvest, \$+\$" in 16
replace col0 = "Reference = Harvest, \$-\$" in 17

replace col0 = "\hline Reference: Top = Bottom" in 18
replace col0 = "Reference: Top = Bottom, \$+\$" in 19
replace col0 = "Reference: Top = Bottom, \$-\$" in 20
replace col0 = "Harvest: Top = Bottom" in 21
replace col0 = "Harvest: Top = Bottom, \$+\$" in 22
replace col0 = "Harvest: Top = Bottom, \$-\$" in 23

replace col0 = "\hline Observations" in 24
replace col0 = "\$R^2\$" in 25

forvalues i=1/6 {
	gen col`i' = . in 1
	gen star`i' = ""
}

forvalues i=1/3 {
	di "in PSNP loop, i=`i'"
	local j = 2*`i'-1
	if `i'==1 {
		replace col`j' = `ET_sym_psnp_le_b' in 1
		replace col`j' = `ET_sym_psnp_le_p' in 2
		replace col`j' = `ET_sym_psnp_harv_b' in 7
		replace col`j' = `ET_sym_psnp_harv_p' in 8
		replace col`j' = `ET_sym_r2' in 25

		local j = 2*`i'
		replace col`j' = `ET_asym_inc_psnp_le_b' in 3
		replace col`j' = `ET_asym_inc_psnp_le_p' in 4
		replace col`j' = `ET_asym_dec_psnp_le_b' in 5
		replace col`j' = `ET_asym_dec_psnp_le_p' in 6
		replace col`j' = `ET_asym_diff_pre_psnp_p' in 13
		replace col`j' = `ET_asym_inc_psnp_harv_b' in 9
		replace col`j' = `ET_asym_inc_psnp_harv_p' in 10
		replace col`j' = `ET_asym_dec_psnp_harv_b' in 11
		replace col`j' = `ET_asym_dec_psnp_harv_p' in 12
		replace col`j' = `ET_asym_diff_harv_psnp_p' in 14
		replace col`j' = `ET_asym_r2' in 25
	}
	else {
		local k `i'
		replace col`j' = `ET_sym_rich_le`k'_b' in 1
		replace col`j' = `ET_sym_rich_le`k'_p' in 2
		replace col`j' = `ET_sym_rich_harv`k'_b' in 7
		replace col`j' = `ET_sym_rich_harv`k'_p' in 8
		replace col`j' = `ET_sym`k'_r2' in 25

		local j = 2*`i'
		replace col`j' = `ET_asym_inc_rich_le`k'_b' in 3
		replace col`j' = `ET_asym_inc_rich_le`k'_p' in 4
		replace col`j' = `ET_asym_dec_rich_le`k'_b' in 5
		replace col`j' = `ET_asym_dec_rich_le`k'_p' in 6
		replace col`j' = `ET_asym_diff_pre_rich`k'_p' in 13
		replace col`j' = `ET_asym_inc_rich_harv`k'_b' in 9
		replace col`j' = `ET_asym_inc_rich_harv`k'_p' in 10
		replace col`j' = `ET_asym_dec_rich_harv`k'_b' in 11
		replace col`j' = `ET_asym_dec_rich_harv`k'_p' in 12
		replace col`j' = `ET_asym_diff_harv_rich`k'_p' in 14
		replace col`j' = `ET_asym`k'_r2' in 25
	}

	* assigning stars for bottom panel
	di "about to rich list with richlist=`richlist'"
	forvalues j=1/2 {
		local row = 1
		if `i'== 1 {
			local varlist sym_psnp_le asym_inc_psnp_le asym_dec_psnp_le sym_psnp_harv asym_inc_psnp_harv asym_dec_psnp_harv
		}
		else {
			local varlist sym_rich_le asym_inc_rich_le asym_dec_rich_le sym_rich_harv asym_inc_rich_harv asym_dec_rich_harv
		}
		foreach var in `varlist' {
			local temp = 2*`row'-1
			local col = 2*`i'-2+`j'
			di "in var loop with row = `row', var=`var', j=`j' and temp = `temp'"
			di "col=`col' and country_var_p = `country'_`var'_p"
			if `i'<2 {
				local p_var ET_`var'_p
			}
			else {
				local p_var ET_`var'`i'_p
			}
			di "p_var = `p_var'"
			replace star`col' = "{***}" in `temp' if ``p_var'' < 0.01
			replace star`col' = "{**}" in `temp' if ``p_var'' > 0.01 & ``p_var'' <= 0.05
			replace star`col' = "{*}" in `temp' if ``p_var'' > 0.05 & ``p_var'' <= 0.1
			replace star`col' = "" in `temp' if col`col'[`temp']==.
			local ++row
		}		
	}
}

* add the F-tests for differences across activities
forvalues i=1/3 {
	local j = 2*`i'-1
	if `i'<2 {
		replace col`j' =  `ET_sym_ref_harv_psnp`i'' in 15
		local j = 2*`i'
		replace col`j' =  `ET_inc_ref_harv_psnp`i'' in 16
		replace col`j' =  `ET_dec_ref_harv_psnp`i'' in 17	
	}
	else {
		replace col`j' =  `ET_sym_ref_harv_rich`i'' in 15
		local j = 2*`i'
		replace col`j' =  `ET_inc_ref_harv_rich`i'' in 16
		replace col`j' =  `ET_dec_ref_harv_rich`i'' in 17	
	}
}

* add the F-tests for differences across panels
local j = 1
foreach var in psnp erich arich {
	local i = 2*`j'-1
	replace col`i' = `ET_sym_ref_`var'' in 18
	replace col`i' = `ET_sym_harv_`var'' in 21
	local i = 2*`j'
	replace col`i' = `ET_inc_ref_`var'' in 19
	replace col`i' = `ET_dec_ref_`var'' in 20
	replace col`i' = `ET_inc_harv_`var'' in 22
	replace col`i' = `ET_dec_harv_`var'' in 23

	local ++j
}


*convert cells to strings
forvalues j=1/6 {
	di "in format loop with j=`j'"

	tostring col`j', replace force format(%9.3f)
	*bottom panel
	forvalues row=1(2)11 {
		replace col`j' = "$"+col`j'+"^"+star`j'+"$" in `row' if star`j'[`row']!=""
		di "value =  col`j'[`row']"
		di col`j'[`row']
		di " and strpos="  strpos(col`j'[`row'],".")
		replace col`j' = "" in `row' if strpos(col`j'[`row'],".")==1
	}
	forvalues row=2(2)12 {
		replace col`j' = "("+col`j'+")" in `row'
		replace col`j' = "" in `row' if col`j'[`row']=="(.)"
	}
}

*observations in bottom panel
local j = 1
foreach var in sym asym sym2 asym2 sym3 asym3 {
	di "obv local = ET_`var'_obv and col=`j'"
	gen ET_`var' = `ET_`var'_obv' in 24
	tostring ET_`var', replace force format(%8.0fc)
	replace col`j' = ET_`var' in 24
	local ++j
}

keep col*
replace col6 = col6 + " \\"
outsheet using "$path/output/ET_extra_margins_bot.tex", replace delim("&") non noq

exit






