*	14-Apr-2016	pwb	splitting out Ethiopia data prep from salam_data_build.do
*	04-Apr-2017 pwb	cleaning code, being called from run_all.do
*	18-Dec-2017	pwb	create variable for hhsize by gender with nokids

clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



*********************************************************
*****************  ethiopia 2011-2012 ************************
********************  wave 1 ****************************
* weights
use "$data_ET/household/sect1_hh_w1.dta", clear
ren household hhid
ren saq01 region
ren saq02 zone
ren saq03 woreda
keep hhid pw ea_id region zone woreda
duplicates drop hhid pw, force
ren pw weight
tempfile ET_weights
save `ET_weights', replace


*Demographics
use "$data_ET/Household/sect1_hh_w1.dta", clear	 //Path to first part of Ethiopia data
gen hhid = household_id
gen pid = individual_id
gen personid = hh_s1q00
gen female = (hh_s1q03==2)
gen male = (hh_s1q03==1)
gen male_head = hh_s1q02==1 & male==1
gen child = (hh_s1q04_a<15)
gen person = 1
gen man = male*(child== 0)
gen woman = female*(child==0)
gen hhhead = 1 if hh_s1q02 == 1
replace hhhead = 0 if hhhead!=1
ren hh_s1q04_a age
label var hhhead "Indicator variable equals 1 if observation is head of household"
rename hh_s1q02 reltohead
keep hhid pid man woman child hhhead personid age male reltohead
tempfile ET_hhmembers
save `ET_hhmembers', replace

* determine which crop is on which plot
*use "$data_ET/Post Harvest/sect9_ph_w1", clear
*rename household_id hhid
*keep if crop_code==2
*recode ph_s9* (.=0)
*gen double wgt_fresh = ph_s9q03_a + ph_s9q03_b/1000
*gen double wgt_dry = ph_s9q05_a + ph_s9q05_b/1000
*keep hhid holder_id parcel_id field_id wgt* crop_code

use "$data_ET/Post Harvest/sect10_ph_w1", clear
rename household_id hhid
keep if crop_code==2
keep hhid holder_id parcel_id field_id crop_code
tempfile crops
save `crops', replace

* get total harvested by household
use "$data_ET/Post Harvest/sect11_ph_w1", clear
rename household_id hhid
keep if crop_code==2

recode ph_s11q03* ph_s11q10* ph_s11q11* ph_s11q12* ph_s11q13* ph_s11q14* ph_s11q15* ph_s11q19* (.=0)
foreach disp in 03 10 11 12 13 14 19 {
	gen wgt_disp`disp' = ph_s11q`disp'_a + ph_s11q`disp'_b/1000
}
egen wgt_total = rowtotal(wgt_disp*)

collapse (sum) wgt_total, by(hhid)
tempfile crops_tot
save `crops_tot', replace

* area *
use "$data_ET/Post Planting/sect2_pp_w1", clear
gen hhid = household_id
ren pp_s2q03 ten
gen own = inlist(ten,1,2)		// NOTE: I assume "granted by local leaders" means owned
gen rent = inlist(ten,3)
gen borrow = inlist(ten,4)
gen other = inlist(ten,10,11,12)
keep hhid holder_id parcel_id own rent borrow
tempfile owned
save `owned', replace


use "$data_ET/Post Planting/sect3_pp_w1", clear
gen hhid = household_id
merge m:1 holder_id parcel_id using `owned', nogen keep(1 3)		// 453 are not matched

merge 1:1 holder_id parcel_id field_id using `crops', keep(3)
ren pp_s3q03 use
replace use=1 if use==. & (rent==1 | borrow==1)		// assuming cultivated if rented/borrowed but usage variable is missing
gen region = saq01
gen zone = saq02
gen woreda = saq03
gen local_unit = pp_s3q02_c
merge m:1 region zone woreda local_unit using "$data_ET/ET_local_area_unit_conversion.dta", gen(merge)

*We should be able to match 26823 observations (that's how many "local units" are used in pp_s3q02_c)
*However, it appears that the conversion units are not used everywhere?
bys region zone local_unit: egen conversion_zone_temp = median(conversion)
replace conversion = conversion_zone_temp if conversion==.
bys region local_unit: egen conversion_reg_temp = median(conversion)
replace conversion = conversion_reg_temp if conversion==.
bys local_unit: egen conversion_temp = median(conversion)
replace conversion = conversion_temp if conversion==.
drop if merge==2
*Now we have 26823, which is the number I noted above
*1 hectare is 10000 square meters
gen area = pp_s3q02_d
gen hectares = area if pp_s3q02_c==1
replace hectares = area/10000 if pp_s3q02_c==2	// dividing by 10000 to get hectares
replace hectares = (area*conversion)/10000 if pp_s3q02_c>2 // conversion is the number of square meters per local unit; dividing by 10000 to get hectares
gen area_GPS = pp_s3q05_c 
gen hectares_GPS = area_GPS/10000
replace hectares = hectares_GPS if hectares==.		// Replacing missing values
gen owned_hectares = hectares*own
collapse (sum) owned_hectares hectares, by(hhid)
gen owned_acres = 2.471*owned_hectares
gen acres = 2.471*hectares
tempfile plots
save `plots', replace


* hired labor - Harvest labor
use "$data_ET/Post Harvest/sect10_ph_w1", clear
ren household_id hhid
merge 1:1 holder_id parcel_id field_id crop_code using `crops', keep(3)			//only keep plots with maize in both files

recode ph_s10q01_a ph_s10q01_b ph_s10q01_d ph_s10q01_e ph_s10q01_g ph_s10q01_h (.=0)
gen harv_days_hired = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e
gen harv_days_hired_withkids = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e +0.5*ph_s10q01_g*ph_s10q01_h	// children at 50% productivity
recode ph_s10q03* (.=0)
gen harv_days_free = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d
gen harv_days_free_withkids = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d + 0.5*ph_s10q03_e*ph_s10q03_f
collapse (sum) *days* , by(hhid)
tempfile harv_days
save `harv_days', replace


* hired labor - PRE-harvest labor
use "$data_ET/Post Planting/sect3_pp_w1", clear
ren household_id hhid
isid holder_id parcel_id field_id		// Check
merge 1:1 holder_id parcel_id field_id using `crops', keep(3)			//only keep plots with maize in both files

keep hhid parcel_id holder_id field_id pp_s3q27* pp_s3q28* pp_s3q29*
recode pp_s3q28_a pp_s3q28_b pp_s3q28_d pp_s3q28_e pp_s3q28_g pp_s3q28_h (.=0)
gen cult_days_hired = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e
gen cult_days_hired_withkids = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e +0.5*pp_s3q28_g*pp_s3q28_h	// children at 50% productivity
*free labor - pre-harvest labor
recode pp_s3q29* (.=0)
gen cult_days_free = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d
gen cult_days_free_withkids = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d + 0.5*pp_s3q29_e*pp_s3q29_f
collapse (sum) *days*, by(hhid)
merge 1:1 hhid using `harv_days', nogen
tempfile hired_labor
save `hired_labor', replace


* family labor demand - Cultivation
use "$data_ET/Post Planting/sect3_pp_w1", clear
gen hhid = household_id
isid holder_id parcel_id field_id		// Check
merge 1:1 holder_id parcel_id field_id using `crops', keep(3)			//only keep plots of maize 

keep hhid holder_id parcel_id field_id pp_s3q27_*
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix pp_s3q27_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
order hhid holder_id parcel_id field_id person* hours*
drop b-x
reshape long personid hours, i(holder_id parcel_id field_id) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.			// 15 obs
sum hours if personid==0			// 20 obs
*NOTE: There are 20 observations for which personid takes on the value of 0, but the hours are positive
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `ET_hhmembers', keep(1 3) nogen		// 93 not matched from master. 35 of these have personid missing or equal to zero.
																						// Therefore, there are 58 unexplained unmatched people with POSITIVE HOURS.																						
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}


save "$path/Constructed Data/ET1_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace


*Harvest
use "$data_ET/Post Harvest/sect10_ph_w1", clear
gen hhid = household_id
merge 1:1 holder_id parcel_id field_id crop_code using `crops', keep(3)			//only keep plots of maize 

keep hhid holder_id parcel_id field_id crop_id crop_code ph_s10q02_*
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix ph_s10q02_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
ren y personid7
gen hours7 = z*ka*la
ren ma personid8
gen hours8 = na*oa*pa
order hhid holder_id parcel_id field_id crop_* person* hours*
drop b-pa
sum hours* if crop_code==.
recode crop_code (.=999) if (hours1!=. & hours1!=0)
sum hours* if crop_code==.	// It appears now that all missing crop codes have ZERO hours, so dropping them won't affect results
drop if crop_code==.
isid holder_id parcel_id field_id crop_code	// Now I can reshape
reshape long personid hours, i(holder_id parcel_id field_id crop_code) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.			// 0 obs
sum hours if personid==0			// 43 obs
*NOTE: There are 43 observations for which personid takes on the value of 0, but the hours are positive
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `ET_hhmembers', keep(1 3) nogen		// 102 not matched from master. 43 of these have personid missing or equal to zero.
																// Therefore, there are 59 unexplained unmatched people with POSITIVE HOURS.																						
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
save "$path/Constructed Data/ET1_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
merge 1:1 hhid using `hhprep', nogen		// Not all are matched from either.
recode *_prep *_harv (.=0)
gen cult_days_hh = man_prep + woman_prep
gen cult_days_hh_withkids = man_prep + woman_prep + child_prep
gen harv_days_hh = man_harv + woman_harv
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep hhid cult_days_hh* harv_days_hh*
merge 1:1 hhid using `hired_labor', keep (3)


** BRING TOGETHER
merge 1:1 hhid using `plots', keep(3) nogen		// 1 not matched from master
merge 1:1 hhid using `ET_weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = cult_days_hh_withkids + cult_days_hired_withkids + cult_days_free_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids + harv_days_free_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Ethiopia, Wave 1", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/ET1_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto ET1_out_lab

tempfile ET_data
save `ET_data', replace


*********************************************************
*****************  ethiopia 2013 ************************
********************  wave 2 ****************************
* weights
use "$data_ET_2/Household/sect1_hh_w2.dta", clear
ren household_id2 y2_hhid
ren household_id hhid
ren saq01 region
ren saq02 zone
ren saq03 woreda
keep *hhid pw ea_id2 region zone woreda
duplicates drop y2_hhid pw, force
ren pw2 weight2
tempfile ET2_weights
save `ET2_weights', replace


*Demographics
use "$data_ET_2/Household/sect1_hh_w2.dta", clear	 //Path to first part of Ethiopia data
drop if hh_s1q04c==2						//drops observations for people who have moved out of the household
gen y2_hhid = household_id2
gen y2_pid = individual_id2
gen y2_personid = hh_s1q00
gen female = (hh_s1q03==2)
gen male = (hh_s1q03==1)
gen male_head = hh_s1q02==1 & male==1
gen child = (hh_s1q04_a<15)
gen person = 1

gen man = male*(child== 0)
gen woman = female*(child==0)
gen hhhead = 1 if hh_s1q02 == 1
replace hhhead = 0 if hhhead!=1
rename hh_s1q04_a age
label var hhhead "Indicator variable equals 1 if observation is head of household"
rename hh_s1q02 reltohead
keep y2_hhid y2_pid man woman child hhhead y2_personid age male reltohead
tempfile ET2_hhmembers
save `ET2_hhmembers', replace

* determine which crop is on which plot
use "$data_ET_2/Post-Harvest/sect10_ph_w2", clear
rename household_id2 y2_hhid
keep if crop_code==2
keep y2_hhid holder_id parcel_id field_id crop_code
tempfile crops
save `crops', replace

* get total harvested by household
use "$data_ET_2/Post-Harvest/sect11_ph_w2", clear
rename household_id2 y2_hhid
keep if crop_code==2
recode ph_s11q03* ph_s11q10* ph_s11q11* ph_s11q12* ph_s11q14* ph_s11q15* ph_s11q19* (.=0)


* Question 3 is for sale, 19 is for amount in storage, but excluding 19 to avoid double counting
foreach disp in 03 {
	gen wgt_disp`disp' = ph_s11q`disp'_a + ph_s11q`disp'_b/1000
}
foreach disp in 10a 10 11 12 14 {
	gen wgt_disp`disp' = ph_s11q`disp'_3
}
egen wgt_total = rowtotal(wgt_disp*)

collapse (sum) wgt_total, by(y2_hhid)
tempfile crops_tot
save `crops_tot', replace

* area *
use "$data_ET_2/Post-Planting/sect2_pp_w2", clear
gen y2_hhid = household_id2
ren pp_s2q03 ten
gen own = inlist(ten,1,2)		// NOTE: I assume "granted by local leaders" means owned
gen rent = inlist(ten,3)
gen borrow = inlist(ten,4)
gen other = inlist(ten,5,6)
keep y2_hhid holder_id parcel_id own rent borrow
tempfile owned
save `owned', replace


use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
gen y2_hhid = household_id2
merge m:1 holder_id parcel_id using `owned', nogen keep(1 3)		// 62 are not matched

merge 1:1 holder_id parcel_id field_id using `crops', keep(3)
gen use = pp_s3q03==1
gen region = saq01
gen zone = saq02
gen woreda = saq03
gen local_unit = pp_s3q02_c
merge m:1 region zone woreda local_unit using "$data_ET/ET_local_area_unit_conversion.dta", gen(merge)

*We should be able to match 23007 observations (that's how many "local units" are used in pp_s3q02_c -- other than 'tilm', which does not appear to be in the conversion dataset)
*However, it appears that the conversion units are not used everywhere?
bys region zone local_unit: egen conversion_zone_temp = median(conversion)
replace conversion = conversion_zone_temp if conversion==.
bys region local_unit: egen conversion_reg_temp = median(conversion)
replace conversion = conversion_reg_temp if conversion==.
bys local_unit: egen conversion_temp = median(conversion)
replace conversion = conversion_temp if conversion==.
drop if merge==2
*Now we have 23007, which is the number I noted above
*1 hectare is 10000 square meters
gen area = pp_s3q02_a
gen hectares = area if pp_s3q02_c==1
replace hectares = area/10000 if pp_s3q02_c==2	// dividing by 10000 to get hectares
replace hectares = (area*conversion)/10000 if pp_s3q02_c>2	// conversion is the number of square meters per local unit; dividing by 10000 to get hectares

*NOTE: using farmer-reported measures of area results in lots of missing values due to the plethora of measurement units used. To see
*what I mean, do "tab pp_s3q02_c_other". It is not possible to convert them all into square meters. As such, I use GPS measurements
*where self-reported area is missing.
gen area_GPS = pp_s3q05_a 
gen hectares_GPS = area_GPS/10000
replace hectares = hectares_GPS if hectares==.		// Replacing missing values
gen owned_hectares = hectares*own
*Now, there are only ~500 missing values
collapse (sum) owned_hectares hectares, by(y2_hhid)
gen owned_acres = 2.471*owned_hectares
gen acres = 2.471*hectares
tempfile plots
save `plots', replace


* hired labor - Harvest labor
use "$data_ET_2/Post-Harvest/sect10_ph_w2", clear
ren household_id2 y2_hhid

merge 1:1 holder_id parcel_id field_id crop_code using `crops', keep(3)
recode ph_s10q01_a ph_s10q01_b ph_s10q01_d ph_s10q01_e ph_s10q01_g ph_s10q01_h (.=0)
gen harv_days_hired = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e
gen harv_days_hired_withkids = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e +0.5*ph_s10q01_g*ph_s10q01_h	// children at 50% productivity
recode ph_s10q03* (.=0)
gen harv_days_free = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d
gen harv_days_free_withkids = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d + 0.5*ph_s10q03_e*ph_s10q03_f
collapse (sum) *days*, by(y2_hhid)
tempfile harv_days
save `harv_days', replace


* hired labor - PRE-harvest labor
use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
ren household_id2 y2_hhid
isid holder_id parcel_id field_id		// Check

merge 1:1 holder_id parcel_id field_id using `crops', keep(3)
keep y2_hhid parcel_id holder_id field_id pp_s3q27* pp_s3q28* pp_s3q29*
recode pp_s3q28_a pp_s3q28_b pp_s3q28_d pp_s3q28_e pp_s3q28_g pp_s3q28_h (.=0)
gen cult_days_hired = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e
gen cult_days_hired_withkids = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e +0.5*pp_s3q28_g*pp_s3q28_h	// children at 50% productivity
recode pp_s3q29* (.=0)
gen cult_days_free = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d
gen cult_days_free_withkids = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d + 0.5*pp_s3q29_e*pp_s3q29_f
collapse (sum) *days*, by(y2_hhid)
merge 1:1 y2_hhid using `harv_days', nogen
tempfile hired_labor
save `hired_labor', replace



* family labor demand - Cultivation
use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
gen y2_hhid = household_id2
isid holder_id parcel_id field_id		// Check
merge 1:1 holder_id parcel_id field_id using `crops', keep(3)
keep y2_hhid holder_id parcel_id field_id pp_s3q27_*
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix pp_s3q27_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
ren y personid7
gen hours7 = z*ca*da
order y2_hhid holder_id parcel_id field_id person* hours*
drop b-da
reshape long personid hours, i(holder_id parcel_id field_id) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.			// 10 obs
sum hours if personid==0			// 20 obs
*NOTE: There are 30 observations for which personid takes on the value of 0, but the hours are positive
collapse (sum) hours, by(y2_hhid personid)
ren personid y2_personid
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 y2_hhid y2_personid using `ET2_hhmembers', keep(1 3) nogen		// 57 not matched from master. 30 of these have personid missing or equal to zero.
																// Therefore, there are 27 unexplained unmatched people with POSITIVE HOURS.
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}
save "$path/Constructed Data/ET2_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y2_hhid)
tempfile hhprep
save `hhprep', replace


*Harvest
use "$data_ET_2/Post-Harvest/sect10_ph_w2", clear
gen y2_hhid = household_id2
keep y2_hhid holder_id parcel_id field_id crop_code ph_s10q02_*
isid holder_id parcel_id field_id crop_code		// Check
merge 1:1 holder_id parcel_id field_id crop_code using `crops', keep(3)
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix ph_s10q02_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
ren y personid7
gen hours7 = z*ka*la
ren ma personid8
gen hours8 = na*oa*pa
order y2_hhid holder_id parcel_id field_id crop_* person* hours*
drop b-pa
reshape long personid hours, i(holder_id parcel_id field_id crop_code) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.			// 2 obs
sum hours if personid==0			// 16 obs
*NOTE: There are 18 observations for which personid takes on the value of 0, but the hours are positive
collapse (sum) hours, by(y2_hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
ren personid y2_personid
merge 1:1 y2_hhid y2_personid using `ET2_hhmembers', keep(1 3) nogen		// 41 not matched from master. 18 of these have personid missing or equal to zero.
																// Therefore, there are 23 unexplained unmatched people with POSITIVE HOURS.
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
save "$path/Constructed Data/ET2_harv_ages.dta", replace			// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y2_hhid)
merge 1:1 y2_hhid using `hhprep', nogen		// Not all are matched from either.
recode *_prep *_harv (.=0)
gen cult_days_hh = man_prep + woman_prep
gen cult_days_hh_withkids = man_prep + woman_prep + child_prep
gen harv_days_hh = man_harv + woman_harv
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep y2_hhid cult_days_hh* harv_days_hh*
merge 1:1 y2_hhid using `hired_labor', assert(2 3) nogen		// 487 not matched from USING


** BRING TOGETHER
merge 1:1 y2_hhid using `plots', keep(3) nogen		// 2 not matched from master
merge 1:1 y2_hhid using `ET2_weights', keep(1 3) nogen			// 25 not matched from master
merge 1:1 y2_hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = cult_days_hh_withkids + cult_days_hired_withkids + cult_days_free_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids + harv_days_free_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Ethiopia, Wave 2", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/ET2_tpl_maize.pdf", replace


gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto ET2_out_lab


** output regression results

estout ET*out_lab using "$path/output/ET_tpl_regs.tex", cells(b(star fmt(3)) se(par fmt(3))) ///
	stats(N r2, fmt(%10.0fc 2) labels("\hline Observations" "\$R^2\$")) ///
	starlevels(* 0.10 ** 0.05 *** 0.01) style(tex) nonumbers ///
	mlabels(none) coll(none) substitute(_ \_) replace
