
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



*********************************************************
*****************  ethiopia 2011-2012 ************************
********************  wave 1 ****************************
* weights
use "$data_ET/household/sect1_hh_w1.dta", clear
ren household hhid
ren saq01 region
ren saq02 zone
ren saq03 woreda
keep hhid pw ea_id region zone woreda
duplicates drop hhid pw, force
ren pw weight
tempfile ET_weights
save `ET_weights', replace


*Demographics
use "$data_ET/Household/sect1_hh_w1.dta", clear	 //Path to first part of Ethiopia data
gen hhid = household_id
gen pid = individual_id
gen personid = hh_s1q00
gen female = (hh_s1q03==2)
gen male = (hh_s1q03==1)
gen male_head = hh_s1q02==1 & male==1
gen child = (hh_s1q04_a<15)
gen person = 1
preserve										// In order to make a few changes
gen man = male*(child== 0)
gen woman = female*(child==0)
gen hhhead = 1 if hh_s1q02 == 1
replace hhhead = 0 if hhhead!=1
ren hh_s1q04_a age
label var hhhead "Indicator variable equals 1 if observation is head of household"
rename hh_s1q02 reltohead
keep hhid pid man woman child hhhead personid age male reltohead
tempfile ET_hhmembers
save `ET_hhmembers', replace
save "$newdata/ET1_hh_ages.dta", replace				// save individual level data to build LFP rate figures
restore											// Restoring previous data
gen any_muslem = hh_s1q07==4
gen head_muslem = hh_s1q07==4 & hh_s1q02==1
ren hh_s1q04_a age
gen hhsize = $hhsize		// (age>=15) & age<=60
replace hhsize = 1 if age>60 & age!=.
gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen kids_phase = (age-10)*0.2 if age<16 & age>10
gen kids_15 = age==15
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
replace hh_s1q05 = 12 if hh_s1q05>12 & hh_s1q05!=.				// assuming values of >12 mean the person has been gone for the last 12 months
gen hhsize_away = hhsize*(12-hh_s1q05)/12
gen hhsize_phase_away = hhsize_phase*(12-hh_s1q05)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename hh_s1q05 months_away
gen temp_migrant = months_away > 2 & age >=15


collapse (sum) prime* eld* hhsize* child person male* female* kids* (mean) temp_migrant months_away (max) any_migrant=temp_migrant *muslem, by(hhid)

tempfile ET_demog
save `ET_demog', replace


*Age of househead age*
use "$data_ET/household/sect1_hh_w1.dta", clear
gen hhid = household_id
gen pid = individual_id
ren hh_s1q04_a age
keep if hh_s1q02==1
gen agehhhead1 =  age
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1, by(hhid)
tempfile ET_headage
save `ET_headage', replace

* Education *
use "$data_ET/household/sect2_hh_w1.dta", clear
gen hhid = household_id
gen pid = individual_id
merge 1:1 pid using `ET_hhmembers', keepusing(hhhead) nogen
ren hh_s2q05 f
gen educ = f if f<=12
replace educ = 12 if inlist(f,13,14,17,24,27,29)
replace educ = 13 if f==31
replace educ = 14 if f==32
replace educ = f-2 if inlist(f,15,16)
replace educ = 15 if inlist(f,18,33)
replace educ = 16 if inlist(f,19,34,35)
replace educ = f-12 if inlist(f,21,22,23)
replace educ = 11 if inlist(f,25,26,28)
replace educ = 13 if f==30
replace educ = 0 if inlist(f,93,94,96,98) | hh_s2q03==2
replace educ = 18 if inlist(f,20)
label var educ "Highest education attained"
keep hhid pid educ hhhead
tempfile educ
save `educ', replace
keep if hhhead==1
rename educ headeduc
duplicates report hhid
tempfile head_educ
save `head_educ', replace


* consumption
use "$data_ET/Consumption aggregate/cons_agg.dta", clear
rename household_id hhid
keep hhid total_cons_ann hh_size real_totcons_aeq adulteq
gen tot_cons_temp = real_totcons_aeq*adulteq
gen exp_pc = tot_cons_temp / hh_size
tempfile hh_consum
save `hh_consum', replace


* get hh asset info *
use "$data_ET/household/sect10_hh_w1.dta", clear
rename household_id hhid
keep hhid hh_s10q00 hh_s10q01
reshape wide hh_s10q01, i(hhid) j(hh_s10q00)
factor hh_s10q01*, fa(1)
predict pc1_wealth, r
drop hh_s10q01*
tempfile hh_wealth
save `hh_wealth', replace

* get hh access to finance info
use "$data_ET/household/sect11b_hh_w1.dta", clear
rename household_id hhid
keep hhid hh_s11bq16*
foreach k in a b c {
	gen fin_constraint_`k' = hh_s11bq16_`k' > 70 & hh_s11bq16_`k' < 80
}
drop if hh_s11bq16_a ==.
collapse (max) fin_constraint* , by(hhid)

egen fin_const1 = rowmax(fin_constraint_a fin_constraint_b fin_constraint_c)
keep hhid fin_const1
tempfile hh_fin_temp1
save `hh_fin_temp1', replace

use "$data_ET/household/sect11c_hh_w1.dta", clear
rename household_id hhid
keep hhid hh_s11bq19*
foreach k in a b c {
	gen fin_constraint_`k' = hh_s11bq19_`k' > 70 & hh_s11bq19_`k' < 80
}
drop if hh_s11bq19_a==.
collapse (max) fin_constraint* , by(hhid)

egen fin_const2 = rowmax(fin_constraint_a fin_constraint_b fin_constraint_c)
keep hhid fin_const2
merge 1:1 hhid using `hh_fin_temp1'
gen any_fin_const = fin_const1==1 | fin_const2==1

keep hhid any_fin_const
tempfile hh_fin_const
save `hh_fin_const', replace

* get hh PSNP participation *
use "$data_ET/household/sect4_hh_w1.dta", clear
rename household_id hhid
gen woreda = saq03 + 100*saq02 + 10000*saq01
bysort woreda: gen temp_psnp = hh_s4q31==1
by woreda: egen any_psnp = max(temp_psnp)
drop temp_psnp
keep hhid woreda any_psnp
collapse (max) any_psnp woreda, by(hhid)
tempfile hh_psnp
save `hh_psnp', replace


* get aez info*
use "$data_ET/Geovariables/Pub_ETH_HouseholdGeovariables_Y1.dta", clear
ren household_id hhid
gen aez = 1 if ssa_ae == 322
replace aez = 2 if ssa_ae == 323
replace aez = 3 if aez==.
keep hhid aez dist_popcenter dist_market
isid hhid
tempfile geo
save `geo', replace

* get crop info
use "$data_ET/Post Harvest/sect10_ph_w1", clear
rename household_id hhid
gen maize = crop_code==2
gen sorghum = crop_code==6
keep hhid holder_id parcel_id field_id maize sorghum
collapse (max) maize sorghum, by(holder_id parcel_id field_id)
tempfile crops
save `crops', replace

* get input info
use "$data_ET/Post Planting/sect7_pp_w1", clear
rename household_id hhid
gen any_oxen = pp_s7q11>0 & pp_s7q11 !=.
collapse (max) any_oxen, by(hhid)
tempfile oxen
save `oxen', replace

use "$data_ET/Post Planting/sect3_pp_w1", clear
rename household_id hhid
gen irrigated = pp_s3q12==1
gen fertilized = pp_s3q14==1
collapse (max) irrigated fertilized, by(hhid)
tempfile inputs
save `inputs', replace

*get sales info
use "$data_ET/Post Harvest/sect11_ph_w1", clear
rename household_id hhid
gen any_sales = ph_s11q01==1
collapse (max) any_sales, by(hhid)
tempfile sales
save `sales', replace


* area *
use "$data_ET/Post Planting/sect2_pp_w1", clear
gen hhid = household_id
ren pp_s2q03 ten
gen own = inlist(ten,1,2)		// assume "granted by local leaders" means owned
gen rent = inlist(ten,3)
gen borrow = inlist(ten,4)
gen other = inlist(ten,10,11,12)
keep hhid holder_id parcel_id own rent borrow
tempfile owned
save `owned', replace


use "$data_ET/Post Planting/sect3_pp_w1", clear
gen hhid = household_id
merge m:1 holder_id parcel_id using `owned', nogen keep(1 3)
ren pp_s3q03 use
replace use=1 if use==. & (rent==1 | borrow==1)		// assuming cultivated if rented/borrowed but usage variable is missing
gen region = saq01
gen zone = saq02
gen woreda = saq03
gen local_unit = pp_s3q02_c
merge 1:1 holder_id parcel_id field_id using `crops', keep(1 3) nogen
merge m:1 region zone woreda local_unit using "$data_ET/ET_local_area_unit_conversion.dta", gen(merge)


bys region zone local_unit: egen conversion_zone_temp = median(conversion)
replace conversion = conversion_zone_temp if conversion==.
bys region local_unit: egen conversion_reg_temp = median(conversion)
replace conversion = conversion_reg_temp if conversion==.
bys local_unit: egen conversion_temp = median(conversion)
replace conversion = conversion_temp if conversion==.
drop if merge==2

*1 hectare is 10000 square meters
gen area = pp_s3q02_d
gen hectares = area if pp_s3q02_c==1
replace hectares = area/10000 if pp_s3q02_c==2	// dividing by 10000 to get hectares
replace hectares = (area*conversion)/10000 if pp_s3q02_c>2 // conversion is the number of square meters per local unit; dividing by 10000 to get hectares
gen area_GPS = pp_s3q05_c 
gen hectares_GPS = area_GPS/10000
replace hectares = hectares_GPS if hectares==.		// Replacing missing values
gen owned_hectares = hectares*own
gen owned_acres = 2.471*owned_hectares
gen acres = 2.471*hectares
gen acres_maize = acres*maize
gen acres_sorghum = acres*sorghum
collapse (sum) owned_hectares hectares acres* owned_acres  (max) maize sorghum, by(hhid)

tempfile plots
save `plots', replace


* hired labor - Harvest labor
use "$data_ET/Post Harvest/sect10_ph_w1", clear
ren household_id hhid
recode ph_s10q01_a ph_s10q01_b ph_s10q01_d ph_s10q01_e ph_s10q01_g ph_s10q01_h (.=0)
gen harv_days_hired = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e
gen harv_days_hired_withkids = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e +0.5*ph_s10q01_g*ph_s10q01_h	// children at 50% productivity
recode ph_s10q03* (.=0)
gen harv_days_free = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d
gen harv_days_free_withkids = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d + 0.5*ph_s10q03_e*ph_s10q03_f
collapse (sum) *days* , by(hhid)
tempfile harv_days
save `harv_days', replace


* hired labor - PRE-harvest labor
use "$data_ET/Post Planting/sect3_pp_w1", clear
ren household_id hhid
isid holder_id parcel_id field_id		// Check
keep hhid parcel_id holder_id field_id pp_s3q27* pp_s3q28* pp_s3q29*
recode pp_s3q28_a pp_s3q28_b pp_s3q28_d pp_s3q28_e pp_s3q28_g pp_s3q28_h (.=0)
gen cult_days_hired = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e
gen cult_days_hired_withkids = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e +0.5*pp_s3q28_g*pp_s3q28_h	// children at 50% productivity
*free labor - pre-harvest labor
recode pp_s3q29* (.=0)
gen cult_days_free = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d
gen cult_days_free_withkids = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d + 0.5*pp_s3q29_e*pp_s3q29_f
collapse (sum) *days*, by(hhid)
merge 1:1 hhid using `harv_days', nogen
tempfile hired_labor
save `hired_labor', replace


* family labor demand - Cultivation
use "$data_ET/Post Planting/sect3_pp_w1", clear
gen hhid = household_id
isid holder_id parcel_id field_id		// Check
keep hhid holder_id parcel_id field_id pp_s3q27_*
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix pp_s3q27_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
order hhid holder_id parcel_id field_id person* hours*
drop b-x
reshape long personid hours, i(holder_id parcel_id field_id) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.
sum hours if personid==0

collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `ET_hhmembers', keep(1 3) nogen	

foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}


save "$newdata/ET1_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace


*Harvest
use "$data_ET/Post Harvest/sect10_ph_w1", clear
gen hhid = household_id
keep hhid holder_id parcel_id field_id crop_id crop_code ph_s10q02_*
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix ph_s10q02_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
ren y personid7
gen hours7 = z*ka*la
ren ma personid8
gen hours8 = na*oa*pa
order hhid holder_id parcel_id field_id crop_* person* hours*
drop b-pa
sum hours* if crop_code==.
recode crop_code (.=999) if (hours1!=. & hours1!=0)
sum hours* if crop_code==.
drop if crop_code==.
isid holder_id parcel_id field_id crop_code
reshape long personid hours, i(holder_id parcel_id field_id crop_code) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.
sum hours if personid==0
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `ET_hhmembers', keep(1 3) nogen	

foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
save "$newdata/ET1_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
merge 1:1 hhid using `hhprep', nogen
recode *_prep *_harv (.=0)
gen cult_days_hh = man_prep + woman_prep
gen cult_days_hh_withkids = man_prep + woman_prep + child_prep
gen harv_days_hh = man_harv + woman_harv
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep hhid cult_days_hh* harv_days_hh*
merge 1:1 hhid using `hired_labor', assert(2 3) nogen

** BRING TOGETHER
merge 1:1 hhid using `plots', keep(3) nogen
merge 1:1 hhid using `ET_weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `ET_demog', assert(2 3) keep(3) nogen
merge 1:1 hhid using `head_educ', keep(1 3) nogen
merge 1:1 hhid using `ET_headage', keep(1 3) nogen
merge 1:1 hhid using `hh_consum', assert(2 3) keep(3) nogen
merge 1:1 hhid using `hh_wealth', assert(2 3) keep(3) nogen
merge 1:1 hhid using `hh_fin_const', keep(1 3) nogen
merge 1:1 hhid using `hh_psnp', assert (2 3) keep(3) nogen
merge 1:1 hhid using `geo', keep(1 3) nogen
merge 1:1 hhid using `oxen', keep(1 3) nogen
merge 1:1 hhid using `inputs', keep(1 3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen

tempfile ET_data
save `ET_data', replace


*********************************************************
*****************  ethiopia 2013 ************************
********************  wave 2 ****************************
* weights
use "$data_ET_2/Household/sect1_hh_w2.dta", clear
ren household_id2 y2_hhid
ren household_id hhid
ren saq01 region
ren saq02 zone
ren saq03 woreda
keep *hhid pw ea_id2 region zone woreda
duplicates drop y2_hhid pw, force
ren pw2 weight2
tempfile ET2_weights
save `ET2_weights', replace


*Demographics
use "$data_ET_2/Household/sect1_hh_w2.dta", clear	 //Path to first part of Ethiopia data
drop if hh_s1q04c==2						//drops observations for people who have moved out of the household
gen y2_hhid = household_id2
gen y2_pid = individual_id2
gen y2_personid = hh_s1q00
gen female = (hh_s1q03==2)
gen male = (hh_s1q03==1)
gen male_head = hh_s1q02==1 & male==1
gen child = (hh_s1q04_a<15)
gen person = 1
preserve										// In order to make a few changes
gen man = male*(child== 0)
gen woman = female*(child==0)
gen hhhead = 1 if hh_s1q02 == 1
replace hhhead = 0 if hhhead!=1
rename hh_s1q04_a age
label var hhhead "Indicator variable equals 1 if observation is head of household"
rename hh_s1q02 reltohead
keep y2_hhid y2_pid man woman child hhhead y2_personid age male reltohead
tempfile ET2_hhmembers
save `ET2_hhmembers', replace
save "$newdata/ET2_hh_ages.dta", replace				// save individual level data to build LFP rate figures

restore											// Restoring previous data
gen any_muslem = hh_s1q07==4
gen head_muslem = hh_s1q07==4 & hh_s1q02==1
ren hh_s1q04_a age
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen kids_phase = (age-10)*0.2 if age<16 & age>=10
gen kids_15 = age==15
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
replace hh_s1q05 = 12 if hh_s1q05>12 & hh_s1q05!=.				// assuming values of >12 mean the person has been gone for the last 12 months
gen hhsize_away = hhsize*(12-hh_s1q05)/12
gen hhsize_phase_away = hhsize_phase*(12-hh_s1q05)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename hh_s1q05 months_away
gen temp_migrant = months_away > 2 & age >=15

collapse (sum) prime* eld* hhsize* child person male* female* kids* (mean) temp_migrant months_away (max) any_migrant=temp_migrant *muslem, by(y2_hhid)
tempfile ET2_demog
save `ET2_demog', replace


*Age of househead age*
use "$data_ET_2/Household/sect1_hh_w2.dta", clear
gen y2_hhid = household_id2
gen y2_pid = individual_id2
ren hh_s1q04_a age
keep if hh_s1q02==1
gen agehhhead1 =  age
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1, by(y2_hhid)
tempfile ET2_headage
save `ET2_headage', replace


use "$data_ET_2/Household/sect2_hh_w2.dta", clear
gen y2_hhid = household_id2
gen y2_pid = individual_id2
merge 1:1 y2_pid using `ET2_hhmembers', keepusing(hhhead) assert(2 3) keep(3) nogen
ren hh_s2q05 f
gen educ = f if f<=12
replace educ = 12 if inlist(f,13,14,17,24,27,29)
replace educ = 13 if f==31
replace educ = 14 if f==32
replace educ = f-2 if inlist(f,15,16)
replace educ = 15 if inlist(f,18,33)
replace educ = 16 if inlist(f,19,34,35)
replace educ = f-12 if inlist(f,21,22,23)
replace educ = 11 if inlist(f,25,26,28)
replace educ = 13 if f==30
replace educ = 0 if inlist(f,93,94,96,98) | hh_s2q03==2
replace educ = 18 if inlist(f,20)
label var educ "Highest education attained"
keep y2_hhid y2_pid educ hhhead
tempfile educ
save `educ', replace
keep if hhhead==1
duplicates report y2_hhid
rename educ headeduc
tempfile head_educ
save `head_educ', replace

* get hh access to finance info
use "$data_ET_2/Household/sect11b_hh_w2.dta", clear
gen y2_hhid = household_id2
keep y2_hhid hh_s11bq16*
foreach k in a b c {
	gen fin_constraint_`k' = hh_s11bq16_`k' > 70 & hh_s11bq16_`k' < 80
}
drop if hh_s11bq16_a==.
collapse (max) fin_constraint* , by(y2_hhid)

egen fin_const1 = rowmax(fin_constraint_a fin_constraint_b fin_constraint_c)
keep y2_hhid fin_const1
tempfile hh_fin_temp1
save `hh_fin_temp1', replace

use "$data_ET_2/Household/sect11c_hh_w2.dta", clear
gen y2_hhid = household_id2
keep y2_hhid hh_s11bq19*
foreach k in a b c {
	gen fin_constraint_`k' = hh_s11bq19_`k' > 70 & hh_s11bq19_`k' < 80
}
drop if hh_s11bq19_a==.
collapse (max) fin_constraint* , by(y2_hhid)

egen fin_const2 = rowmax(fin_constraint_a fin_constraint_b fin_constraint_c)
keep y2_hhid fin_const2
merge 1:1 y2_hhid using `hh_fin_temp1'
gen any_fin_const = fin_const1==1 | fin_const2==1
keep y2_hhid any_fin_const
tempfile hh_fin_const
save `hh_fin_const', replace


* get crop info
use "$data_ET_2/Post-Harvest/sect10_ph_w2", clear
gen maize = crop_code==2
gen sorghum = crop_code==6
keep holder_id parcel_id field_id maize sorghum
collapse (max) maize sorghum, by(holder_id parcel_id field_id)
tempfile crops
save `crops', replace

* get input info
use "$data_ET_2/Post-Planting/sect7_pp_w2", clear
rename household_id2 y2_hhid
gen any_oxen = pp_s7q11>0 & pp_s7q11 !=.
collapse (max) any_oxen, by(y2_hhid)
tempfile oxen
save `oxen', replace

use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
rename household_id2 y2_hhid
gen irrigated = pp_s3q12==1
gen fertilized = pp_s3q14==1
collapse (max) irrigated fertilized, by(y2_hhid)
tempfile inputs
save `inputs', replace

*get sales info
use "$data_ET_2/Post-Harvest/sect11_ph_w2", clear
rename household_id2 y2_hhid
gen any_sales = ph_s11q01==1
collapse (max) any_sales, by(y2_hhid)
tempfile sales
save `sales', replace

* area *
use "$data_ET_2/Post-Planting/sect2_pp_w2", clear
gen y2_hhid = household_id2
ren pp_s2q03 ten
gen own = inlist(ten,1,2)		// NOTE: I assume "granted by local leaders" means owned
gen rent = inlist(ten,3)
gen borrow = inlist(ten,4)
gen other = inlist(ten,5,6)
keep y2_hhid holder_id parcel_id own rent borrow
tempfile owned
save `owned', replace


use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
gen y2_hhid = household_id2
merge m:1 holder_id parcel_id using `owned', nogen keep(1 3)
gen use = pp_s3q03==1
gen region = saq01
gen zone = saq02
gen woreda = saq03
gen local_unit = pp_s3q02_c
merge 1:1 holder_id parcel_id field_id using `crops', keep(1 3) nogen

merge m:1 region zone woreda local_unit using "$data_ET/ET_local_area_unit_conversion.dta", gen(merge)

bys region zone local_unit: egen conversion_zone_temp = median(conversion)
replace conversion = conversion_zone_temp if conversion==.
bys region local_unit: egen conversion_reg_temp = median(conversion)
replace conversion = conversion_reg_temp if conversion==.
bys local_unit: egen conversion_temp = median(conversion)
replace conversion = conversion_temp if conversion==.
drop if merge==2
gen area = pp_s3q02_a
gen hectares = area if pp_s3q02_c==1
replace hectares = area/10000 if pp_s3q02_c==2	// dividing by 10000 to get hectares
replace hectares = (area*conversion)/10000 if pp_s3q02_c>2	// conversion is the number of square meters per local unit; dividing by 10000 to get hectares

gen area_GPS = pp_s3q05_a 
gen hectares_GPS = area_GPS/10000
replace hectares = hectares_GPS if hectares==.		// Replacing missing values
gen owned_hectares = hectares*own
gen owned_acres = 2.471*owned_hectares
gen acres = 2.471*hectares
gen acres_maize = acres*maize
gen acres_sorghum = acres*sorghum
collapse (sum) owned_hectares hectares acres* owned_acres (max) maize sorghum, by(y2_hhid)
tempfile plots
save `plots', replace


* hired labor - Harvest labor
use "$data_ET_2/Post-Harvest/sect10_ph_w2", clear
ren household_id2 y2_hhid
recode ph_s10q01_a ph_s10q01_b ph_s10q01_d ph_s10q01_e ph_s10q01_g ph_s10q01_h (.=0)
gen harv_days_hired = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e
gen harv_days_hired_withkids = ph_s10q01_a*ph_s10q01_b + ph_s10q01_d*ph_s10q01_e +0.5*ph_s10q01_g*ph_s10q01_h	// children at 50% productivity
recode ph_s10q03* (.=0)
gen harv_days_free = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d
gen harv_days_free_withkids = ph_s10q03_a*ph_s10q03_b + ph_s10q03_c*ph_s10q03_d + 0.5*ph_s10q03_e*ph_s10q03_f
collapse (sum) *days*, by(y2_hhid)
tempfile harv_days
save `harv_days', replace


* hired labor - PRE-harvest labor
use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
ren household_id2 y2_hhid
isid holder_id parcel_id field_id		// Check
keep y2_hhid parcel_id holder_id field_id pp_s3q27* pp_s3q28* pp_s3q29*
recode pp_s3q28_a pp_s3q28_b pp_s3q28_d pp_s3q28_e pp_s3q28_g pp_s3q28_h (.=0)
gen cult_days_hired = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e
gen cult_days_hired_withkids = pp_s3q28_a*pp_s3q28_b + pp_s3q28_d*pp_s3q28_e +0.5*pp_s3q28_g*pp_s3q28_h	// children at 50% productivity
recode pp_s3q29* (.=0)
gen cult_days_free = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d
gen cult_days_free_withkids = pp_s3q29_a*pp_s3q29_b + pp_s3q29_c*pp_s3q29_d + 0.5*pp_s3q29_e*pp_s3q29_f
collapse (sum) *days*, by(y2_hhid)
merge 1:1 y2_hhid using `harv_days', nogen
tempfile hired_labor
save `hired_labor', replace



* family labor demand - Cultivation
use "$data_ET_2/Post-Planting/sect3_pp_w2", clear
gen y2_hhid = household_id2
isid holder_id parcel_id field_id		// Check
keep y2_hhid holder_id parcel_id field_id pp_s3q27_*
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix pp_s3q27_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
ren y personid7
gen hours7 = z*ca*da
order y2_hhid holder_id parcel_id field_id person* hours*
drop b-da
reshape long personid hours, i(holder_id parcel_id field_id) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.
sum hours if personid==0
collapse (sum) hours, by(y2_hhid personid)
ren personid y2_personid
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 y2_hhid y2_personid using `ET2_hhmembers', keep(1 3) nogen

foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}
save "$newdata/ET2_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y2_hhid)
tempfile hhprep
save `hhprep', replace


*Harvest
use "$data_ET_2/Post-Harvest/sect10_ph_w2", clear
gen y2_hhid = household_id2
keep y2_hhid holder_id parcel_id field_id crop_code ph_s10q02_*
isid holder_id parcel_id field_id crop_code		// Check
*NOTE: Can only do this for all pre-harvest activities in aggregate. Cannot separate weeding from ridging from etc
renpfix ph_s10q02_
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
ren q personid5
gen hours5 = r*s*t
ren u personid6
gen hours6 = v*w*x
ren y personid7
gen hours7 = z*ka*la
ren ma personid8
gen hours8 = na*oa*pa
order y2_hhid holder_id parcel_id field_id crop_* person* hours*
drop b-pa
reshape long personid hours, i(holder_id parcel_id field_id crop_code) j(num)
drop if personid==. & (hours==0 | hours==.)
drop if personid==0 & (hours==0 | hours==.)
sum hours if personid==.
sum hours if personid==0
collapse (sum) hours, by(y2_hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
ren personid y2_personid
merge 1:1 y2_hhid y2_personid using `ET2_hhmembers', keep(1 3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
save "$newdata/ET2_harv_ages.dta", replace			// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y2_hhid)
merge 1:1 y2_hhid using `hhprep', nogen
recode *_prep *_harv (.=0)
gen cult_days_hh = man_prep + woman_prep
gen cult_days_hh_withkids = man_prep + woman_prep + child_prep
gen harv_days_hh = man_harv + woman_harv
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep y2_hhid cult_days_hh* harv_days_hh*
merge 1:1 y2_hhid using `hired_labor', assert(2 3) nogen


** BRING TOGETHER
merge 1:1 y2_hhid using `plots', keep(3) nogen
merge 1:1 y2_hhid using `ET2_weights', keep(1 3) nogen
merge 1:1 y2_hhid using `ET2_demog', keep(1 3) nogen
merge 1:1 y2_hhid using `head_educ', keep(1 3) nogen
merge 1:1 y2_hhid using `ET2_headage', keep(1 3) nogen
merge 1:1 y2_hhid using `hh_fin_const', keep(1 3) nogen
merge 1:1 y2_hhid using `oxen', keep(1 3) nogen
merge 1:1 y2_hhid using `inputs', keep(1 3) nogen
merge 1:1 y2_hhid using `sales', keep(1 3) nogen

rename y2_hhid hhid_wave2
rename y2_* *
tempfile ET2_data
save `ET2_data', replace



**********************************
****
****    Combine panel and construct key labor demand variables
****
**********************************


**********
**Ethiopia
**********
use `ET_data', clear
append using `ET2_data', gen(wave2)
gen wave = wave2==0
replace wave = 2 if wave2==1
bys hhid: egen hhidcount = count(wave)
keep if hhidcount==2


*Recoding
recode cult_days_* (.=0)
recode harv_days_* (.=0)							// I assume these are zeros (same assumption as the coding above)
recode owned_hectares (.=0)
recode hectares (.=0)

gen log_ld = ln(cult_days_hh + cult_days_hired + cult_days_free)	// Missings
replace log_ld = ln(0.01) if log_ld==.
** add labor demand for harvest labor
gen log_harv = ln(harv_days_hh + harv_days_hired + harv_days_free)
replace log_harv = ln(0.01) if log_harv==.
gen log_A = ln(acres)		// Missings
replace log_A = ln(0.01) if log_A==.

** Make a number of possible labor demand measures
* No children
gen ld_cult_nokids = cult_days_hh + cult_days_hired + cult_days_free
la var ld_cult_nokids "LD: no kids; prep, weed; waves 1-2"
gen ld_harv_nokids = harv_days_hh + harv_days_hired + harv_days_free
la var ld_harv_nokids "LD: no kids; harv only; waves 1-2"
gen ld_tot_nokids = ld_cult_nokids + ld_harv_nokids
la var ld_tot_nokids "LD: no kids; prep, weed, fert, harv; waves 1-2"

* With children
gen ld_cult_kids = cult_days_hh_withkids + cult_days_hired_withkids + cult_days_free_withkids
la var ld_cult_kids "LD: incl. kids; prep, weed, fert; "
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids + harv_days_free_withkids
la var ld_harv_kids "LD: incl. kids; harv only; waves 1-2"
gen ld_tot_kids = ld_cult_kids + ld_harv_kids
la var ld_tot_kids "LD: incl. kids; prep, weed, fert, harv; waves 1-2"

bysort hhid: egen temp_ld = sum(ld_tot_kids)
drop if temp_ld == 0
bysort hhid: egen temp_A = sum(acres)
drop if temp_A == 0
drop temp_A temp_ld

foreach i of varlist ld_* {
	gen log_`i' = ln(`i')
	local label : variable label `i'
	label variable log_`i' `"Log `label''"'
	replace log_`i' = ln($no_work) if `i'==0
}

replace owned_hectares = owned_hectares + 0.01 if log_A!=. & owned_hectares==0		// replace the ownership zeros so that sample size is identical to log_A sample size
replace owned_acres = owned_acres + 0.01 if log_A!=. & owned_acres==0
gen log_owned = ln(owned_acres)
gen log_hhsize = ln(hhsize)
gen log_phase = ln(hhsize_phase)
gen log_hhaway = ln(hhsize_away)
gen log_phase_away = ln(hhsize_phase_away)
gen share_pm = prime_male/person
gen share_pf = prime_female/person
gen share_em = eld_male/person
gen share_ef = eld_female/person
gen age_head1 = agehhhead1
gen age_squared1 = agehhead_squared1
gen female_head = 1-male_head
gen female_hhsize = female_head*log_hhsize
drop if hhsize_phase==0			// with all elderly being counted fully, only households with no ages entered have hhsize==0
gen zero = hhsize==0
replace log_hhsize = ln(0.01) if hhsize==0
replace log_hhaway = ln(0.01) if hhsize_away==0
replace log_phase_away = ln(0.01) if hhsize_phase_away==0
replace age_squared1 = age_squared1/1000
la var log_ld "Log of labor demanded"
la var log_A "Log acres cultivated"
la var log_owned "Log acres owned"
la var log_hhsize "Log HH size (15<=age<=60)"
la var log_phase "Log HH size with phase-in and out"
la var share_pm "Prime male share"
la var share_pf "Prime female share"
la var share_em "Elderly male share"
la var share_ef "Elderly female share"
la var age_head1 "Age of household head"
la var age_squared1 "Age of household head squared (000s)"
la var female_head "Female head of household"
la var female_hhsize "Log of household size for female heads"
la var hhsize "Household size"
la var cult_days_hh "Total household labor"
la var cult_days_hired "Total hired labor"
la var male_head "Male head of household"
la var hhsize "Household size"
la var cult_days_hh "Total household labor"
la var cult_days_hired "Total hired labor"
la var owned_hectares "Hectares owned"
la var hectares "Hectares farmed"
la var male_head "Male head of household"

* Drop households with no acreage cultivated
drop if acres==0

* winsorizing top 5 largest acres, owned_acres, exp_pc
foreach var in acres owned_acres exp_pc {
	di "var = `var'"
	gsort - `var'
	forvalues i=1/5 {
		di "var=`var' and i=`i'"
		replace `var' = `var'[6] in `i'
	}
}

* set-up EA to use for village level IV
sort hhid wave
by hhid: gen ea_temp = ea_id[_n-1]
replace ea_id = ea_temp if wave==2
rename ea_id ea1

* vars for hhsize by gender
gen log_male = ln(male_phase)
replace log_male = ln(0.1) if male_phase==0
gen log_female = ln(female_phase)
replace log_female = ln(0.1) if female_phase==0
gen log_male_nokids = ln(hhsize_male)
replace log_male_nokids = ln(0.1) if hhsize_male==0
gen log_female_nokids = ln(hhsize_female)
replace log_female_nokids = ln(0.1) if hhsize_female ==0

* set up ever financially constrained
bysort hhid: egen ever_fin_const = max(any_fin_const) 
by hhid: egen nevermiss = count(any_fin_const)
replace ever_fin_const = . if nevermiss!=2

keep hhsize* log* ld* hhid wave hhsize* *acres* male* female*  prime* eld* share_* age* kids* *muslem *_fin_const ///
	weight* female_head region zone woreda female_hhsize person *educ exp_pc pc1_wealth any_psnp aez ea1 months_away dist* ///
	maize sorghum fertilized irrigated any* temp_migrant
	
save "$newdata/ET panel data merged", replace

svyset [pweight=weight]
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave

*Generating region zone FE:
egen reg_zone_wave_FE = group(region zone wave)

* Wealth categories in Wave 1
sum exp_pc if wave==1, det
local cut50 = r(p50)
gen temp = exp_pc<`cut50' & wave==1
bysort hhid: egen poor50 = sum(temp)
replace temp = exp_pc>=`cut50' & wave==1
bysort hhid: egen exp_rich50 = sum(temp)
drop temp

* Wealth categories by asset index
sum pc1_wealth, det
local cut50 = r(p50)
gen temp = pc1_wealth <`cut50' & wave==1
bysort hhid: egen asset_poor50 = sum(temp)
replace temp = pc1_wealth>=`cut50' & wave==1
bysort hhid: egen asset_rich50 = sum(temp)
drop temp
gen rich50 = exp_rich50

* Spread PSNP info across waves
bysort hhid: egen temp_psnp = max(any_psnp)
replace any_psnp = temp_psnp

* Spread AEZ zone info across waves
bysort hhid: egen ae_zone = max(aez)

local controls log_A


****** create vars for whether household increased or decreased in size *******
sort hhid wave
by hhid: gen increase = ($hhsize_var>$hhsize_var[_n-1]) if _n==2
by hhid: gen decrease = ($hhsize_var<$hhsize_var[_n-1]) if _n==2
by hhid: gen male_inc = (male_phase>male_phase[_n-1]) if _n==2
by hhid: gen male_dec = (male_phase<male_phase[_n-1]) if _n==2
by hhid: gen female_inc = (female_phase>female_phase[_n-1]) if _n==2
by hhid: gen female_dec = (female_phase<female_phase[_n-1]) if _n==2


****** create vars for agricultural activity, with kids phased in *******
rename log_ld_cult_kids act_log_ld_0
rename log_ld_harv_kids act_log_ld_1
label define act_labels 0 "Pre-Harvest w/ Kids" 1 "Harvest"

reshape long act_log_ld_, i(hhid wave) j(activity)
label values activity act_labels
rename act_log_ld_ act_log_ld

local dep_var act_log_ld

foreach i of varlist `dep_var' log_phase log_hhsize log_phase_away log_male log_female share_pm share_pf share_em log_A log_owned log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

gen INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
gen DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_male = diff_log_male*male_inc
gen DEC_male = diff_log_male*male_dec
gen INC_female = diff_log_female*female_inc
gen DEC_female = diff_log_female*female_dec

la var INC_hhsize "Increase in HH Size"
la var DEC_hhsize "Decrease in HH Size"
la var INC_male "Increase in Male HH Size"
la var DEC_male "Decrease in Male HH Size"
la var INC_female "Increase in Female HH Size"
la var DEC_female "Decrease in Female HH Size"
label define rich_labels 1 "Top 50\% Wealth" 0 "Bottom 50\% Wealth"
label values rich50 rich_labels
label var rich50 "Top 50\% Wealth"
label var log_hhsize "Log(HH Size)"


save "$newdata/ET_reg_ready", replace		// to be used in the file "Combined analysis.do"

