* pwb	22-Mar-2016	splitting out Malawi data prep from salam_data_build.do

*********************************
*** Directories and Paths     ***
*** SALAM project - Fall 2014 ***
*********************************
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000

if c(username)=="Josh" {
	global path 			"/Users/Josh/Dropbox/UW/Classes/Year 2 (2014-2015)/RA/SALAM"
	global data_MW 			"$path/Data/Malawi"
	global output			"$path/output/Ag Panels"
	global do				"$path/do"
	global newdata			"$path/prc_data"
	global fragments		"$do/Labor Demand and Wage - Do-file fragments"
	global draft1			"/Users/Josh/Dropbox/UW/Classes/Year 2 (2014-2015)/RA/Drafts/Draft 1 - 01.28.15/Tables"
}
	
if c(username)=="bdillon2" {
	global path				"/Users/bdillon2/Dropbox/SALAM"
	global data_MW 			"/Users/bdillon2/Dropbox/SALAM/Data/MALAWI"
	global output			"/Users/bdillon2/Dropbox/SALAM/output/Ag Panels"
	global do				"/Users/bdillon2/Dropbox/SALAM/do"
	global newdata			"/Users/bdillon2/Dropbox/SALAM/Data/prc_data"
	sysdir set PERSONAL 	"$do/ado"		// this gets me the "labeldis" command
	global fragments		"$do/Labor Demand and Wage - Do-file fragments"
}


if c(username)=="peterbrummund" {
	global path				"/Users/peterbrummund/Dropbox/SALAM"
	global data_MW  		"$path/Data/Malawi"
	global output			"$path/output/Ag Panels"
	global do				"$path/do"
	global newdata			"$path/prc_data"
	global fragments		"$do/Labor Demand and Wage - Do-file fragments"
	sysdir set PERSONAL 	"$do/ado"		// this gets me the "labeldis" command
}

global hhsize "age>=15 & age<=60"
global prime "age>=15 & age<=60"
global elderly "age>60"
global prime_noage "age<=57 & age>=18"
global child "age<15"
global time_away 12
global oldmem "age>=15 & age<=60"


*********************************************************
*****************  malawi 2013 **************************
********************  wave 2 ****************************

***** HH variables that we need

* acreage of each plot
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_C", clear
ren y2_hhid hhid
gen acres = ag_c04a if ag_c04b==1
replace acres = ag_c04a*2.471 if ag_c04b==2
replace acres = ag_c04a*0.000247105 if ag_c04b==3
replace acres = ag_c04c if acres==.			// use the GPS measure if the farmer estimate is missing
gen plotnum = substr(ag_c00,2,2)
destring plotnum, replace
keep hhid plotnum acres 
drop if hhid=="" | plotnum==.
tempfile acres
save `acres', replace


* weights
use "$data_MW/2013/Dataset/Household/HH_MOD_A_FILT", clear
destring ea_id , gen(ea)
ren y2_hhid hhid
ren case_id real_hhid
gen year = hh_a23b_3
replace year = hh_a23a_3 if year==.
gen month = hh_a23b_2
replace month = hh_a23a_2 if month==.
gen month_int = (month-1)/12
gen date_int = year+month_int
ren hh_a10a ta
ren hh_a10b dist_ta
tostring qx_type, replace
keep hhid HHID real_hhid hh_wgt district ta dist_ta qx_type hh_a05 ea ea_id month year month_int date_int
duplicates drop hhid, force
ren hh_wgt weight
tempfile MW2_weights
save `MW2_weights', replace

* region
use "$data_MW/2013/Dataset/Household/HH_MOD_A_FILT", clear
destring ea_id , gen(ea)
ren y2_hhid hhid
ren case_id real_hhid
keep hhid region
isid hhid
tempfile region
save `region', replace

* demographics
use "$data_MW/2013/Dataset/Household/HH_MOD_B", clear
ren y2_hhid hhid
gen person = 1
ren hh_b01 personid
ren hh_b06_3a age
gen female = (hh_b03==2)
gen male = (hh_b03==1)
gen child = $child
gen man = male*(child==0)
gen woman = female*(child==0)
gen own_child = hh_b04==3
gen adult_children = own_child==1 & child==0
gen prime_noage = ($prime_noage)
gen aged_in = age>=15 & age<=18
gen aged_out = age>60 & age<=64
gen pm_equiv = (age>14)*(age<61)*(male==1)
gen pf_equiv = (age>14)*(age<61)*(male==0)
gen em_equiv = (1-(age-60)*0.04)*(age>60)*(age<81)*(male==1)+0.20*(age>80)*(male==1)
gen ef_equiv = (1-(age-60)*0.04)*(age>60)*(age<81)*(male==0)+0.20*(age>80)*(male==0)
gen child_equiv = (1-(0.1*(15-age)))*(age<15)*(age>=5)
gen adult_equiv_hh = child_equiv*(age<15)+pm_equiv*(age>60)*(male==1)+pf_equiv*(age>60)*(male==0)+(age>14)*(age<61)+em_equiv*(age>60)*(male==1)+ef_equiv*(age>60)*(male==0)
replace adult_equiv_hh = . if age==.

** pwb - Create age categories ala LeFave and Thomas, 0-14, 15-19, 20-34, 35-49, 50-64, 65+, by male and female
gen male_014 = age<=14 & male==1
gen male_1519 = age>14 & age<20 & male==1
gen male_2034 = age>=20 & age<35 & male==1
gen male_3549 = age>=35 & age<50 & male==1
gen male_5064 = age>=50 & age<65 & male==1
gen male_65up = age>=65 & male==1
gen female_014 = age<=14 & male==0
gen female_1519 = age>14 & age<20 & male==0
gen female_2034 = age>=20 & age<35 & male==0
gen female_3549 = age>=35 & age<50 & male==0
gen female_5064 = age>=50 & age<65 & male==0
gen female_65up = age>=65 & male==0

gen male_head = hh_b04==1 & male==1
label var female "Female"
label var child "Child"
keep hhid personid man woman child female* male* age adult_equiv PID
tempfile MW2_demog
save `MW2_demog', replace

***** get the labor demand data
* Malawi
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
destring y2_hhid, replace
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
duplicates drop hhid plotnum, force				// just that 1 problem case								
keep hhid plotnum ag_d47* ag_d48*
drop if plotnum==.
drop *g *h *i *j
recode ag*a ag*b ag*c ag*d ag*e ag*f (.=0)					// correcting missing work days
gen cult_days_hired = ag_d47a + ag_d47c +0.5*ag_d47e	// children at 50% productivity
gen harv_days_hired = ag_d48a + ag_d48c	+0.5*ag_d48e	
collapse (sum) *days*, by(hhid plotnum)
tempfile hired
save `hired', replace


* family labor demand
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
destring y2_hhid, replace
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
drop if plotnum==.
duplicates drop hhid plotnum, force				// just that 1 problem case
keep hhid plotnum ag_d42* ag_d43* ag_d44*
tempfile hhlabor
save `hhlabor', replace
keep hhid plotnum ag_d42*
renpfix ag_d42

preserve		// maximum planting period, for the LD time graph
egen pl_dur = rowmax(b f j n)
collapse (max) pl_dur, by(hhid plotnum)
tempfile plant_duration
save `plant_duration', replace
restore

ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid plotnum personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge m:1 hhid personid using `MW2_demog', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days
	ren `i' `i'_prep
}
collapse (sum) man woman child, by(hhid plotnum)
tempfile hhprep
save `hhprep', replace
use `hhlabor', clear

*weed
keep hhid plotnum ag_d43*
renpfix ag_d43
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid plotnum personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge m:1 hhid personid using `MW2_demog', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days
	ren `i' `i'_weed
}
collapse (sum) man woman child, by(hhid plotnum)
tempfile hhweed
save `hhweed', replace
use `hhlabor', clear

*harv
keep hhid plotnum ag_d44*
renpfix ag_d44
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid plotnum personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge m:1 hhid personid using `MW2_demog', keep(3) nogen		// very few unmatched
foreach i of varlist child man woman {
	replace `i' = `i'*days
	ren `i' `i'_harv
}
collapse (sum) man woman child, by(hhid plotnum)
merge 1:1 hhid plotnum using `hhprep', nogen
merge 1:1 hhid plotnum using `hhweed', nogen
gen cult_days_hh = man_weed + man_prep + woman_weed + woman_prep
gen prep_days_hh = man_prep + woman_prep
gen weed_days_hh = man_weed + woman_weed
gen harv_days_hh = man_harv + woman_harv
gen cult_days_hh_withkids = man_weed + man_prep + woman_weed + woman_prep + 0.5*(child_weed + child_prep)
gen prep_days_hh_withkids = man_prep + woman_prep + 0.5*(child_prep)
gen weed_days_hh_withkids = man_weed + woman_weed + 0.5*(child_weed)
gen harv_days_hh_withkids = man_harv + woman_harv + 0.5*(child_harv)
keep hhid plotnum cult_days* harv_days* prep_days* weed_days*
merge 1:1 hhid plotnum using `hired', assert(2 3) nogen
isid hhid plotnum
recode *_* (.=0)			// recode missing LD to zero
tempfile labordemand
save `labordemand', replace


**** Set up the timing data
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
tab ag_d35_1a
tab ag_d35_1b
* generate a new variable that shows the time path of planting from the hypothetical start of the season forward
gen plant = ((ag_d35_1a-7)+ag_d35_1b*0.5)*(ag_d35_1a>=7) + ((ag_d35_1a+5)+ag_d35_1b*0.5)*(ag_d35_1a<7) if ag_d35_1a!=.

/*
- July is month zero
- Completion of planting in first half of July gives plant==0.5
- Completion of planting in second half of July gives plant==1
- Completion of planting in first half of August gives plant==1.5
- etc.
*/

la def plant_month 0 "July 2012"
la def plant_month 1 "August", add
la def plant_month 2 "September", add
la def plant_month 3 "October", add
la def plant_month 4 "November", add
la def plant_month 5 "December", add
la def plant_month 6 "January", add
la def plant_month 7 "February", add
la def plant_month 8 "March", add
la def plant_month 9 "April", add
la def plant_month 10 "May", add
la def plant_month 11 "June", add
la def plant_month 12 "July 2013", add
la def plant_month 13 "August", add
la def plant_month 14 "September", add
la val plant plant_month
*hist plant, bin(24)
collapse (max) plant, by(hhid plotnum)
tempfile plant
save `plant', replace

* time path of harvesting
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_G", clear
ren y2_hhid hhid
gen plotnum = substr(ag_g00,2,2)
destring plotnum, replace
tab ag_g12a
tab ag_g12b
drop if inlist(ag_g12a,48,84)		// 2 problem cases
drop if plotnum==.
duplicates tag hhid plotnum, gen(duptag)
tab duptag		// multiple crops per plot -- lots of duplicates
collapse (max) harv_end = ag_g12b (min) harv_start = ag_g12a, by(hhid plotnum)
gen harvest_end = (harv_end-6)*(harv_end>=10) + (harv_end+6)*(harv_end<10) if harv_end!=.
gen harvest_start = (harv_start-6)*(harv_start>=10) + (harv_start+6)*(harv_start<10) if harv_start!=.


* randomly choose whether to adjust harvest start or harvest end by half a month
set seed 161891435 // (spells PRINCE)
gen coinflip = runiform()
replace harvest_start = harvest_start-0.5 if coinflip<=0.5		// creates space for possible cultivation and harvest overlapped in the month (also sets harvest period equal to its expected value)
replace harvest_end = harvest_end+0.5 if coinflip>0.5
drop harv_end harv_start

* bring together and plot histograms
merge 1:1 hhid plotnum using `plant'
drop _merge
la val harvest_end plant_month
la val harvest_start plant_month


/* 
twoway (histogram plant, bin(24) start(0) color(green) xlabel(1 "August" 4 "November" 7 "February" 10 "May" 13 "August", angle(45))) ///
(histogram harvest_end, bin(12) fcolor(none) lcolor(black)), legend(order(1 "Planting" 2 "Harvest")) ///
graphregion(color(white)) bgcolor(white) ///
xtitle("Planting or harvest: month completed") ///
ytitle("Density") 
*/

*** Labor demand over time
/*
Set-up
1. Planting time ranges from plant_month-MAX to plant_month, where MAX is the longest-serving household member who planted
2. Harvest time ranges from harv_start to harv_end
3. Remaining months are for other activities
4. Count the number of months in each group
5. HH labor is then allocated evenly to each month in group, and across plots by acreage
6. Hired labor is allocated to harvest precisely and then non-harvest labor is split evenly between the other 2 groups
*/

ren plant plant_end
merge 1:1 hhid plotnum using `plant_duration', assert(1 3) nogen // 187 plots without a duration -- must be no HH workers -- for those, let's assume a half-month of planting
gen p_s = round(((10*pl_dur)/4),5)/10
replace p_s = 0.5 if p_s==. | p_s==0	// 1/2 month is minimum planting time
gen plant_start = plant_end-p_s
sum if plant_end>harvest_start			// 53 plots with overlap ... drop them for now
drop if plant_end>=harvest_start
gen cult_start = plant_end
gen cult_end = harvest_start
foreach i of varlist *end *start {
	drop if `i'==.
}



*twoway (histogram cult_start, bin(24) start(0) color(green) xlabel(1 "August" 4 "November" 7 "February" 10 "May" 13 "August", angle(45))) ///
*(histogram cult_end, bin(10) fcolor(none) lcolor(black)), legend(order(1 "Cult start" 2 "Cult end")) ///
*graphregion(color(white)) bgcolor(white)


/*		YOU DON'T NEED THE ACREAGE WEIGHTS -- you have everything at the plot level, for this graph
merge 1:1 hhid plotnum using `acres', keep(1 3) nogen
drop if acres==.	// dropping 180 plots with no acres
* generate acre proportions
egen A = sum(acres), by(hhid)
gen acr_sh = acres/A
*/


* bring in labor demand
merge 1:1 hhid plotnum using `labordemand', assert(2 3) keep(3) nogen
drop pl_dur p_s
order hhid plotnum  plant_star plant_e cult_s cult_e harvest_s harvest_e 
*br
gen dur_p = plant_end - plant_start
gen dur_c = cult_end - cult_start
gen dur_h = harvest_end - harvest_start
gen dur_t = harvest_end - plant_start

sum dur* // cases with harvest end before harvest start probably need to extend the harvest into oct-dec 2013 (it is getting picked up as oct-dec 2012) ... for now, ignore
drop if dur_h<0		// CHECK THIS -- temporary measure
sum dur*
foreach i in p c h t {
	gen seg_`i' = dur_`i'*2	// number of segments
}
gen cult_percent_plant = dur_p/(dur_p + dur_c)
drop *kids		// use the adult figures for the moment
drop cult_days_hh		// this is just the sum of prep and weed, but we're counting those separately


* LD per segment
gen h_ld_perseg = (harv_days_hired+harv_days_hh)/seg_h
gen c_ld_perseg = (weed_days_hh + cult_days_hired*(1-cult_percent_plant))/seg_c
gen p_ld_perseg = (prep_days_hh + cult_days_hired*cult_percent_plant)/seg_p
gen h_ld_hh_perseg = (harv_days_hh)/seg_h
gen c_ld_hh_perseg = (weed_days_hh)/seg_c
gen p_ld_hh_perseg = (prep_days_hh)/seg_p
gen h_ld_hired_perseg = (harv_days_hired)/seg_h
gen c_ld_hired_perseg = (cult_days_hired*(1-cult_percent_plant))/seg_c
gen p_ld_hired_perseg = (cult_days_hired*cult_percent_plant)/seg_p

sum *perseg
keep hhid plotnum *start *end *perseg *hh *hired

forvalues i=0(5)150 {
	gen ld_`i' = 0
	replace ld_`i' = p_ld_perseg if (`i'/10)>=plant_start & (`i'/10)<plant_end
	replace ld_`i' = c_ld_perseg if (`i'/10)>=cult_start & (`i'/10)<cult_end
	replace ld_`i' = h_ld_perseg if (`i'/10)>=harvest_start & (`i'/10)<harvest_end	
	gen sd_ld_`i' = ld_`i'
	
	gen hh_ld_`i'=0
	replace hh_ld_`i' = p_ld_hh_perseg if (`i'/10)>=plant_start & (`i'/10)<plant_end
	replace hh_ld_`i' = c_ld_hh_perseg if (`i'/10)>=cult_start & (`i'/10)<cult_end
	replace hh_ld_`i' = h_ld_hh_perseg if (`i'/10)>=harvest_start & (`i'/10)<harvest_end	
	
	gen hired_ld_`i'=0
	replace hired_ld_`i' = p_ld_hired_perseg if (`i'/10)>=plant_start & (`i'/10)<plant_end
	replace hired_ld_`i' = c_ld_hired_perseg if (`i'/10)>=cult_start & (`i'/10)<cult_end
	replace hired_ld_`i' = h_ld_hired_perseg if (`i'/10)>=harvest_start & (`i'/10)<harvest_end	
	
}

egen check = rowtotal(ld_*)
egen compare = rowtotal(*_hh *_hired)
*assert check==compare
gen diff=check-compare		// CHECK THIS -- some problem with about 3% of cases
tab diff


*** GRAPH
merge m:1 hhid using `region', assert(2 3) keep(3) nogen

/* Method 1
preserve
collapse (mean) ld_* (sd) sd_ld_*, by(region)
reshape long ld_ sd_ld_, i(region) j(period)
la val period

twoway (line ld_ period if region==1, lcolor(red)) ///
(line ld_  period if region==2, lcolor(black)) ///
(line ld_  period if region==3, lcolor(green)), ///
legend(order(1 "North" 2 "Central" 3 "South"))
restore
*/

* Method 2
keep hhid plotnum region ld_* hh_ld_* hired_ld_*
reshape long ld_ hired_ld_ hh_ld_, i(hhid plotnum region) j(period)
la val period
la var period
replace period = period/10
la def plant_month 0 "July 2012"
la def plant_month 1 "August", add
la def plant_month 2 "September", add
la def plant_month 3 "October", add
la def plant_month 4 "November", add
la def plant_month 5 "December", add
la def plant_month 6 "January", add
la def plant_month 7 "February", add
la def plant_month 8 "March", add
la def plant_month 9 "April", add
la def plant_month 10 "May", add
la def plant_month 11 "June", add
la def plant_month 12 "July 2013", add
la def plant_month 13 "August", add
la def plant_month 14 "September", add
la def plant_month 15 "October", add
la val period plant_month

/*
twoway (lpolyci ld_ period if region==1, clp(solid) clc(blue) clw(thin) alp(..-..) alc(blue) alw(vthin) acol(none)) ///
(lpolyci ld_ period if region==2, clp(solid) clc(green) clw(thin) alp(..-..) alc(green) alw(vthin) acol(none)) ///
(lpolyci ld_ period if region==3, clp(solid) clc(orange) clw(thin) alp(..-..) alc(orange) alw(vthin) acol(none)), ///
legend(order(2 "North" 4 "Central" 6 "South") rows(1)) ///
graphregion(color(white)) bgcolor(white) ///
xlabel(1 "August" 4 "November" 7 "February" 10 "May" 13 "August", angle(45)) ///
ylabel(,angle(horizontal)) ///
xtitle("Month") ///
xline(6, lc(black) lw(vthin)) ///
text(0.1 5.9  "2012", place(w) size(2.5)) ///
text(0.1 6.1  "2013", place(e) size(2.5)) ///
ytitle("Plot-level labor demand" "(person-days per half month)") 
graph export "$path/output/Malawi_LD_timeline_color.pdf", replace
graph export "$path/output/Malawi_LD_timeline_color.png", replace
*/

* Combined
twoway (lpoly ld_ period if region==1, clp(solid) clc(black) clw(thin) ) ///
(lpoly ld_ period if region==2, clp(_..._...) clc(black) clw(thin) ) ///
(lpoly ld_ period if region==3, clp(-----) clc(black) clw(thin) ), ///
legend(order(1 "North" 2 "Central" 3 "South") rows(1)) ///
graphregion(color(white)) bgcolor(white) ///
xlabel(1 "August" 4 "November" 7 "February" 10 "May" 13 "August", angle(45)) ///
ylabel(,angle(horizontal)) ///
xtitle("Month") ///
xline(6, lc(black) lw(vthin)) ///
text(0.1 5.9  "2012", place(w) size(2.5)) ///
text(0.1 6.1  "2013", place(e) size(2.5)) ///
ytitle("Plot-level labor demand" "(person-days per half month)") 
graph export "$path/output/Malawi_LD_timeline_bw.pdf", replace


* Household only
twoway (lpoly hh_ld_ period if region==1, clp(solid) clc(black) clw(thin) ) ///
(lpoly hh_ld_ period if region==2, clp(_..._...) clc(black) clw(thin) ) ///
(lpoly hh_ld_ period if region==3, clp(-----) clc(black) clw(thin) ), ///
legend(order(1 "North" 2 "Central" 3 "South") rows(1)) ///
graphregion(color(white)) bgcolor(white) ///
xlabel(1 "August" 4 "November" 7 "February" 10 "May" 13 "August", angle(45)) ///
ylabel(,angle(horizontal)) ///
xtitle("Month") ///
xline(6, lc(black) lw(vthin)) ///
text(0.1 5.9  "2012", place(w) size(2.5)) ///
text(0.1 6.1  "2013", place(e) size(2.5)) ///
ytitle("Plot-level labor demand" "(person-days per half month)") 
graph export "$path/output/Malawi_HH_LD_timeline_bw.pdf", replace


* Hired only
twoway (lpoly hired_ld_ period if region==1, clp(solid) clc(black) clw(thin) ) ///
(lpoly hired_ld_ period if region==2, clp(_..._...) clc(black) clw(thin) ) ///
(lpoly hired_ld_ period if region==3, clp(-----) clc(black) clw(thin) ), ///
legend(order(1 "North" 2 "Central" 3 "South") rows(1)) ///
graphregion(color(white)) bgcolor(white) ///
xlabel(1 "August" 4 "November" 7 "February" 10 "May" 13 "August", angle(45)) ///
ylabel(,angle(horizontal)) ///
xtitle("Month") ///
xline(6, lc(black) lw(vthin)) ///
text(0.01 5.9  "2012", place(w) size(2.5)) ///
text(0.01 6.1  "2013", place(e) size(2.5)) ///
ytitle("Plot-level labor demand" "(person-days per half month)") 
graph export "$path/output/Malawi_hired_LD_timeline_bw.pdf", replace






























