
***********************************
*** Directories and Paths       ***
*** SALAM project - Spring 2016 ***
***********************************

clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000

if c(username)=="Josh" {
	global path 			"/Users/Josh/Dropbox/UW/Classes/Year 2 (2014-2015)/RA/SALAM"
	global data_MW 			"$path/Data/Malawi"
	global output			"$path/output/Ag Panels"
	global do				"$path/do"
	global newdata			"$path/prc_data"
	global fragments		"$do/Labor Demand and Wage - Do-file fragments"
	global draft1			"/Users/Josh/Dropbox/UW/Classes/Year 2 (2014-2015)/RA/Drafts/Draft 1 - 01.28.15/Tables"
}
	
if c(username)=="bdillon2" {
	global path				"/Users/bdillon2/Dropbox/SALAM"
	global data_MW 			"/Users/bdillon2/Dropbox/SALAM/Data/MALAWI"
	global output			"/Users/bdillon2/Dropbox/SALAM/output/Ag Panels"
	global do				"/Users/bdillon2/Dropbox/SALAM/do"
	global newdata			"/Users/bdillon2/Dropbox/SALAM/Data/prc_data"
	sysdir set PERSONAL 	"$do/ado"		// this gets me the "labeldis" command
	global fragments		"$do/Labor Demand and Wage - Do-file fragments"
}


if c(username)=="peterbrummund" {
	global path				"/Users/peterbrummund/Dropbox/SALAM"
	global data_MW  		"$path/Data/Malawi"
	global output			"$path/output/Ag Panels"
	global do				"$path/do"
	global newdata			"$path/prc_data"
	global fragments		"$do/Labor Demand and Wage - Do-file fragments"
	sysdir set PERSONAL 	"$do/ado"		// this gets me the "labeldis" command
}

global hhsize "age>=15 & age<=60"
global prime "age>=15 & age<=60"
global elderly "age>60"
global prime_noage "age<=57 & age>=18"
global child "age<15"
global time_away 12
global oldmem "age>=15 & age<=60"

********************************************
*******			 Load data			********
********************************************

*use "$data_MW/2010-2011/Dataset/Consumption aggregate/ihs3_summary.dta", clear


* Timing and location
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_A_FILT", clear
destring case_id, replace
ren case_id hhid
keep hhid hh_a23a_1 hh_a23b_1 hh_a23c_1 hh_a01
gen region = floor(hh_a01/100)
la def reg 1 "North"
la def reg 2 "Central", add
la def reg 3 "South", add
la val region reg
drop hh_a01
ren hh_a23a day
ren hh_a23b month
ren hh_a23c year
gen date = mdy(month,day,year)
gen dateraw = date
format date %td
tab date
tempfile time_region
save `time_region', replace

* Labor supply
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_E", clear
destring case_id, replace
ren case_id hhid
ren hh_e05 ls_water
ren hh_e06 ls_firewood
ren hh_e07 ls_ag
ren hh_e08 ls_nfbizboss
ren hh_e09 ls_nfbizhelp
ren hh_e10 ls_ganyu
ren hh_e11 ls_wagelabor
ren hh_e12 ls_apprent
keep hhid id_co ls_*
tempfile laborsupply
save `laborsupply', replace

* Demographics
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_B", clear
destring case_id, replace
ren case_id hhid
ren hh_b05a age
gen male = hh_b03==1
keep hhid id_code age male
merge 1:1 hhid id_code using `laborsupply', assert(1 3) keep(3) nogen
merge m:1 hhid using `time_region', assert(3) nogen


*********************************************
*											*
***		Collapse and make figures		  ***
*											*
*********************************************

keep if age>=15 & age<=65
tempfile hold
save `hold', replace

sort date

gen ls_ag_both = ls_ag
gen ls_ag_men = ls_ag if male==1
gen ls_ag_women = ls_ag if male==0
gen ls_ganyu_both = ls_ganyu
gen ls_ganyu_men = ls_ganyu if male==1
gen ls_ganyu_women = ls_ganyu if male==0
collapse (sum) ls_ag* ls_ganyu*, by(region hhid date dateraw)

* OWN FARM LABOR: both men and women, then men only, then women only

foreach group in "both" {
	*local group = "both"
	twoway (lpolyci ls_ag_`group' dateraw if region==1, bw(30) clp(solid) clc(blue) clw(thin) alp(..-..) alc(blue) alw(vthin) acol(none)) ///
	(lpolyci ls_ag_`group' dateraw if region==2, clp(solid) clc(green) clw(thin) alp(..-..) alc(green) alw(vthin) acol(none)) ///
	(lpolyci ls_ag_`group' dateraw if region==3, clp(solid) clc(orange) clw(thin) alp(..-..) alc(orange) alw(vthin) acol(none)), ///
	legend(order(2 "North" 4 "Central" 6 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	ylabel(0(5)35,angle(horizontal)) ///
	xlabel(18353 "April 2010" 18444 "July 2010" 18536 "October 2010" 18628 "January 2011" 18717 "April 2011", angle(45)) ///
	xtitle("Date") ///
	ytitle("Household level labor supply" "(Hours per last 7 days)")
	*title("Own farm labor, men and women")
	graph export "$path/output/Malawi_LS_ownfarm_`group'_color.pdf", replace
	graph export "$path/output/Malawi_LS_ownfarm_`group'_color.png", replace

	twoway (lpoly ls_ag_`group' dateraw if region==1,  bw(30) clp(solid) clc(black) clw(thin) ) ///
	(lpoly ls_ag_`group' dateraw if region==2, clp(_..._...) clc(black) clw(thin) ) ///
	(lpoly ls_ag_`group' dateraw  if region==3, clp(-----) clc(black) clw(thin) ), ///
	legend(order(1 "North" 2 "Central" 3 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	ylabel(0(5)35,angle(horizontal)) ///
	xlabel(18353 "April 2010" 18444 "July 2010" 18536 "October 2010" 18628 "January 2011" 18717 "April 2011", angle(45)) ///
	xtitle("Date") ///
	ytitle("Household level labor supply" "(Hours per last 7 days)")
	*title("Own farm labor, men and women")
	graph export "$path/output/Malawi_LS_ownfarm_`group'_bw.pdf", replace
	graph export "$path/output/Malawi_LS_ownfarm_`group'_bw.png", replace
}


foreach group in "men" "women" {
	*local group = "both"
	twoway (lpolyci ls_ag_`group' dateraw if region==1, bw(30) clp(solid) clc(blue) clw(thin) alp(..-..) alc(blue) alw(vthin) acol(none)) ///
	(lpolyci ls_ag_`group' dateraw if region==2, clp(solid) clc(green) clw(thin) alp(..-..) alc(green) alw(vthin) acol(none)) ///
	(lpolyci ls_ag_`group' dateraw if region==3, clp(solid) clc(orange) clw(thin) alp(..-..) alc(orange) alw(vthin) acol(none)), ///
	legend(order(2 "North" 4 "Central" 6 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	ylabel(0(5)20,angle(horizontal)) ///
	xlabel(18353 "April 2010" 18444 "July 2010" 18536 "October 2010" 18628 "January 2011" 18717 "April 2011", angle(45)) ///
	xtitle("Date") ///
	ytitle("Household level labor supply" "(Hours per last 7 days)")
	*title("Own farm labor, men and women")
	graph export "$path/output/Malawi_LS_ownfarm_`group'_color.pdf", replace
	graph export "$path/output/Malawi_LS_ownfarm_`group'_color.png", replace

	twoway (lpoly ls_ag_`group' dateraw if region==1,  bw(30) clp(solid) clc(black) clw(thin) ) ///
	(lpoly ls_ag_`group' dateraw if region==2, clp(_..._...) clc(black) clw(thin) ) ///
	(lpoly ls_ag_`group' dateraw  if region==3, clp(-----) clc(black) clw(thin) ), ///
	legend(order(1 "North" 2 "Central" 3 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	ylabel(0(5)20,angle(horizontal)) ///
	xlabel(18353 "April 2010" 18444 "July 2010" 18536 "October 2010" 18628 "January 2011" 18717 "April 2011", angle(45)) ///
	xtitle("Date") ///
	ytitle("Household level labor supply" "(Hours per last 7 days)")
	*title("Own farm labor, men and women")
	graph export "$path/output/Malawi_LS_ownfarm_`group'_bw.pdf", replace
	graph export "$path/output/Malawi_LS_ownfarm_`group'_bw.png", replace
}




* GANYU LABOR: both men and women, then men only, then women only

foreach group in "both" "men" "women" {
	
	twoway (lpolyci ls_ganyu_`group' dateraw if region==1, bw(35)  clp(solid) clc(blue) clw(thin) alp(..-..) alc(blue) alw(vthin) acol(none)) ///
	(lpolyci ls_ganyu_`group' dateraw if region==2, bw(35) clp(solid) clc(green) clw(thin) alp(..-..) alc(green) alw(vthin) acol(none)) ///
	(lpolyci ls_ganyu_`group' dateraw if region==3, bw(35) clp(solid) clc(orange) clw(thin) alp(..-..) alc(orange) alw(vthin) acol(none)), ///
	legend(order(2 "North" 4 "Central" 6 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	ylabel(0 1 2 3 4 5,angle(horizontal)) ///
	xlabel(18353 "April 2010" 18444 "July 2010" 18536 "October 2010" 18628 "January 2011" 18717 "April 2011", angle(45)) ///
	xtitle("Date") ///
	ytitle("Household level labor supply" "(Hours per last 7 days)")
	*title("Ganyu labor, men and women")
	graph export "$path/output/Malawi_LS_ganyu_`group'_color.pdf", replace
	graph export "$path/output/Malawi_LS_ganyu_`group'_color.png", replace
	
	twoway (lpoly ls_ganyu_`group' dateraw if region==1,  bw(35) clp(solid) clc(black) clw(thin) ) ///
	(lpoly ls_ganyu_`group' dateraw if region==2, clp(_..._...) clc(black) clw(thin) bw(35) ) ///
	(lpoly ls_ganyu_`group' dateraw  if region==3, clp(-----) clc(black) clw(thin) bw(35) ), ///
	legend(order(1 "North" 2 "Central" 3 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white) ///
	ylabel(0 1 2 3 4 5,angle(horizontal)) ///
	xlabel(18353 "April 2010" 18444 "July 2010" 18536 "October 2010" 18628 "January 2011" 18717 "April 2011", angle(45)) ///
	xtitle("Date") ///
	ytitle("Household level labor supply" "(Hours per last 7 days)")
	*title("Ganyu labor, men and women")
	graph export "$path/output/Malawi_LS_ganyu_`group'_bw.pdf", replace
	graph export "$path/output/Malawi_LS_ganyu_`group'_bw.png", replace
		
}





















