* pwb	22-Mar-2016	splitting out Malawi data prep from salam_data_build.do
* pwb	04-Apr-2017	cleaning code, being called from run_all.do
* pwb	18-Dec-2017	create variable for hhsize by gender with nokids



clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



*******************************************
*******			 Malawi	2010-2011			********
***************    wave 1 ********************
********************************************

* weights
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_A_FILT", clear
destring case_id, replace
ren case_id hhid 
ren hh_a01 district
gen year = hh_a23c_2
replace year = hh_a23c_1 if year==.
gen month = hh_a23b_2
replace month = hh_a23b_1 if month==.
gen month_int = (month-1)/12
gen date_int = year+month_int
ren hh_a02 ta
ren hh_a02b dist_ta
keep hhid hh_wgt district ta dist_ta ea_id month year month_int date_int
egen distta = group(district ta)
duplicates drop hhid, force
ren hh_wgt weight
tempfile weights
save `weights', replace

* demographics
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_B", clear
destring case_id, replace
ren case_id hhid
ren hh_b01 personid
ren hh_b05a age
gen person = 1
gen female = (hh_b03==2)
gen male = (hh_b03==1)
gen own_child = hh_b04==3
gen child = $child
gen adult_children = own_child==1 & child==0
gen man = male*(child==0)
gen woman = female*(child==0)
rename hh_b04 reltohead
keep hhid personid man woman child age qx_type visit male reltohead
tempfile hhworkers
save `hhworkers', replace


* determine which crop is on which plot
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
rename case_id hhid
gen plotnum = substr(ag_d00,2,2)
drop if plotnum==""
destring plotnum, replace
duplicates drop hhid plotnum, force
gen crop_code = 2 if ag_d20a < 5 | ag_d20b < 5 | ag_d20c < 5 | ag_d20d < 5 | ag_d20e < 5
keep if crop_code==2

keep hhid plotnum crop_code
tempfile crops
save `crops', replace



* get total harvested by household
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_B", clear
destring case_id, replace
rename case_id hhid
keep if ag_b23==1
destring ea_id, replace
gen region = int(ea_id / 10000000)

* Ox-cart is 468 kgs and a large pail is 18.05, 17.33, 17.75 in the north, center, south respectively (shelled)
* Unshelled weight is 0.83 less
gen wgt_temp = 0
replace wgt_temp = ag_b04a if ag_b04b==1			//kgs
replace wgt_temp = 50*ag_b04a if ag_b04b==2			// 50kg bags
replace wgt_temp = 90*ag_b04a if ag_b04b==3			// 90kg bags
replace wgt_temp = 468*ag_b04a if ag_b04b==12		// ox-carts
replace wgt_temp = 18.05*ag_b04a if ag_b04b==5 & region== 1			// large-pail North
replace wgt_temp = 17.33*ag_b04a if ag_b04b==5 & region== 2			// large-pail Center
replace wgt_temp = 17.75*ag_b04a if ag_b04b==5 & region== 3			// large-pail South
replace wgt_temp = wgt_temp * 0.83 if ag_b04c==2 & ag_b04b> 3		// convert for unshelled maize

collapse (sum) wgt_tot=wgt_temp, by(hhid)
tempfile crops_tot
save `crops_tot', replace


* area *
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
ren case_id hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
duplicates drop hhid plotnum, force 				// 1 problem case
merge 1:1 hhid plotnum using `crops', keep(3)		// keep only maize plots

* we're going to treat the "others" as borrowed, based on the predominant answers to: list ag_d03_os if ag_d03_os~=""
ren ag_d03 ten
gen own = inlist(ten,1,2,3,4,5)
gen rent = inlist(ten,6,7,8)
gen borrow = inlist(ten,9,10,11)
ren ag_d14 use
replace use=1 if use==. & (rent==1 | borrow==1)		// assuming cultivated if rented/borrowed but usage variable is missing
keep hhid plotnum own
tempfile owned
save `owned', replace


use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_C", clear
destring case_id, replace
ren case_id hhid
gen acres = ag_c04a if ag_c04b==1
replace acres = ag_c04a*2.471 if ag_c04b==2
replace acres = ag_c04a*0.000247105 if ag_c04b==3
replace acres = ag_c04c if acres==.			// use the GPS measure if the farmer estimate is missing
gen plotnum = substr(ag_c00,2,2)
destring plotnum, replace
gen acresGPS = ag_c04c
keep hhid plotnum acres acresGPS
gen numplots = 1
merge 1:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
collapse (sum) owned_acres acres acresGPS numplots, by(hhid)
tempfile plots
save `plots', replace

* hired labor

* Malawi
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
ren case_id hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
duplicates drop hhid plotnum, force				// just that 1 problem case
drop if ag_d45==1								// drop the cross-sectional households
keep hhid plotnum ag_d46* ag_d47* ag_d48* ag_d52* ag_d54*
drop if plotnum==.
drop *g *h *i *j *os
drop ag_d46*
merge 1:1 hhid plotnum using `crops', keep(3)		// keep only maize plots

recode ag*a ag*b ag*c ag*d ag*e ag*f (.=0)					// correcting missing work days
gen cult_days_hired = ag_d47a + ag_d47c + ag_d52a + ag_d52b
gen harv_days_hired = ag_d48a + ag_d48c	+ ag_d54a + ag_d54b
gen cult_days_hired_withkids = cult_days_hired +0.5*ag_d47e + 0.5*ag_d52c	// children at 50% productivity
gen harv_days_hired_withkids = harv_days_hired +0.5*ag_d48e + 0.5*ag_d54c
collapse (sum) *days* , by(hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
ren case_id hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
drop if plotnum==.
duplicates drop hhid plotnum, force				// just that 1 problem case
drop if ag_d45==1					// drop the cross-sectional households
keep hhid plotnum ag_d42* ag_d43* ag_d44*
merge 1:1 hhid plotnum using `crops', keep(3)		// keep only maize plots
tempfile hhlabor
save `hhlabor', replace
keep hhid plotnum ag_d42*
renpfix ag_d42
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `hhworkers', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}

collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
use `hhlabor', clear
*weed
keep hhid plotnum ag_d43*
renpfix ag_d43
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `hhworkers', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed
}
collapse (sum) man woman child, by(hhid)
*pwb 11-Dec-2015 Added section to include harvest labor*
tempfile hhweed
save `hhweed', replace
use `hhlabor', clear
keep hhid plotnum ag_d44*
renpfix ag_d44
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `hhworkers', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
collapse (sum) man woman child, by(hhid)

merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
recode _all (.=0)
gen cult_days_hh = man_weed + man_prep + woman_weed + woman_prep
gen prep_days_hh = man_prep + woman_prep
gen weed_days_hh = man_weed + woman_weed
gen harv_days_hh = man_harv + woman_harv
gen cult_days_hh_withkids = man_weed + man_prep + woman_weed + woman_prep + child_weed + child_prep
gen prep_days_hh_withkids = man_prep + woman_prep + child_prep
gen weed_days_hh_withkids = man_weed + woman_weed + child_weed
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep hhid cult_days* harv_days* prep_days* weed_days*
merge 1:1 hhid using `hired_labor', assert(2 3) nogen
recode *hh* (.=0)

** BRING TOGETHER
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = prep_days_hh_withkids + weed_days_hh_withkids + cult_days_hired_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Malawi, Wave 1", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/MW1_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto MW1_out_lab



*********************************************************
*****************  malawi 2013 ******************************
********************  wave 2 ****************************
* weights
use "$data_MW/2013/Dataset/Household/HH_MOD_A_FILT", clear
destring ea_id , gen(ea)
ren y2_hhid hhid
ren case_id real_hhid
gen year = hh_a23b_3
replace year = hh_a23a_3 if year==.
gen month = hh_a23b_2
replace month = hh_a23a_2 if month==.
gen month_int = (month-1)/12
gen date_int = year+month_int
ren hh_a10a ta
ren hh_a10b dist_ta
tostring qx_type, replace
keep hhid HHID real_hhid hh_wgt district ta dist_ta qx_type hh_a05 ea ea_id month year month_int date_int
duplicates drop hhid, force
ren hh_wgt weight
tempfile MW2_weights
save `MW2_weights', replace


* demographics
use "$data_MW/2013/Dataset/Household/HH_MOD_B", clear
ren y2_hhid hhid
gen person = 1
ren hh_b01 personid
ren hh_b06_3a age
gen female = (hh_b03==2)
gen male = (hh_b03==1)
gen child = $child
gen man = male*(child==0)
gen woman = female*(child==0)
gen own_child = hh_b04==3
gen adult_children = own_child==1 & child==0
gen prime_noage = ($prime_noage)
gen aged_in = age>=15 & age<=18
gen aged_out = age>60 & age<=64

gen male_head = hh_b04==1 & male==1

label var female "Female"
label var child "Child"
rename hh_b04 reltohead
keep hhid personid man woman child female* male* age PID reltohead
tempfile MW2_demog
save `MW2_demog', replace

* determine which crop is on which plot
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
drop if plotnum==""
destring plotnum, replace
gen crop_code = 2 if ag_d20a < 5 | ag_d20b < 5 | ag_d20c < 5 | ag_d20d < 5 | ag_d20e < 5
keep if crop_code==2

keep hhid plotnum crop_code
tempfile crops
save `crops', replace



* get total harvested by household
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_BA", clear

* get region info
merge m:1 y2_hhid using "$data_MW/2013/Dataset/Household/HH_MOD_A_FILT", keep(3)

ren y2_hhid hhid
keep if ag_b0c < 5
keep ag_b0c hhid region ag_b04*

* Ox-cart is 468 kgs and a large pail is 18.05, 17.33, 17.75 in the north, center, south respectively (shelled)
* Unshelled weight is 0.83 less
gen wgt_temp = 0
replace wgt_temp = ag_b04a if ag_b04b==1			//kgs
replace wgt_temp = 50*ag_b04a if ag_b04b==2			// 50kg bags
replace wgt_temp = 90*ag_b04a if ag_b04b==3			// 90kg bags
replace wgt_temp = 468*ag_b04a if ag_b04b==12		// ox-carts
replace wgt_temp = 18.05*ag_b04a if ag_b04b==5 & region== 1			// large-pail North
replace wgt_temp = 17.33*ag_b04a if ag_b04b==5 & region== 2			// large-pail Center
replace wgt_temp = 17.75*ag_b04a if ag_b04b==5 & region== 3			// large-pail South
replace wgt_temp = wgt_temp * 0.83 if ag_b04c==2 & ag_b04b> 3		// convert for unshelled maize

collapse (sum) wgt_tot=wgt_temp, by(hhid)
tempfile crops_tot
save `crops_tot', replace



* area *
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
* we're going to treat the "others" as borrowed, based on the predominant answers to: list ag_d03_os if ag_d03_os~=""
merge 1:1 hhid plotnum using `crops', keep(3)		// keep only maize plots
ren ag_d03 ten
gen own = inlist(ten,1,2,3,4,5)
gen rent = inlist(ten,6,7,8)
gen borrow = inlist(ten,9,10,11)
ren ag_d14 use
replace use=1 if use==. & (rent==1 | borrow==1)		// assuming cultivated if rented/borrowed but usage variable is missing
duplicates drop hhid plotnum, force 				// 1 problem case
keep hhid plotnum own
tempfile owned
save `owned', replace


use "$data_MW/2013/Dataset/Agriculture/AG_MOD_C", clear
ren y2_hhid hhid
gen acres = ag_c04a if ag_c04b==1
replace acres = ag_c04a*2.471 if ag_c04b==2
replace acres = ag_c04a*0.000247105 if ag_c04b==3
replace acres = ag_c04c if acres==.			// use the GPS measure if the farmer estimate is missing
gen acresGPS = ag_c04c
gen plotnum = substr(ag_c00,2,2)
destring plotnum, replace
keep hhid plotnum acres acresGPS
gen numplots = 1
merge m:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
collapse (sum) owned_acres acres acresGPS numplots, by(hhid)
tempfile plots
save `plots', replace

* hired labor

* Malawi
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
destring y2_hhid, replace
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
duplicates drop hhid plotnum, force				// just that 1 problem case	
merge 1:1 hhid plotnum using `crops', keep(3)		// keep only maize plots						
keep hhid plotnum ag_d47* ag_d48* ag_d52* ag_d54*
drop if plotnum==.
drop *g *h *i *j
recode ag*a ag*b ag*c ag*d ag*e ag*f (.=0)					// correcting missing work days
gen cult_days_hired = ag_d47a + ag_d47c + ag_d52a + ag_d52b
gen harv_days_hired = ag_d48a + ag_d48c + ag_d54a + ag_d54b
gen cult_days_hired_withkids = cult_days_hired + 0.5*ag_d47e + 0.5*ag_d52c	// children at 50% productivity
gen harv_days_hired_withkids = harv_days_hired + 0.5*ag_d48e + 0.5*ag_d54c
collapse (sum) *days*, by(hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
destring y2_hhid, replace
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
drop if plotnum==.
duplicates drop hhid plotnum, force				// just that 1 problem case
merge 1:1 hhid plotnum using `crops', keep(3)		// keep only maize plots
keep hhid plotnum ag_d42* ag_d43* ag_d44*
tempfile hhlabor
save `hhlabor', replace
keep hhid plotnum ag_d42*
renpfix ag_d42
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `MW2_demog', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
use `hhlabor', clear
*weed
keep hhid plotnum ag_d43*
renpfix ag_d43
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `MW2_demog', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed
}
collapse (sum) man woman child, by(hhid)
tempfile hhweed
save `hhweed', replace
use `hhlabor', clear
*harv
keep hhid plotnum ag_d44*
renpfix ag_d44
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `MW2_demog', keep(3) nogen		// only 18 in master not matched
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}

collapse (sum) man woman child, by(hhid)

merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
recode man* woman* child* (.=0)
gen cult_days_hh = man_weed + man_prep + woman_weed + woman_prep
gen prep_days_hh = man_prep + woman_prep
gen weed_days_hh = man_weed + woman_weed
gen harv_days_hh = man_harv + woman_harv
gen cult_days_hh_withkids = man_weed + man_prep + woman_weed + woman_prep + child_weed + child_prep
gen prep_days_hh_withkids = man_prep + woman_prep + child_prep
gen weed_days_hh_withkids = man_weed + woman_weed + child_weed
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep hhid cult_days* harv_days* prep_days* weed_days*
merge 1:1 hhid using `hired_labor', assert(2 3) nogen


** BRING TOGETHER
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `MW2_weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = prep_days_hh_withkids + weed_days_hh_withkids + cult_days_hired_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Malawi, Wave 2", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/MW2_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto MW2_out_lab

estout MW*out_lab using "$path/output/MW_tpl_regs.tex", cells(b(star fmt(3)) se(par fmt(3))) ///
	stats(N r2, fmt(%10.0fc 2) labels("\hline Observations" "\$R^2\$")) ///
	starlevels(* 0.10 ** 0.05 *** 0.01) style(tex) nonumbers ///
	mlabels(none) coll(none) substitute(_ \_) replace

