clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



*******************************************
*******			 Malawi	2010-2011			********
***************    wave 1 ********************
********************************************

* weights
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_A_FILT", clear
destring case_id, replace
ren case_id hhid 
ren hh_a01 district
gen year = hh_a23c_2
replace year = hh_a23c_1 if year==.
gen month = hh_a23b_2
replace month = hh_a23b_1 if month==.
gen month_int = (month-1)/12
gen date_int = year+month_int
ren hh_a02 ta
ren hh_a02b dist_ta
keep hhid hh_wgt district ta dist_ta ea_id month year month_int date_int
egen distta = group(district ta)
duplicates drop hhid, force
ren hh_wgt weight
tempfile weights
save `weights', replace

* demographics
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_B", clear
destring case_id, replace
ren case_id hhid
ren hh_b01 personid
ren hh_b05a age
gen person = 1
gen female = (hh_b03==2)
gen male = (hh_b03==1)
gen own_child = hh_b04==3
gen child = $child
gen adult_children = own_child==1 & child==0
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
rename hh_b04 reltohead
keep hhid personid man woman child age qx_type visit male reltohead
tempfile hhworkers
save `hhworkers', replace
egen temp = group(qx_type)
drop if temp==1														// drop the cross-sectional households
drop temp
save "$newdata/MW1_hh_ages.dta", replace				// save individual level data to build LFP rate figures
restore

gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
gen hhsize_away = hhsize*(12-hh_b07)/12
gen hhsize_phase_away = hhsize_phase*(12-hh_b07)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename hh_b07 months_away
gen temp_migrant = months_away > 2 & age >=15

gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
collapse (sum) prime* eld* hhsize* adult* male* female* own_child child person (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile demog
save `demog', replace

*Age of househead age*
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_B", clear
destring case_id, replace
gen male_head = hh_b03==1 & hh_b04==1
ren case_id hhid
ren hh_b01 personid
gen agehhhead1 =  hh_b05a if hh_b04 ==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1 (max) male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* head education *
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_C", clear
destring case_id, replace
ren case_id hhid
keep if hh_c01==1
gen headeduc = hh_c08
replace headeduc = headeduc-5 if inlist(headeduc,20,21,22,23)		// training college is not post-university
replace headeduc = 0 if hh_c06==2
replace headeduc = hh_c08 if hh_c06==2 & hh_c08!=.
keep hhid headeduc
tempfile headeduc
save `headeduc', replace

* get hh consumption *
use "$data_MW/2010-2011/Dataset/Consumption aggregate/ihs3_summary.dta", clear
destring case_id, gen(hhid)
keep hhid rexpagg rexpaggcap hhsize
rename rexpaggcap exp_pc
tempfile hh_consum
save `hh_consum', replace


* get hh asset info *
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_L.dta", clear
destring case_id, gen(hhid)
keep hhid hh_l02 hh_l03
replace hh_l03 = 0 if hh_l03==.
reshape wide hh_l03, i(hhid) j(hh_l02)
factor hh_l03*, fa(1)
predict pc1_wealth, r
drop hh_l03*
tempfile hh_wealth
save `hh_wealth', replace

* get aez info*
use "$data_MW/2010-2011/Dataset/Geo-variables/HouseholdGeovariables.dta", clear
destring case_id, replace
ren case_id hhid
gen aez = 1 if ssa_ae==312
replace aez = 2 if ssa_ae==313
replace aez = 3 if aez==.
rename dist_auction dist_market
keep hhid aez dist_popcenter dist_market
isid hhid
tempfile geo
save `geo', replace


* area *
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
ren case_id hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
* we're treat the "others" as borrowed, based on the predominant answers to: list ag_d03_os if ag_d03_os~=""
ren ag_d03 ten
gen own = inlist(ten,1,2,3,4,5)
gen rent = inlist(ten,6,7,8)
gen borrow = inlist(ten,9,10,11)
ren ag_d14 use
replace use=1 if use==. & (rent==1 | borrow==1)		// assuming cultivated if rented/borrowed but usage variable is missing
gen maize = ag_d20a < 5 | ag_d20b < 5 | ag_d20c < 5 | ag_d20d < 5 | ag_d20e < 5
gen groundnut = (ag_d20a<17 & ag_d20a>10) | (ag_d20b<17 & ag_d20b>10) | (ag_d20c<17 & ag_d20c>10) | (ag_d20d<17 & ag_d20d>10) | (ag_d20e<17 & ag_d20e>10)
gen irrigated = ag_d28a!=7
gen fertilized = (ag_d36==1) | (ag_d38==1)
duplicates drop hhid plotnum, force
keep hhid plotnum own maize groundnut irrigated fertilized
tempfile owned
save `owned', replace


use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_C", clear
destring case_id, replace
ren case_id hhid
gen acres = ag_c04a if ag_c04b==1
replace acres = ag_c04a*2.471 if ag_c04b==2
replace acres = ag_c04a*0.000247105 if ag_c04b==3
replace acres = ag_c04c if acres==.			// use the GPS measure if the farmer estimate is missing
gen plotnum = substr(ag_c00,2,2)
destring plotnum, replace
gen acresGPS = ag_c04c
keep hhid plotnum acres acresGPS
gen numplots = 1
merge 1:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
gen acres_maize = maize*acres
gen acres_groundnut = groundnut*acres
collapse (sum) owned_acres acres* numplots (max) maize groundnut irrigated fertilized, by(hhid)
tempfile plots
save `plots', replace


* get crop sales info
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_B", clear
destring case_id, replace
ren case_id hhid
gen any_sold = ag_b06==1
collapse (max) any_sold, by(hhid)
tempfile sales
save `sales', replace


* hired labor

* Malawi
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
ren case_id hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
duplicates drop hhid plotnum, force
drop if ag_d45==1								// drop the cross-sectional households
keep hhid plotnum ag_d46* ag_d47* ag_d48* ag_d52* ag_d54*
drop if plotnum==.
drop *g *h *i *j *os
drop ag_d46*
recode ag*a ag*b ag*c ag*d ag*e ag*f (.=0)					// correcting missing work days
gen cult_days_hired = ag_d47a + ag_d47c + ag_d52a + ag_d52b
gen harv_days_hired = ag_d48a + ag_d48c	+ ag_d54a + ag_d54b
gen cult_days_hired_withkids = cult_days_hired +0.5*ag_d47e + 0.5*ag_d52c	// children at 50% productivity
gen harv_days_hired_withkids = harv_days_hired +0.5*ag_d48e + 0.5*ag_d54c
collapse (sum) *days* , by(hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_MW/2010-2011/Dataset/Agriculture/AG_MOD_D", clear
destring case_id, replace
ren case_id hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
drop if plotnum==.
duplicates drop hhid plotnum, force
drop if ag_d45==1					// drop the cross-sectional households
keep hhid plotnum ag_d42* ag_d43* ag_d44*
tempfile hhlabor
save `hhlabor', replace
keep hhid plotnum ag_d42*
renpfix ag_d42
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `hhworkers', keep(3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}
save "$newdata/MW1_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
use `hhlabor', clear
*weed
keep hhid plotnum ag_d43*
renpfix ag_d43
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `hhworkers', keep(3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed
}
save "$newdata/MW1_weed_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
*capture harvest labor*
tempfile hhweed
save `hhweed', replace
use `hhlabor', clear
keep hhid plotnum ag_d44*
renpfix ag_d44
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `hhworkers', keep(3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
save "$newdata/MW1_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)

merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
recode _all (.=0)
gen cult_days_hh = man_weed + man_prep + woman_weed + woman_prep
gen prep_days_hh = man_prep + woman_prep
gen weed_days_hh = man_weed + woman_weed
gen harv_days_hh = man_harv + woman_harv
gen cult_days_hh_withkids = man_weed + man_prep + woman_weed + woman_prep + child_weed + child_prep
gen prep_days_hh_withkids = man_prep + woman_prep + child_prep
gen weed_days_hh_withkids = man_weed + woman_weed + child_weed
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep hhid cult_days* harv_days* prep_days* weed_days*
merge 1:1 hhid using `hired_labor', assert(2 3) nogen
recode *hh* (.=0)

** BRING TOGETHER
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `demog', assert(2 3) keep(3) nogen
merge 1:1 hhid using `headeduc', assert(2 3) keep(3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `hh_consum', keep(3) nogen force
merge 1:1 hhid using `hh_wealth', keep(3) nogen force
merge 1:1 hhid using `geo', keep(1 3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen

tempfile MW_data
save `MW_data', replace


*********************************************************
*****************  malawi 2013 ******************************
********************  wave 2 ****************************
* weights
use "$data_MW/2013/Dataset/Household/HH_MOD_A_FILT", clear
destring ea_id , gen(ea)
ren y2_hhid hhid
ren case_id real_hhid
gen year = hh_a23b_3
replace year = hh_a23a_3 if year==.
gen month = hh_a23b_2
replace month = hh_a23a_2 if month==.
gen month_int = (month-1)/12
gen date_int = year+month_int
ren hh_a10a ta
ren hh_a10b dist_ta
tostring qx_type, replace
keep hhid HHID real_hhid hh_wgt district ta dist_ta qx_type hh_a05 ea ea_id month year month_int date_int
duplicates drop hhid, force
ren hh_wgt weight
tempfile MW2_weights
save `MW2_weights', replace


* demographics
use "$data_MW/2013/Dataset/Household/HH_MOD_B", clear
ren y2_hhid hhid
gen person = 1
ren hh_b01 personid
ren hh_b06_3a age
gen female = (hh_b03==2)
gen male = (hh_b03==1)
gen child = $child
gen man = male*(child==0)
gen woman = female*(child==0)
gen own_child = hh_b04==3
gen adult_children = own_child==1 & child==0
gen prime_noage = ($prime_noage)
gen aged_in = age>=15 & age<=18
gen aged_out = age>60 & age<=64

gen male_head = hh_b04==1 & male==1
preserve
label var female "Female"
label var child "Child"
rename hh_b04 reltohead
keep hhid personid man woman child female* male* age PID reltohead
tempfile MW2_demog
save `MW2_demog', replace
save "$newdata/MW2_hh_ages.dta", replace				// save individual level data to build LFP rate figures
restore

rename hhsize reported_hhsize
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen hhsize_phase = hhsize
replace hhsize_phase = 1 if age>60 & age!=.
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
gen hhsize_away = hhsize*(12-hh_b07)/12
gen hhsize_phase_away = hhsize_phase*(12-hh_b07)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename hh_b07 months_away
gen temp_migrant = months_away > 2 & age >=15

gen recent_migrant = hhsize*hh_b06_1==99
gen hhsize_child = 1
foreach i in 10 11 12 13{
	gen hhsize_`i' = age>`i'
}
gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
tempfile ind_mw2
save `ind_mw2', replace
collapse (max) reported_hhsize recent_migrant (sum) person aged* prime* eld* hhsize* own_child child male* female* (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile MW2_prime
save `MW2_prime', replace

*Age of househead age*
use "$data_MW/2013/Dataset/Household/HH_MOD_B", clear
ren y2_hhid hhid
ren hh_b01 personid
gen agehhhead1 =  hh_b06_3a if hh_b04 ==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1, by(hhid)
tempfile household_headage 
save `household_headage', replace

* head education *
use "$data_MW/2013/Dataset/Household/HH_MOD_C", clear
ren y2_hhid hhid
keep if hh_c01==1
gen headeduc = hh_c08
replace headeduc = headeduc-5 if inlist(headeduc,20,21,22,23)		// training college is not post-university
replace headeduc = 0 if hh_c06==2
replace headeduc = hh_c08 if hh_c06==2 & hh_c08!=.
keep hhid headeduc
tempfile headeduc
save `headeduc', replace


* area *
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
* we treat the "others" as borrowed, based on the predominant answers to: list ag_d03_os if ag_d03_os~=""
ren ag_d03 ten
gen own = inlist(ten,1,2,3,4,5)
gen rent = inlist(ten,6,7,8)
gen borrow = inlist(ten,9,10,11)
ren ag_d14 use
replace use=1 if use==. & (rent==1 | borrow==1)		// assuming cultivated if rented/borrowed but usage variable is missing
gen maize = ag_d20a < 5 | ag_d20b < 5 | ag_d20c < 5 | ag_d20d < 5 | ag_d20e < 5
gen groundnut = (ag_d20a<17 & ag_d20a>10) | (ag_d20b<17 & ag_d20b>10) | (ag_d20c<17 & ag_d20c>10) | (ag_d20d<17 & ag_d20d>10) | (ag_d20e<17 & ag_d20e>10)
gen irrigated = ag_d28a!=7
gen fertilized = (ag_d36==1) | (ag_d38==1)
duplicates drop hhid plotnum, force
keep hhid plotnum own maize groundnut irrigated fertilized

tempfile owned
save `owned', replace


use "$data_MW/2013/Dataset/Agriculture/AG_MOD_C", clear
ren y2_hhid hhid
gen acres = ag_c04a if ag_c04b==1
replace acres = ag_c04a*2.471 if ag_c04b==2
replace acres = ag_c04a*0.000247105 if ag_c04b==3
replace acres = ag_c04c if acres==.			// use the GPS measure if the farmer estimate is missing
gen acresGPS = ag_c04c
gen plotnum = substr(ag_c00,2,2)
destring plotnum, replace
keep hhid plotnum acres acresGPS
gen numplots = 1
merge m:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
gen acres_maize = maize*acres
gen acres_groundnut = groundnut*acres
collapse (sum) owned_acres acres* numplots (max) maize groundnut irrigated fertilized, by(hhid)
tempfile plots
save `plots', replace


* get crop sales info
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_BA", clear
rename y2_hhid hhid
gen any_sold = ag_b06==1
collapse (max) any_sold, by(hhid)
tempfile sales
save `sales', replace


* hired labor

* Malawi
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
destring y2_hhid, replace
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
duplicates drop hhid plotnum, force								
keep hhid plotnum ag_d47* ag_d48* ag_d52* ag_d54*
drop if plotnum==.
drop *g *h *i *j
recode ag*a ag*b ag*c ag*d ag*e ag*f (.=0)					// correcting missing work days
gen cult_days_hired = ag_d47a + ag_d47c + ag_d52a + ag_d52b
gen harv_days_hired = ag_d48a + ag_d48c + ag_d54a + ag_d54b
gen cult_days_hired_withkids = cult_days_hired + 0.5*ag_d47e + 0.5*ag_d52c	// children at 50% productivity
gen harv_days_hired_withkids = harv_days_hired + 0.5*ag_d48e + 0.5*ag_d54c
collapse (sum) *days*, by(hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_MW/2013/Dataset/Agriculture/AG_MOD_D", clear
destring y2_hhid, replace
ren y2_hhid hhid
gen plotnum = substr(ag_d00,2,2)
destring plotnum, replace
drop if plotnum==.
duplicates drop hhid plotnum, force
keep hhid plotnum ag_d42* ag_d43* ag_d44*
tempfile hhlabor
save `hhlabor', replace
keep hhid plotnum ag_d42*
renpfix ag_d42
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `MW2_demog', keep(3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep
}
save "$newdata/MW2_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
use `hhlabor', clear
*weed
keep hhid plotnum ag_d43*
renpfix ag_d43
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `MW2_demog', keep(3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed
}
save "$newdata/MW2_weed_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhweed
save `hhweed', replace
use `hhlabor', clear
*harv
keep hhid plotnum ag_d44*
renpfix ag_d44
ren a personid1
gen hours1 = b*c*d
ren e personid2
gen hours2 = f*g*h
ren i personid3
gen hours3 = j*k*l
ren m personid4
gen hours4 = n*o*p
order hhid plotnum person* hours*
drop b-p
reshape long personid hours, i(hhid plotnum) j(num)
drop if personid==.
collapse (sum) hours, by(hhid personid)
gen days = round(hours/6)											// the mode is 5-6 hours so we are calling that a full day
drop hours
merge 1:1 hhid personid using `MW2_demog', keep(3) nogen
foreach i of varlist child man woman {
	replace `i' = `i'*days if age>=15
	replace `i' = (age-10)*0.2*`i'*days if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv
}
save "$newdata/MW2_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)

merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
recode man* woman* child* (.=0)
gen cult_days_hh = man_weed + man_prep + woman_weed + woman_prep
gen prep_days_hh = man_prep + woman_prep
gen weed_days_hh = man_weed + woman_weed
gen harv_days_hh = man_harv + woman_harv
gen cult_days_hh_withkids = man_weed + man_prep + woman_weed + woman_prep + child_weed + child_prep
gen prep_days_hh_withkids = man_prep + woman_prep + child_prep
gen weed_days_hh_withkids = man_weed + woman_weed + child_weed
gen harv_days_hh_withkids = man_harv + woman_harv + child_harv
keep hhid cult_days* harv_days* prep_days* weed_days*
merge 1:1 hhid using `hired_labor', assert(2 3) nogen


** BRING TOGETHER
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `MW2_weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `headeduc', keep(1 3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `MW2_prime', assert(2 3) keep(3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen

*Renaming variables to allow proper merging for analysis
ren hhid y2_hhid
ren real_hhid hhid
destring hhid, replace
format %18.0g hhid
tempfile MW2_data
save `MW2_data', replace




**********************************
****
****    Combine panel and construct key labor demand variables
****
**********************************

***********
** Malawi
***********
use `MW_data', clear
la val dist_ta 
tostring dist_ta, replace
append using `MW2_data', gen(wave2)
format %18.0g hhid
gen wave = wave2+1
gen hhid_t = string(hhid,"%16.0g")
gen check = length(hhid_t)
assert check==12
drop hhid check
ren hhid_t hhid
tab hh_a05
duplicates tag hhid wave, gen(duptag)
assert duptag==0 if wave==1
tab duptag if wave==2
bys hh_a05: tab duptag if wave==2
drop duptag
drop if hh_a05==2	// drop those that are identified as splits
bys hhid: egen wave_count = count(wave)		// Counting observations
duplicates tag hhid wave, gen(duptag)
gen three_digits = substr(y2_hhid,-3,.)		// Dropping a couple of "splits" (denoted by the last two digits not being 01, when there is another household that is 01)
replace three_digits ="" if duptag==0
destring three_digits, replace
egen mingroup = min(three_digits) if wave==2 & duptag>0, by(hhid)
drop if duptag>0 & three_digits!=mingroup
drop duptag three_digits mingroup wave_count
codebook *hhid* if wave==2, compact

label var hhsize "Household size"
label var cult_days_hh "Total household labor"
label var cult_days_hired "Total hired labor"
label var owned_acres "Acres owned"
label var acres "Acres farmed"
label var numplots "Number of plots"
label var male_head "Male head of household"

*Recoding
recode *days* (.=0)
recode owned_acres (.=0)
recode acres (.=0)
recode numplots (.=0)

** Make a number of possible labor demand measures
* No children
gen ld_cult_nokids = prep_days_hh + weed_days_hh + cult_days_hired 
la var ld_cult_nokids "LD: no kids; prep, weed; waves 1-2"
gen ld_harv_nokids = harv_days_hh + harv_days_hired
la var ld_harv_nokids "LD: no kids; harv only; waves 1-2"
gen ld_tot_nokids = ld_cult_nokids + ld_harv_nokids
la var ld_tot_nokids "LD: no kids; prep, weed, harv; waves 1-2"

* With children
gen ld_cult_kids = prep_days_hh_withkids + weed_days_hh_withkids + cult_days_hired_withkids
la var ld_cult_kids "LD: incl. kids; prep, weed, fert; "
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
la var ld_harv_kids "LD: incl. kids; harv only; waves 1-2"
gen ld_tot_kids = ld_cult_kids + ld_harv_kids
la var ld_tot_kids "LD: incl. kids; prep, weed, fert, harv; waves 1-2"

** dropping households with no labor demand ever or no acreage planted ever
bysort hhid: egen temp_ld = sum(ld_tot_kids)
by hhid: egen temp_A = sum(acres)
drop if temp_ld == 0
drop if temp_A == 0
drop temp_ld temp_A

foreach i of varlist ld_* {
	gen log_`i' = ln(`i')
	local label : variable label `i'
	label variable log_`i' `"Log `label''"'
	replace log_`i' = ln($no_work) if `i'==0
}

gen log_ld = ln(cult_days_hh + cult_days_hired)
gen log_harv = ln(harv_days_hh + harv_days_hired)
replace log_harv = ln(0.01) if log_harv==.
gen log_A = ln(acres)
replace log_A = ln(0.01) if log_A==.
gen log_AGPS = ln(acresGPS)
replace owned_acres = owned_acres + 0.01 if log_A!=. & owned_acres==0		// replace the ownership zeros so that sample size is identical to log_A sample size
gen log_owned = ln(owned_acres)
gen log_hhsize = ln(hhsize)
gen log_phase = ln(hhsize_phase)
gen log_hhaway = ln(hhsize_away)
gen log_phase_away = ln(hhsize_phase_away)
drop if hhsize_phase == 0 
replace log_hhsize = ln(0.01) if hhsize==0
replace log_phase_away = ln(0.01) if hhsize_phase_away==0
gen zero_hhsize = hhsize==0
gen share_pm = prime_male/person
gen share_pf = prime_female/person
gen share_em = eld_male/person
gen share_ef = eld_female/person
gen age_head1 = agehhhead1
gen age_squared1 = agehhead_squared1
gen female_head = 1-male_head
gen female_hhsize = female_head*log_hhsize
replace age_squared1 = age_squared1/1000
la var log_ld "Log of labor demanded"
la var log_harv "Log of harvest labor demanded"
la var log_A "Log acres cultivated"
la var log_owned "Log acres owned"
la var log_hhsize "Log HH size (15<=age<=60)"
la var log_phase "Log HH size with phase-in and out"
la var share_pm "Prime male share"
la var share_pf "Prime female share"
la var share_em "Elderly male share"
la var share_ef "Elderly female share"
la var age_head1 "Age of household head"
la var age_squared1 "Age of household head squared (000s)"
la var female_head "Female head of household"
la var female_hhsize "Log of household size for female heads"
la var hhsize "Household size"
la var owned_acres "Acres owned"
la var acres "Acres farmed"
la var numplots "Number of plots"
la var male_head "Male head of household"
la var owned_acres "Acres owned"

* Drop households with no acreage cultivated
drop if acres==0

* winsorizing top 5 largest acres, owned_acres, exp_pc
foreach var in acres owned_acres exp_pc {
	di "var = `var'"
	gsort - `var'
	forvalues i=1/5 {
		di "var=`var' and i=`i'"
		replace `var' = `var'[6] in `i'
	}
}

*set up EA to use for village level IV
rename ea_id ea1

* vars for hhsize by gender
gen log_male = ln(male_phase)
replace log_male = ln(0.1) if male_phase==0
gen log_female = ln(female_phase)
replace log_female = ln(0.1) if female_phase==0
gen log_male_nokids = ln(hhsize_male)
replace log_male_nokids = ln(0.1) if hhsize_male==0
gen log_female_nokids = ln(hhsize_female)
replace log_female_nokids = ln(0.1) if hhsize_female ==0

keep hhsize* log* ld* hhid wave* age* numpl  *acres* male* female* prime* eld* share_* ///
 female_head ta district female_hhsize *educ exp_pc pc1_wealth aez ea1 months_away dist* ///
 maize groundnut fertilized irrigated any_* temp_migrant
drop wave2


save "$newdata/Malawi Panel Data Clean", replace


destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave

*Generating region/district FE:
egen dist_wave_FE = group(district wave)

* Wealth categories in Wave 1
sum exp_pc if wave==1, det
local cut50 = r(p50)
gen temp = exp_pc<`cut50' & wave==1
bysort hhid: egen poor50 = sum(temp)
replace temp = exp_pc>=`cut50' & wave==1
bysort hhid: egen exp_rich50 = sum(temp)
drop temp

* Wealth categories by asset index
sum pc1_wealth, det
local cut50 = r(p50)
gen temp = pc1_wealth <`cut50' & wave==1
bysort hhid: egen asset_poor50 = sum(temp)
replace temp = pc1_wealth>=`cut50' & wave==1
bysort hhid: egen asset_rich50 = sum(temp)
drop temp
gen rich50 = exp_rich50

* Spread AEZ info across waves
bysort hhid: egen ae_zone = max(aez)

local controls log_A


****** create vars for whether household increased or decreased in size *******
sort hhid wave
by hhid: gen increase = ($hhsize_var>$hhsize_var[_n-1]) if _n==2
by hhid: gen decrease = ($hhsize_var<$hhsize_var[_n-1]) if _n==2
by hhid: gen male_inc = (male_phase>male_phase[_n-1]) if _n==2
by hhid: gen male_dec = (male_phase<male_phase[_n-1]) if _n==2
by hhid: gen female_inc = (female_phase>female_phase[_n-1]) if _n==2
by hhid: gen female_dec = (female_phase<female_phase[_n-1]) if _n==2

****** create vars for agricultural activity, with kids phased in *******
rename log_ld_cult_kids act_log_ld_0
rename log_ld_harv_kids act_log_ld_1
label define act_labels 0 "Pre-Harvest w/ Kids" 1 "Harvest"

reshape long act_log_ld_, i(hhid wave) j(activity)
label values activity act_labels
rename act_log_ld_ act_log_ld

local dep_var act_log_ld

foreach i of varlist `dep_var' log_phase log_hhsize log_phase_away log_male log_female share_pm share_pf share_em log_A log_owned log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

gen INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
gen DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_male = diff_log_male*male_inc
gen DEC_male = diff_log_male*male_dec
gen INC_female = diff_log_female*female_inc
gen DEC_female = diff_log_female*female_dec

la var INC_hhsize "Increase in HH Size"
la var DEC_hhsize "Decrease in HH Size"
la var INC_male "Increase in Male HH Size"
la var DEC_male "Decrease in Male HH Size"
la var INC_female "Increase in Female HH Size"
la var DEC_female "Decrease in Female HH Size"
label define rich_labels 1 "Top 50\% Wealth" 0 "Bottom 50\% Wealth"
label values rich50 rich_labels
label var rich50 "Top 50\% Wealth"
label var log_hhsize "Log(HH Size)"

save "$newdata/MW_reg_ready", replace		// to be used in the file "Combined analysis.do"
