* pwb	18-Dec-2017	create variable for hhsize by gender with nokids

clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



********************************************
********************************************
*******			 Tanzania			********
*******			  Wave 1			********
*******			 2008-2009			********
********************************************
********************************************


* weights
use "$data_TZ/2008-2009/Dataset/Household/SEC_A_T", clear
gen y1_hhid = hhid
renpfix hh_
gen year = sa2q18y
gen month = sa2q18m
gen month_int = (month-1)/12
gen date_int = year+month_int
egen distgroup = group(region district)
gen ea1 = ea + 1000*locality + 10000*ward + 1000000*district + 10000000*region
gen ward1 = ward + 100*district + 1000*region
keep hhid weight weight_trimmed region dist* month year month_int date_int y1_hhid ea1 ward1
duplicates drop hhid, force				// 0 duplicates
tempfile weights
save `weights', replace


* demographics
use "$data_TZ/2008-2009/Dataset/Household/SEC_B_C_D_E1_F_G1_U", clear
gen person = 1
ren sbq4 age
ren sbmemno indid
gen female = (sbq2==2)
gen male = (sbq2==1)
gen child = $child
gen own_child = sbq5==3
gen adult_children = own_child==1 & child==0
gen man = male*(child==0)
gen woman = female*(child==0)
ren sbq5 reltohead
keep hhid indid man woman child age male reltohead
tempfile hhworkers
save `hhworkers', replace


* determine which crop is on which plot
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep if s3aq5code==11
rename s3aq5code crop_code
keep hhid plotnum crop_code
tempfile crops
save `crops', replace

* get total harvested by household
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_4A", clear
rename zaocode crop_code
keep if crop_code==11
collapse (sum) wgt_tot=s4aq15, by(hhid)
tempfile crops_tot
save `crops_tot', replace


* plots and crops
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
merge 1:1 hhid plotnum using `crops', keep(3) nogen			// keep only plots with maize
ren s3aq22 ten
gen own = (ten==1 | ten==5)
keep hhid plotnum own
tempfile owned
save `owned', replace


use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_2A", clear
ren s2aq4 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
destring plotnum, replace
keep hhid plotnum acres
gen numplots = 1
merge 1:1 hhid plotnum using `owned', keep(3) nogen
gen owned_acres=acres*own
collapse (sum) owned_acres acres numplots, by(hhid)
tempfile plots
save `plots', replace


* hired labor
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren s3aq62 hire
recode hire (2=0)
recode s3aq63_* (.=0)
merge 1:1 hhid plotnum using `crops', keep(3)			// keep only plots with maize

ren s3aq63_1 man_prep_days
ren s3aq63_2 woman_prep_days
ren s3aq63_4 man_weed_days
ren s3aq63_5 woman_weed_days
ren s3aq63_7 man_harv_days
ren s3aq63_8 woman_harv_days
gen harv_days_hired = man_harv_days + woman_harv_days
gen prep_days_hired = man_prep_days + woman_prep_days
gen weed_days_hired = man_weed_days + woman_weed_days
gen harv_days_hired_withkids = harv_days_hired
gen prep_days_hired_withkids = prep_days_hired
gen weed_days_hired_withkids = weed_days_hired
collapse (sum) prep_d* weed_d* harv_d*, by(hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep hhid plotnum s3aq61*		
merge 1:1 hhid plotnum using `crops', keep(3)			// keep only plots with maize
	
** prep
preserve
keep hhid plotnum s3aq61_id1-s3aq61_12
renpfix s3aq61_ prep
reshape long prepid prep, i(hhid plotnum) j(num)
drop if prepid==.
ren prepid indid
collapse (sum) prep, by(hhid indid)
merge 1:1 hhid indid using `hhworkers', keep(1 3)	
tab prep if _merge==1		// only 6 umatched of the unmatched have non-zero prep labor
keep if _merge==3			
drop _merge
foreach i of varlist man woman child {
	replace `i' = `i'*prep if age>=15
	replace `i' = (age-10)*0.2*`i'*prep if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep_days
}
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
restore

** weed
preserve
keep hhid plotnum s3aq61_id13-s3aq61_24
renpfix s3aq61_ weed
reshape long weedid weed, i(hhid plotnum) j(num)
drop if weedid==.
ren weedid indid
collapse (sum) weed, by(hhid indid)
merge 1:1 hhid indid using `hhworkers', keep(1 3) 
tab weed if _merge==1	// only a handful of the unmatched have non-zero weed labor
keep if _merge==3
drop _merge
foreach i of varlist man woman child {
	replace `i' = `i'*weed if age>=15
	replace `i' = (age-10)*0.2*`i'*weed if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed_days
}
collapse (sum) man woman child, by(hhid)
tempfile hhweed
save `hhweed', replace
restore


*harv
keep hhid plotnum s3aq61_id25-s3aq61_36
renpfix s3aq61_ harv
reshape long harvid harv, i(hhid plotnum) j(num)
drop if harvid==.
ren harvid indid
collapse (sum) harv, by(hhid indid)
merge 1:1 hhid indid using `hhworkers', keep(1 3)
tab harv if _merge==1			// only a few of the unmatched have non-zero harv labor
keep if _merge==3
drop _merge
foreach i of varlist man woman child {
	replace `i' = `i'*harv if age>=15
	replace `i' = (age-10)*0.2*`i'*harv if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv_days
}
collapse (sum) man woman child, by(hhid)
merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
recode man* woman* child* (.=0)
** bd - keep labor disaggregated for the moment
gen harv_days_hh = man_harv_days + woman_harv_days
gen prep_days_hh = man_prep_days + woman_prep_days
gen weed_days_hh = man_weed_days + woman_weed_days
gen harv_days_hh_withkids = man_harv_days + woman_harv_days + child_harv_days
gen prep_days_hh_withkids = man_prep_days + woman_prep_days + child_prep_days
gen weed_days_hh_withkids = man_weed_days + woman_weed_days + child_weed_days
collapse (sum) prep_d* weed_d* harv_d*, by(hhid)
merge 1:1 hhid using `hired_labor', assert(2 3) nogen		// All matched from master
recode *_hh* (.=0)


** BRING TOGETHER
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = prep_days_hh_withkids + prep_days_hired_withkids
gen ld_weed_kids = weed_days_hh_withkids + weed_days_hired_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids + ld_weed_kids


* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Tanzania, Wave 1", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/TZ1_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto TZ1_out_lab




********************************************
********************************************
*******			 Tanzania			********
*******			  Wave 2			********
*******			 2010-2011			********
********************************************
********************************************

* weights
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_A", clear
*merge 1:1 y2_hhid using `y2splits', assert(3) nogen
gen hhid_y2 = y2_hhid
renpfix y2_
gen person = 1
gen splits = hh_a11==3
gen year = hh_a18_year
gen month = hh_a18_month
gen month_int = (month-1)/12
gen date_int = year+month_int
egen distgroup = group(region district)
gen ward2 = ward + 1000*district + 10000*region
keep hhid weight region dist* month year month_int date_int splits hhid_y2 hh_a11 ward2
duplicates drop hhid, force
tempfile weights
save `weights', replace

* demographics
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_B", clear
gen hhid_indmerge = hhid_2008
gen hhidtemp = y2_hhid
renpfix y2_
gen person = 1
ren hh_b04 age
gen female = (hh_b02==2)
gen male = (hh_b02==1)
gen child = $child
gen own_child = hh_b05==3
gen adult_children = own_child==1 & child==0
gen man = male*(child==0)
gen woman = female*(child==0)
ren hh_b05 reltohead
keep hhid indidy2 man woman child age male reltohead
tempfile hhworkers
save `hhworkers', replace

* determine which crop is on which plot
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep if zaocode==11
rename zaocode crop_code
keep hhid plotnum crop_code
tempfile crops
save `crops', replace

* get total harvested by household
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC4A", clear
renpfix y2_
rename zaocode crop_code
keep if crop_code==11
collapse (sum) wgt_tot=ag4a_15, by(hhid)
tempfile crops_tot
save `crops_tot', replace


* plots and crops
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
merge 1:1 hhid plotnum using `crops', keep(3)		//keep only plots of maize
ren ag3a_24 ten
gen own = (ten==1 | ten==5)
keep hhid plotnum own
tempfile owned
save `owned', replace

use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC2A", clear
renpfix y2_
ren ag2a_04 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep hhid plotnum acres
merge 1:1 hhid plotnum using `owned', nogen
gen owned_acres = acres*own
gen numplots = 1
collapse (sum) owned_acres acres numplots, by(hhid)
tempfile plots
save `plots', replace

use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC2A", clear
renpfix y2_
ren ag2a_04 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
destring plotnum, replace
keep hhid plotnum acres
gen numplots = 1
merge 1:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
collapse (sum) owned_acres acres numplots, by(hhid)
tempfile plots
save `plots', replace


* hired labor
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren ag3a_71 hire
recode hire (2=0)
recode ag3a_72_* (.=0)
merge 1:1 hhid plotnum using `crops', keep(3)		//keep only plots of maize

ren ag3a_72_1 woman_prep_days
ren ag3a_72_2 man_prep_days
ren ag3a_72_21 child_prep_days
ren ag3a_72_4 woman_weed_days
ren ag3a_72_5 man_weed_days
ren ag3a_72_51 child_weed_days
ren ag3a_72_61 woman_fert_days
ren ag3a_72_62 man_fert_days
ren ag3a_72_63 child_fert_days
ren ag3a_72_7 woman_harv_days
ren ag3a_72_8 man_harv_days
ren ag3a_72_81 child_harv_days
gen harv_days_hired = man_harv_days + woman_harv_days
gen prep_days_hired = man_prep_days + woman_prep_days
gen weed_days_hired = man_weed_days + woman_weed_days
gen fert_days_hired = man_fert_days + woman_fert_days
gen harv_days_hired_withkids = man_harv_days + woman_harv_days + 0.5*child_harv_days
gen prep_days_hired_withkids = man_prep_days + woman_prep_days + 0.5*child_prep_days
gen weed_days_hired_withkids = man_weed_days + woman_weed_days + 0.5*child_weed_days
gen fert_days_hired_withkids = man_fert_days + woman_fert_days + 0.5*child_fert_days
collapse (sum) prep_d* weed_d* fert_d* harv_d*, by(hhid)
tempfile hired_labor
save `hired_labor', replace

* family labor demand
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep hhid plotnum ag3a_70*			// NOTE: the enumerator manual does not indicate an age cut-off for "child" status among hired workers
merge 1:1 hhid plotnum using `crops', keep(3)		//keep only plots of maize
** prep								// 		 above, I defined children as those <15 yrs
preserve
keep hhid plotnum ag3a_70_id1-ag3a_70_6
renpfix ag3a_70_ prep
reshape long prepid prep, i(hhid plotnum) j(num)
drop if prepid==.
ren prepid indidy2
collapse (sum) prep, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers', keep(1 3)		// only 3 in master not matched
tab prep if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*prep if age>=15
	replace `i' = (age-10)*0.2*`i'*prep if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep_days
}
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
restore

** weed
preserve
keep hhid plotnum ag3a_70_id13-ag3a_70_18
renpfix ag3a_70_ weed
reshape long weedid weed, i(hhid plotnum) j(num)
drop if weedid==.
ren weedid indidy2
collapse (sum) weed, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers', keep(1 3)
tab weed if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*weed if age>=15
	replace `i' = (age-10)*0.2*`i'*weed if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed_days
}
collapse (sum) man woman child, by(hhid)
tempfile hhweed
save `hhweed', replace
restore

** fert
preserve
keep hhid plotnum ag3a_70_id37-ag3a_70_42
renpfix ag3a_70_ fert
reshape long fertid fert, i(hhid plotnum) j(num)
drop if fertid==.
ren fertid indidy2
collapse (sum) fert, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers', keep(1 3)
tab fert if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*fert if age>=15
	replace `i' = (age-10)*0.2*`i'*fert if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_fert_days
}
collapse (sum) man woman child, by(hhid)
tempfile hhfert
save `hhfert', replace
restore
*harv
keep hhid plotnum ag3a_70_id25-ag3a_70_30
renpfix ag3a_70_ harv
reshape long harvid harv, i(hhid plotnum) j(num)
drop if harvid==.
ren harvid indidy2
collapse (sum) harv, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers'
tab harv if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*harv if age>=15
	replace `i' = (age-10)*0.2*`i'*harv if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv_days
}
collapse (sum) man woman child, by(hhid)
merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
merge 1:1 hhid using `hhfert', nogen
recode man* woman* child* (.=0)

** bd - keep labor disaggregated for the moment
gen harv_days_hh = man_harv_days + woman_harv_days
gen prep_days_hh = man_prep_days + woman_prep_days
gen weed_days_hh = man_weed_days + woman_weed_days
gen fert_days_hh = man_fert_days + woman_fert_days
gen harv_days_hh_withkids = man_harv_days + woman_harv_days + child_harv_days
gen prep_days_hh_withkids = man_prep_days + woman_prep_days + child_prep_days
gen weed_days_hh_withkids = man_weed_days + woman_weed_days + child_weed_days
gen fert_days_hh_withkids = man_fert_days + woman_fert_days + child_fert_days
collapse (sum) prep_d* weed_d* harv_d* fert_d*, by(hhid)
merge 1:1 hhid using `hired_labor', assert(2 3) nogen		// All matched from master
recode *_hh* (.=0)


** BRING TOGETHER
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = prep_days_hh_withkids + prep_days_hired_withkids
gen ld_weed_kids = weed_days_hh_withkids + weed_days_hired_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids + ld_weed_kids + fert_days_hh_withkids + fert_days_hired_withkids


* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Tanzania, Wave 2", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/TZ2_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto TZ2_out_lab


tempfile TZ2_data
save `TZ2_data', replace


********************************************
********************************************
*******			 Tanzania			********
*******			  Wave 3			********
*******			 2012-2013			********
********************************************
********************************************

* weights
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_A", clear
*merge 1:1 y3_hhid using `y3splits', assert(3) nogen
gen year = hh_a18_3
gen month = hh_a18_2
gen month_int = (month-1)/12
gen date_int = year+month_int
gen region = hh_a01_1
gen district = hh_a02_1
egen distgroup = group(region district)
gen ward3 = hh_a03_1 + 1000*district + 10000*region
gen weight = y3_weight
ren hh_a11 location_y3
keep y3_hhid weight y3_weight region dist* month year month_int date_int location  hh_a10 ward3
duplicates drop y3_hhid, force
tempfile weights
save `weights', replace

* demographics
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_B", clear
gen hhid3_ind = y2_hhid
gen hhid_y2 = y2_hhid
gen person = 1
ren hh_b04 age
gen female = (hh_b02==2)
gen male = (hh_b02==1)
gen child = $child
gen own_child = hh_b05==3
gen adult_children = own_child==1 & child==0

gen man = male*(child==0)
gen woman = female*(child==0)
ren hh_b05 reltohead
keep y3_hhid indidy3 man woman child age male reltohead
tempfile hhworkers
save `hhworkers', replace


* determine which crop is on which plot
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep if ag3a_07_2==11
rename ag3a_07_2 crop_code
keep y3_hhid plotnum crop_code
tempfile crops
save `crops', replace

* get total harvested by household
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_4A", clear
rename zaocode crop_code
keep if crop_code==11
collapse (sum) wgt_tot=ag4a_28, by(y3_hhid)
tempfile crops_tot
save `crops_tot', replace


* plots and crops
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
merge 1:1 y3_hhid plotnum using `crops', keep(3)			//keep only plots with maize
ren ag3a_25 ten
gen own = (ten==1 | ten==5)
keep y3_hhid plotnum own
tempfile owned
save `owned', replace

use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_2A", clear
ren ag2a_04 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep y3_hhid plotnum acres
gen numplots = 1
merge 1:1 y3_hhid plotnum using `owned', keep(3) nogen
gen owned_acres=acres*own
collapse (sum) owned_acres acres numplots, by(y3_hhid)
tempfile plots
save `plots', replace


* hired labor
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren ag3a_73 hire
recode hire (2=0)
recode ag3a_74_* (.=0)
merge 1:1 y3_hhid plotnum using `crops', keep(3)			//keep only plots with maize

* notation from wave 2:
ren ag3a_74_1 woman_prep_days
ren ag3a_74_2 man_prep_days
ren ag3a_74_3 child_prep_days
ren ag3a_74_5 woman_weed_days
ren ag3a_74_6 man_weed_days
ren ag3a_74_7 child_weed_days
ren ag3a_74_9 woman_fert_days
ren ag3a_74_10 man_fert_days
ren ag3a_74_11 child_fert_days
ren ag3a_74_13 woman_harv_days
ren ag3a_74_14 man_harv_days
ren ag3a_74_15 child_harv_days
gen harv_days_hired = man_harv_days + woman_harv_days
gen prep_days_hired = man_prep_days + woman_prep_days
gen weed_days_hired = man_weed_days + woman_weed_days
gen fert_days_hired = man_fert_days + woman_fert_days
gen harv_days_hired_withkids = man_harv_days + woman_harv_days + 0.5*child_harv_days
gen prep_days_hired_withkids = man_prep_days + woman_prep_days + 0.5*child_prep_days
gen weed_days_hired_withkids = man_weed_days + woman_weed_days + 0.5*child_weed_days
gen fert_days_hired_withkids = man_fert_days + woman_fert_days + 0.5*child_fert_days
collapse (sum) prep_d* weed_d* fert_d* harv_d*, by(y3_hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep y3_hhid plotnum ag3a_72*			// NOTE: the enumerator manual does not indicate an age cut-off for "child" status among hired workers
merge 1:1 y3_hhid plotnum using `crops', keep(3)			//keep only plots with maize

** prep								// 		 above, I defined children as those <15 yrs
preserve
keep y3_hhid plotnum ag3a_72_id1-ag3a_72_6
renpfix ag3a_72_ prep
reshape long prepid prep, i(y3_hhid plotnum) j(num)
drop if prepid==.
ren prepid indidy3
collapse (sum) prep, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3) // only 1 in master not matched
tab prep if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*prep if age>=15
	replace `i' = (age-10)*0.2*`i'*prep if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep_days
}
collapse (sum) man woman child, by(y3_hhid)
tempfile hhprep
save `hhprep', replace
restore

** weed
preserve
keep y3_hhid plotnum ag3a_72_id7-ag3a_72_12
renpfix ag3a_72_ weed
reshape long weedid weed, i(y3_hhid plotnum) j(num)
drop if weedid==.
ren weedid indidy3
collapse (sum) weed, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3) 
tab weed if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*weed if age>=15
	replace `i' = (age-10)*0.2*`i'*weed if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed_days
}
collapse (sum) man woman child, by(y3_hhid)
tempfile hhweed
save `hhweed', replace
restore

** fert
preserve
keep y3_hhid plotnum ag3a_72_id13-ag3a_72_18
renpfix ag3a_72_ fert
reshape long fertid fert, i(y3_hhid plotnum) j(num)
drop if fertid==.
ren fertid indidy3
collapse (sum) fert, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3)
tab fert if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*fert if age>=15
	replace `i' = (age-10)*0.2*`i'*fert if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_fert_days
}
collapse (sum) man woman child, by(y3_hhid)
tempfile hhfert
save `hhfert', replace
restore

*harv
keep y3_hhid plotnum ag3a_72_id18-ag3a_72_24
renpfix ag3a_72_ harv
reshape long harvid harv, i(y3_hhid plotnum) j(num)
drop if harvid==.
ren harvid indidy3
collapse (sum) harv, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3) 
tab harv if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*harv if age>=15
	replace `i' = (age-10)*0.2*`i'*harv if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv_days
}
collapse (sum) man woman child, by(y3_hhid)
merge 1:1 y3_hhid using `hhprep', nogen
merge 1:1 y3_hhid using `hhweed', nogen
merge 1:1 y3_hhid using `hhfert', nogen
recode man* woman* child* (.=0)

** bd - keep labor disaggregated for the moment
gen harv_days_hh = man_harv_days + woman_harv_days
gen prep_days_hh = man_prep_days + woman_prep_days
gen weed_days_hh = man_weed_days + woman_weed_days
gen fert_days_hh = man_fert_days + woman_fert_days
gen harv_days_hh_withkids = man_harv_days + woman_harv_days + child_harv_days
gen prep_days_hh_withkids = man_prep_days + woman_prep_days + child_prep_days
gen weed_days_hh_withkids = man_weed_days + woman_weed_days + child_weed_days
gen fert_days_hh_withkids = man_fert_days + woman_fert_days + child_fert_days
collapse (sum) prep_d* weed_d* harv_d* fert_d*, by(y3_hhid)
merge 1:1 y3_hhid using `hired_labor', assert(2 3) nogen	
ren y3_hhid hhid
recode *_hh* (.=0)
ren hhid y3_hhid


** BRING TOGETHER
merge 1:1 y3_hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_cult_kids = prep_days_hh_withkids + prep_days_hired_withkids
gen ld_weed_kids = weed_days_hh_withkids + weed_days_hired_withkids
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
gen ld_tot_kids = ld_cult_kids + ld_harv_kids + ld_weed_kids + fert_days_hh_withkids + fert_days_hired_withkids


* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Tanzania, Wave 3", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/TZ3_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto TZ3_out_lab

estout TZ*out_lab using "$path/output/TZ_tpl_regs.tex", cells(b(star fmt(3)) se(par fmt(3))) ///
	stats(N r2, fmt(%10.0fc 2) labels("\hline Observations" "\$R^2\$")) ///
	starlevels(* 0.10 ** 0.05 *** 0.01) style(tex) nonumbers ///
	mlabels(none) coll(none) substitute(_ \_) replace
