clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



********************************************
********************************************
*******			 Tanzania			********
*******			  Wave 1			********
*******			 2008-2009			********
********************************************
********************************************


* weights
use "$data_TZ/2008-2009/Dataset/Household/SEC_A_T", clear
gen y1_hhid = hhid
renpfix hh_
gen year = sa2q18y
gen month = sa2q18m
gen month_int = (month-1)/12
gen date_int = year+month_int
egen distgroup = group(region district)
gen ea1 = ea + 1000*locality + 10000*ward + 1000000*district + 10000000*region
gen ward1 = ward + 100*district + 1000*region
keep hhid weight weight_trimmed region dist* month year month_int date_int y1_hhid ea1 ward1
duplicates drop hhid, force
tempfile weights
save `weights', replace


* demographics
use "$data_TZ/2008-2009/Dataset/Household/SEC_B_C_D_E1_F_G1_U", clear
gen person = 1
ren sbq4 age
ren sbmemno indid
gen female = (sbq2==2)
gen male = (sbq2==1)
gen child = $child
gen own_child = sbq5==3
gen adult_children = own_child==1 & child==0
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
ren sbq5 reltohead
keep hhid indid man woman child age male reltohead
tempfile hhworkers
save `hhworkers', replace
save "$newdata/TZ1_hh_ages.dta", replace				// save individual level data to build LFP rate figures
restore

gen hhsize = ($hhsize) & sbq9<=$time_away
replace hhsize = 1 if age>60 & age!=.
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
gen hhsize_away = hhsize*(12-sbq9)/12
gen hhsize_phase_away = hhsize_phase*(12-sbq9)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename sbq9 months_away
gen temp_migrant = months_away > 2 & age >=15

gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
collapse (sum)  prime* eld* hhsize* male* female* child own_child adult_children person (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile demog
save `demog', replace

*Age of househead head*
use "$data_TZ/2008-2009/Dataset/Household/SEC_B_C_D_E1_F_G1_U", clear
gen male_head = sbq2==1 if sbq5==1 
gen agehhhead1 =  sbq4 if sbq5==1
gen agehhspouse1 = sbq4 if sbq5==2
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhspouse1 agehhead_squared1 male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* education *
use "$data_TZ/2008-2009/Dataset/Household/SEC_B_C_D_E1_F_G1_U", clear
keep if sbq5==1 | sbq5==2
gen headeduc= scq6-10 if scq6>=11 & scq6<=17 & sbq5==1
replace headeduc = 7 if (scq6==19 | scq6==18) & sbq5==1			// count 8 years of primary as effectively 7 years, b/c of policy change
replace headeduc = scq6-13 if scq6>=21 & scq6<=25 & sbq5==1		// count "O+plus" as effectively the same as partial completion of A-levels
replace headeduc = 13 if scq6==32 & sbq5==1
replace headeduc = 14 if scq6==33 & sbq5==1					// same here: A+ is like a single year of university
replace headeduc = scq6-27 if inlist(scq6,41,42,43,44,45) & sbq5==1
replace headeduc = 0 if scq6==2 & sbq5==1

keep hhid headeduc
collapse (firstnm) headeduc, by(hhid)
tempfile headeduc
save `headeduc', replace

* get hh asset info *
use "$data_TZ/2008-2009/Dataset/Household/SEC_N.dta", clear

reshape wide snq1, i(hhid) j(sncode)
forvalues i=1/52 {
	if `i'<10 {
		replace snq140`i' = 0 if snq140`i'==.
	}
	else {
		replace snq14`i' = 0 if snq14`i'==.
	}
}
factor snq14*, fa(1)
predict pc1_wealth, r
drop snq14*
tempfile hh_wealth
save `hh_wealth', replace

* get AEZ info *
use "$data_TZ/2008-2009/Dataset/Geovariables/HH.Geovariables_Y1.dta", clear
gen aez = 1 if land03==313
replace aez = 2 if land03==323
replace aez = 3 if aez==.
rename dist03 dist_popcenter
rename dist04 dist_market
keep hhid aez dist_*
isid hhid
tempfile geo
save `geo', replace


* plots and crops
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren s3aq22 ten
gen own = (ten==1 | ten==5)
rename s3aq5code crop_code
gen maize = crop_code==11
gen cassava = crop_code==21
gen irrigated = s3aq15==1
gen fertilized = (s3aq37==1) | (s3aq43==1)
keep hhid plotnum own crop_code maize cassava irrigated fertilized
tempfile owned
save `owned', replace


use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_2A", clear
ren s2aq4 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
destring plotnum, replace
keep hhid plotnum acres
gen numplots = 1
merge 1:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
gen acres_maize = maize*acres
gen acres_cassava = cassava*acres
collapse (sum) owned_acres acres* numplots (max) maize cassava irrigated fertilized, by(hhid)
tempfile plots
save `plots', replace

* get crop sales info
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_5A", clear
collapse (min) any_sold=s5aq1, by(hhid)
replace any_sold = any_sold==1
tempfile sales
save `sales', replace

* gen farming asset info
use "$data_TZ/2008-2009/Dataset/Household/SEC_N", clear
gen any_asset = inlist(sncode,431,435,443,444,446,447,449,452)
collapse (max) any_asset, by(hhid)
tempfile farming_assets
save `farming_assets', replace

* hired labor
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren s3aq62 hire
recode hire (2=0)
recode s3aq63_* (.=0)

ren s3aq63_1 man_prep_days
ren s3aq63_2 woman_prep_days
ren s3aq63_4 man_weed_days
ren s3aq63_5 woman_weed_days
ren s3aq63_7 man_harv_days
ren s3aq63_8 woman_harv_days
gen harv_days_hired = man_harv_days + woman_harv_days
gen prep_days_hired = man_prep_days + woman_prep_days
gen weed_days_hired = man_weed_days + woman_weed_days
gen harv_days_hired_withkids = harv_days_hired
gen prep_days_hired_withkids = prep_days_hired
gen weed_days_hired_withkids = weed_days_hired
collapse (sum) prep_d* weed_d* harv_d*, by(hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_TZ/2008-2009/Dataset/Agriculture/SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep hhid plotnum s3aq61*		
	
** prep
preserve
keep hhid plotnum s3aq61_id1-s3aq61_12
renpfix s3aq61_ prep
reshape long prepid prep, i(hhid plotnum) j(num)
drop if prepid==.
ren prepid indid
collapse (sum) prep, by(hhid indid)
merge 1:1 hhid indid using `hhworkers', keep(1 3)	
tab prep if _merge==1
keep if _merge==3			
drop _merge
foreach i of varlist man woman child {
	replace `i' = `i'*prep if age>=15
	replace `i' = (age-10)*0.2*`i'*prep if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep_days
}
save "$newdata/TZ1_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
restore

** weed
preserve
keep hhid plotnum s3aq61_id13-s3aq61_24
renpfix s3aq61_ weed
reshape long weedid weed, i(hhid plotnum) j(num)
drop if weedid==.
ren weedid indid
collapse (sum) weed, by(hhid indid)
merge 1:1 hhid indid using `hhworkers', keep(1 3) 
tab weed if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist man woman child {
	replace `i' = `i'*weed if age>=15
	replace `i' = (age-10)*0.2*`i'*weed if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed_days
}
save "$newdata/TZ1_weed_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhweed
save `hhweed', replace
restore


*harv
keep hhid plotnum s3aq61_id25-s3aq61_36
renpfix s3aq61_ harv
reshape long harvid harv, i(hhid plotnum) j(num)
drop if harvid==.
ren harvid indid
collapse (sum) harv, by(hhid indid)
merge 1:1 hhid indid using `hhworkers', keep(1 3)
tab harv if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist man woman child {
	replace `i' = `i'*harv if age>=15
	replace `i' = (age-10)*0.2*`i'*harv if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv_days
}
save "$newdata/TZ1_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
recode man* woman* child* (.=0)
** keep labor disaggregated for the moment
gen harv_days_hh = man_harv_days + woman_harv_days
gen prep_days_hh = man_prep_days + woman_prep_days
gen weed_days_hh = man_weed_days + woman_weed_days
gen harv_days_hh_withkids = man_harv_days + woman_harv_days + child_harv_days
gen prep_days_hh_withkids = man_prep_days + woman_prep_days + child_prep_days
gen weed_days_hh_withkids = man_weed_days + woman_weed_days + child_weed_days
collapse (sum) prep_d* weed_d* harv_d*, by(hhid)
merge 1:1 hhid using `hired_labor', assert(2 3) nogen
recode *_hh* (.=0)


** BRING TOGETHER
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `demog', assert(2 3) keep(3) nogen
merge 1:1 hhid using `headeduc', assert(2 3) keep(3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `geo', keep(1 3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen
merge 1:1 hhid using `farming_assets', keep(1 3) nogen

tempfile TZ1_data
save `TZ1_data', replace



********************************************
********************************************
*******			 Tanzania			********
*******			  Wave 2			********
*******			 2010-2011			********
********************************************
********************************************

* weights
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_A", clear
gen hhid_y2 = y2_hhid
renpfix y2_
gen person = 1
gen splits = hh_a11==3
gen year = hh_a18_year
gen month = hh_a18_month
gen month_int = (month-1)/12
gen date_int = year+month_int
egen distgroup = group(region district)
gen ward2 = ward + 1000*district + 10000*region
keep hhid weight region dist* month year month_int date_int splits hhid_y2 hh_a11 ward2
duplicates drop hhid, force
tempfile weights
save `weights', replace

* demographics
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_B", clear
gen hhid_indmerge = hhid_2008
gen hhidtemp = y2_hhid
renpfix y2_
gen person = 1
ren hh_b04 age
gen female = (hh_b02==2)
gen male = (hh_b02==1)
gen child = $child
gen own_child = hh_b05==3
gen adult_children = own_child==1 & child==0
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
ren hh_b05 reltohead
keep hhid indidy2 man woman child age male reltohead
tempfile hhworkers
save `hhworkers', replace
save "$newdata/TZ2_hh_ages.dta", replace				// save individual level data to build LFP rate figures
restore
gen prime_noage = ($prime_noage)
gen aged_in = age>=15 & age<=16
gen aged_out = age>60 & age<=61

gen hhsize = $hhsize & hh_b10<=$time_away
replace hhsize = 1 if age>60 & age!=.
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
gen hhsize_away = hhsize*(12-hh_b10)/12
gen hhsize_phase_away = hhsize_phase*(12-hh_b10)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename hh_b10 months_away
gen temp_migrant = months_away > 2 & age >=15

gen recent_migrant = hhsize*(hh_b06==99)
gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
tempfile ind_tz2
save `ind_tz2', replace
collapse (sum)  recent_migrant person prime* eld* child hhsize* male* female* aged* own_child (mean) temp_migrant months_away (max) any_migrant=temp_migrant ///
 (firstnm) hhid_2008 hhid_indmerge, by(hhid)
tempfile demog
save `demog', replace

*Age of househead head*
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_B", clear
renpfix y2_
gen agehhhead1 =  hh_b04 if hh_b05==1
gen agehhspouse1 = hh_b04 if hh_b05==2
gen male_head = hh_b02==1 if hh_b05==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhspouse1 agehhead_squared1 male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* education *
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_C", clear
merge 1:1 y2_hhid indidy2 using "$data_TZ/2010-2011/Dataset/Household/HH_SEC_B"		// to get spouse category
renpfix y2_
keep if hh_b05==1 | hh_b05==2
gen headeduc= hh_c07-10 if hh_c07>=11 & hh_c07<=17 & hh_b05==1
replace headeduc = 7 if (hh_c07==20 | hh_c07==18) & hh_b05==1			// count 8 years of primary as effectively 7 years, b/c of policy change
replace headeduc = hh_c07-13 if hh_c07>=21 & hh_c07<=25 & hh_b05==1	// count "O+plus" as effectively the same as partial completion of A-levels
replace headeduc = 12 if hh_c07==31 & hh_b05==1
replace headeduc = 13 if hh_c07==32 & hh_b05==1
replace headeduc = 14 if hh_c07==33 & hh_b05==1			// same here: A+ is like a single year of university
replace headeduc = hh_c07-27 if inlist(hh_c07,41,42,43,44,45) & hh_b05==1
replace headeduc = 0 if hh_c03==2 & hh_b05==1

keep hhid headeduc
collapse (firstnm) headeduc, by(hhid)
tempfile headeduc
save `headeduc', replace

* get hh consumption *
use "$data_TZ/2010-2011/Dataset/Household/TZY2.HH.Consumption.dta", clear
rename y2_hhid hhid
keep hhid expm expmR hhsize
gen exp_pc = expmR / hhsize
tempfile hh_consum
save `hh_consum', replace

* get hh asset info *
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_N.dta", clear
rename y2_hhid hhid
reshape wide hh_n01_2, i(hhid) j(itemcode)
forvalues i=1/52 {
	if `i'<10 {
		replace hh_n01_240`i' = 0 if hh_n01_240`i'==.
	}
	else {
		replace hh_n01_24`i' = 0 if hh_n01_24`i'==.
	}
}
factor hh_n01_24*, fa(1)
predict pc1_wealth, r
drop hh_n01_24*
tempfile hh_wealth
save `hh_wealth', replace


* plots and crops
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren ag3a_24 ten
gen own = (ten==1 | ten==5)
rename zaocode crop_code
gen maize = crop_code==11
gen cassava = crop_code==21
gen irrigated = ag3a_17==1
gen fertilized = (ag3a_39==1) | (ag3a_45==1)
keep hhid plotnum own crop_code maize cassava irrigated fertilized
tempfile owned
save `owned', replace


use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC2A", clear
renpfix y2_
ren ag2a_04 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
destring plotnum, replace
keep hhid plotnum acres
gen numplots = 1
merge 1:1 hhid plotnum using `owned', keep(3)
gen owned_acres=acres*own
gen acres_maize = maize*acres
gen acres_cassava = cassava*acres
collapse (sum) owned_acres acres* numplots (max) maize cassava irrigated fertilized, by(hhid)
tempfile plots
save `plots', replace

* get crop sales info
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC5A", clear
renpfix y2_
collapse (min) any_sold=ag5a_01, by(hhid)
replace any_sold = any_sold==1
tempfile sales
save `sales', replace

* gen farming asset info
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_N", clear
renpfix y2_
drop if hh_n01_2==0
gen any_asset = inlist(itemcode,431,435,443,444,446,447,449,452)
collapse (max) any_asset, by(hhid)
tempfile farming_assets
save `farming_assets', replace

* hired labor
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren ag3a_71 hire
recode hire (2=0)
recode ag3a_72_* (.=0)


ren ag3a_72_1 woman_prep_days
ren ag3a_72_2 man_prep_days
ren ag3a_72_21 child_prep_days
ren ag3a_72_4 woman_weed_days
ren ag3a_72_5 man_weed_days
ren ag3a_72_51 child_weed_days
ren ag3a_72_61 woman_fert_days
ren ag3a_72_62 man_fert_days
ren ag3a_72_63 child_fert_days
ren ag3a_72_7 woman_harv_days
ren ag3a_72_8 man_harv_days
ren ag3a_72_81 child_harv_days
gen harv_days_hired = man_harv_days + woman_harv_days
gen prep_days_hired = man_prep_days + woman_prep_days
gen weed_days_hired = man_weed_days + woman_weed_days
gen fert_days_hired = man_fert_days + woman_fert_days
gen harv_days_hired_withkids = man_harv_days + woman_harv_days + 0.5*child_harv_days
gen prep_days_hired_withkids = man_prep_days + woman_prep_days + 0.5*child_prep_days
gen weed_days_hired_withkids = man_weed_days + woman_weed_days + 0.5*child_weed_days
gen fert_days_hired_withkids = man_fert_days + woman_fert_days + 0.5*child_fert_days
collapse (sum) prep_d* weed_d* fert_d* harv_d*, by(hhid)
tempfile hired_labor
save `hired_labor', replace

* family labor demand
use "$data_TZ/2010-2011/Dataset/Agriculture/AG_SEC3A", clear
renpfix y2_
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep hhid plotnum ag3a_70*			// NOTE: the enumerator manual does not indicate an age cut-off for "child" status among hired workers
** prep								// 		 above, I defined children as those <15 yrs
preserve
keep hhid plotnum ag3a_70_id1-ag3a_70_6
renpfix ag3a_70_ prep
reshape long prepid prep, i(hhid plotnum) j(num)
drop if prepid==.
ren prepid indidy2
collapse (sum) prep, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers', keep(1 3)
tab prep if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*prep if age>=15
	replace `i' = (age-10)*0.2*`i'*prep if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep_days
}
save "$newdata/TZ2_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhprep
save `hhprep', replace
restore

** weed
preserve
keep hhid plotnum ag3a_70_id13-ag3a_70_18
renpfix ag3a_70_ weed
reshape long weedid weed, i(hhid plotnum) j(num)
drop if weedid==.
ren weedid indidy2
collapse (sum) weed, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers', keep(1 3)
tab weed if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*weed if age>=15
	replace `i' = (age-10)*0.2*`i'*weed if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed_days
}
save "$newdata/TZ2_weed_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhweed
save `hhweed', replace
restore

** fert
preserve
keep hhid plotnum ag3a_70_id37-ag3a_70_42
renpfix ag3a_70_ fert
reshape long fertid fert, i(hhid plotnum) j(num)
drop if fertid==.
ren fertid indidy2
collapse (sum) fert, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers', keep(1 3)
tab fert if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*fert if age>=15
	replace `i' = (age-10)*0.2*`i'*fert if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_fert_days
}
save "$newdata/TZ2_fert_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
tempfile hhfert
save `hhfert', replace
restore
*harv
keep hhid plotnum ag3a_70_id25-ag3a_70_30
renpfix ag3a_70_ harv
reshape long harvid harv, i(hhid plotnum) j(num)
drop if harvid==.
ren harvid indidy2
collapse (sum) harv, by(hhid indidy2)
merge 1:1 hhid indidy2 using `hhworkers'
tab harv if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*harv if age>=15
	replace `i' = (age-10)*0.2*`i'*harv if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv_days
}
save "$newdata/TZ2_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(hhid)
merge 1:1 hhid using `hhprep', nogen
merge 1:1 hhid using `hhweed', nogen
merge 1:1 hhid using `hhfert', nogen
recode man* woman* child* (.=0)

** keep labor disaggregated for the moment
gen harv_days_hh = man_harv_days + woman_harv_days
gen prep_days_hh = man_prep_days + woman_prep_days
gen weed_days_hh = man_weed_days + woman_weed_days
gen fert_days_hh = man_fert_days + woman_fert_days
gen harv_days_hh_withkids = man_harv_days + woman_harv_days + child_harv_days
gen prep_days_hh_withkids = man_prep_days + woman_prep_days + child_prep_days
gen weed_days_hh_withkids = man_weed_days + woman_weed_days + child_weed_days
gen fert_days_hh_withkids = man_fert_days + woman_fert_days + child_fert_days
collapse (sum) prep_d* weed_d* harv_d* fert_d*, by(hhid)
merge 1:1 hhid using `hired_labor', assert(2 3) nogen
recode *_hh* (.=0)


** BRING TOGETHER
merge 1:1 hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 hhid using `demog', assert(2 3) keep(3) nogen
merge 1:1 hhid using `headeduc', assert(2 3) keep(3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `hh_consum', keep(3) nogen force
merge 1:1 hhid using `hh_wealth', assert(2 3) keep(3) nogen force
merge 1:1 hhid using `sales', keep(1 3) nogen
merge 1:1 hhid using `farming_assets', keep(1 3) nogen

tempfile TZ2_data
save `TZ2_data', replace


********************************************
********************************************
*******			 Tanzania			********
*******			  Wave 3			********
*******			 2012-2013			********
********************************************
********************************************

* weights
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_A", clear
gen year = hh_a18_3
gen month = hh_a18_2
gen month_int = (month-1)/12
gen date_int = year+month_int
gen region = hh_a01_1
gen district = hh_a02_1
egen distgroup = group(region district)
gen ward3 = hh_a03_1 + 1000*district + 10000*region
gen weight = y3_weight
ren hh_a11 location_y3
keep y3_hhid weight y3_weight region dist* month year month_int date_int location  hh_a10 ward3
duplicates drop y3_hhid, force
tempfile weights
save `weights', replace

* demographics
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_B", clear
gen hhid3_ind = y2_hhid
gen hhid_y2 = y2_hhid
gen person = 1
ren hh_b04 age
gen female = (hh_b02==2)
gen male = (hh_b02==1)
gen child = $child
gen own_child = hh_b05==3
gen adult_children = own_child==1 & child==0
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
ren hh_b05 reltohead
keep y3_hhid indidy3 man woman child age male reltohead
tempfile hhworkers
save `hhworkers', replace
save "$newdata/TZ3_hh_ages.dta", replace				// save individual level data to build LFP rate figures
restore
gen prime_noage = ($prime_noage)
gen aged_in = age>=15 & age<=16
gen aged_out = age>60 & age<=61


gen hhsize = $hhsize & hh_b10<=$time_away
replace hhsize = 1 if age>60 & age!=.
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
gen hhsize_away = hhsize*(12-hh_b10)/12
gen hhsize_phase_away = hhsize_phase*(12-hh_b10)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename hh_b10 months_away
gen temp_migrant = months_away > 2 & age >=15

gen recent_migrant = hhsize*hh_b06==99
gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
tempfile ind_tz3
save `ind_tz3', replace
collapse (sum)  recent_migrant prime* eld* child hhsize* male* female*  aged* person own_child (first) hhid3_ind hhid_y2 y2_hhid (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(y3_hhid)
tempfile demog
save `demog', replace

*Age of househead age*
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_B", clear
gen agehhhead1 =  hh_b04 if hh_b05==1
gen agehhspouse1 = hh_b04 if hh_b05==2
gen male_head = hh_b02==1 if hh_b05==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhspouse1 agehhead_squared1 male_head, by(y3_hhid)
tempfile household_headage 
save `household_headage', replace

* education *
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_C", clear
merge 1:1 y3_hhid indidy3 using "$data_TZ/2012-2013/Dataset/Household/HH_SEC_B"		// to get spouse category
keep if hh_b05==1 | hh_b05==2
gen headeduc= hh_c07-10 if hh_c07>=11 & hh_c07<=17 & hh_b05==1
replace headeduc = 7 if (hh_c07==20 | hh_c07==18) & hh_b05==1			// count 8 years of primary as effectively 7 years, b/c of policy change
replace headeduc = hh_c07-13 if hh_c07>=21 & hh_c07<=25 & hh_b05==1	// count "O+plus" as effectively the same as partial completion of A-levels
replace headeduc = 12 if hh_c07==31 & hh_b05==1
replace headeduc = 13 if hh_c07==32 & hh_b05==1
replace headeduc = 14 if hh_c07==33 & hh_b05==1			// same here: A+ is like a single year of university
replace headeduc = hh_c07-27 if inlist(hh_c07,41,42,43,44,45) & hh_b05==1
replace headeduc = 0 if hh_c03==2 & hh_b05==1

keep y3_hhid headeduc
collapse (firstnm) headeduc, by(y3_hhid)
tempfile headeduc
save `headeduc', replace

* plots and crops
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren ag3a_25 ten
gen own = (ten==1 | ten==5)
rename ag3a_07_2 crop_code
gen maize = crop_code==11
gen cassava = crop_code==21
gen irrigated = ag3a_18==1
gen fertilized = (ag3a_41==1) | (ag3a_47==1)
keep y3_hhid plotnum own crop_code maize cassava irrigated fertilized
tempfile owned
save `owned', replace


use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_2A", clear
ren ag2a_04 acres
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep y3_hhid plotnum acres
gen numplots = 1
merge 1:1 y3_hhid plotnum using `owned', assert(3) nogen
gen owned_acres=acres*own
gen acres_maize = maize*acres
gen acres_cassava = cassava*acres
collapse (sum) owned_acres acres* numplots (max) maize cassava irrigated fertilized, by(y3_hhid)
tempfile plots
save `plots', replace

* get crop sales info
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_5A", clear
collapse (min) any_sold=ag5a_01, by(y3_hhid)
replace any_sold = any_sold==1
tempfile sales
save `sales', replace

* gen farming asset info
use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_M", clear
drop if hh_m01==0
gen any_asset = inlist(itemcode,431,435,443,444,446,447,449,452)
collapse (max) any_asset, by(y3_hhid)
tempfile farming_assets
save `farming_assets', replace

* hired labor
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
ren ag3a_73 hire
recode hire (2=0)
recode ag3a_74_* (.=0)

* notation from wave 2:
ren ag3a_74_1 woman_prep_days
ren ag3a_74_2 man_prep_days
ren ag3a_74_3 child_prep_days
ren ag3a_74_5 woman_weed_days
ren ag3a_74_6 man_weed_days
ren ag3a_74_7 child_weed_days
ren ag3a_74_9 woman_fert_days
ren ag3a_74_10 man_fert_days
ren ag3a_74_11 child_fert_days
ren ag3a_74_13 woman_harv_days
ren ag3a_74_14 man_harv_days
ren ag3a_74_15 child_harv_days
gen harv_days_hired = man_harv_days + woman_harv_days
gen prep_days_hired = man_prep_days + woman_prep_days
gen weed_days_hired = man_weed_days + woman_weed_days
gen fert_days_hired = man_fert_days + woman_fert_days
gen harv_days_hired_withkids = man_harv_days + woman_harv_days + 0.5*child_harv_days
gen prep_days_hired_withkids = man_prep_days + woman_prep_days + 0.5*child_prep_days
gen weed_days_hired_withkids = man_weed_days + woman_weed_days + 0.5*child_weed_days
gen fert_days_hired_withkids = man_fert_days + woman_fert_days + 0.5*child_fert_days
collapse (sum) prep_d* weed_d* fert_d* harv_d*, by(y3_hhid)
tempfile hired_labor
save `hired_labor', replace


* family labor demand
use "$data_TZ/2012-2013/Dataset/Agriculture/AG_SEC_3A", clear
gen plotnumber = substr(plotnum,2,2)
destring plotnumber, replace force
drop plotnum
ren plotnumber plotnum
keep y3_hhid plotnum ag3a_72*

** prep
preserve
keep y3_hhid plotnum ag3a_72_id1-ag3a_72_6
renpfix ag3a_72_ prep
reshape long prepid prep, i(y3_hhid plotnum) j(num)
drop if prepid==.
ren prepid indidy3
collapse (sum) prep, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3)
tab prep if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*prep if age>=15
	replace `i' = (age-10)*0.2*`i'*prep if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_prep_days
}
save "$newdata/TZ3_prep_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y3_hhid)
tempfile hhprep
save `hhprep', replace
restore

** weed
preserve
keep y3_hhid plotnum ag3a_72_id7-ag3a_72_12
renpfix ag3a_72_ weed
reshape long weedid weed, i(y3_hhid plotnum) j(num)
drop if weedid==.
ren weedid indidy3
collapse (sum) weed, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3) 
tab weed if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*weed if age>=15
	replace `i' = (age-10)*0.2*`i'*weed if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_weed_days
}
save "$newdata/TZ3_weed_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y3_hhid)
tempfile hhweed
save `hhweed', replace
restore

** fert
preserve
keep y3_hhid plotnum ag3a_72_id13-ag3a_72_18
renpfix ag3a_72_ fert
reshape long fertid fert, i(y3_hhid plotnum) j(num)
drop if fertid==.
ren fertid indidy3
collapse (sum) fert, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3)
tab fert if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*fert if age>=15
	replace `i' = (age-10)*0.2*`i'*fert if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_fert_days
}
save "$newdata/TZ3_fert_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y3_hhid)
tempfile hhfert
save `hhfert', replace
restore

*harv
keep y3_hhid plotnum ag3a_72_id18-ag3a_72_24
renpfix ag3a_72_ harv
reshape long harvid harv, i(y3_hhid plotnum) j(num)
drop if harvid==.
ren harvid indidy3
collapse (sum) harv, by(y3_hhid indidy3)
merge 1:1 y3_hhid indidy3 using `hhworkers', keep(1 3) 
tab harv if _merge==1
keep if _merge==3
drop _merge
foreach i of varlist child man woman {
	replace `i' = `i'*harv if age>=15
	replace `i' = (age-10)*0.2*`i'*harv if age<15 & age>=10
	replace `i' = 0 if age<10
	ren `i' `i'_harv_days
}
save "$newdata/TZ3_harv_ages.dta", replace				// save individual level data to build LFP rate figures
collapse (sum) man woman child, by(y3_hhid)
merge 1:1 y3_hhid using `hhprep', nogen
merge 1:1 y3_hhid using `hhweed', nogen
merge 1:1 y3_hhid using `hhfert', nogen
recode man* woman* child* (.=0)

** bd - keep labor disaggregated for the moment
gen harv_days_hh = man_harv_days + woman_harv_days
gen prep_days_hh = man_prep_days + woman_prep_days
gen weed_days_hh = man_weed_days + woman_weed_days
gen fert_days_hh = man_fert_days + woman_fert_days
gen harv_days_hh_withkids = man_harv_days + woman_harv_days + child_harv_days
gen prep_days_hh_withkids = man_prep_days + woman_prep_days + child_prep_days
gen weed_days_hh_withkids = man_weed_days + woman_weed_days + child_weed_days
gen fert_days_hh_withkids = man_fert_days + woman_fert_days + child_fert_days
collapse (sum) prep_d* weed_d* harv_d* fert_d*, by(y3_hhid)
merge 1:1 y3_hhid using `hired_labor', assert(2 3) nogen	
ren y3_hhid hhid
recode *_hh* (.=0)
ren hhid y3_hhid


** BRING TOGETHER
merge 1:1 y3_hhid using `plots', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `demog', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `headeduc', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 y3_hhid using `sales', keep(1 3) nogen
merge 1:1 y3_hhid using `farming_assets', keep(1 3) nogen

tempfile TZ3_data
save `TZ3_data', replace


***********************************************************************

** 		COMBINE PANEL AND CONSTRUCT KEY LABOR DEMAND VARIABLES

***********************************************************************
use `TZ1_data', clear
append using `TZ2_data', gen(wave2)
append using `TZ3_data', gen(wave3)


*Have to merge wave 1 and wave 2 using hhid and wave 2 and wave 3 using hhid_y2
gen wave = wave2==0 & wave3==0
replace wave = 2 if wave2==1
replace wave = 3 if wave3==1

drop if hh_a11==3 | hh_a10==2	// These are SPLITS

tab wave
assert wave!=.
codebook *hhid* if wave==1, compact
codebook *hhid* if wave==2, compact
codebook *hhid* if wave==3, compact
codebook hhid if wave==1
codebook hhid if wave==2
codebook hhid_2008 if wave==2

* clean up wave 2 link
duplicates tag hhid_2008 if wave==2, gen(duptag)
tab duptag
assert hhid==hhid_y2 if wave==2
gen twodigits = substr(hhid_y2,-2,.) if wave==2 & duptag>0
destring twodigits, replace
egen mingroup = min(twodigits) if wave==2 & duptag>0, by(hhid_2008) 
drop if duptag>0 & twodigits!=mingroup		// keep the lowest listed HH splitoff (all are 1, except one 2, who is probably a widow)
drop duptag twodigits mingroup
codebook hhid_2008 if wave==2

* clean up wave 3 link
assert hhid_y2==y2_hhid if wave==3
assert hhid3_ind==hhid_y2 if wave==3
drop y2_hhid hhid3_ind
codebook *hhid* if wave==3, compact
drop if hhid_y2=="" & wave==3
duplicates tag hhid_y2 if wave==3, gen(duptag)
gen twodigits = substr(y3_hhid,-2,.) if wave==3 & duptag>0
destring twodigits, replace
egen mingroup = min(twodigits) if wave==3 & duptag>0, by(hhid_y2) 
drop if duptag>0 & twodigits!=mingroup		// keep the lowest listed HH splitoff (all are 1, except one 2, who is probably a widow)
drop duptag twodigits mingroup
codebook hhid_y2 if wave==3
assert hhid_y2=="" if wave==1
bys hhid_y2: gen wave_2_3 = _N if inlist(wave,2,3)
drop if wave_2_3==1 & wave==3
codebook hhid_y2 if wave==3
drop hhid_ind
assert hhid==y1_hhid if wave==1
drop y1_hhid
assert hhid==hhid_y2 if wave==2
replace hhid=hhid_2008 if wave==2
compress hhid
ren hhid hhid_y1
drop y3_hhid hhid_2008
codebook *hhid* if wave==1, compact
codebook *hhid* if wave==2, compact
codebook *hhid* if wave==3, compact

destring hhid_y2, replace
destring hhid_y1, replace
bys hhid_y1: gen wave_1_2 = _N if inlist(wave,1,2)
drop if wave_1_2==1 & wave==1		// these are wave 1 cross-section HHs
drop if wave_1_2==1 & wave_2_3==1 & wave==2	// these are wave 2 cross-section HHs
drop wave_1_2 wave_2_3		

egen double h2_min = min(hhid_y2), by(hhid_y1)
format hhid_y1 hhid_y2 h2_min %20.0g
sort hhid_y1 hhid_y2
replace hhid_y2=h2_min if wave==1
drop if wave==1 & hhid_y2==.		// these are wave 1 cross-section HHs
drop h2_min				// now hhid_y2 


*This command will generate a variable if a household is in wave 1 and wave 2 AND is an original household
bys hhid_y2: egen wave_count = count(wave)
assert wave_count==3 | wave_count==2

drop hhid_y1
ren hhid_y2 hhid


*Recoding
recode *days_* (.=0)							// I assume these are zeros (same assumption as the coding above)
recode owned_acres (.=0)
recode acres (.=0)

capture drop twins* first* second* third* fourth* hh_10 hh_a11 death wave3 y3_weigh split_out adult_c adult_e split* location_y3 *death* newborn
order hhid wave wave_c

bys wave: sum *prep* *weed* *fert* *harv*

** Make a number of possible labor demand measures
* No children
gen ld_prep_nokids = prep_days_hh + prep_days_hired
la var ld_prep_nokids "LD: no kids; prep; waves 1-3"
gen ld_weed_nokids = weed_days_hh + weed_days_hired
la var ld_weed_nokids "LD: no kids; weed; waves 1-3"
gen ld_harv_nokids = harv_days_hh + harv_days_hired
la var ld_harv_nokids "LD: no kids; harv only; waves 1-3"
gen ld_tot_nokids = ld_prep_nokids + ld_harv_nokids + ld_weed_nokids + fert_days_hh + fert_days_hired
la var ld_tot_nokids "LD: no kids; prep, weed, fert, harv; waves 1-3"

* With children
gen ld_cult_kids = prep_days_hh_withkids + prep_days_hired_withkids
la var ld_cult_kids "LD: incl. kids; prep; "
gen ld_weed_kids = weed_days_hh_withkids + weed_days_hired_withkids
la var ld_weed_kids "LD: incl. kids; weed; "
gen ld_harv_kids = harv_days_hh_withkids + harv_days_hired_withkids
la var ld_harv_kids "LD: incl. kids; harv only; waves 1-3"
gen ld_tot_kids = ld_cult_kids + ld_harv_kids + ld_weed_kids + fert_days_hh_withkids + fert_days_hired_withkids
la var ld_tot_kids "LD: incl. kids; prep, weed, fert, harv; waves 1-3"


* dropping households that report no labor demand for at least half of the waves they appear in the data
bysort hhid: egen count_waves = count(wave)
gen ld_zero = ld_tot_kids==0
by hhid: egen cnt_ld = sum(ld_zero)
gen temp_rate = cnt_ld / count_waves
drop if temp_rate > 0.5
drop count_waves ld_zero temp_rate

foreach i of varlist ld_* {
	gen log_`i' = ln(`i')
	local label : variable label `i'
	label variable log_`i' `"Log `label''"'
	replace log_`i' = ln($no_work) if `i'==0
}
gen log_A = ln(acres)
replace log_A = ln(0.01) if log_A==.
replace owned_acres = owned_acres + 0.01 if log_A!=. & owned_acres==0		// replace the ownership zeros so that sample size is identical to log_A sample size
gen log_owned = ln(owned_acres)
gen log_hhsize = ln(hhsize)
gen log_phase = ln(hhsize_phase)
gen log_hhaway = ln(hhsize_away)
gen log_phase_away = ln(hhsize_phase_away)
gen share_pm = prime_male/person
gen share_pf = prime_female/person
gen share_em = eld_male/person
gen share_ef = eld_female/person
gen age_head1 = agehhhead1
gen age_squared1 = agehhead_squared1
gen female_head = 1-male_head
gen female_hhsize = female_head*log_hhsize
replace age_squared1 = age_squared1/1000
replace log_hhaway = ln(0.01) if hhsize_away==0
replace log_phase_away = ln(0.01) if hhsize_phase_away==0
la var log_A "Log acres cultivated"
la var log_owned "Log acres owned"
la var log_hhsize "Log HH size (15<=age<=60)"
la var log_phase "Log HH size with phase-in and out"
la var share_pm "Prime male share"
la var share_pf "Prime female share"
la var share_em "Elderly male share"
la var share_ef "Elderly female share"
la var age_head1 "Age of household head"
la var age_squared1 "Age of household head squared (000s)"
la var female_head "Female head of household"
la var female_hhsize "Log of household size for female heads"
la var hhsize "Household size"
la var owned_acres "Acres owned"
la var acres "Acres farmed"
la var numplots "Number of plots"
la var male_head "Male head of household"
la var owned_acres "Acres owned"


* Drop households with no acreage cultivated
drop if acres==0

* winsorizing top 5 largest acres, owned_acres, exp_pc
foreach var in acres owned_acres exp_pc {
	di "var = `var'"
	gsort - `var'
	forvalues i=1/5 {
		di "var=`var' and i=`i'"
		replace `var' = `var'[6] in `i'
	}
}

* set-up EA to use for village level IV
sort hhid wave
by hhid: egen ea_temp = max(ea1)
replace ea1 = ea_temp

* vars for hhsize by gender
gen log_male = ln(male_phase)
replace log_male = ln(0.1) if male_phase==0
gen log_female = ln(female_phase)
replace log_female = ln(0.1) if female_phase==0
gen log_male_nokids = ln(hhsize_male)
replace log_male_nokids = ln(0.1) if hhsize_male==0
gen log_female_nokids = ln(hhsize_female)
replace log_female_nokids = ln(0.1) if hhsize_female ==0

keep hhsize* log* ld* hhid wave* age* numpl  *acres* male* female* prime* eld* share_* ///
 female_head region district female_hhsize *educ exp* *days* pc1_wealth aez ea1 ward* months_away dist* ///
 maize cassava irrigated fertilized any_* temp_migrant
save "$newdata/TZ panel data merged", replace

isid hhid wave
xtset hhid wave

*spread aez info across waves
bysort hhid: egen ae_zone = max(aez)

*Generating region/district FE:
egen reg_dist_wave_FE = group(region district wave)


* Wealth categories by expenditure per capita in Wave 1
sum exp_pc if wave==2, det
local cut50 = r(p50)
gen temp = exp_pc<`cut50' & wave==2
bysort hhid: egen poor50 = sum(temp)
replace temp = exp_pc>=`cut50' & wave==2
bysort hhid: egen exp_rich50 = sum(temp)
drop temp

* Wealth categories by asset index
sum pc1_wealth, det
local cut50 = r(p50)
gen temp = pc1_wealth <`cut50' & wave==2
bysort hhid: egen asset_poor50 = sum(temp)
replace temp = pc1_wealth>=`cut50' & wave==2
bysort hhid: egen asset_rich50 = sum(temp)
drop temp

gen rich50 = exp_rich50

local controls log_A

****** create vars for whether household increased or decreased in size *******
sort hhid wave
by hhid: gen increase = ($hhsize_var>$hhsize_var[_n-1]) if _n==2
by hhid: gen decrease = ($hhsize_var<$hhsize_var[_n-1]) if _n==2
by hhid: gen male_inc = (male_phase>male_phase[_n-1]) if _n==2
by hhid: gen male_dec = (male_phase<male_phase[_n-1]) if _n==2
by hhid: gen female_inc = (female_phase>female_phase[_n-1]) if _n==2
by hhid: gen female_dec = (female_phase<female_phase[_n-1]) if _n==2

****** create vars for agricultural activity, with kids phased in *******
rename log_ld_cult_kids act_log_ld_0
rename log_ld_weed_kids act_log_ld_1
rename log_ld_harv_kids act_log_ld_2
label define act_labels 0 "Prep" 1 "Weeding" 2 "Harvest"

reshape long act_log_ld_, i(hhid wave) j(activity)
label values activity act_labels
rename act_log_ld_ act_log_ld
local dep_var act_log_ld

foreach i of varlist `dep_var' log_phase log_hhsize log_phase_away log_male log_female share_pm share_pf share_em log_A log_owned log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

gen INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
gen DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_male = diff_log_male*(diff_log_male>0)
gen DEC_male = diff_log_male*(diff_log_male<0)
gen INC_female = diff_log_female*(diff_log_female>0)
gen DEC_female = diff_log_female*(diff_log_female<0)

la var INC_hhsize "Increase in HH Size"
la var DEC_hhsize "Decrease in HH Size"
la var INC_male "Increase in Male HH Size"
la var DEC_male "Decrease in Male HH Size"
la var INC_female "Increase in Female HH Size"
la var DEC_female "Decrease in Female HH Size"
label var log_hhsize "Log(HH Size)"

save "$newdata/TZ_reg_ready", replace		// to be used in the file "Combined analysis.do"

