*	04-Apr-2017 pwb	cleaning code, being called from run_all.do
*	18-Dec-2017	pwb create variable for hhsize by gender with nokids

clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000


********************************************
*******		  Uganda  2005-2006	    ********
*******		        Wave 1	        ********
********************************************

* weights
use "$data_UG/2005-2006/Dataset/Household/GSEC1", clear
destring HHID, replace
ren HHID hhid
ren comm ea1
gen year = h1bq2c
gen month = h1bq2b
gen month_int = (month-1)/12
gen date_int = year+month_int
gen district = h1aq1			// NOTE: need to make sure all disricts line up when finished with all coding
destring district, replace
keep hhid hmult region district year month month_int date_int ea1
duplicates drop hhid, force
ren hmult weight
tempfile weights
save `weights', replace


* demographics
use "$data_UG/2005-2006/Dataset/Household/GSEC2", clear
destring HHID, replace
ren HHID hhid
ren h2q9 age
gen person = 1
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize				// Note: no people recorded as guests in raw data.
replace hhsize = 1 if age>60 & age!=.
gen female = (h2q4==2)
gen male = (h2q4==1)
gen child = $child
gen own_child = h2q5==3
gen adult_children = own_child==1 & child==0
* Dropping if no longer a member of household
keep if h2q13==1
ren pid personid
ren h2q5 reltohead
preserve
keep hhid personid PID reltohead
tempfile PID
save `PID', replace
restore

gen man = male*(child==0)
gen woman = female*(child==0)
keep hhid personid man woman child age male age PID reltohead
tempfile hhworkers
save `hhworkers', replace

* determine which crop is on which plot
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren a4aq1 parcel
ren a4aq2 plotnum
ren a4aid record
keep if a4aq5b==130
rename a4aq5b crop_code
duplicates drop hhid parcel plotnum, force			// 3 problem observations
keep hhid parcel plotnum record crop_code
tempfile maize_plots
save `maize_plots', replace
collapse (first) crop_code , by(hhid parcel)
tempfile maize_parcels
save `maize_parcels', replace

* get total harvested by household
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC7A", clear
destring HHID, replace
ren HHID hhid
ren a7aq2b crop_code
keep if crop_code==130
gen wgt_temp = a7aq3b * a7aq3d
collapse (sum) wgt_tot=wgt_temp, by(hhid)
tempfile crops_tot
save `crops_tot', replace

* plots
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC2A", clear
destring HHID, replace
ren HHID hhid
ren a2aq5 acres
ren a2aq2 parcel
merge 1:m hhid parcel using `maize_parcels', keep(3)			//keep only parcels with maize
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots, by(hhid)
tempfile plotsowned
save `plotsowned', replace


* FAMILY labor (in first crop cycle)
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC5A", clear
destring HHID, gen(hhid)
ren a5aq2 parcel
ren a5aq3 plotnum
ren a5aid record
duplicates drop hhid record parcel plotnum, force
merge 1:1 hhid parcel plotnum record using `maize_plots', keep(3)			//keep only plots with maize

recode a5aq* (.=0)
ren a5aq4 prep_days_male
ren a5aq5 prep_days_female
ren a5aq6 prep_days_child
gen prep_days_hh = prep_days_male+prep_days_female
gen prep_days_hh_withkids = prep_days_male+prep_days_female+(prep_days_child*0.5)
ren a5aq7 inputs_days_male
ren a5aq8 inputs_days_female
ren a5aq9 inputs_days_child
gen inputs_days_hh = inputs_days_male+inputs_days_female
gen inputs_days_hh_withkids = inputs_days_male+inputs_days_female+(inputs_days_child*0.5)
ren a5aq10 weed_days_male
ren a5aq11 weed_days_female
ren a5aq12 weed_days_child
gen weed_days_hh = weed_days_male+weed_days_female
gen weed_days_hh_withkids = weed_days_male+weed_days_female+(weed_days_child*0.5)
ren a5aq13 harvest_days_male
ren a5aq14 harvest_days_female
ren a5aq15 harvest_days_child
gen harvest_days_hh = harvest_days_male+harvest_days_female
gen harvest_days_hh_withkids = harvest_days_male+harvest_days_female+(harvest_days_child*0.5)
gen cult_days_hh = prep_days_hh+inputs_days_hh+weed_days_hh+harvest_days_hh
gen cult_days_hh_withkids = prep_days_hh_withkids + inputs_days_hh_withkids + weed_days_hh_withkids + harvest_days_hh_withkids
collapse (sum) *days*, by(hhid)
tempfile family
save `family', replace

* HIRED labor (in first crop cycle)
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC6A", clear
destring HHID, gen(hhid)
ren a6aid record
ren a6aq4 hired_days
merge 1:1 hhid record using `maize_plots', keep(3)			//keep only plots with maize

recode hired_days (.=0)
gen cult_days_hired = hired_days
gen cult_days_hired_withkids = hired_days
collapse (sum) cult_days_hired* hired_days, by(hhid)


** BRING TOGETHER
merge 1:1 hhid using `family', nogen				// There is one household that was not matched from master and 10 from using
* We need to keep all observations from both using and master for above merge. This includes all households that had any labor--family or hired--applied to plots.
recode cult_days* (.=0)
merge 1:1 hhid using `plotsowned', keep(1 3) nogen	// There are 357 not matched from master (perhaps they simply don't own plots)
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_tot_kids = cult_days_hh_withkids + cult_days_hired_withkids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Uganda, Wave 1", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/UG1_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto UG1_out_lab




********************************************
*******		  Uganda  2009-2010	    ********
*******		        Wave 2	        ********
********************************************

* weights
use "$data_UG/2009-2010/Dataset/Household/GSEC1", clear
destring HHID, gen(hhid)
gen split2 = hh_status == 3
ren h1aq1 district
ren comm ea2
gen year = h1bq2c
gen month = h1bq2b
gen month_int = (month-1)/12
gen date_int = year+month_int
*egen district = group(region h1aq1)
keep hhid wgt* region district hh_status year month month_int date_int split2 HHID_parent HHID ea2
duplicates drop hhid, force
ren wgt09wo weight_nosplit
ren wgt09 weight
tempfile weights
save `weights', replace


* demographics
use "$data_UG/2009-2010/Dataset/Household/GSEC2", clear
drop if h2q7==5 | h2q7==6 | h2q7==7
destring HHID, replace
ren HHID hhid
ren h2q8 age
gen person = 1
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen female = (h2q3==2)
gen male = (h2q3==1)
gen child = $child
gen own_child = h2q4==3
gen adult_children = own_child==1 & child==0
* Dropping if no longer a member of household
keep if h2q11!=2
ren h2q1 personid
gen man = male*(child==0)
gen woman = female*(child==0)
keep hhid personid man woman child age PID
tempfile hhworkers
save `hhworkers', replace

* determine which crop is on which plot
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren a4aq2 parcel
ren a4aq4 plotnum
ren a4aq6 crop_code
keep if crop_code ==130

keep hhid parcel plotnum crop_code
tempfile maize_plots
save `maize_plots', replace
collapse (first) crop_code , by(hhid parcel)
tempfile maize_parcels
save `maize_parcels', replace

* get total harvested by household
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC5A", clear
destring HHID, replace
ren HHID hhid
ren a5aq5 crop_code
keep if crop_code==130
gen wgt_temp = a5aq6a * a5aq6d
collapse (sum) wgt_tot=wgt_temp, by(hhid)
tempfile crops_tot
save `crops_tot', replace


* plots
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC2A", clear
destring HHID, gen(hhid)
ren a2aq5 acres
replace acres = a2aq4 if acres==.
ren a2aq2 parcel
merge 1:1 hhid parcel using `maize_parcels', keep(3)		// keep only parcels with maize
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots, by(hhid)
tempfile plotsowned
save `plotsowned', replace


* all labor (in first crop cycle)
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
ren a3aq1 parcel
ren a3aq3 plotnum 
keep hhid parcel plotnum a3aq38-a3aq43
merge 1:1 hhid parcel plotnum using `maize_plots', keep(3)		// keep only plots with maize

ren a3aq39 cult_days_hh
recode cult_days_hh (.=0)
gen cult_days_hh_withkids=cult_days_hh
ren a3aq42a man_days
ren a3aq42b woman_days
ren a3aq42c child_days
recode *days (.=0)				// so that we don't try to add missings to numbers
gen cult_days_hired = woman_days + man_days
gen cult_days_hired_withkids = woman_days + man_days + 0.5*child_days
collapse (sum) cult* , by(hhid)


** BRING TOGETHER
merge 1:1 hhid using `plotsowned', keep(1 3) nogen	// 213 not matched from master
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_tot_kids = cult_days_hh_withkids + cult_days_hired_withkids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Uganda, Wave 2", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/UG2_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto UG2_out_lab

format %19.0g hhid
tempfile UG2_data
save `UG2_data', replace





********************************************
*******		  Uganda  2010-2011	    ********
*******		        Wave 3	        ********
********************************************

* weights
use "$data_UG/2010-2011/Dataset/Household/GSEC1", clear
destring HHID, replace
ren HHID hhid
ren comm ea3
gen split3 = spitoff10_11==1
gen split09 = spitoff09_10==1
gen month_int = (month-1)/12
gen date_int = year+month_int
*ren h1aq1 district
egen district = group(region h1aq1)
keep hhid wgt region district hh_status spit* month year month_int date_int split* ea3
duplicates drop hhid, force
ren wgt weight
tempfile weights
save `weights', replace

* demographics
use "$data_UG/2010-2011/Dataset/Household/GSEC2", clear
gen deceased_temp = h2q7==10
bys HHID: egen deceased = sum(deceased_temp)
drop if h2q7==5 | h2q7==6 | h2q7==7 | h2q7==10
destring HHID, replace
ren HHID hhid
gen person = 1
ren h2q8 age
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen female = (h2q3==0)
gen male = (h2q3==1)
gen child = $child
gen own_child = h2q4==3
gen adult_children = own_child==1 & child==0
* Dropping if no longer a member of household
keep if h2q11!=2
ren h2q1 personid
ren h2q4 reltohead

gen man = male*(child==0)
gen woman = female*(child==0)
ren reltohead h2q4
keep hhid PID personid man woman child age h2q4 h2q7
tempfile hhworkers
save `hhworkers', replace


* determine which crop is on which plot
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren prcid parcel
ren pltid plotnum
ren cropID crop_code
keep if crop_code ==130
duplicates drop hhid parcel plotnum, force			// dropping 3 problem observations
keep hhid parcel plotnum crop_code
tempfile maize_plots
save `maize_plots', replace
collapse (first) crop_code , by(hhid parcel)
tempfile maize_parcels
save `maize_parcels', replace

* get total harvested by household
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC5A", clear
destring HHID, replace
ren HHID hhid
ren cropID crop_code
keep if crop_code==130
gen wgt_temp = a5aq6a * a5aq6d
collapse (sum) wgt_tot=wgt_temp, by(hhid)
tempfile crops_tot
save `crops_tot', replace

* plots
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC2A", clear
destring HHID, replace
ren HHID hhid
ren a2aq5 acres
replace acres = a2aq4 if acres==.
ren prcid parcel
merge 1:1 hhid parcel using `maize_parcels', keep(3) 			// keeping only parcel with maize
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots, by(hhid)
tempfile plotsowned
save `plotsowned', replace


* all labor (in first crop cycle)
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
ren prcid parcel
ren pltid plotnum 
keep hhid parcel plotnum a3aq38-a3aq43
merge 1:1 hhid parcel plotnum using `maize_plots', keep(3) 			// keeping only plots with maize
ren a3aq39 cult_days_hh
recode cult_days_hh (.=0)
gen cult_days_hh_withkids=cult_days_hh
ren a3aq42a man_days
ren a3aq42b woman_days
ren a3aq42c child_days
recode *days (.=0)				// so that we don't try to add missings to numbers
gen cult_days_hired = woman_days + man_days
gen cult_days_hired_withkids = woman_days + man_days + 0.5*child_days
collapse (sum) cult* , by(hhid)


** BRING TOGETHER
merge 1:1 hhid using `plotsowned', keep(1 3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_tot_kids = cult_days_hh_withkids + cult_days_hired_withkids

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Uganda, Wave 3", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/UG3_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto UG3_out_lab


format %18.0g hhid
tempfile UG3_data
save `UG3_data', replace


********************************************
*******		  Uganda  2011-2012	    ********
*******		        Wave 4	        ********
********************************************

* weights
use "$data_UG/2011-2012/Dataset/Household/GSEC1", clear
destring HHID, gen(hhid)
format hhid %19.0g
ren comm ea4
gen split4 = wave==3
gen appearance = wave
gen original = wave==0
ren h1aq1 district
gen month_int = (month-1)/12
gen date_int = year+month_int
*egen district1 = group(region district)
destring district, replace
keep hhid mult region district HH_2005 month year month_int date_int split* original appearance ea4
duplicates drop hhid, force
ren mult weight
tempfile weights
save `weights', replace

* demographics
use "$data_UG/2011-2012/Dataset/Household/GSEC2", clear
destring HHID, gen(hhid)
format hhid %19.0g
drop if h2q7==5 | h2q7==6 | h2q7==7
duplicates tag PID, gen(tag)
drop if tag==1 & h2q5==.	// This drops the duplicates correctly
drop tag
ren h2q8 age
gen person = 1
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen child = $child
gen female = (h2q3==2)
gen male = (h2q3==1)
gen own_child = h2q4==3
gen adult_children = own_child==1 & child==0
*Dropping if no longer a member of household
keep if h2q11!=2
destring h2q1, replace
ren h2q1 personid
ren h2q4 reltohead
gen man = male*(child==0)
gen woman = female*(child==0)
keep hhid personid man woman child age PID
tempfile hhworkers
save `hhworkers', replace

* determine which crop is on which plot
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren parcelID parcel
ren plotID plotnum
ren cropID crop_code
keep if crop_code ==130
duplicates drop hhid parcel plotnum, force			// dropping 9 problem observations
keep hhid parcel plotnum crop_code
tempfile maize_plots
save `maize_plots', replace
collapse (first) crop_code , by(hhid parcel)
tempfile maize_parcels
save `maize_parcels', replace

* get total harvested by household
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC5A", clear
destring HHID, replace
ren HHID hhid
ren cropID crop_code
keep if crop_code==130
gen wgt_temp = a5aq6a * a5aq6d
collapse (sum) wgt_tot=wgt_temp, by(hhid)
tempfile crops_tot
save `crops_tot', replace


* plots
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC2A", clear
gen double hhid = HHID
format hhid %19.0g
ren a2aq5 acres
ren parcelID parcel
merge 1:1 hhid parcel using `maize_parcels', keep(3) 		// keep only parcels with maize
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots, by(hhid)
tempfile plotsowned
save `plotsowned', replace


* all labor (in first crop cycle)
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC3A", clear
gen double hhid = HHID
format hhid %19.0g
ren parcelID parcel
ren plotID plotnum 
keep hhid parcel plotnum a3aq31-A3AQ49
merge 1:1 hhid parcel plotnum using `maize_plots', keep(3) 		// keep only plots with maize
ren a3aq32 cult_days_hh
recode cult_days_hh (.=0)
gen cult_days_hh_withkids=cult_days_hh
ren a3aq35a man_days
ren a3aq35b woman_days
ren a3aq35c child_days
recode *days (.=0)				// so that we don't try to add missings to numbers
recode A3AQ47 A3AQ48 A3AQ49 (.=0)
gen cult_days_hired = woman_days + man_days
gen cult_days_hired_withkids = woman_days + man_days + 0.5*child_days
gen cult_days_free = A3AQ47 + A3AQ48
gen cult_days_free_withkids = A3AQ47 + A3AQ48 + 0.5*A3AQ49
recode cult* (.=0)
collapse (sum) cult* , by(hhid)
tempfile labor
save `labor'


** BRING TOGETHER
use `weights', clear

merge 1:1 hhid using `labor', keep(1 3) nogen		// 689 not matched (2161 matched; not matched have no agriculture)
merge 1:1 hhid using `plotsowned', keep(1 3) nogen	// 876 not matched (no owned plots)
merge 1:1 hhid using `crops_tot', keep(3) nogen

* create LD variables
gen ld_tot_kids = cult_days_hh_withkids + cult_days_hired_withkids
replace ld_tot_kids = ld_tot_kids + cult_days_free_withkids if cult_days_free_withkids!=.

* create Total Product of Labor curve
*gen log_out_acres = ln(wgt_fresh)
gen log_out_acres = ln(wgt_tot / acres)
gen log_lab_acres = ln(ld_tot_kids / acres)

sum log_out_acres, det
drop if log_out_acres > r(p99)
drop if log_out_acres < r(p1)

sum log_lab_acres, det
drop if log_lab_acres > r(p99)
drop if log_lab_acres < r(p1)

twoway (scatter log_out_acres log_lab_acres, mcolor(gray))  (qfit log_out_acres log_lab_acres, lc(black)), ///
	graphregion(color(white)) bgcolor(white) title("Uganda, Wave 4", color(black) size(7)) ///
	ytitle("Log(Output per Acre)", size(5)) xtitle("Log(Labor per Acre)", size(5)) ///
	legend(off)
graph export "$path/output/UG4_tpl_maize.pdf", replace

gen log_lab_sq = log_lab_acres * log_lab_acres
reg log_out_acres log_lab_acres log_lab_sq
est sto UG4_out_lab

estout UG*out_lab using "$path/output/UG_tpl_regs.tex", cells(b(star fmt(3)) se(par fmt(3))) ///
	stats(N r2, fmt(%10.0fc 2) labels("\hline Observations" "\$R^2\$")) ///
	starlevels(* 0.10 ** 0.05 *** 0.01) style(tex) nonumbers ///
	mlabels(none) coll(none) substitute(_ \_) replace
	


