clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000


********************************************
*******		  Uganda  2005-2006	    ********
*******		        Wave 1	        ********
********************************************

* weights
use "$data_UG/2005-2006/Dataset/Household/GSEC1", clear
destring HHID, replace
ren HHID hhid
ren comm ea1
gen year = h1bq2c
gen month = h1bq2b
gen month_int = (month-1)/12
gen date_int = year+month_int
gen district = h1aq1
destring district, replace
keep hhid hmult region district year month month_int date_int ea1
duplicates drop hhid, force
ren hmult weight
tempfile weights
save `weights', replace


* demographics
use "$data_UG/2005-2006/Dataset/Household/GSEC2", clear
destring HHID, replace
ren HHID hhid
ren h2q9 age
gen person = 1
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen female = (h2q4==2)
gen male = (h2q4==1)
gen child = $child
gen own_child = h2q5==3
gen adult_children = own_child==1 & child==0
* Dropping if no longer a member of household
keep if h2q13==1
ren pid personid
ren h2q5 reltohead
preserve
keep hhid personid PID reltohead
tempfile PID
save `PID', replace
restore
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
keep hhid personid man woman child age male age PID reltohead
tempfile hhworkers
save `hhworkers', replace
save "$newdata/UG1_hh_ages.dta", replace
restore

gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were not away from the household
gen hhsize_away = hhsize*(h2q6)/12
gen hhsize_phase_away = hhsize_phase*(h2q6)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename h2q6 months_away
replace months_away = 12 - months_away
gen temp_migrant = months_away > 2 & age >=15

tempfile ind_ug1
save `ind_ug1', replace
collapse (sum) person prime* eld* hhsize* male* female* child own_child adult_children (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile demog
save `demog', replace


*Age of househead age*
use "$data_UG/2005-2006/Dataset/Household/GSEC2", clear
destring HHID, replace
ren HHID hhid
gen male_head = h2q4==1 if h2q5==1
ren pid personid
gen agehhhead1 =  h2q9 if h2q5==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1 male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* Education *
use "$data_UG/2005-2006/Dataset/Household/GSEC4", clear
merge 1:1 PID using "$data_UG/2005-2006/Dataset/Household/GSEC2", keep(3)
destring HHID, replace
rename HHID hhid
rename pid personid
ren h4q4 f
gen educ = f-10 if inlist(f,10,11,12,13,14,15,16,17)
replace educ = 7 if inlist(f,21,22,23)
replace educ = f-23 if inlist(f,31,32,33,34,35,36)
replace educ = 0 if h4q2==1
gen head_educ = educ if h2q5==1
label var head_educ "Highest education attained by household head"

preserve
collapse (first) head_educ, by(hhid)
tempfile head_educ
save `head_educ', replace
restore

label var educ "Highest education attained"
keep hhid personid educ head_educ
tempfile education
save `education', replace

* get hh consumption *
use "$data_UG/2005-2006/Dataset/Consumption aggregate/2005-06 consumption.dta", clear
destring HHID, replace
rename HHID hhid
keep hhid welfare cpexp30 hsize
gen exp_pc = cpexp30 / hsize
tempfile hh_consum
save `hh_consum', replace

* get AEZ info *
use "$data_UG/2009-2010/Dataset/Geovariables/UNPS_Geovars_0910.dta", clear
destring HHID, gen(hhid)
gen aez = 1 if ssa_ae==314
replace aez = 2 if ssa_ae==324
replace aez = 3 if aez==.
keep hhid aez dist_market dist_popcenter
isid hhid
tempfile geo
save `geo', replace

* plots
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC2A", clear
destring HHID, replace
ren HHID hhid
ren a2aq5 acres
ren a2aq2 parcel
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots, by(hhid)
tempfile plotsowned
save `plotsowned', replace

use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC2A", clear
destring HHID, replace
ren HHID hhid
ren a2aq5 acres
ren a2aq2 parcel
ren a2aq7 ten
ren a2aq13a use
gen own=1							// parcels in this section are all "owned" in some sense
gen rent=0
gen borrow=0
gen cult = inlist(use,1,2)
gen out = inlist(use,3,4)
gen fallow = use==5
gen other = inlist(use,6,7,8)
keep hhid acres parcel use own-other
tempfile owned
save `owned', replace

use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC2B", clear
destring HHID, replace
ren HHID hhid
ren a2bq5 acres
ren a2bq2 parcel
preserve
keep hhid parcel acres
append using `parcel_owned'
tempfile parcellist
save `parcellist', replace
restore
gen own = 0
gen rent = (a2bq9>0) & (a2bq9<.)
gen borrow = (rent==0)
ren a2bq15a use
tab use
gen cult = inlist(use,1,2)
gen fallow = use==5
gen other  = inlist(use,6,7,8)
gen out = use==3
keep hhid acres parcel own-out
append using `owned'
gen tenure = own+rent+borrow
gen usage = cult+fallow+other+out
assert tenure==1
assert usage<=1
keep if cult==1
gen owned_acres = acres*own
collapse (sum) owned_acres acres, by(hhid)
tempfile plots
save `plots', replace

* FAMILY labor (in first crop cycle)
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC5A", clear
destring HHID, gen(hhid)
ren a5aq2 parcel
ren a5aq3 plotnum 
recode a5aq* (.=0)
ren a5aq4 prep_days_male
ren a5aq5 prep_days_female
ren a5aq6 prep_days_child
gen prep_days_hh = prep_days_male+prep_days_female
gen prep_days_hh_withkids = prep_days_male+prep_days_female+(prep_days_child*0.5)
ren a5aq7 inputs_days_male
ren a5aq8 inputs_days_female
ren a5aq9 inputs_days_child
gen inputs_days_hh = inputs_days_male+inputs_days_female
gen inputs_days_hh_withkids = inputs_days_male+inputs_days_female+(inputs_days_child*0.5)
ren a5aq10 weed_days_male
ren a5aq11 weed_days_female
ren a5aq12 weed_days_child
gen weed_days_hh = weed_days_male+weed_days_female
gen weed_days_hh_withkids = weed_days_male+weed_days_female+(weed_days_child*0.5)
ren a5aq13 harvest_days_male
ren a5aq14 harvest_days_female
ren a5aq15 harvest_days_child
gen harvest_days_hh = harvest_days_male+harvest_days_female
gen harvest_days_hh_withkids = harvest_days_male+harvest_days_female+(harvest_days_child*0.5)
gen cult_days_hh = prep_days_hh+inputs_days_hh+weed_days_hh+harvest_days_hh
gen cult_days_hh_withkids = prep_days_hh_withkids + inputs_days_hh_withkids + weed_days_hh_withkids + harvest_days_hh_withkids
collapse (sum) *days*, by(hhid)
tempfile family
save `family', replace

* HIRED labor (in first crop cycle)
use "$data_UG/2005-2006/Dataset/Agriculture/AGSEC6A", clear
destring HHID, gen(hhid)
ren a6aq4 hired_days
recode hired_days (.=0)
gen cult_days_hired = hired_days
gen cult_days_hired_withkids = hired_days
collapse (sum) cult_days_hired* hired_days, by(hhid)


** BRING TOGETHER
merge 1:1 hhid using `family', nogen
recode cult_days* (.=0)
merge 1:1 hhid using `plots', keep(1 3) nogen
merge 1:1 hhid using `plotsowned', keep(1 3) nogen
merge 1:1 hhid using `demog', keep(3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `hh_consum', keep(3) force nogen
merge 1:1 hhid using `head_educ', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `geo', keep(1 3) nogen
tempfile UG1_data
save `UG1_data', replace



********************************************
*******		  Uganda  2009-2010	    ********
*******		        Wave 2	        ********
********************************************

* weights
use "$data_UG/2009-2010/Dataset/Household/GSEC1", clear
destring HHID, gen(hhid)
gen split2 = hh_status == 3
ren h1aq1 district
ren comm ea2
gen year = h1bq2c
gen month = h1bq2b
gen month_int = (month-1)/12
gen date_int = year+month_int
*egen district = group(region h1aq1)
keep hhid wgt* region district hh_status year month month_int date_int split2 HHID_parent HHID ea2
duplicates drop hhid, force
ren wgt09wo weight_nosplit
ren wgt09 weight
tempfile weights
save `weights', replace


* demographics
use "$data_UG/2009-2010/Dataset/Household/GSEC2", clear
drop if h2q7==5 | h2q7==6 | h2q7==7
destring HHID, replace
ren HHID hhid
ren h2q8 age
gen person = 1
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen female = (h2q3==2)
gen male = (h2q3==1)
gen child = $child
gen own_child = h2q4==3
gen adult_children = own_child==1 & child==0
* Dropping if no longer a member of household
keep if h2q11!=2
ren h2q1 personid
ren h2q4 reltohead
preserve
keep hhid personid PID reltohead
tempfile PID
save `PID', replace
restore
preserve
keep hhid PID personid age male reltohead
save "$newdata/UG2_hh_ages.dta", replace
restore
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
keep hhid personid man woman child age PID
tempfile hhworkers
save `hhworkers', replace
restore
gen aged_in = age>=15 & age<=19
gen aged_out = age>60 & age<=64
recode h2q9c (9999=.)		// Recoding don't know years to missing 

gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were present in the household
gen hhsize_away = hhsize*(h2q5)/12
gen hhsize_phase_away = hhsize_phase*(h2q5)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename h2q5 months_away
replace months_away = 12 - months_away
gen temp_migrant = months_away > 2 & age >=15

tempfile ind_ug2
save `ind_ug2', replace
collapse (sum) person prime* eld* hhsize* male* female* child own_child adult_children aged* (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile demog
save `demog', replace


*Age of househead age*
use "$data_UG/2009-2010/Dataset/Household/GSEC2", clear
destring HHID, replace
ren HHID hhid
ren h2q1 personid
gen agehhhead1 =  h2q8 if h2q4==1
gen male_head = h2q3==1 if h2q4==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1 male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* Education *
use "$data_UG/2009-2010/Dataset/Household/GSEC4", clear
merge 1:1 PID using "$data_UG/2009-2010/Dataset/Household/GSEC2", keep(3)
destring HHID, gen(hhid)
rename PID personid
ren h4q7 f
gen educ = f-10 if inlist(f,10,11,12,13,14,15,16,17)
replace educ = 7 if inlist(f,21,22,23)
replace educ = f-23 if inlist(f,31,32,33,34,35,36)
replace educ = 0 if h4q5==1		

replace educ = h4q9 if h4q9==1
replace educ = h4q9-10 if inlist(h4q9,10,11,12,13,14,15,16,17)
replace educ = h4q9-23 if inlist(h4q9,31,32,33,34,35,36)

gen head_educ = educ if h2q4==1
label var head_educ "Highest education attained by household head"

preserve
collapse (first) head_educ, by(hhid)
tempfile head_educ
save `head_educ', replace
restore

label var educ "Highest education attained"
keep hhid personid educ head_educ
tempfile education
save `education', replace


* get hh consumption *
use "$data_UG/2009-2010/Dataset/Consumption aggregate/UNPS 2009-10 Consumption Aggregate.dta", clear
destring HHID, replace
rename HHID hhid
keep hhid welfare cpexp30
rename welfare exp_pc
replace exp_pc = exp_pc*12			// convernt monthly exp to yearly
tempfile hh_consum
save `hh_consum', replace

* get hh assets
use "$data_UG/2009-2010/Dataset/Household/GSEC14", clear
destring HHID, gen(hhid)
keep hhid h14q2 h14q4
replace h14q4=0 if h14q4==.
reshape wide h14q4, i(hhid) j(h14q2)
factor h14q4*, fa(1)
predict pc1_wealth, r
drop h14q4*
tempfile hh_wealth
save `hh_wealth', replace

* determine which crop is on which plot
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren a4aq2 parcel
ren a4aq4 plotnum
ren a4aq6 crop_code
gen maize = crop_code==130
gen beans = crop_code==210
gen cassava = crop_code==630
keep hhid parcel plotnum maize beans cassava
tempfile crop_plots
save `crop_plots', replace
collapse (max) maize beans cassava , by(hhid parcel)
tempfile crop_parcels
save `crop_parcels', replace


* plots
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC2A", clear
destring HHID, gen(hhid)
ren a2aq5 acres
replace acres = a2aq4 if acres==.
ren a2aq2 parcel
gen irrigated = a2aq20==1
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots (max) irrigated, by(hhid)
tempfile plotsowned
save `plotsowned', replace

use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC2A", clear
destring HHID, gen(hhid)
ren a2aq5 acres
replace acres = a2aq4 if acres==.
ren a2aq2 parcel
ren a2aq7 ten
ren a2aq13a use
gen own=1							// parcels in this section are all "owned" in some sense
gen rent=0
gen borrow=0
gen cult = inlist(use,1,2)
gen out = inlist(use,3,4)
gen fallow = use==5
gen other = inlist(use,6,7,96)
keep hhid acres parcel use own-other
tempfile owned
save `owned', replace

use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC2B", clear
destring HHID, gen(hhid)
ren a2bq5 acres
replace acres = a2bq4 if acres==.
ren a2bq2 parcel
preserve
keep hhid parcel acres
append using `parcel_owned'
tempfile parcellist
save `parcellist', replace
restore
gen own = 0
gen rent = (a2bq9>0) & (a2bq9<.)
gen borrow = (rent==0)
ren a2bq15a use
tab use
gen cult = inlist(use,1,2)
gen fallow = use==5
gen other  = inlist(use,3,6,7,96)
gen out = 0
keep hhid acres parcel own-out
append using `owned'
gen tenure = own+rent+borrow
gen usage = cult+fallow+other+out
assert tenure==1
assert usage<=1
keep if cult==1
merge 1:1 hhid parcel using `crop_parcels', keep(1 3) nogen
gen owned_acres = acres*own
gen acres_maize = acres*maize
gen acres_beans = acres*beans
gen acres_cassava = acres*cassava
collapse (sum) owned_acres acres* (max) maize beans cassava, by(hhid)
tempfile plots
save `plots', replace

* get inputs
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
gen fertilized = (a3aq4==1) | (a3aq14==1)
collapse (max) fertilized, by(hhid)
tempfile inputs
save `inputs', replace

* get crop sales
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC5A", clear
destring HHID, replace
ren HHID hhid
gen any_sold = a5aq7a>0 & a5aq7a<.
collapse (max) any_sold, by(hhid)
tempfile sales
save `sales', replace

* family labor (in first crop cycle)
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC3A", clear
destring HHID, gen(hhid)
ren a3aq1 parcel
ren a3aq3 plotnum 
keep hhid parcel plotnum a3aq38-a3aq43
ren a3aq39 cult_days_hh
ren a3aq40a personid1
ren a3aq40b personid2
ren a3aq40c personid3
drop if parcel==. | plotnum==.
reshape long personid, i(hhid parcel plotnum) j(num)
drop if personid==. & (cult_days_hh==0 | cult_days_hh ==.)
drop if personid==0 & (cult_days_hh ==0 | cult_days_hh ==.)
sum cult_days_hh if personid==.
sum cult_days_hh if personid==0
collapse (mean) cult_days_hh, by(hhid personid)
drop if personid==.
merge 1:1 hhid personid using `hhworkers', keep(1 3) nogen
save "$newdata/UG2_prep_ages.dta", replace


* all labor (in first crop cycle)
use "$data_UG/2009-2010/Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
ren a3aq1 parcel
ren a3aq3 plotnum 
keep hhid parcel plotnum a3aq38-a3aq43
ren a3aq39 cult_days_hh
recode cult_days_hh (.=0)
gen cult_days_hh_withkids=cult_days_hh
ren a3aq42a man_days
ren a3aq42b woman_days
ren a3aq42c child_days
recode *days (.=0)
gen cult_days_hired = woman_days + man_days
gen cult_days_hired_withkids = woman_days + man_days + 0.5*child_days
collapse (sum) cult* , by(hhid)


** BRING TOGETHER
merge 1:1 hhid using `plots', keep(1 3) nogen
merge 1:1 hhid using `plotsowned', keep(1 3) nogen
merge 1:1 hhid using `demog', keep(3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `hh_consum', keep(3) nogen force
merge 1:1 hhid using `hh_wealth', keep(1 3) nogen force
merge 1:1 hhid using `head_educ', keep(1 3) nogen
merge 1:1 hhid using `inputs', keep(1 3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen

format %19.0g hhid
tempfile UG2_data
save `UG2_data', replace





********************************************
*******		  Uganda  2010-2011	    ********
*******		        Wave 3	        ********
********************************************

* weights
use "$data_UG/2010-2011/Dataset/Household/GSEC1", clear
destring HHID, replace
ren HHID hhid
ren comm ea3
gen split3 = spitoff10_11==1
gen split09 = spitoff09_10==1
gen month_int = (month-1)/12
gen date_int = year+month_int
egen district = group(region h1aq1)
keep hhid wgt region district hh_status spit* month year month_int date_int split* ea3
duplicates drop hhid, force
ren wgt weight
tempfile weights
save `weights', replace

* demographics
use "$data_UG/2010-2011/Dataset/Household/GSEC2", clear
gen deceased_temp = h2q7==10
bys HHID: egen deceased = sum(deceased_temp)
drop if h2q7==5 | h2q7==6 | h2q7==7 | h2q7==10
destring HHID, replace
ren HHID hhid
gen person = 1
ren h2q8 age
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen female = (h2q3==0)
gen male = (h2q3==1)
gen child = $child
gen own_child = h2q4==3
gen adult_children = own_child==1 & child==0
* Dropping if no longer a member of household
keep if h2q11!=2
ren h2q1 personid
ren h2q4 reltohead
preserve
keep hhid personid PID reltohead
tempfile PIDs
save `PIDs', replace
restore
preserve
keep hhid PID personid age male reltohead
save "$newdata/UG3_hh_ages.dta", replace
restore
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
ren reltohead h2q4
keep hhid PID personid man woman child age h2q4 h2q7
tempfile hhworkers
save `hhworkers', replace
bysort hhid personid: egen temp_min = min(h2q4)
drop if temp_min != h2q4
bysort hhid personid: egen temp_max = max(age)
drop if temp_max != age
duplicates tag hhid personid, gen(temp)
drop if h2q7==2 & temp==1
drop temp
duplicates tag hhid personid, gen(temp)
drop if h2q7==. & temp==1
isid hhid personid

keep hhid personid PID age
tempfile hhworkers2
save `hhworkers2', replace

restore
gen aged_in = age==15
gen aged_out = age>60 & age<=61

gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were present in the household
gen hhsize_away = hhsize*(h2q5)/12
gen hhsize_phase_away = hhsize_phase*(h2q5)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename h2q5 months_away
replace months_away = 12 - months_away
gen temp_migrant = months_away > 2 & age >=15

tempfile ind_ug3
save `ind_ug3', replace
collapse (sum) person prime* eld* hhsize* male* female* child own_child adult_children aged* (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile demog
save `demog', replace

*Age of househead age*
use "$data_UG/2010-2011/Dataset/Household/GSEC2", clear
destring HHID, replace
ren HHID hhid
ren h2q1 personid
gen agehhhead1 =  h2q8 if h2q4==1
gen male_head = h2q3==1 if h2q4==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1 male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* Education *
use "$data_UG/2010-2011/Dataset/Household/GSEC4", clear
merge 1:1 PID using "$data_UG/2010-2011/Dataset/Household/GSEC2", keep(3)
destring HHID, replace
rename HHID hhid
rename PID personid
ren h4q7 f
gen educ = f-10 if inlist(f,10,11,12,13,14,15,16,17)
replace educ = 7 if inlist(f,21,22,23)
replace educ = f-23 if inlist(f,31,32,33,34,35,36)
replace educ = 0 if h4q5==1
gen head_educ = educ if h2q4==1
label var head_educ "Highest education attained by household head"

preserve
collapse (first) head_educ, by(hhid)
tempfile head_educ
save `head_educ', replace
restore

label var educ "Highest education attained"
keep hhid personid educ head_educ
tempfile education
save `education', replace

* determine which crop is on which plot
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren prcid parcel
ren pltid plotnum
ren cropID crop_code
gen maize = crop_code==130
gen beans = crop_code==210
gen cassava = crop_code==630
keep hhid parcel plotnum maize beans cassava
tempfile crop_plots
save `crop_plots', replace
collapse (max) maize beans cassava , by(hhid parcel)
tempfile crop_parcels
save `crop_parcels', replace

* plots
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC2A", clear
destring HHID, replace
ren HHID hhid
ren a2aq5 acres
replace acres = a2aq4 if acres==.
ren prcid parcel
gen irrigated = a2aq20==1
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots (max) irrigated, by(hhid)
tempfile plotsowned
save `plotsowned', replace

use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC2A", clear
destring HHID, replace
ren HHID hhid
ren a2aq5 acres
replace acres = a2aq4 if acres==.
ren prcid parcel
ren a2aq7 ten
ren a2aq13a use
gen own=1							// parcels in this section are all "owned" in some sense
gen rent=0
gen borrow=0
gen cult = inlist(use,1,2)
gen out = inlist(use,3,4)
gen fallow = use==5
gen other = inlist(use,6,7,96)
keep hhid acres parcel use own-other
tempfile owned
save `owned', replace

use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC2B", clear
destring HHID, replace
ren HHID hhid
ren a2bq5 acres
replace acres = a2bq4 if acres==.
ren prcid parcel
preserve
keep hhid parcel acres
append using `parcel_owned'
tempfile parcellist
save `parcellist', replace
restore
gen own = 0
gen rent = (a2bq9>0) & (a2bq9<.)
gen borrow = (rent==0)
ren a2bq15a use
tab use
gen cult = inlist(use,1,2)
gen fallow = use==5
gen other  = use==96
gen out = 0
keep hhid acres parcel own-out
append using `owned'
gen tenure = own+rent+borrow
gen usage = cult+fallow+other+out
assert tenure==1
assert usage<=1
keep if cult==1
merge 1:1 hhid parcel using `crop_parcels', keep(1 3) nogen
gen owned_acres = acres*own
gen acres_maize = acres*maize
gen acres_beans = acres*beans
gen acres_cassava = acres*cassava
collapse (sum) owned_acres acres* (max) maize beans cassava, by(hhid)
tempfile plots
save `plots', replace

* get inputs
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
gen fertilized = (a3aq4==1) | (a3aq14==1)
collapse (max) fertilized, by(hhid)
tempfile inputs
save `inputs', replace

* get crop sales
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC5A", clear
destring HHID, replace
ren HHID hhid
gen any_sold = a5aq7a>0 & a5aq7a<.
collapse (max) any_sold, by(hhid)
tempfile sales
save `sales', replace

* ages for family labor (in first crop cycle)
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC3A", clear
destring HHID, gen(hhid)
ren prcid parcel
ren pltid plotnum 
keep hhid parcel plotnum a3aq38-a3aq43
ren a3aq39 cult_days_hh
ren a3aq40a personid1
ren a3aq40b personid2
ren a3aq40c personid3
drop if parcel==. | plotnum==.
reshape long personid, i(hhid parcel plotnum) j(num)
drop if personid==. & (cult_days_hh==0 | cult_days_hh ==.)
drop if personid==0 & (cult_days_hh ==0 | cult_days_hh ==.)
sum cult_days_hh if personid==.
sum cult_days_hh if personid==0
collapse (mean) cult_days_hh, by(hhid personid)
drop if personid==.
merge 1:1 hhid personid using `hhworkers2', keep(1 3) nogen
isid hhid personid
save "$newdata/UG3_prep_ages.dta", replace

* all labor (in first crop cycle)
use "$data_UG/2010-2011/Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
ren prcid parcel
ren pltid plotnum 
keep hhid parcel plotnum a3aq38-a3aq43
ren a3aq39 cult_days_hh
recode cult_days_hh (.=0)
gen cult_days_hh_withkids=cult_days_hh
ren a3aq42a man_days
ren a3aq42b woman_days
ren a3aq42c child_days
recode *days (.=0)
gen cult_days_hired = woman_days + man_days
gen cult_days_hired_withkids = woman_days + man_days + 0.5*child_days
collapse (sum) cult* , by(hhid)


** BRING TOGETHER
merge 1:1 hhid using `plots', keep(3) nogen
merge 1:1 hhid using `plotsowned', keep(1 3) nogen
merge 1:1 hhid using `demog', keep(3) nogen
merge 1:1 hhid using `household_headage', assert(2 3) keep(3) nogen
merge 1:1 hhid using `weights', assert(2 3) keep(3) nogen
merge 1:1 hhid using `head_educ', keep(3) nogen
merge 1:1 hhid using `inputs', keep(1 3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen


format %18.0g hhid
tempfile UG3_data
save `UG3_data', replace




********************************************
*******		  Uganda  2011-2012	    ********
*******		        Wave 4	        ********
********************************************

* weights
use "$data_UG/2011-2012/Dataset/Household/GSEC1", clear
destring HHID, gen(hhid)
format hhid %19.0g
ren comm ea4
gen split4 = wave==3
gen appearance = wave
gen original = wave==0
ren h1aq1 district
gen month_int = (month-1)/12
gen date_int = year+month_int
destring district, replace
keep hhid mult region district HH_2005 month year month_int date_int split* original appearance ea4
duplicates drop hhid, force
ren mult weight
tempfile weights
save `weights', replace

* demographics
use "$data_UG/2011-2012/Dataset/Household/GSEC2", clear
destring HHID, gen(hhid)
format hhid %19.0g
drop if h2q7==5 | h2q7==6 | h2q7==7
duplicates tag PID, gen(tag)
drop if tag==1 & h2q5==.	// This drops the duplicates
drop tag
ren h2q8 age
gen person = 1
gen prime_noage = ($prime_noage)
gen hhsize = $hhsize
replace hhsize = 1 if age>60 & age!=.
gen child = $child
gen female = (h2q3==2)
gen male = (h2q3==1)
gen own_child = h2q4==3
gen adult_children = own_child==1 & child==0
*Dropping if no longer a member of household
keep if h2q11!=2
destring h2q1, replace
preserve
duplicates drop PID, force
tempfile merge
save `merge', replace
restore
ren h2q1 personid
ren h2q4 reltohead
preserve
keep hhid personid PID reltohead
tempfile PID
save `PID', replace
restore
preserve
keep hhid PID personid age male reltohead
* need to make file unique by hhid and personid to match with family labor demand information
destring PID, replace
duplicates tag PID, gen(temp)
drop if temp!=0
drop temp
save "$newdata/UG4_hh_ages.dta", replace
restore
preserve
gen man = male*(child==0)
gen woman = female*(child==0)
keep hhid personid man woman child age PID
tempfile hhworkers
save `hhworkers', replace
restore
gen aged_in = age==15
gen aged_out = age>60 & age<=61

gen prime_male = ($prime)*male
gen prime_female = ($prime)*female
gen eld_male = ($elderly)*male
gen eld_female = ($elderly)*female
gen hhsizeprime = age>=15 & age<=60
gen hhsize_phase = hhsize
replace hhsize_phase = (age-10)*0.2 if age<15 & age>=10		// child phase-in, a 10yr old is worth 0, 11yr is worth 0.2 and a 15yr is worth 1
gen male_phase = hhsize_phase * male
gen female_phase = hhsize_phase * female
gen hhsize_male = hhsize * male
gen hhsize_female = hhsize * female

*weight people by how long they were present in the household
gen hhsize_away = hhsize*(h2q5)/12
gen hhsize_phase_away = hhsize_phase*(h2q5)/12
gen male_phase_away = hhsize_phase_away * male
gen female_phase_away = hhsize_phase_away * female
rename h2q5 months_away
replace months_away = 12 - months_away
gen temp_migrant = months_away > 2 & age >=15

tempfile ind_ug4
save `ind_ug4', replace
collapse (sum) person prime* eld* hhsize* male* female* child own_child adult_children aged* (mean) temp_migrant months_away (max) any_migrant=temp_migrant, by(hhid)
tempfile demog
save `demog', replace

*Age of househead age*
use "$data_UG/2011-2012/Dataset/Household/GSEC2", clear
destring HHID, gen(hhid)
format hhid %19.0g
ren h2q1 personid
gen agehhhead1 =  h2q8 if h2q4==1
gen male_head = h2q3==1 if h2q4==1
gen agehhead_squared1 = agehhhead1*agehhhead1
collapse agehhhead1 agehhead_squared1 male_head, by(hhid)
tempfile household_headage 
save `household_headage', replace

* Education *
use "$data_UG/2011-2012/Dataset/Household/GSEC4", clear
destring HHID, gen(hhid)
format hhid %19.0g
duplicates tag PID, gen(tag)
drop if tag==1 & h4q7==. & h4q9==. & h4q10==.
drop if tag==1 & (h4q7==. | h4q7==99) & h4q9==99 & h4q10==99
duplicates drop PID, force		
merge 1:1 PID using `merge', keep(3) nogen
rename PID personid
ren h4q7 f
gen educ = f-10 if inlist(f,10,11,12,13,14,15,16,17)
replace educ = 7 if inlist(f,21,22,23)
replace educ = f-23 if inlist(f,31,32,33,34,35,36)
replace educ = 0 if h4q5==1	
gen head_educ = educ if h2q4==1
label var head_educ "Highest education attained by household head"

preserve
collapse (first) head_educ, by(hhid)
tempfile head_educ
save `head_educ', replace
restore

label var educ "Highest education attained"
keep hhid personid educ head_educ
tempfile education
save `education', replace

* determine which crop is on which plot
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC4A", clear
destring HHID, replace
ren HHID hhid
ren parcelID parcel
ren plotID plotnum
ren cropID crop_code
gen maize = crop_code==130
gen beans = crop_code==210
gen cassava = crop_code==630
keep hhid parcel plotnum maize beans cassava
tempfile crop_plots
save `crop_plots', replace
collapse (max) maize beans cassava , by(hhid parcel)
tempfile crop_parcels
save `crop_parcels', replace

* plots
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC2A", clear
gen double hhid = HHID
format hhid %19.0g
ren a2aq5 acres
ren parcelID parcel
gen irrigated = a2aq18==1
preserve
keep hhid parcel acres
tempfile parcel_owned
save `parcel_owned', replace
restore
gen numplots = 1
collapse (sum) acres numplots (max) irrigated, by(hhid)
tempfile plotsowned
save `plotsowned', replace

use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC2A", clear
gen double hhid = HHID
format hhid %19.0g
ren a2aq5 acres
ren parcelID parcel
ren a2aq7 ten
ren a2aq11a use
gen own=1							// parcels in this section are all "owned" in some sense
gen rent=0
gen borrow=0
gen cult = inlist(use,1,2)
gen out = inlist(use,3,4)
gen fallow = use==5
gen other = inlist(use,6,7,96)
keep hhid acres parcel use own-other
tempfile owned
save `owned', replace

use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC2B", clear
gen double hhid = HHID
format hhid %19.0g
ren a2bq5 acres
ren parcelID parcel
preserve
keep hhid parcel acres
append using `parcel_owned'
tempfile parcellist
save `parcellist', replace
restore
gen own = 0
gen rent = (a2bq9>0) & (a2bq9<.)
gen borrow = (rent==0)
ren a2bq12a use
tab use
gen cult = inlist(use,1,2)
gen fallow = use==5
gen other  = inlist(use,3,6,96)
gen out = 0
keep hhid acres parcel own-out
append using `owned'
gen tenure = own+rent+borrow
gen usage = cult+fallow+other+out
assert tenure==1
assert usage<=1
keep if cult==1
merge 1:1 hhid parcel using `crop_parcels', keep(1 3) nogen
gen owned_acres = acres*own
gen acres_maize = acres*maize
gen acres_beans = acres*beans
gen acres_cassava = acres*cassava
collapse (sum) owned_acres acres* (max) maize beans cassava, by(hhid)
tempfile plots
save `plots', replace

* get inputs
use "$data_UG/2011-2012//Dataset/Agriculture/AGSEC3A", clear
destring HHID, replace
ren HHID hhid
gen fertilized = (a3aq4==1) | (a3aq13==1)
collapse (max) fertilized, by(hhid)
tempfile inputs
save `inputs', replace

* get crop sales
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC5A", clear
destring HHID, replace
ren HHID hhid
gen any_sold = a5aq7a>0 & a5aq7a<.
collapse (max) any_sold, by(hhid)
tempfile sales
save `sales', replace

* ages for family labor (in first crop cycle)
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC3A", clear
gen double hhid = HHID
format hhid %19.0g
ren parcelID parcel
ren plotID plotnum 
keep hhid parcel plotnum a3aq31-A3AQ49
ren a3aq32 cult_days_hh

ren a3aq33a PID1
ren a3aq33b PID2
ren a3aq33c PID3
drop if parcel==. | plotnum==.
reshape long PID, i(hhid parcel plotnum) j(num)
drop if PID==.
drop if PID==0
collapse (mean) cult_days_hh, by(PID)
merge 1:1 PID using "$newdata/UG4_hh_ages.dta", keep(1 3) nogen
save "$newdata/UG4_prep_ages.dta", replace


* all labor (in first crop cycle)
use "$data_UG/2011-2012/Dataset/Agriculture/AGSEC3A", clear
gen double hhid = HHID
format hhid %19.0g
ren parcelID parcel
ren plotID plotnum 
keep hhid parcel plotnum a3aq31-A3AQ49
ren a3aq32 cult_days_hh
recode cult_days_hh (.=0)
gen cult_days_hh_withkids=cult_days_hh
ren a3aq35a man_days
ren a3aq35b woman_days
ren a3aq35c child_days
recode *days (.=0)				// so that we don't try to add missings to numbers
recode A3AQ47 A3AQ48 A3AQ49 (.=0)
gen cult_days_hired = woman_days + man_days
gen cult_days_hired_withkids = woman_days + man_days + 0.5*child_days
gen cult_days_free = A3AQ47 + A3AQ48
gen cult_days_free_withkids = A3AQ47 + A3AQ48 + 0.5*A3AQ49
recode cult* (.=0)
collapse (sum) cult* , by(hhid)
tempfile labor
save `labor'


** BRING TOGETHER
use `weights', clear

merge 1:1 hhid using `labor', keep(1 3) nogen
merge 1:1 hhid using `plots', keep(1 3) nogen
merge 1:1 hhid using `plotsowned', keep(1 3) nogen
merge 1:1 hhid using `demog', keep(1 3) nogen
merge 1:1 hhid using `household_headage', keep(1 3) nogen
merge 1:1 hhid using `head_educ', keep(1 3) nogen
merge 1:1 hhid using `inputs', keep(1 3) nogen
merge 1:1 hhid using `sales', keep(1 3) nogen

drop district
tempfile UG4_data
save `UG4_data', replace


**********************************
****
****    Combine panel and construct key labor demand variables
****
**********************************


***********
** Uganda
***********
use `UG1_data', clear
append using `UG2_data', gen(wave2)
*use `UG2_data', clear
append using `UG3_data', gen(wave3)
append using `UG4_data', gen(wave4)
format %18.0g hhid

gen wave = 1
replace wave = 2 if wave2==1
replace wave = 3 if wave3==1
replace wave = 4 if wave4==1

gen hhid_string = string(hhid,"%20.0g")
drop hhid
ren hhid_string hhid
drop if hhsize==0

*** allowing HH's to not be in all 4 waves. later code will ensure HH distance of just 1 wave
drop if split4==1

label var hhsize "Household size"
label var cult_days_hh "Total household labor"
label var cult_days_hired "Total hired labor"
label var owned_acres "Acres owned"
label var acres "Acres farmed"
label var numplots "Number of plots"
label var male_head "Male head of household"

*Recoding
recode cult_days_* (.=0)						// I assume these are zeros (same assumption as the coding above)
recode owned_acres (.=0)
recode acres (.=0)
recode numplots (.=0)
recode hired_* (.=0) 
recode prep_* (.=0)
recode inputs_* (.=0)
recode weed_* (.=0)
recode harvest_* (.=0)

** Make a number of possible labor demand measures
* No children
gen ld_tot_nokids = cult_days_hh + cult_days_hired
replace ld_tot_nokids = ld_tot_nokids + cult_days_free if wave==4 & cult_days_free !=.
la var ld_tot_nokids "LD: no kids; waves 1-4"

* With children
gen ld_tot_kids = cult_days_hh_withkids + cult_days_hired_withkids
replace ld_tot_kids = ld_tot_kids + cult_days_free_withkids if wave==4 & cult_days_free_withkids!=.
la var ld_tot_kids "LD: with kids; waves 1-4"


* dropping households that report no labor demand for at least half of the waves they appear in the data
bysort hhid: egen count_waves = count(wave)
gen ld_zero = ld_tot_kids ==0
by hhid: egen cnt_ld = sum(ld_zero)
gen acre_zero = acres==0
by hhid: egen cnt_A = sum(acre_zero)
gen temp_rate = cnt_ld / count_waves
gen temp_acre = cnt_A / count_waves
drop if temp_rate > 0.5
drop if temp_acre > 0.5

drop count_waves ld_zero temp_rate temp_acre cnt_A acre_zero

foreach i of varlist ld_* {
	gen log_`i' = ln(`i')
	local label : variable label `i'
	label variable log_`i' `"Log `label''"'
	replace log_`i' = ln($no_work) if `i'==0
}

gen log_A = ln(acres)		// Missings
replace log_A = ln(0.01) if log_A==.

replace owned_acres = owned_acres + 0.01 if log_A!=. & owned_acres==0		// replace the ownership zeros so that sample size is identical to log_A sample size
gen log_owned = ln(owned_acres)
gen log_hhsize = ln(hhsize)
gen log_phase = ln(hhsize_phase)
gen log_hhaway = ln(hhsize_away)
gen log_phase_away = ln(hhsize_phase_away)
drop if hhsize_phase==0	| hhsize_phase==.
replace log_hhsize = ln(0.01) if hhsize==0
replace log_hhaway = ln(0.01) if hhsize_away==0
replace log_phase_away = ln(0.01) if hhsize_phase_away==0
gen share_pm = prime_male/person
gen share_pf = prime_female/person
gen share_em = eld_male/person
gen share_ef = eld_female/person
gen age_head1 = agehhhead1
gen age_squared1 = agehhead_squared1
gen female_head = 1-male_head
gen female_hhsize = female_head*log_hhsize
replace age_squared1 = age_squared1/1000
la var log_A "Log acres cultivated"
la var log_owned "Log acres owned"
la var log_hhsize "Log HH size (15<=age<=60)"
la var log_phase "Log HH size with phase-in and out"
la var share_pm "Prime male share"
la var share_pf "Prime female share"
la var share_em "Elderly male share"
la var share_ef "Elderly female share"
la var age_head1 "Age of household head"
la var age_squared1 "Age of household head squared (000s)"
la var aged_in "Child aged into household size"
la var aged_out "Adult aged out of household size"
la var female_head "Female head of household"
la var female_hhsize "Log of household size for female heads"


recode region (0=1)
tab region, gen(regionfe)
egen reg_wave = group(region wave)
tab reg_wave, gen(reg_wave)
recode wave2 wave3 wave4 (.=0)
gen hhdist = substr(hhid,1,3)
egen dist_wave = group(hhdist wave)
tab dist_wave, gen(dist_wave)


* Drop households with no acreage cultivated
drop if acres==0

* winsorizing top 5 largest acres, owned_acres, exp_pc
foreach var in acres owned_acres exp_pc {
	di "var = `var'"
	gsort - `var'
	forvalues i=1/5 {
		di "var=`var' and i=`i'"
		replace `var' = `var'[6] in `i'
	}
}

* set-up EA to use for village level IV
bysort hhid: egen wave_cnt = count(male)
destring ea2, replace
destring ea3, replace
gen ea_temp = ea1
replace ea_temp = ea2 if wave==2
replace ea_temp = ea3 if wave==3
replace ea_temp = ea4 if wave==4
by hhid: egen ea_max = max(ea_temp)
bysort ea3: egen ea3_max = max(ea_max) if wave==3
bysort ea2: egen ea2_max = max(ea_max) if wave==2
gen ea = ea_max
replace ea = ea3_max if ea_max<10000000 & wave==3
replace ea = ea2_max if ea_max<10000000 & wave==2
drop ea1 ea2* ea3* ea4 ea_max ea_temp wave_cnt

* vars for hhsize by gender
gen log_male = ln(male_phase)
replace log_male = ln(0.1) if male_phase==0
gen log_female = ln(female_phase)
replace log_female = ln(0.1) if female_phase==0
gen log_male_nokids = ln(hhsize_male)
replace log_male_nokids = ln(0.1) if hhsize_male==0
gen log_female_nokids = ln(hhsize_female)
replace log_female_nokids = ln(0.1) if hhsize_female ==0

keep hhsize* log* ld* hhid wave* age* numpl  *acres* male* female* prime* eld* share_* ///
 female_head region district female_hhsize *educ exp* *days* pc1_wealth aez ea months_away dist* ///
 maize beans cassava fertilized irrigated any_* temp_migrant
 
save "$newdata/UG panel data merged", replace


destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
isid hhid wave
xtset hhid wave

* Generate FE for regressions
egen dist_wave_FE = group(district wave)
egen reg_wave_FE = group(region wave)

* Wealth categories in Wave 2
sum exp_pc if wave==2, det
local cut50 = r(p50)
gen temp = exp_pc<`cut50' & wave==2
bysort hhid: egen poor50 = sum(temp)
replace temp = exp_pc>=`cut50' & wave==2
bysort hhid: egen exp_rich50 = sum(temp)
drop temp

* Wealth categories by asset index
sum pc1_wealth, det
local cut50 = r(p50)
gen temp = pc1_wealth <`cut50' & wave==1
bysort hhid: egen asset_poor50 = sum(temp)
replace temp = pc1_wealth>=`cut50' & wave==1
bysort hhid: egen asset_rich50 = sum(temp)
drop temp
gen rich50 = exp_rich50

* spread AEZ info across waves
bysort hhid: egen ae_zone = max(aez)

local controls log_A // zero

****** create vars for whether household increased or decreased in size *******
sort hhid wave
by hhid: gen increase = ($hhsize_var>$hhsize_var[_n-1]) if _n==2
by hhid: gen decrease = ($hhsize_var<$hhsize_var[_n-1]) if _n==2
by hhid: gen male_inc = (male_phase>male_phase[_n-1]) if _n==2
by hhid: gen male_dec = (male_phase<male_phase[_n-1]) if _n==2
by hhid: gen female_inc = (female_phase>female_phase[_n-1]) if _n==2
by hhid: gen female_dec = (female_phase<female_phase[_n-1]) if _n==2

****** create vars for agricultural activity, with kids phased in *******
rename log_ld_tot_kids act_log_ld

local dep_var act_log_ld

foreach i of varlist `dep_var' log_phase log_hhsize log_phase_away log_male log_female share_pm share_pf share_em log_A log_owned log_male_nokids log_female_nokids {
	gen diff_`i' = D.`i'
}

gen INC_hhsize = diff_$hhsize_var*(diff_$hhsize_var>0)
gen DEC_hhsize = diff_$hhsize_var*(diff_$hhsize_var<0)
gen INC_male = diff_log_male*(diff_log_male>0)
gen DEC_male = diff_log_male*(diff_log_male<0)
gen INC_female = diff_log_female*(diff_log_female>0)
gen DEC_female = diff_log_female*(diff_log_female<0)

la var INC_hhsize "Increase in HH Size"
la var DEC_hhsize "Decrease in HH Size"
la var INC_male "Increase in Male HH Size"
la var DEC_male "Decrease in Male HH Size"
la var INC_female "Increase in Female HH Size"
la var DEC_female "Decrease in Female HH Size"
label define rich_labels 1 "Top 50\% Wealth" 0 "Bottom 50\% Wealth"
label values rich50 rich_labels
label var rich50 "Top 50\% Wealth"
label var log_hhsize "Log(HH Size)"

save "$newdata/UG_reg_ready", replace

