
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



*********************************************************
*														*
**				Ethiopia							   **
*														*
*********************************************************

* Start by identifying HHs in both waves (we can do it this way because there are only 2 waves)

use "$newdata/ET panel data merged", clear
keep hhid
duplicates drop hhid, force
tempfile hhs_we_use
save `hhs_we_use', replace


use "$data_ET/Household/sect1_hh_w1", clear
isid household_id individual_id
ren household_id hhid
ren individual_id pid
ren hh_s1q04_a age1
ren ea_id ea1
sum if age1==.
replace age1= round(hh_s1q04_b/12) if age==.
keep hhid pid age1 ea1
merge m:1 hhid using `hhs_we_use', assert(1 3) keep(3) nogen
tempfile wave1
save `wave1', replace

use "$data_ET_2/Household/sect1_hh_w2", clear
drop if household_id==""
drop if hh_s1q04c==2		// drop those who are no longer in the household
ren household_id hhid
ren household_id hhid2
ren individual_id pid
ren individual_id2 pid2
merge m:1 hhid using `hhs_we_use', assert(1 3) keep(3) nogen
ren hh_s1q04_a age2
sum if age2==.
replace age2= round(hh_s1q04_b/12) if age2==.
keep hhid pid pid2 age2
merge 1:1 hhid pid using `wave1'
isid hhid pid


* GROUP 1: individuals in (i) only wave 1, or (ii) both waves)
preserve
drop if _merge==1
gen movedin = 0
gen movedout = _merge==2
gen wave_both = _merge==3
sum if wave_both==1
sum age1 if wave_both==1 
sum age2 if wave_both==1
replace age1 = max(age2-2,0) if wave_both==1 & age1==. & age2!=.
replace age2 = age1+2 if wave_both==1 & age1!=. & age2==.
assert age2!=. & age1!=. if wave_both==1
sum if movedout==1
drop if age1==. & movedout==1
gen diff = age2-age1 if wave_both==1
replace age2=age1+2 if wave_both==1 & ~inlist(diff,1,2,3)
assert age1<age2 if wave_both==1
drop diff
tempfile wave_1_or_both
save `wave_1_or_both', replace


* GROUP 2: individuals in wave 2 only
restore
keep if _merge==1	// these are the new people in wave 2
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
gen agedout = 0
append using `wave_1_or_both'
gen check = movedin + movedout + wave_both
assert check==1
drop check

gen lf_agedin = age2>=15 & age1<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age2>=15 
gen lf_movedout = movedout==1 & age1>=15 
gen lfs_wave1 = (wave_both==1 | movedout==1) & age1>= 15
gen lfs_wave2 = (wave_both==1 | movedin==1) & age2>=15 

gen lf_agedin_2 = (age2>=11 & age1<15 & movedout==0  & movedin==0)*(min(1,(age2-10)*0.2)-max(0,(age1-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age2>=11)*min(1,(age2-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age1>=11)*min(1,(age1-10)*0.2)	
gen lfs_wave1_2 = ((wave_both==1 | movedout==1) & age1>=11)*min(1,(age1-10)*0.2)
gen lfs_wave2_2 = ((wave_both==1 | movedin==1) & age2>=11)*min(1,(age2-10)*0.2)

gen hhs_wave1 = (wave_both==1 | movedout==1)
gen hhs_wave2 = (wave_both==1 | movedin==1)
tempfile ind
save `ind', replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave1_2 lfs_wave2_2, by(hhid)
destring hhid, replace

save "$newdata/ET_hhld_movers", replace
restore


*** Summary table of movers
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
merge 1:1 pid using "$newdata/ET1_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9,10,12,13)
gen non_fam = inlist(reltohead,14,15)

*get prep days worked
preserve
use "$newdata/ET1_prep_ages.dta", clear
drop if pid==""
tempfile et_prep_ages
save `et_prep_ages', replace
restore
merge 1:1 pid using `et_prep_ages', keep(1 3) nogen
rename days prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
preserve
use "$newdata/ET1_harv_ages.dta", clear
drop if pid==""
tempfile et_harv_ages
save `et_harv_ages', replace
restore
merge 1:1 pid using `et_harv_ages', keep(1 3) nogen
rename days harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age1 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto et12_moveout

* get info for people who moved in
use `ind', clear
keep if lf_movedin_2 == 1
*get age, educ, and reltohead
rename pid2 y2_pid
merge 1:1 y2_pid using "$newdata/ET2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9,10,12,13)
gen non_fam = inlist(reltohead,14,15)

*get prep days worked
preserve
use "$newdata/ET2_prep_ages.dta", clear
drop if y2_pid==""
tempfile et2_prep_ages
save `et2_prep_ages', replace
restore
merge 1:1 y2_pid using `et2_prep_ages', keep(1 3) nogen
rename days prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
preserve
use "$newdata/ET2_harv_ages.dta", clear
drop if y2_pid==""
tempfile et2_harv_ages
save `et2_harv_ages', replace
restore
merge 1:1 y2_pid using `et2_harv_ages', keep(1 3) nogen
rename days harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age2 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto et12_movein


* get info for people who stayed in household
use `ind', clear
keep if wave_both==1
*get age, educ, and reltohead
merge 1:1 pid using "$newdata/ET1_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9,10,12,13)
gen non_fam = inlist(reltohead,14,15)
replace age = (age1 + age2) / 2

*get prep days worked
merge 1:1 pid using `et_prep_ages', keep(1 3) nogen
rename days prep_days1
gen any_prep1 = prep_days1>0 & prep_days1!=.
rename pid2 y2_pid
merge 1:1 y2_pid using `et2_prep_ages', keep(1 3) nogen
rename days prep_days2
gen any_prep2 = prep_days2>0 & prep_days2!=.
gen any_prep = (any_prep1 + any_prep2)/2
gen prep_days = (prep_days1 + prep_days2)/2


*gen harvest days worked
merge 1:1 pid using `et_harv_ages', keep(1 3) nogen
rename days harv_days1
gen any_harv1 = harv_days1>0 & harv_days1!=.
merge 1:1 y2_pid using `et2_harv_ages', keep(1 3) nogen
rename days harv_days2
gen any_harv2 = harv_days2>0 & harv_days2!=.
gen any_harv = (any_harv1 + any_harv2) / 2
gen harv_days = (harv_days1 + harv_days2) / 2


sum age1 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto et12_stayer

la var age "Age"
la var male "\% Male"
la var son_daughter "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked Cultivation"
la var prep_days "Avg. Days Worked Cultivation"
la var any_harv "\% Worked Harvest"
la var harv_days "Avg. Days Worked Harvest"

esttab et12* using "$path/output/ET_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%9.0gc) labels("Number of Obs.")) label replace fragment tex


use `ind', clear
*** Produce Country level Summary table for changes in HH size
collapse (sum) hhs_* lfs_wave1* lfs_wave2* lf_movedin* lf_movedout* lf_agedin* (firstnm) ea1, by(hhid)	// first collapse to HH level

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
destring ea1, gen(temp)
gen region = int(temp/1000000000)
gen zone = inlist(region,1,3,4,7)
replace zone = 2 if inlist(region,2,5,6,12,13,15)
drop temp
	
*gen net change by HH
gen lfs_change = lfs_wave2_2 - lfs_wave1_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0

*aggregate up to EA level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec zone (count) num_hh=hhs_wave2, by(ea1)
sum num_hh, det

twoway (scatter ea_per_inc ea_per_dec if zone==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if zone==2, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("Share HHs with net increase") xtitle("Share HHs with net decrease") ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(label(1 "Highlands") label(2 "Lowlands") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Ethiopia, Wave 1 to 2", color(black) size(7))
graph export "$path/output/ET12_net_change_scatter.pdf", replace

twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Ethiopia, Wave 1 to 2", color(black) size(7))
graph export "$path/output/ET12_net_change_scatter_combined.pdf", replace


use `hhchange', clear

gen lfs_change = lfs_wave2 - lfs_wave1
gen lfs_change_2 = lfs_wave2_2 - lfs_wave1_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave2-hhs_wave1
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto et_sum_changes_m1


*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto et_sum_changes_m2


*********************************************************
*														*
**				Malawi				  				   **
*														*
*********************************************************

** Get the identifying information for HHs in our regressions
use "$newdata/Malawi Panel Data Clean", clear
isid hhid wave
keep if wave==2
duplicates drop hhid, force
keep hhid
ren hhid hhid_1
tempfile hhs_we_use
save `hhs_we_use', replace

* Start by identifying HHs in both waves
use "$data_MW/2013/Dataset/Household/HH_MOD_A_FILT", clear
drop if hh_a05==2		// Dropping splits	
ren y2_hhid hhid_2	
keep case_id hhid_2
duplicates tag case_id, gen(duptag)
assert length(hhid_2)==8
gen last3 = substr(hhid_2,6,3)
destring last3, replace force
egen minlast = min(last3), by(case_id)
drop if duptag>0 & last3>minlast		// drop the duplicates with the higher value of y2_hhid
drop duptag minlast last3
isid case_id
isid hhid_2
ren case_id hhid_1
merge 1:1 hhid_1 using `hhs_we_use', assert(1 3) keep(3) nogen
tempfile hh
save `hh', replace

* Individuals in Wave 2
use "$data_MW/2013/Dataset/Household/HH_MOD_B", clear
codebook hh_b01, compact
ren y2_hhid hhid_2
merge m:1 hhid_2 using `hh', nogen assert(1 3) keep(3) 	// keep(3) drops the individuals in split-ff
recode hh_b06_1 (99=.)
keep hh_b01 hh_b05a hh_b06_1 hhid_1  hhmember hhid_2
order hhid_1 
sum
ren hh_b01 pid2
ren hh_b05a age
ren hh_b06_1 pid1
gen wave = 2
tempfile wave2
save `wave2', replace
save "$newdata/MW2_temp_ids.dta", replace

use "$data_MW/2010-2011/Dataset/Household/HH_MOD_B", clear
keep case_id id_code hh_b05a
ren id_code pid1
ren case_id hhid_1
merge m:1 hhid_1 using `hh', assert(1 3) keep(3) nogen	// only keeping hhids that appear in both waves
drop hhid_2		// all matching can be done on hhid_1
ren hh_b05a age
gen wave = 1
append using `wave2'
order hhid* wave pid*
sort hhid_1 pid1


* checks
preserve
keep if pid1==.	// keep only those with no obs for pid1
assert wave==2
isid hhid_2 pid2
restore
preserve
drop if wave==2
isid hhid_1 pid1
restore
preserve 
drop if wave==1
isid hhid_2 pid2
restore


* GROUP 1: individuals in (i) only wave 1, or (ii) both waves)
preserve
drop if pid1==.
isid hhid_1 pid1 wave
drop hhid_2
foreach i of varlist pid2 age hhmember {
	ren `i' `i'_
}
reshape wide pid2_ age_ hhmember_, i(hhid_1 pid1) j(wave)
gen movedin = 0
gen movedout = pid2_2==.
gen wave_both = pid2_2!=.
drop pid2_1 hhmember_1
sum if wave_both==1
sum age_1 
sum age_2
replace age_1 = max(age_2-3,0) if wave_both==1 & age_1==. & age_2!=.
replace age_2 = age_1+3 if wave_both==1 & age_1!=. & age_2==.
sum if wave_both==1	
sum if movedout==1	
drop if age_1==. & movedout==1		// dropping so that this obs is not inadvertently counted as non-working
gen diff = age_2-age_1 if wave_both==1
replace age_2=age_1+3 if wave_both==1 & ~inlist(diff,2,3,4)
assert age_1<age_2 if wave_both==1
drop diff
tempfile wave_1_or_both
save `wave_1_or_both', replace


* GROUP 2: individuals in wave 2 only
restore
keep if pid1==.		// these are the new people in wave 2
isid hhid_2 pid2
drop pid1 wave
ren hhmember hhmember_2
ren age age_2
ren pid2 pid2_2
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
append using `wave_1_or_both'
gen check = movedin + movedout + wave_both
assert check==1
drop check

ren age_2 age2
ren age_1 age1

gen lf_agedin = age2>=15 & age1<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age2>=15 
gen lf_movedout = movedout==1 & age1>=15 
gen lfs_wave1 = (wave_both==1 | movedout==1) & age1>= 15
gen lfs_wave2 = (wave_both==1 | movedin==1) & age2>=15 

gen lf_agedin_2 = (age2>=11 & age1<15 & movedout==0  & movedin==0)*(min(1,(age2-10)*0.2)-max(0,(age1-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age2>=11)*min(1,(age2-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age1>=11)*min(1,(age1-10)*0.2)	
gen lfs_wave1_2 = ((wave_both==1 | movedout==1) & age1>=11)*min(1,(age1-10)*0.2)
gen lfs_wave2_2 = ((wave_both==1 | movedin==1) & age2>=11)*min(1,(age2-10)*0.2)

gen hhs_wave1 = (wave_both==1 | movedout==1)
gen hhs_wave2 = (wave_both==1 | movedin==1)
tempfile ind
save `ind', replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave1_2 lfs_wave2_2, by(hhid_1)
destring hhid_1, gen(hhid)
save "$newdata/MW_hhld_movers", replace
restore

*** Get EA information
use "$data_MW/2010-2011/Dataset/Household/HH_MOD_A_FILT", clear
ren ea_id ea1
ren case_id hhid_1
rename hh_a01 district
keep ea1 hhid_1 district
tempfile ea_info
save `ea_info', replace


*** Summary table of movers
use `ind', clear
destring hhid_1, gen(hhid)
rename pid1 personid
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
merge 1:1 hhid personid using "$newdata/MW1_hh_ages.dta", keep(1 3) nogen
gen child_fam = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9,10,12)
gen non_fam = inlist(reltohead,13,14,15)

*get prep days worked
merge 1:1 hhid personid using "$newdata/MW1_prep_ages.dta", keep(1 3) nogen
rename days prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
merge 1:1 hhid personid using "$newdata/MW1_harv_ages.dta", keep(1 3) nogen
rename days harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age1 male child_fam other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male child_fam other_fam non_fam any_prep prep_days any_harv harv_days
est sto mw12_moveout

* get info for people who moved in
use `ind', clear
rename pid2_2 pid2
keep if lf_movedin_2 == 1
* gen hhid_2 from above
merge 1:1 hhid_1 pid2 using `wave2', assert(2 3) keep(3) nogen
*get age, educ, and reltohead
gen hhid = hhid_2
rename pid2 personid
merge 1:1 hhid personid using "$newdata/MW2_hh_ages.dta", keep(1 3) nogen
gen child_fam = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9,10,12)
gen non_fam = inlist(reltohead,13,14,15)

*get prep days worked
merge 1:1 hhid personid using "$newdata/MW2_prep_ages.dta", keep(1 3) nogen
rename days prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
merge 1:1 hhid personid using "$newdata/MW2_harv_ages.dta", keep(1 3) nogen
rename days harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age2 male child_fam other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male child_fam other_fam non_fam any_prep prep_days any_harv harv_days
est sto mw12_movein


* get info for people who stayed in household
use `ind', clear
keep if wave_both==1
destring hhid_1, gen(hhid1)
rename pid1 personid1
rename pid2_2 pid2

*get age, educ, and reltohead
gen personid = personid1
gen double hhid = hhid1
merge 1:1 hhid personid using "$newdata/MW1_hh_ages.dta", keep(1 3) nogen
gen child_fam = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9,10,12)
gen non_fam = inlist(reltohead,13,14,15)
replace age = (age1 + age2) / 2

*get prep days worked
merge 1:1 hhid personid using "$newdata/MW1_prep_ages.dta", keep(1 3) nogen
rename days prep_days1
gen any_prep1 = prep_days1>0 & prep_days1!=.
drop hhid

* get hhid_2 from above
gen pid1 = personid1
drop hhid_2
preserve
use "$newdata/MW2_temp_ids.dta", clear
keep if hhid_1!="" & pid1!=.
tempfile mw_temp_ids
save `mw_temp_ids', replace
restore
merge 1:1 hhid_1 pid1 using `mw_temp_ids', assert(2 3) keep(3) nogen
gen hhid = hhid_2
replace personid = pid2
merge 1:1 hhid personid using "$newdata/MW2_prep_ages.dta", keep(1 3) nogen
rename days prep_days2
gen any_prep2 = prep_days2>0 & prep_days2!=.
gen any_prep = (any_prep1 + any_prep2)/2
gen prep_days = (prep_days1 + prep_days2)/2


*gen harvest days worked
replace personid = personid1
drop hhid
gen double hhid = hhid1
merge 1:1 hhid personid using "$newdata/MW1_harv_ages.dta", keep(1 3) nogen
rename days harv_days1
gen any_harv1 = harv_days1>0 & harv_days1!=.
drop hhid
gen hhid = hhid_2
replace personid = pid2
merge 1:1 hhid personid using "$newdata/MW2_prep_ages.dta", keep(1 3) nogen
rename days harv_days2
gen any_harv2 = harv_days2>0 & harv_days2!=.
gen any_harv = (any_harv1 + any_harv2) / 2
gen harv_days = (harv_days1 + harv_days2) / 2


sum age1 male child_fam other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male child_fam other_fam non_fam any_prep prep_days any_harv harv_days
est sto mw12_stayer

la var age "Age"
la var male "\% Male"
la var child_fam "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked Cultivation"
la var prep_days "Avg. Days Worked Cultivation"
la var any_harv "\% Worked Harvest"
la var harv_days "Avg. Days Worked Harvest"

esttab mw12* using "$path/output/MW_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%9.0gc) labels("Number of Obs.")) label replace fragment tex

use `ind', clear
drop hhid_2
*** Produce Country level Summary table for changes in HH size
collapse (sum) hhs_* lfs_wave1* lfs_wave2* lf_movedin* lf_movedout* lf_agedin*, by(hhid)	// first collapse to HH level
merge 1:1 hhid_1 using `ea_info', keep(3) nogen

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
gen region = int(district/100)

*gen net change by HH
gen lfs_change = lfs_wave2_2 - lfs_wave1_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0

*aggregate up to EA level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec region (count) num_hh=hhs_wave2, by(ea1)
sum num_hh, det

twoway (scatter ea_per_inc ea_per_dec if region==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==2, msymbol(smplus) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==3, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("% of Households in village with net increase") xtitle("% of Households in village with net decrease") ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(label(1 "North") label(2 "Center") label(3 "South") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Malawi, Change from Wave 1 to 2", color(black))
graph export "$path/output/MW12_net_change_scatter.pdf", replace


twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Malawi, Wave 1 to 2", color(black) size(7))
graph export "$path/output/MW12_net_change_scatter_combined.pdf", replace


use `hhchange', clear
gen lfs_change = lfs_wave2 - lfs_wave1
gen lfs_change_2 = lfs_wave2_2 - lfs_wave1_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave2-hhs_wave1
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto mw_sum_changes_m1


*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto mw_sum_changes_m2



*********************************************************
*														*
**				Tanzania							   **
*														*
*********************************************************

** Get the identifying information for HHs in our regressions
use "$newdata/TZ panel data merged", clear
* the above file uses the wave 2 HHIDs, since those have to be matchable to the other waves
isid hhid wave
keep hhid
duplicates drop hhid, force
tempfile hhs_we_use
save `hhs_we_use', replace


****************************************
*			Wave 1 to Wave 2   		   *
****************************************

* identify non-splits as HHs that have only a single matched HH in the next wave

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
drop if y1_hhid==""
isid y1_hhid indidy1
tempfile w1_indiv
save `w1_indiv', replace	// match file at y1 individual level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
drop if y2_hhid==""
isid y2_hhid indidy2
tempfile w2_indiv
save `w2_indiv', replace	// match file at y2 individual level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
keep y1_hhid
drop if y1_hhid==""
duplicates drop y1_hhid, force
tempfile y1_hhs
save `y1_hhs', replace	// match file at y1 household level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
keep y2_hhid
drop if y2_hhid==""
duplicates drop y2_hhid, force
gen y2_match_y1 = substr(y2_hhid,1,length(y2_hhid)-2)
gen y2_last2 = substr(y2_hhid,length(y2_hhid)-1,2)
gen check = length(y2_match_y1)
assert check==14
drop check
* choose which split to keep
duplicates tag y2_match_y1, gen(duptag)
tab duptag
destring y2_last2, force replace
egen min_id = min(y2_last2) if duptag>0, by(y2_match_y1)
drop if min_id!=. & duptag>0 & y2_last2!=min_id				// keep only the lowest number HH
gen nosplit= duptag==0
drop duptag
isid y2_match
drop min_id y2_last2
ren y2_match y1_hhid		// match file between y2 and y1, after accounting for splits

merge 1:1 y1_hhid using `y1_hhs', assert(2 3) nogen keep(3)	// there were no replacements in LSMS-ISA wave 2, so no merge==1
destring y2_hhid, gen(hhid)
merge 1:1 hhid using `hhs_we_use'
* _merge==2 are HHs that will match to wave 3 (later), but not to wave 1
* _merge==1 are households that are non-ag or are dropped from the regression analysis for some other reason
keep if _merge==3
drop _merge		// now this data set includes wave 1 to wave 2 matches
isid y1_hhid
isid y2_hhid
tempfile wave12
save `wave12', replace

* get the ages
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_B", clear
ren hh_b04 age2
keep y2_hhid hhid_2008 indidy2 age
tab age, missing	// only 3 missing
merge m:1 y2_hhid using `wave12', assert(1 3) keep(3) nogen
assert hhid_2008==y1_hhid
drop hhid_2008
destring y2_hhid, gen(hhid_check)
assert hhid==hhid_check
drop hhid hhid_check
isid y2_hhid indidy2
merge 1:1 y2_hhid indidy2 using `w2_indiv', assert(2 3) keep(3) keepus(UPI3) nogen
tempfile ages2
save `ages2', replace

use "$data_TZ/2008-2009/Dataset/Household/SEC_B_C_D_E1_F_G1_U", clear
ren sbq4 age1
ren sbmemno indidy1
ren hhid y1_hhid
keep y1_hhid indidy1 age1
merge m:1 y1_hhid using `wave12', assert(1 3) keep(3) nogen
destring y2_hhid, gen(hhid_check)
assert hhid==hhid_check
drop hhid hhid_check
isid y1_hhid indidy1
merge 1:1 y1_hhid indidy1 using `w1_indiv', assert(2 3) keep(3) keepus(UPI3) nogen
merge 1:1 UPI3 using `ages2'
rename _merge age_merge
tempfile ages12
save `ages12', replace

* get the EA info
use "$data_TZ/2008-2009/Dataset/Household/SEC_A_T.dta", clear
gen ea1 = ea + 1000*locality + 10000*ward + 1000000*district + 10000000*region
keep hhid ea1 region
rename hhid y1_hhid
isid y1_hhid
merge 1:1 y1_hhid using `wave12', assert(1 3) keep(3) nogen
destring y2_hhid, gen(hhid_check)
assert hhid==hhid_check
drop hhid hhid_check
isid y1_hhid
merge 1:m y1_hhid using `w1_indiv', assert(2 3) keep(3) keepus(UPI3) nogen
merge 1:1 UPI3 using `ages12', assert(2 3) keep(2 3) nogen

* GROUP 1: individuals in (i) only wave 1, or (ii) both waves)
preserve
drop if age_merge ==2
gen movedin = 0
gen movedout = age2==.
gen wave_both = age2!=.
sum if wave_both==1
sum if movedout==1		
drop if age1==. & movedout==1		// dropping so that there are no inadvertently counted as non-working
gen diff = age2-age1 if wave_both==1
tab diff
replace age2=age1+2 if wave_both==1 & ~inlist(diff,1,2,3)
assert age1<age2 if wave_both==1
drop diff
tempfile wave_1_or_both
save `wave_1_or_both', replace

* GROUP 2: individuals in wave 2 only
restore
keep if age_merge ==2		// these are the new people in wave 2
count
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
gen agedout = 0
append using `wave_1_or_both'
gen check = movedin + movedout + wave_both
sum movedin movedout wave_both
assert check==1
drop check

gen lf_agedin = age2>=15 & age1<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age2>=15 
gen lf_movedout = movedout==1 & age1>=15 
gen lfs_wave1 = (wave_both==1 | movedout==1) & age1>= 15
gen lfs_wave2 = (wave_both==1 | movedin==1) & age2>=15 

gen lf_agedin_2 = (age2>=11 & age1<15 & movedout==0  & movedin==0)*(min(1,(age2-10)*0.2)-max(0,(age1-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age2>=11)*min(1,(age2-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age1>=11)*min(1,(age1-10)*0.2)	
gen lfs_wave1_2 = ((wave_both==1 | movedout==1) & age1>=11)*min(1,(age1-10)*0.2)
gen lfs_wave2_2 = ((wave_both==1 | movedin==1) & age2>=11)*min(1,(age2-10)*0.2)
gen hhs_wave1 = (wave_both==1 | movedout==1)
gen hhs_wave2 = (wave_both==1 | movedin==1)
sum *movedin*
tempfile ind
save `ind', replace
sum *movedin*
save "$newdata/TZ1_merge_temp.dta", replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave1_2 lfs_wave2_2, by(y2_hhid)
destring y2_hhid, gen(hhid)
gen wave = 2
save "$newdata/TZ12_hhld_movers", replace
restore


*** Summary table of movers
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
gen hhid = y1_hhid
gen indid = indidy1
merge 1:1 hhid indid using "$newdata/TZ1_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10)

*get prep days worked
merge 1:1 hhid indid using "$newdata/TZ1_prep_ages.dta", keep(1 3) nogen
rename prep prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
merge 1:1 hhid indid using "$newdata/TZ1_harv_ages.dta", keep(1 3) nogen
rename harv harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age1 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto tz12_moveout


* get info for people who moved in
*use `ind', clear
use "$newdata/TZ1_merge_temp.dta", clear
sum lf_movedin*
tab lf_movedin_2
keep if lf_movedin_2 == 1
*get age, educ, and reltohead
gen hhid = y2_hhid
merge 1:1 hhid indidy2 using "$newdata/TZ2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10)

*get prep days worked
merge 1:1 hhid indidy2 using "$newdata/TZ2_prep_ages.dta", keep(1 3) nogen
rename prep prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
merge 1:1 hhid indidy2 using "$newdata/TZ2_harv_ages.dta", keep(1 3) nogen
rename harv harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age2 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto tz12_movein

* get info for people who stayed in household
use `ind', clear
keep if wave_both==1
*get age, educ, and reltohead
gen hhid = y1_hhid
gen indid = indidy1
merge 1:1 hhid indid using "$newdata/TZ1_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10)
replace age = (age1 + age2) / 2

*get prep days worked
merge 1:1 hhid indid using "$newdata/TZ1_prep_ages.dta", keep(1 3) nogen
rename prep prep_days1
gen any_prep1 = prep_days1>0 & prep_days1!=.
replace hhid = y2_hhid
merge 1:1 hhid indidy2 using "$newdata/TZ2_prep_ages.dta", keep(1 3) nogen
rename prep prep_days2
gen any_prep2 = prep_days2>0 & prep_days2!=.
gen any_prep = (any_prep1 + any_prep2)/2
gen prep_days = (prep_days1 + prep_days2)/2


*gen harvest days worked
replace hhid = y1_hhid
merge 1:1 hhid indid using "$newdata/TZ1_harv_ages.dta", keep(1 3) nogen
gen harv_days1 = harv
sum harv*
gen any_harv1 = harv_days1>0 & harv_days1!=.

replace hhid = y2_hhid
merge 1:1 hhid indidy2 using "$newdata/TZ2_prep_ages.dta", keep(1 3) nogen
rename harv harv_days2
gen any_harv2 = harv_days2>0 & harv_days2!=.
gen any_harv = (any_harv1 + any_harv2) / 2
gen harv_days = (harv_days1 + harv_days2) / 2


sum age1 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto tz12_stayer

la var age "Age"
la var male "\% Male"
la var son_daughter "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked Cultivation"
la var prep_days "Avg. Days Worked Cultivation"
la var any_harv "\% Worked Harvest"
la var harv_days "Avg. Days Worked Harvest"

esttab tz12* using "$path/output/TZ12_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%9.0gc) labels("Number of Obs.")) label replace fragment tex


use `ind', clear
*** Produce Country level Summary table for changes in HH size
collapse (sum) hhs_* lfs_wave1* lfs_wave2* lf_movedin* lf_movedout* lf_agedin* region (firstnm) ea1, by(y1_hhid)	// first collapse to HH level

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
gen zone = 1 if inlist(region,18,16,17,19,20,15,14)
replace zone = 2 if inlist(region,12,11,1,2,13,21,3)
replace zone = 3 if inlist(region,10,9,8,5,6,7,4,51,52,53,54,55)

*gen net change by HH
gen lfs_change = lfs_wave2_2 - lfs_wave1_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0

*aggregate up to ward level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec zone (count) num_hh=hhs_wave2, by(ea1)
sum num_hh, det

twoway (scatter ea_per_inc ea_per_dec if zone==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if zone==2, msymbol(smplus) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if zone==3, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("% of Households in village with net increase") xtitle("% of Households in village with net decrease") ///
	legend(label(1 "Northwest") label(2 "Central") label(3 "Southeast") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Tanzania, Change from Wave 1 to 2", color(black))
graph export "$path/output/TZ12_net_change_scatter.pdf", replace

twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Tanzania, Wave 1 to 2", color(black) size(7))
graph export "$path/output/TZ12_net_change_scatter_combined.pdf", replace

use `hhchange', clear

gen lfs_change = lfs_wave2 - lfs_wave1
gen lfs_change_2 = lfs_wave2_2 - lfs_wave1_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave2-hhs_wave1
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto tz12_sum_changes_m1


*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto tz12_sum_changes_m2


****************************************
*			Wave 2 to Wave 3   		   *
****************************************

* identify non-splits as HHs that have only a single matched HH in the next wave

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
drop if y3_hhid==""
isid y3_hhid indidy3
tempfile w3_indiv
save `w3_indiv', replace	// match file at y3 individual level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
drop if y2_hhid==""
isid y2_hhid indidy2
tempfile w2_indiv
save `w2_indiv', replace	// match file at y2 individual level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
keep y2_hhid
drop if y2_hhid==""
duplicates drop y2_hhid, force
tempfile y2_hhs
save `y2_hhs', replace	// match file at y1 household level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
keep y2_hhid y3_hhid
drop if y3_hhid==""
duplicates drop y3_hhid, force
tempfile y3_to_y2
save `y3_to_y2', replace	// match file for hhids between y3 and y2 household level

use "$data_TZ/2012-2013/Dataset/Misc/NPSY3.PANEL.KEY.dta", clear
keep y3_hhid
drop if y3_hhid==""
duplicates drop y3_hhid, force
merge 1:1 y3_hhid using `y3_to_y2', assert(3) nogen
codebook, compact
drop if y2_hhid==""
duplicates tag y2_hhid, gen(duptag)
gen y3_first4 = substr(y3_hhid,1,4)
gen y3_last3 = substr(y3_hhid,6,3)
destring y3_last3, replace
destring y3_first4, replace
tab duptag

* choose which split to keep
egen min_id = min(y3_last3) if duptag>0, by(y2_hhid)
drop if min_id!=. & duptag>0 & y3_last3!=min_id				// keep only the lowest number HH
duplicates tag y2_hhid, gen(dup2)
tab dup2
egen min_id2 = min(y3_first4) if dup2>0, by(y2_hhid)		// repeat using the first 4
drop if min_id2!=. & dup2>0 & y3_first4!=min_id				// keep only the lowest number HH
gen nosplit= duptag==0
assert nosplit== 0 if dup2>0
drop duptag dup2
isid y3_hhid
isid y2_hhid
drop min_id* y3_last3 y3_first4
merge 1:1 y3_hhid using `y3_to_y2', assert(2 3) keep(3) nogen	// doing this to get wave 2 ID for upcoming match
drop if y2_hhid==""
isid y2_hhid
isid y3_hhid
merge 1:1 y2_hhid using `y2_hhs', assert(2 3) nogen keep(3)	// there were no replacements in LSMS-ISA wave 2, so no merge==1
destring y2_hhid, gen(hhid)
merge 1:1 hhid using `hhs_we_use'
keep if _merge==3
drop _merge		// now this data set includes wave 1 to wave 2 matches
tempfile wave23
save `wave23', replace

* get the ages
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_B", clear
ren hh_b04 age2
keep y2_hhid hhid_2008 indidy2 age
tab age, missing	// only 3 missing
merge m:1 y2_hhid using `wave23', assert(1 3) keep(3) nogen
drop hhid_2008
destring y2_hhid, gen(hhid_check)
assert hhid==hhid_check
drop hhid hhid_check
isid y2_hhid indidy2
merge 1:1 y2_hhid indidy2 using `w2_indiv', assert(2 3) keep(3) keepus(UPI3) nogen
tempfile ages2
save `ages2', replace

use "$data_TZ/2012-2013/Dataset/Household/HH_SEC_B", clear
ren hh_b04 age3
keep y3_hhid indidy3 age3
isid y3_hhid indidy3
merge m:1 y3_hhid using `wave23', assert(1 3) keep(3) nogen
destring y2_hhid, gen(hhid_check)
assert hhid==hhid_check
drop hhid hhid_check
isid y3_hhid indidy3
merge 1:1 y3_hhid indidy3 using `w3_indiv', assert(2 3) keep(3) keepus(UPI3) nogen
merge 1:1 UPI3 using `ages2'
rename _merge age_merge
tempfile ages23
save `ages23', replace

* get the EA info
use "$data_TZ/2010-2011/Dataset/Household/HH_SEC_A", clear
gen ea2 = ea + 1000*ward + 1000000*district + 10000000*region
keep y2_hhid ea2 region
merge 1:1 y2_hhid using `wave12', assert(1 3) keep(3) nogen
destring y2_hhid, gen(hhid_check)
assert hhid==hhid_check
drop hhid hhid_check
merge 1:m y2_hhid using `w2_indiv', assert(2 3) keep(3) keepus(UPI3) nogen

merge 1:1 UPI3 using `ages23', nogen

* GROUP 1: individuals in (i) only wave 2, or (ii) both waves
preserve
drop if age_merge ==1
gen movedin = 0
gen movedout = age3==.
gen wave_both = age3!=.
sum if wave_both==1
sum if movedout==1
drop if age2==. & movedout==1		// dropping so that there are no inadvertently counted as non-working
gen diff = age3-age2 if wave_both==1
tab diff
replace age3=age2+2 if wave_both==1 & ~inlist(diff,1,2,3)
assert age2<age3 if wave_both==1
drop diff
tempfile wave_2_or_both
save `wave_2_or_both', replace

* GROUP 2: individuals in wave 3 only
restore
keep if age_merge ==1		// these are the new people in wave 3
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
gen agedout = 0
append using `wave_2_or_both'
gen check = movedin + movedout + wave_both
assert check==1
drop check


gen lf_agedin = age3>=15 & age2<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age3>=15 
gen lf_movedout = movedout==1 & age2>=15 
gen lfs_wave2 = (wave_both==1 | movedout==1) & age2>= 15
gen lfs_wave3 = (wave_both==1 | movedin==1) & age3>=15 

gen lf_agedin_2 = (age3>=11 & age2<15 & movedout==0  & movedin==0)*(min(1,(age3-10)*0.2)-max(0,(age2-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age3>=11)*min(1,(age3-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age2>=11)*min(1,(age2-10)*0.2)	
gen lfs_wave2_2 = ((wave_both==1 | movedout==1) & age2>=11)*min(1,(age2-10)*0.2)
gen lfs_wave3_2 = ((wave_both==1 | movedin==1) & age3>=11)*min(1,(age3-10)*0.2)

gen hhs_wave2 = (wave_both==1 | movedout==1)
gen hhs_wave3 = (wave_both==1 | movedin==1)
tempfile ind
save `ind', replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave2_2 lfs_wave3_2, by(y2_hhid)
destring y2_hhid, gen(hhid)
gen wave = 3
save "$newdata/TZ23_hhld_movers", replace
append using "$newdata/TZ12_hhld_movers"
save "$newdata/TZ_hhld_movers", replace
restore


*** Summary table of movers
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
gen hhid = y2_hhid
merge 1:1 hhid indidy2 using "$newdata/TZ2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10)

*get prep days worked
merge 1:1 hhid indidy2 using "$newdata/TZ2_prep_ages.dta", keep(1 3) nogen
rename prep prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
merge 1:1 hhid indidy2 using "$newdata/TZ2_harv_ages.dta", keep(1 3) nogen
rename harv harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age2 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto tz23_moveout


* get info for people who moved in
use `ind', clear
sum lf_movedin*
tab lf_movedin_2
keep if lf_movedin_2 == 1
*get age, educ, and reltohead
merge 1:1 y3_hhid indidy3 using "$newdata/TZ3_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10)
*get prep days worked
merge 1:1 y3_hhid indidy3 using "$newdata/TZ3_prep_ages.dta", keep(1 3) nogen
rename prep prep_days
gen any_prep = prep_days>0 & prep_days!=.

*gen harvest days worked
merge 1:1 y3_hhid indidy3 using "$newdata/TZ3_harv_ages.dta", keep(1 3) nogen
rename harv harv_days
gen any_harv = harv_days>0 & harv_days!=.

sum age3 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto tz23_movein


* get info for people who stayed in household
use `ind', clear
keep if wave_both==1
*get age, educ, and reltohead
gen hhid = y2_hhid
merge 1:1 hhid indidy2 using "$newdata/TZ2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10)
replace age = (age3 + age2) / 2

*get prep days worked
merge 1:1 hhid indidy2 using "$newdata/TZ2_prep_ages.dta", keep(1 3) nogen
rename prep prep_days2
gen any_prep2 = prep_days2>0 & prep_days2!=.

merge 1:1 y3_hhid indidy3 using "$newdata/TZ3_prep_ages.dta", keep(1 3) nogen
rename prep prep_days3
gen any_prep3 = prep_days3>0 & prep_days3!=.
gen any_prep = (any_prep3 + any_prep2)/2
gen prep_days = (prep_days3 + prep_days2)/2


*gen harvest days worked
replace hhid = y2_hhid
merge 1:1 hhid indidy2 using "$newdata/TZ2_harv_ages.dta", keep(1 3) nogen
gen harv_days2 = harv
gen any_harv2 = harv_days2>0 & harv_days2!=.


merge 1:1 y3_hhid indidy3 using "$newdata/TZ3_prep_ages.dta", keep(1 3) nogen
rename harv harv_days3
gen any_harv3 = harv_days3>0 & harv_days3!=.
gen any_harv = (any_harv3 + any_harv2) / 2
gen harv_days = (harv_days3 + harv_days2) / 2


sum age2 male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
estpost sum age male son_daughter other_fam non_fam any_prep prep_days any_harv harv_days
est sto tz23_stayer

la var age "Age"
la var male "\% Male"
la var son_daughter "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked Cultivation"
la var prep_days "Avg. Days Worked Cultivation"
la var any_harv "\% Worked Harvest"
la var harv_days "Avg. Days Worked Harvest"

esttab tz23* using "$path/output/TZ23_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%9.0gc) labels("Number of Obs.")) label replace fragment tex

esttab tz12_moveout tz12_movein tz12_stayer tz23_moveout tz23_movein tz23_stayer using "$path/output/TZ_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed" "Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		mgroups("Wave 1-2" "Wave 2-3", pattern(1 0 0 1 0 0) span prefix(\multicolumn{@span}{c}{) suffix(})) ///
		stats(N, fmt(%9.0gc) labels("Number of Obs.")) label replace fragment tex


use `ind', clear
*** Produce Country level Summary table for changes in HH size

collapse (sum) hhs_* lfs_wave2* lfs_wave3* lf_movedin* lf_movedout* lf_agedin* region (firstnm) ea2, by(y2_hhid)	// first collapse to HH level

foreach i of varlist *_2 {
	replace `i' = round(`i',0.1)
}

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
gen zone = 1 if inlist(region,18,16,17,19,20,15,14)
replace zone = 2 if inlist(region,12,11,1,2,13,21,3)
replace zone = 3 if inlist(region,10,9,8,5,6,7,4,51,52,53,54,55)

*gen net change by HH
gen lfs_change = lfs_wave3_2 - lfs_wave2_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0

*aggregate up to ward level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec zone (count) num_hh=hhs_wave2, by(ea2)
sum num_hh

twoway (scatter ea_per_inc ea_per_dec if zone==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if zone==2, msymbol(smplus) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if zone==3, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("% of Households in village with net increase") xtitle("% of Households in village with net decrease") ///
	legend(label(1 "Northwest") label(2 "Central") label(3 "Southeast") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Tanzania, Change from Wave 2 to 3", color(black))
graph export "$path/output/TZ23_net_change_scatter.pdf", replace

twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Tanzania, Wave 2 to 3", color(black) size(7))
graph export "$path/output/TZ23_net_change_scatter_combined.pdf", replace

use `hhchange', clear

gen lfs_change = lfs_wave3 - lfs_wave2
gen lfs_change_2 = lfs_wave3_2 - lfs_wave2_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave3-hhs_wave2
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto tz23_sum_changes_m1


*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto tz23_sum_changes_m2

*********************************************************
*														*
**				Uganda								   **
*														*
*********************************************************

* get the individual details for each wave
use "$data_UG/2005-2006/Dataset/Household/GSEC2", clear
isid HHID PID
isid PID
keep HHID PID h2q9
ren h2q9 age1
tempfile wave1
save `wave1', replace

use "$data_UG/2009-2010/Dataset/Household/GSEC2", clear
keep if h2q7>=1 & h2q7<=4		
keep HHID PID h2q8
ren h2q8 age2
isid HHID PID
isid PID
tempfile wave2
save `wave2', replace

use "$data_UG/2010-2011/Dataset/Household/GSEC2", clear
isid HHID PID
isid PID
keep if h2q7>=1 & h2q7<=4
keep HHID PID h2q8
ren h2q8 age3
tempfile wave3
save `wave3', replace


use "$data_UG/2011-2012/Dataset/Household/GSEC2", clear
isid HHID PID
keep if h2q7>=1 & h2q7<=4 
isid PID
keep HHID PID h2q8
ren h2q8 age4
tempfile wave4
save `wave4', replace


* get the EA details for each wave
use "$data_UG/2005-2006/Dataset/Household/GSEC1", clear
isid HHID
keep HHID comm
ren comm ea1
tempfile wave1_ea
save `wave1_ea', replace

use "$data_UG/2009-2010/Dataset/Household/GSEC1", clear
isid HHID
keep HHID comm
ren comm ea2
tempfile wave2_ea
save `wave2_ea', replace

use "$data_UG/2010-2011/Dataset/Household/GSEC1", clear
isid HHID
keep HHID comm
ren comm ea3
tempfile wave3_ea
save `wave3_ea', replace

use "$data_UG/2011-2012/Dataset/Household/GSEC1", clear
isid HHID
keep HHID comm
ren comm ea4
tempfile wave4_ea
save `wave4_ea', replace


****************************************
*			Wave 1 to Wave 2   		   *
****************************************

use `wave1', clear
keep HHID
duplicates drop HHID, force
tempfile w1_hh
save `w1_hh', replace

use `wave2', clear
keep HHID
duplicates drop HHID, force
merge 1:1 HHID using `w1_hh'
keep if _merge==3
drop _merge
tempfile match_12
save `match_12', replace

use `wave1', clear
merge m:1 HHID using `match_12', assert(1 3) keep(3) nogen
tempfile w1_m
save `w1_m', replace

use `wave2', clear
merge m:1 HHID using `match_12', assert(1 3) keep(3) nogen
merge 1:1 HHID PID using `w1_m'	


assert age1!=. if _merge==2 | _merge==3
assert age2==. if _merge==2 


* GROUP 1: individuals in (i) only wave 1, or (ii) both waves)
preserve
drop if _merge==1	// drop those in wave 2 only
gen movedin = 0
gen movedout = _merge==2
gen wave_both = _merge==3
drop if age1==. & movedout==1
gen diff = age2-age1 if wave_both==1
replace age2=age1+4 if wave_both==1 & ~inlist(diff,2,3,4,5,6)
assert age1<age2 if wave_both==1
drop diff
tempfile wave_1_or_both
save `wave_1_or_both', replace


* GROUP 2: individuals in wave 2 only
restore
keep if _merge==1		// these are the new people in wave 2
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
gen agedout = 0
append using `wave_1_or_both'
gen check = movedin + movedout + wave_both
assert check==1
drop check



gen lf_agedin = age2>=15 & age1<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age2>=15 
gen lf_movedout = movedout==1 & age1>=15 
gen lfs_wave1 = (wave_both==1 | movedout==1) & age1>= 15
gen lfs_wave2 = (wave_both==1 | movedin==1) & age2>=15 

gen lf_agedin_2 = (age2>=11 & age1<15 & movedout==0  & movedin==0)*(min(1,(age2-10)*0.2)-max(0,(age1-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age2>=11)*min(1,(age2-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age1>=11)*min(1,(age1-10)*0.2)	
gen lfs_wave1_2 = ((wave_both==1 | movedout==1) & age1>=11)*min(1,(age1-10)*0.2)
gen lfs_wave2_2 = ((wave_both==1 | movedin==1) & age2>=11)*min(1,(age2-10)*0.2)

gen hhs_wave1 = (wave_both==1 | movedout==1)
gen hhs_wave2 = (wave_both==1 | movedin==1)
tempfile ind
save `ind', replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave1_2 lfs_wave2_2, by(HHID)
destring HHID, gen(hhid)
gen wave = 2
save "$newdata/UG12_hhld_movers", replace
restore


*** Summary table of movers
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG1_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9)
gen non_fam = inlist(reltohead,10,11,12)

sum age1 male son_daughter other_fam non_fam
estpost sum age male son_daughter other_fam non_fam
est sto ug12_moveout

* get info for people who moved in
use `ind', clear
keep if lf_movedin_2 == 1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)

*get prep days worked
preserve
use "$newdata/UG2_prep_ages.dta", clear
drop if PID==""
tempfile ug2_prep_ages
save `ug2_prep_ages', replace
restore
merge 1:1 PID using `ug2_prep_ages', keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age2 male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug12_movein

* get info for people who stayed in household
use `ind', clear
keep if wave_both==1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG1_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8,9)
gen non_fam = inlist(reltohead,10,11,12)
replace age = (age1 + age2) / 2

*get prep days worked
merge 1:1 PID using `ug2_prep_ages', keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age1 male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug12_stayer

la var age "Age"
la var male "\% Male"
la var son_daughter "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked on Farm"

esttab ug12* using "$path/output/UG12_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%8.0gc) labels("Number of Obs.")) label replace fragment tex

use `ind', clear
*** Produce Country level Summary table for changes in HH size
collapse (sum) hhs_* lfs_wave1* lfs_wave2* lf_movedin* lf_movedout* lf_agedin*  , by(HHID)	// first collapse to HH level
merge 1:1 HHID using `wave1_ea', assert(2 3) keep(3) nogen

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
gen region = int(ea1/10000000)

*gen net change by HH
gen lfs_change = lfs_wave2_2 - lfs_wave1_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0

*aggregate up to EA level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec region (count) num_hh=hhs_wave2, by(ea1)

twoway (scatter ea_per_inc ea_per_dec if region==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==2, msymbol(smplus) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==3, msymbol(smsquare_hollow) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==4, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("% of Households in village with net increase") xtitle("% of Households in village with net decrease") ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(label(1 "Central") label(2 "Eastern") label(3 "Northern") label(4 "Western") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Uganda, Change from Wave 1 to 2", color(black))
graph export "$path/output/UG12_net_change_scatter.pdf", replace

twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Uganda, Wave 1 to 2", color(black) size(7))
graph export "$path/output/UG12_net_change_scatter_combined.pdf", replace


use `hhchange', clear

gen lfs_change = lfs_wave2 - lfs_wave1
gen lfs_change_2 = lfs_wave2_2 - lfs_wave1_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave2-hhs_wave1
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto ug12_sum_changes_m1

*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto ug12_sum_changes_m2


****************************************
*			Wave 2 to Wave 3   		   *
****************************************

use `wave2', clear
keep HHID
duplicates drop HHID, force
tempfile w2_hh
save `w2_hh', replace

use `wave3', clear
keep HHID
duplicates drop HHID, force
merge 1:1 HHID using `w2_hh'
keep if _merge==3
drop _merge
tempfile match_23
save `match_23', replace

use `wave2', clear
merge m:1 HHID using `match_23', assert(1 3) keep(3) nogen
tempfile w2_m
save `w2_m', replace

use `wave3', clear
merge m:1 HHID using `match_23', assert(1 3) keep(3) nogen
merge 1:1 HHID PID using `w2_m'	
assert age3==. if _merge==2 
preserve 
ren _merge merge
keep if age3==. & merge==1
merge 1:1 HHID PID using `wave4', keep(3) nogen
replace age3 = age4-1 if merge==1 & age3==.
assert _N==3
ren merge _merge
drop age4
tempfile addon
save `addon', replace
restore
count
drop if _merge==1 & age3==.
count
append using `addon'
sum age* if _merge==3
replace age3= age2+1 if age3==. & _merge==3
assert age3!=. if _merge==3


* GROUP 1: individuals in (i) only wave 2, or (ii) both waves
preserve
drop if _merge==1	// drop those in wave 3 only
gen movedin = 0
gen movedout = _merge==2
gen wave_both = _merge==3
replace age2=age3-1 if wave_both==1 & age2==.
drop if age2==. & movedout==1
gen diff = age3-age2 if wave_both==1
replace age3=age2+1 if wave_both==1 & ~inlist(diff,1,2)
assert age2<=age3 if wave_both==1
drop diff
tempfile wave_2_or_both
save `wave_2_or_both', replace


* GROUP 2: individuals in wave 3 only
restore
keep if _merge==1		// these are the new people in wave 3
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
gen agedout = 0

append using `wave_2_or_both'
gen check = movedin + movedout + wave_both
assert check==1
drop check


gen lf_agedin = age3>=15 & age2<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age3>=15 
gen lf_movedout = movedout==1 & age2>=15 
gen lfs_wave2 = (wave_both==1 | movedout==1) & age2>= 15
gen lfs_wave3 = (wave_both==1 | movedin==1) & age3>=15 

gen lf_agedin_2 = (age3>=11 & age2<15 & movedout==0  & movedin==0)*(min(1,(age3-10)*0.2)-max(0,(age2-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age3>=11)*min(1,(age3-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age2>=11)*min(1,(age2-10)*0.2)	
gen lfs_wave2_2 = ((wave_both==1 | movedout==1) & age2>=11)*min(1,(age2-10)*0.2)
gen lfs_wave3_2 = ((wave_both==1 | movedin==1) & age3>=11)*min(1,(age3-10)*0.2)

gen hhs_wave2 = (wave_both==1 | movedout==1)
gen hhs_wave3 = (wave_both==1 | movedin==1)
tempfile ind23
save `ind23', replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave2_2 lfs_wave3_2, by(HHID)
destring HHID, gen(hhid)
gen wave = 3
save "$newdata/UG23_hhld_movers", replace
restore

*** Summary table of movers
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)

*get prep days worked

merge 1:1 PID using `ug2_prep_ages', keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug23_moveout

* get info for people who moved in
use `ind23', clear
keep if lf_movedin_2 == 1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG3_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)

*get prep days worked
preserve
use "$newdata/UG3_prep_ages.dta", clear
drop if PID==""
tempfile ug3_prep_ages
save `ug3_prep_ages', replace
restore
merge 1:1 PID using `ug3_prep_ages', keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug23_movein

* get info for people who stayed in household
use `ind23', clear
keep if wave_both==1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG2_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)
replace age = (age2 + age3) / 2

*get prep days worked

merge 1:1 PID using `ug3_prep_ages', keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug23_stayer

la var age "Age"
la var male "\% Male"
la var son_daughter "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked on Farm"

esttab ug23* using "$path/output/UG23_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%8.0gc) labels("Number of Obs.")) label replace fragment tex

use `ind23', clear
*** Produce Country level Summary table for changes in HH size
collapse (sum) hhs_* lfs_wave2* lfs_wave3* lf_movedin* lf_movedout* lf_agedin*  , by(HHID)	// first collapse to HH level
merge 1:1 HHID using `wave2_ea', assert(2 3) keep(3) nogen

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
destring ea2, gen(temp)
gen region = int(temp/1000000)
drop temp
*gen net change by HH
gen lfs_change = lfs_wave3_2 - lfs_wave2_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
drop if ea2==""

*aggregate up to EA level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec region (count) num_hh=hhs_wave2, by(ea2)

twoway (scatter ea_per_inc ea_per_dec if region==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==2, msymbol(smplus) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==3, msymbol(smsquare_hollow) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==4, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("% of Households in village with net increase") xtitle("% of Households in village with net decrease") ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(label(1 "Central") label(2 "Eastern") label(3 "Northern") label(4 "Western") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Uganda, Change from Wave 2 to 3", color(black))
graph export "$path/output/UG23_net_change_scatter.pdf", replace


twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Uganda, Wave 2 to 3", color(black) size(7))
graph export "$path/output/UG23_net_change_scatter_combined.pdf", replace


use `hhchange', clear

gen lfs_change = lfs_wave3 - lfs_wave2
gen lfs_change_2 = lfs_wave3_2 - lfs_wave2_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave3-hhs_wave2
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto ug23_sum_changes_m1

*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto ug23_sum_changes_m2


****************************************
*			Wave 3 to Wave 4   		   *
****************************************

use `wave3', clear
keep HHID
duplicates drop HHID, force
tempfile w3_hh
save `w3_hh', replace

use `wave4', clear
keep HHID
duplicates drop HHID, force
merge 1:1 HHID using `w3_hh'	
keep if _merge==3
drop _merge
tempfile match_34
save `match_34', replace

use `wave3', clear
merge m:1 HHID using `match_34', assert(1 3) keep(3) nogen
tempfile w3_m
save `w3_m', replace

use `wave4', clear
merge m:1 HHID using `match_34', assert(1 3) keep(3) nogen
merge 1:1 HHID PID using `w3_m'


replace age3 = age4-1 if _merge==3 & age3==.
preserve
keep if age3==. & _merge==2
ren _merge merge
merge 1:1 HHID PID using `ind23', keep(1 3) nogen
replace age3= age2+1 if age3==.
keep HHID PID age4 age3 merge
ren merge _merge
drop if age3==.			// losing 1 obs
tempfile fixed
save `fixed', replace
restore
count
drop if age3==. & _merge==2
count
append using `fixed'
count
assert age4==. if _merge==2 
assert age4!=. if _merge==1	


* GROUP 1: individuals in (i) only wave 3, or (ii) both waves
preserve
drop if _merge==1	// drop those in wave 4 only
gen movedin = 0
gen movedout = _merge==2
gen wave_both = _merge==3
sum if wave_both==1		// no missing ages
sum if movedout==1		// no missing ages
drop if age3==. & movedout==1		// no effect
gen diff = age4-age3 if wave_both==1
replace age4 = age3+1 if wave_both==1 & ~inlist(diff,1,2)
tempfile wave_3_or_both
save `wave_3_or_both', replace


* GROUP 2: individuals in wave 3 only
restore
keep if _merge==1		// these are the new people in wave 4
gen movedin = 1
gen movedout = 0
gen wave_both = 0
gen agedin = 0
gen agedout = 0

append using `wave_3_or_both'
gen check = movedin + movedout + wave_both
assert check==1
drop check


gen lf_agedin = age4>=15 & age3<15 & movedout==0 & movedin==0
gen lf_movedin = movedin==1 & age4>=15 
gen lf_movedout = movedout==1 & age3>=15 
gen lfs_wave3 = (wave_both==1 | movedout==1) & age3>= 15
gen lfs_wave4 = (wave_both==1 | movedin==1) & age4>=15 

gen lf_agedin_2 = (age4>=11 & age3<15 & movedout==0  & movedin==0)*(min(1,(age4-10)*0.2)-max(0,(age3-10)*0.2))
gen lf_movedin_2 = (movedin==1 & age4>=11)*min(1,(age4-10)*0.2)
gen lf_movedout_2 = (movedout==1 & age3>=11)*min(1,(age3-10)*0.2)	
gen lfs_wave3_2 = ((wave_both==1 | movedout==1) & age3>=11)*min(1,(age3-10)*0.2)
gen lfs_wave4_2 = ((wave_both==1 | movedin==1) & age4>=11)*min(1,(age4-10)*0.2)

gen hhs_wave3 = (wave_both==1 | movedout==1)
gen hhs_wave4 = (wave_both==1 | movedin==1)
tempfile ind
save `ind', replace

** collapse data to be used in heterogeneity analysis by move type
preserve
collapse (sum) lf_agedin_2 lf_movedin_2 lf_movedout_2 lfs_wave3_2 lfs_wave4_2, by(HHID)
destring HHID, gen(hhid)
gen wave = 4
save "$newdata/UG34_hhld_movers", replace
append using "$newdata/UG12_hhld_movers"
append using "$newdata/UG23_hhld_movers"
save "$newdata/UG_hhld_movers", replace
restore


*** Summary table of movers
* get info for people who moved out
keep if lf_movedout_2 == 1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG3_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)

*get prep days worked
merge 1:1 PID using `ug3_prep_ages', keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug34_moveout

* get info for people who moved in
use `ind', clear
keep if lf_movedin_2 == 1
*get age, educ, and reltohead
destring PID, replace
merge 1:1 PID using "$newdata/UG4_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)

*get prep days worked
merge 1:1 PID using "$newdata/UG4_prep_ages.dta", keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug34_movein

* get info for people who stayed in household
use `ind', clear
keep if wave_both==1
*get age, educ, and reltohead
merge 1:1 PID using "$newdata/UG3_hh_ages.dta", keep(1 3) nogen
gen son_daughter = reltohead==3
gen other_fam = inlist(reltohead,1,2,4,5,6,7,8)
gen non_fam = inlist(reltohead,9,10,96)
replace age = (age3 + age4) / 2

*get prep days worked
destring PID, replace
merge 1:1 PID using "$newdata/UG4_prep_ages.dta", keep(1 3) nogen
gen any_prep = cult_days_hh>0 & cult_days_hh!=.

sum age male son_daughter other_fam non_fam any_prep
estpost sum age male son_daughter other_fam non_fam any_prep
est sto ug34_stayer

la var age "Age"
la var male "\% Male"
la var son_daughter "\% Child"
la var other_fam "\% Other Family Member"
la var non_fam "\% Not a Family Member"
la var any_prep "\% Worked on Farm"

esttab ug34* using "$path/output/UG34_mover_stats.tex", cell(mean(fmt(%9.2fc)) sd(par)) ///
		mtitles("Moved-Out" "Moved-In" "Stayed") posthead("\hline") ///
		stats(N, fmt(%8.0gc) labels("Number of Obs.")) label replace fragment tex

use `ind', clear
*** Produce Country level Summary table for changes in HH size
collapse (sum) hhs_* lfs_wave3* lfs_wave4* lf_movedin* lf_movedout* lf_agedin* , by(HHID)	// first collapse to HH level
merge 1:1 HHID using `wave3_ea', assert(2 3) keep(3) nogen

foreach i of varlist *_2 {
	replace `i' = round(`i',0.1)
}

tempfile hhchange
save `hhchange', replace

*** produce scatterplot of net changes by village
destring ea3, gen(temp)
gen region = int(temp/1000000)
drop temp
*gen net change by HH
gen lfs_change = lfs_wave4_2 - lfs_wave3_2
gen lfs_ch_check= lf_agedin_2 + lf_movedin_2 - lf_movedout_2
assert abs(lfs_change-lfs_ch_check)<0.0001
gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0

*aggregate up to EA level
collapse (mean) ea_per_inc=hh_inc ea_per_dec=hh_dec region (count) num_hh=hhs_wave3, by(ea3)

twoway (scatter ea_per_inc ea_per_dec if region==1, msymbol(smcircle) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==2, msymbol(smplus) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==3, msymbol(smsquare_hollow) mcolor(black)) || ///
	(scatter ea_per_inc ea_per_dec if region==4, msymbol(smtriangle_hollow) mcolor(black)), ///
	ytitle("% of Households in village with net increase") xtitle("% of Households in village with net decrease") ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(label(1 "Central") label(2 "Eastern") label(3 "Northern") label(4 "Western") rows(1)) ///
	graphregion(color(white)) bgcolor(white)  title("Uganda, Change from Wave 3 to 4", color(black))
graph export "$path/output/UG34_net_change_scatter.pdf", replace

twoway (scatter ea_per_inc ea_per_dec, msymbol(smcircle) mcolor(black)), ///
	ytitle("Share of HHs with net increase", size(5)) xtitle("Share of HHs with net decrease", size(5)) ///
	xscale(r(0 1)) xlabel(0(0.2)1) legend(off) ///
	ylabel(,angle(horizontal)) ///
	graphregion(color(white)) bgcolor(white)  title("Uganda, Wave 3 to 4", color(black) size(7))
graph export "$path/output/UG34_net_change_scatter_combined.pdf", replace

use `hhchange', clear

gen lfs_change = lfs_wave4 - lfs_wave3
gen lfs_change_2 = lfs_wave4_2 - lfs_wave3_2
gen lf_anychange = lfs_change!=0
gen lf_anychange_2 = lfs_change_2!=0

gen hh_inc = lfs_change>0
gen hh_dec = lfs_change<0
gen hh_inc_2 = lfs_change_2>0
gen hh_dec_2 = lfs_change_2<0

*post summary statistics of inter-annual changes - method1 (kids phased in)
gen hhs_change = hhs_wave4-hhs_wave3
replace lf_movedout_2 = -lf_movedout_2
estpost sum hhs_change lfs_change_2 lf_movedin_2 lf_movedout_2 lf_agedin_2 lf_anychange_2 hh_inc_2 hh_dec_2
est sto ug34_sum_changes_m1

*post summary statistics of inter-annual changes - method2 (no kids)
replace lf_movedout = -lf_movedout
estpost sum hhs_change lfs_change lf_movedin lf_movedout lf_agedin lf_anychange hh_inc hh_dec
est sto ug34_sum_changes_m2


la var hhs_change "$\Delta$ Number of members"
la var lfs_change_2 "$\Delta$ Labor endowment (E)"
la var lf_movedin_2 "    $\qquad \Delta$ E from move-ins"
la var lf_movedout_2 "    $\qquad \Delta$ E from move-outs"
la var lf_agedin_2 "    $\qquad \Delta$ E from aging children"
la var lf_anychange_2 "Any net $\Delta$ in E (=1)"
la var hh_inc_2 "Increase in E (=1)"
la var hh_dec_2 "Decrease in E (=1)"

*output sum stat table for changes (method1) in household size for all countries
estout *changes_m1 using "$path/output/combined_change_stats1.tex", cells(mean(fmt(%11.2fc)) ) ///
	label mlabels(none) nonumbers collabels(none) extracols(2 3 5) style(tex) replace


la var hhs_change "$\Delta$ Number of members"
la var lfs_change "$\Delta$ Labor endowment (LE)"
la var lf_movedin "    $\qquad \Delta$ LE from move-ins"
la var lf_movedout "    $\qquad \Delta$ LE from move-outs"
la var lf_agedin "    $\qquad \Delta$ LE from aging children"
la var lf_anychange "Any net $\Delta$ in LE (=1)"
la var hh_inc "Increase in LE (=1)"
la var hh_dec "Decrease in LE (=1)"

*output sum stat table for changes (method2) in household size for all countries
estout *changes_m2 using "$path/output/combined_change_stats2.tex", cells(mean(fmt(%11.2fc)) ) ///
	label mlabels(none) nonumbers collabels(none) extracols(2 3 5) style(tex) replace

exit

