
clear
clear matrix
drop _all
program drop _all
set more off
set trace off
set mem 120m
set matsize 2000



*********************************************************
*														*
**				Ethiopia							   **
*														*
*********************************************************

use "$newdata/ET panel data merged", clear
svyset [pweight=weight]
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
xtset hhid wave


* PPP exchange rates to USD from World Bank WDI. Can be found in /Data/WDI_exchange_rates.xlsx
gen exp_pc_usd = exp_pc/5.685 if wave==1

estpost sum  hhsize_phase hhsize share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc 
est sto et_sums

la var ld_cult_kids "Reference labor (person-days)"
la var ld_harv_kids "Harvest labor (person-days)"
estpost sum ld_cult_kids ld_harv_kids
est sto et_ld_sum

estpost sum  hhsize_phase hhsize hhsize_phase_away months_away share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc  ld_cult_kids ld_harv_kids
est sto et_sums_combined

* count temporary migrants
mat migrants = J(4,2,.)
sum temp_migrant
mat migrants[1,1] = r(mean)
sum any_migrant
mat migrants[1,2] = r(mean)


*build LFP rate figure for each wave
forvalues wave=1/2 {
	if `wave'==1 {
		local pid_var pid
	}
	else {
		local pid_var y2_pid
	}
	use "$newdata/ET`wave'_hh_ages.dta", clear

	destring `pid_var', replace
	drop if age==.
	collapse (count) num_hh=`pid_var', by(age)
	tempfile ET_hhages
	save `ET_hhages', replace

	use "$newdata/ET`wave'_prep_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_prep=`pid_var' (mean) prep_days=days, by(age)
	tempfile ET_prepages
	save `ET_prepages', replace
	

	use "$newdata/ET`wave'_harv_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_harv=`pid_var' (mean) harv_days=days, by(age)

	merge 1:1 age using `ET_hhages', nogen
	merge 1:1 age using `ET_prepages'

	gen lfp_prep = num_prep / num_hh
	gen lfp_harv = num_harv / num_hh

	
	if `wave'==1 {
		twoway (lpoly lfp_prep age, clp(solid) clc(black) clw(medium) yaxis(1)) ///
		(lpoly lfp_harv age, clp(shortdash_dot) clc(black) clw(medium) yaxis(1)) ///
		(lpoly prep_days age, clp(shortdash) clc(black) clw(medium) yaxis(2)) ///
		(lpoly harv_days age, clp(longdash_dot) clc(black) clw(medium) yaxis(2)), ///
		legend(order(1 "LFP, Cultivation" 3 "Avg Days, Cultivation" 2 "LFP, Harvest" 4 "Avg Days, Harvest") rows(2) size(4.6)) ///
		graphregion(color(white)) bgcolor(white) title("Ethiopia, Wave `wave'", color(black) size(7)) ///
		ylabel(,angle(horizontal) axis(1) labsize(4.5)) xtitle("Age", size(5)) ///
		text(0.85  0 "LFP rate", place(e) size(5)) ///	
		text(0.85  100 "Days", place(w) size(5)) ///	
		ytitle("", axis(2))	ylabel(0(40)200, angle(horizontal) axis(2)  labsize(4.5)) ///
		xlabel(,labsize(4.5))
		graph export "$path/output/ET`wave'_lfp_bw.pdf", replace
	}
	else {
		twoway (lpoly lfp_prep age, clp(solid) clc(black) clw(medium) yaxis(1)) ///
		(lpoly lfp_harv age, clp(shortdash_dot) clc(black) clw(medium) yaxis(1)) ///
		(lpoly prep_days age, clp(shortdash) clc(black) clw(medium) yaxis(2)) ///
		(lpoly harv_days age, clp(longdash_dot) clc(black) clw(medium) yaxis(2)), ///
		legend(order(1 "LFP, Cultivation" 3 "Avg Days, Cultivation" 2 "LFP, Harvest" 4 "Avg Days, Harvest") rows(2) size(4.6)) ///
		graphregion(color(white)) bgcolor(white) title("Ethiopia, Wave `wave'", color(black) size(7)) ///
		ylabel(,angle(horizontal) axis(1) labsize(4.5)) xtitle("Age", size(5)) ///
		text(0.65  0 "LFP rate", place(e) size(5)) ///	
		text(0.65  100 "Days", place(w) size(5)) ///	
		ytitle("", axis(2))	ylabel(0(40)200, angle(horizontal) axis(2)  labsize(4.5)) ///
		xlabel(,labsize(4.5))
		graph export "$path/output/ET`wave'_lfp_bw.pdf", replace
	}
}



*********************************************************
*														*
**				Malawi				  				   **
*														*
*********************************************************

use "$newdata/Malawi Panel Data Clean", clear
destring hhid, replace
isid hhid wave
xtset hhid wave

* PPP exchange rates to USD from World Bank WDI. Can be found in /Data/WDI_exchange_rates.xlsx
gen exp_pc_usd = exp_pc/72.244 if wave==1

estpost sum  hhsize_phase hhsize share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc 
est sto mw_sums

la var ld_cult_kids "Reference labor (person-days)"
la var ld_harv_kids "Harvest labor (person-days)"
estpost sum ld_cult_kids ld_harv_kids
est sto mw_ld_sum

estpost sum  hhsize_phase hhsize hhsize_phase_away months_away share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc  ld_cult_kids ld_harv_kids
est sto mw_sums_combined

* count temporary migrants
sum temp_migrant
mat migrants[2,1] = r(mean)
sum any_migrant
mat migrants[2,2] = r(mean)


*build LFP rate figure for each wave
forvalues wave=1/2 {
	local pid_var personid
	use "$newdata/MW`wave'_hh_ages.dta", clear

	destring `pid_var', replace
	drop if age==.
	collapse (count) num_hh=`pid_var', by(age)
	tempfile MW_hhages
	save `MW_hhages', replace

	use "$newdata/MW`wave'_prep_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_prep=`pid_var' (mean) prep_days=days, by(age)
	tempfile MW_prepages
	save `MW_prepages', replace

	use "$newdata/MW`wave'_weed_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_weed=`pid_var' (mean) weed_days=days, by(age)
	tempfile MW_weedages
	save `MW_weedages', replace

	use "$newdata/MW`wave'_harv_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_harv=`pid_var' (mean) harv_days=days, by(age)

	merge 1:1 age using `MW_hhages', nogen
	merge 1:1 age using `MW_prepages', nogen
	merge 1:1 age using `MW_weedages', nogen

	gen lfp_prep = num_prep / num_hh
	gen lfp_weed = num_weed / num_hh
	gen lfp_harv = num_harv / num_hh
	drop if age > 100

	if `wave'==1 {
		twoway (lpoly lfp_prep age, clp(solid) clc(black) clw(medium) yaxis(1)) ///
		(lpoly lfp_harv age, clp(shortdash_dot) clc(black) clw(medium) yaxis(1)) ///
		(lpoly prep_days age, clp(shortdash) clc(black) clw(medium) yaxis(2)) ///
		(lpoly harv_days age, clp(longdash_dot) clc(black) clw(medium) yaxis(2)), ///
		legend(order(1 "LFP, Cultivation" 3 "Avg Days, Cultivation" 2 "LFP, Harvest" 4 "Avg Days, Harvest") rows(2) size(4.6)) ///
		graphregion(color(white)) bgcolor(white) title("Malawi, Wave `wave'", color(black) size(7)) ///
		ylabel(,angle(horizontal) axis(1) labsize(4.5)) xtitle("Age", size(5)) ///
		text(1.05  0 "LFP rate", place(e) size(5)) ///	
		text(1.05  100 "Days", place(w) size(5)) ///	
		ytitle("", axis(2))	ylabel(0(40)200, angle(horizontal) axis(2)  labsize(4.5)) ///
		xlabel(,labsize(4.5))
		graph export "$path/output/MW`wave'_lfp_bw.pdf", replace
	}
	else {
		twoway (lpoly lfp_prep age, clp(solid) clc(black) clw(medium) yaxis(1)) ///
		(lpoly lfp_harv age, clp(shortdash_dot) clc(black) clw(medium) yaxis(1)) ///
		(lpoly prep_days age, clp(shortdash) clc(black) clw(medium) yaxis(2)) ///
		(lpoly harv_days age, clp(longdash_dot) clc(black) clw(medium) yaxis(2)), ///
		legend(order(1 "LFP, Cultivation" 3 "Avg Days, Cultivation" 2 "LFP, Harvest" 4 "Avg Days, Harvest") rows(2) size(4.6)) ///
		graphregion(color(white)) bgcolor(white) title("Malawi, Wave `wave'", color(black) size(7)) ///
		ylabel(,angle(horizontal) axis(1) labsize(4.5)) xtitle("Age", size(5)) ///
		text(0.85  0 "LFP rate", place(e) size(5)) ///	
		text(0.85  100 "Days", place(w) size(5)) ///	
		ytitle("", axis(2))	ylabel(0(40)200, angle(horizontal) axis(2)  labsize(4.5)) ///
		xlabel(,labsize(4.5))
		graph export "$path/output/MW`wave'_lfp_bw.pdf", replace
	}

}


*********************************************************
*														*
**				Tanzania							   **
*														*
*********************************************************

use "$newdata/TZ panel data merged", clear
isid hhid wave
xtset hhid wave

* PPP exchange rates to USD from World Bank WDI. Can be found in /Data/WDI_exchange_rates.xlsx
gen exp_pc_usd = exp_pc/500.277 if wave==2

estpost sum  hhsize_phase hhsize share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc 
est sto tz_sums

la var ld_cult_kids "Reference labor (person-days)"
la var ld_weed_kids "Weeding labor (person-days)"
la var ld_harv_kids "Harvest labor (person-days)"
estpost sum ld_cult_kids ld_weed_kids ld_harv_kids
est sto tz_ld_sum

estpost sum  hhsize_phase hhsize hhsize_phase_away months_away share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc  ld_cult_kids ld_weed_kids ld_harv_kids
est sto tz_sums_combined

* count temporary migrants
sum temp_migrant
mat migrants[3,1] = r(mean)
sum any_migrant
mat migrants[3,2] = r(mean)


*build LFP rate figure for each wave
forvalues wave=1/3 {
	if `wave'==1 {
		local pid_var indid
	}
	else if `wave'==2 {
		local pid_var indidy2
	}
	else {
		local pid_var indidy3
	}
	use "$newdata/TZ`wave'_hh_ages.dta", clear

	destring `pid_var', replace
	drop if age==.
	collapse (count) num_hh=`pid_var', by(age)
	tempfile TZ_hhages
	save `TZ_hhages', replace

	use "$newdata/TZ`wave'_prep_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_prep=`pid_var' (mean) prep_days=prep, by(age)
	tempfile TZ_prepages
	save `TZ_prepages', replace

	use "$newdata/TZ`wave'_weed_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_weed=`pid_var' (mean) weed_days=weed, by(age)
	tempfile TZ_weedages
	save `TZ_weedages', replace

	use "$newdata/TZ`wave'_harv_ages.dta", clear
	destring `pid_var', replace
	collapse (count) num_harv=`pid_var' (mean) harv_days=harv, by(age)

	merge 1:1 age using `TZ_hhages', nogen
	merge 1:1 age using `TZ_prepages', nogen
	merge 1:1 age using `TZ_weedages', nogen

	gen lfp_prep = num_prep / num_hh
	gen lfp_weed = num_weed / num_hh
	gen lfp_harv = num_harv / num_hh


	twoway (lpoly lfp_prep age, clp(solid) clc(black) clw(medium) yaxis(1)) ///
	(lpoly lfp_weed age, clp(longdash) clc(black) clw(medium) yaxis(1) ) ///
	(lpoly lfp_harv age, clp(shortdash_dot) clc(black) clw(medium) yaxis(1)) ///
	(lpoly prep_days age, clp(shortdash) clc(black) clw(medium) yaxis(2)) ///
	(lpoly weed_days age, clp(dot) clc(black) clw(medium) yaxis(2)) ///
	(lpoly harv_days age, clp(longdash_dot) clc(black) clw(medium) yaxis(2)), ///
	legend(order(1 "LFP, Cultivation" 4 "Avg Days, Cultivation" 2 "LFP, Weeding" 5 "Avg Days, Weeding" 3 "LFP, Harvest" 6 "Avg Days, Harvest") rows(3) size(4.6)) ///
	graphregion(color(white)) bgcolor(white) title("Tanzania, Wave `wave'", color(black) size(7)) ///
	ylabel(,angle(horizontal) axis(1) labsize(4.5)) xtitle("Age", size(5)) ///
	text(0.65  0 "LFP rate", place(e) size(5)) ///	
	text(0.65  100 "Days", place(w) size(5)) ///	
	ytitle("", axis(2))	ylabel(0(40)200, angle(horizontal) axis(2)  labsize(4.5)) ///
	xlabel(,labsize(4.5))
	graph export "$path/output/TZ`wave'_lfp_bw.pdf", replace

}


*********************************************************
*														*
**				Uganda								   **
*														*
*********************************************************

use "$newdata/UG panel data merged", clear
destring hhid, replace		// Have to destring in order to use as panel identifier for xt
format hhid %19.0g			// I want to see the ENTIRE length, not scientific notation
isid hhid wave
xtset hhid wave


* PPP exchange rates to USD from World Bank WDI. Can be found in /Data/WDI_exchange_rates.xlsx
replace exp_pc = . if wave==1
gen exp_pc_usd = exp_pc/507.445 if wave==2

rename head_educ headeduc
la var log_ld_tot_kids "Log labor demand (person-days)"
la var hhsize_phase "Labor endowment, with kids"
la var hhsize "Labor endowment, no kids"
la var hhsize_phase_away "Labor end., with kids and time away"
la var months_away "Months away"
la var share_pm "Prime male share"
la var share_pf "Prime female share"
la var share_em "Elderly male share"
la var share_ef "Elderly female share"
la var acres "Acres cultivated"
la var owned_acres "Acres owned"
la var agehhhead1 "Age of head (years)"
la var headeduc "Education of head (years)"
la var exp_pc "Expend. PC (local curr.)"
la var exp_pc_usd "Expend. PC (USD)"

estpost sum  hhsize_phase hhsize hhsize_phase_away months_away share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc 
est sto ug_sums


*output sum stat table for all countries
esttab *sums using "$path/output/combined_sum_stats.tex", cell(mean(fmt(%11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.2fc %11.0fc %11.1fc)) sd(par)) ///
		mtitles("Ethiopia" "Malawi" "Tanzania" "Uganda") posthead("\hline") nodep ///
		stats(N, fmt(%9.0fc) labels("Number of obs.")) label replace fragment tex

ren ld_tot_kids ld_cult_kids
la var ld_cult_kids "Reference labor (person-days)"
estpost sum ld_cult_kids
est sto ug_ld_sum
estpost sum  hhsize_phase hhsize hhsize_phase_away months_away share_pm share_pf share_em share_ef acres owned_acres agehhhead1 headeduc  ld_cult_kids
est sto ug_sums_combined
ren ld_cult_kids ld_tot_kids


*output labod demand table for all countries
esttab *ld_sum using "$path/output/combined_ld_stats.tex", cell(mean(fmt(%11.2fc %11.2fc %11.2fc %11.2fc %11.2fc)) sd(par)) ///
		mtitles("Ethiopia" "Malawi" "Tanzania" "Uganda") posthead("\hline") nodep ///
		stats(N, fmt(%9.0fc) labels("Number of Obs.")) label replace fragment tex


tempfile temp
tempfile temp2
estout *sums_combined using `temp', cell("mean(fmt(2 2 2 2 2 2 2 1)) sd(fmt(2 2 2 2 2 2 2 1))") ///
		ml(none) coll(none) stats(N, fmt(0) labels("\hline Number of Obs.")) style(tex) label replace
filefilter `temp' `temp2', from("ld_cult_kids") to("Reference labor (person-days)")
filefilter `temp2' `temp', from("ld_harv_kids") to("Harvest labor (person-days)") replace
filefilter `temp' "$path/output/combined_all_sumstats.tex", from("ld_weed_kids") to("Weeding labor (person-days)") replace

		
* count temporary migrants
sum temp_migrant
mat migrants[4,1] = r(mean)
sum any_migrant
mat migrants[4,2] = r(mean)
mat rown migrants = "Ethiopia" "Malawi" "Tanzania" "Uganda"
mat list migrants
esttab matrix(migrants, fmt(3)) using "$path/output/combined_migrant_stats.tex", nonumbers replace fragment nomtitles collabels(none) posthead("")

		

*build LFP rate figure for each wave
forvalues wave=2/4 {
	use "$newdata/UG`wave'_hh_ages.dta", clear

	drop if age==.
	collapse (count) num_hh= personid, by(age)
	tempfile UG_hhages
	save `UG_hhages', replace
	use "$newdata/UG`wave'_prep_ages.dta", clear
	collapse (count) num_prep= personid, by(age)
	merge 1:1 age using `UG_hhages'

	gen lfp_prep = num_prep / num_hh
	preserve
	keep lfp_prep age
	gen wave = `wave'
	tempfile ug`wave'
	save `ug`wave'', replace
	restore
	twoway (lpoly lfp_prep age, clp(solid) clc(black) clw(thin)), ///
	legend(order(1 "LFP - All Activities") rows(1) size(medium)) ///
	graphregion(color(white)) bgcolor(white) title("Uganda, Wave `wave'", color(black) size(large)) ///
	ylabel(,angle(horizontal) axis(1)) xtitle("Age") ytitle("LFP Rate", size(medlarge))
	graph export "$path/output/UG`wave'_lfp_bw.pdf", replace

}

use `ug2', clear
append using `ug3'
append using `ug4'

twoway (lpoly lfp_prep age if wave==2, clp(solid) clc(black) clw(medium)) ///
(lpoly lfp_prep age if wave==3, clp(longdash_dot) clc(black) clw(medium)) ///
(lpoly lfp_prep age if wave==4, clp(shortdash) clc(black) clw(medium)), ///
legend(order(1 "LFP, Wave 2" 3 "LFP, Wave 4" 2 "LFP, Wave 3") rows(2) size(4.6)) ///
graphregion(color(white)) bgcolor(white) title("Uganda, Waves 2-4", color(black) size(7)) ///
ylabel(,angle(horizontal) labsize(4.5)) xtitle("Age", size(5)) ///
text(0.85  0 "LFP rate", place(e) size(5)) ///		
xlabel(,labsize(4.5)) ytitle("")
graph export "$path/output/UG_2to4_lfp_bw.pdf", replace



exit

