*********************************
*** Dillon, Brummund, Mwabu
*** Asymmetric Non-Separation and Rural Labor Markets
*** Master do file 	            
*********************************

global path	= c(pwd)
global data_ET 			"$path/Data/Ethiopia/2011-2012/Dataset"
global data_ET_2		"$path/Data/Ethiopia/2013-2014/Dataset"
global data_TZ 			"$path/Data/Tanzania"
global data_UG 			"$path/Data/Uganda"
global data_MW 			"$path/Data/Malawi"
global output			"$path/output"
global do				"$path/do"
global newdata			"$path/Data/prc_data"


capture log close
log using "${path}/do/run_all_log.txt", text replace


*** Set up global variables ****
global hhsize "age>=15 & age<=60"
global prime "age>=15 & age<=60"
global elderly "age>60"
global prime_noage "age<=57 & age>=18"
global child "age<15"
global time_away 12
global oldmem "age>=15 & age<=60"

* flag to control how code handles households with 0 labor demand
global no_work .1

* flag to control how code counts who is in household, with kids phased in or excluded
global hhsize_var log_phase

*** Set up panel data for each LSMS country ****
do "${path}/do/Ethiopia panel data prep3.do"
do "${path}/do/Malawi panel data prep3.do"
do "${path}/do/Tanzania panel data prep3.do"
do "${path}/do/Uganda panel data prep3.do"

*** Run summary statistic analysis ****
do "${path}/do/combined_sum_stats.do"
do "${path}/do/combined_sum_changes.do"

*** Run main regression analysis ****
do "${path}/do/Combined analysis.do"

*** Run land regression analysis ****
do "${path}/do/Combined land analysis.do"

*** Run regression analysis by gender ****
do "${path}/do/Combined gender analysis.do"

*** Run regression analysis by PSNP and wealth in Ethiopia ****
do "${path}/do/Ethiopia extra analysis.do"

*** Run first stage, instrumenting change in labor endowment with village average change
do "${path}/do/Combined village_IV analysis.do"

*** Run regression analysis, IV for acreage cultivated with acreage owned ****
do "${path}/do/Combined IV analysis.do"

*** Run main regression analysis, excluding land control ****
do "${path}/do/Combined noland analysis.do"

*** Run robustness checks for no kids ****
do "${path}/do/Combined nokids analysis.do"

*** Run regression analysis by AEZ ****
do "${path}/do/Combined aez analysis.do"

*** Run regression analysis by wealth ****
do "${path}/do/Combined wealth analysis.do"


/***** New analysis  *******/

*** Run regression analysis, accounting for time away in labor endowment ****
global hhsize_var log_phase_away
do "${path}/do/Combined time away analysis.do"
global hhsize_var log_phase

*** Run regression analysis, splitting out changes due to aging in ****
do "${path}/do/Combined agedin analysis.do"

*** Run regression analysis by Muslem in Ethiopia ****
do "${path}/do/Ethiopia muslem analysis.do"

*** Run regression analysis by Financial Constraint in Ethiopia ****
do "${path}/do/Ethiopia fin_const analysis.do"

*** Produce TPL curves ****
do "${path}/do/Ethiopia output data prep.do"
do "${path}/do/Malawi output data prep.do"
do "${path}/do/Tanzania output data prep.do"
do "${path}/do/Uganda output data prep.do"

log close
exit


